"""Mouse anatomy"""
from typing import Literal, Union

from pydantic import BaseModel, ConfigDict, Field
from typing_extensions import Annotated

from aind_data_schema_models.registries import Registry


class _MouseAnatomicalStructureModel(BaseModel):
    """Base model for mouse anatomy"""

    model_config = ConfigDict(frozen=True)
    name: str
    registry: Registry.ONE_OF
    registry_identifier: str


class _Anatomical_Structure(_MouseAnatomicalStructureModel):
    """Model Anatomical structure"""

    name: Literal["Anatomical structure"] = "Anatomical structure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_0"] = "EMAPA_0"


class _First_Polar_Body(_MouseAnatomicalStructureModel):
    """Model first polar body"""

    name: Literal["first polar body"] = "first polar body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16032"] = "EMAPA_16032"


class _1_Cell_Stage_Embryo(_MouseAnatomicalStructureModel):
    """Model 1-cell stage embryo"""

    name: Literal["1-cell stage embryo"] = "1-cell stage embryo"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16033"] = "EMAPA_16033"


class _Second_Polar_Body(_MouseAnatomicalStructureModel):
    """Model second polar body"""

    name: Literal["second polar body"] = "second polar body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16034"] = "EMAPA_16034"


class _Zona_Pellucida(_MouseAnatomicalStructureModel):
    """Model zona pellucida"""

    name: Literal["zona pellucida"] = "zona pellucida"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16035"] = "EMAPA_16035"


class _2_Cell_Stage_Embryo(_MouseAnatomicalStructureModel):
    """Model 2-cell stage embryo"""

    name: Literal["2-cell stage embryo"] = "2-cell stage embryo"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16036"] = "EMAPA_16036"


class _4_8_Cell_Stage_Embryo(_MouseAnatomicalStructureModel):
    """Model 4-8 cell stage embryo"""

    name: Literal["4-8 cell stage embryo"] = "4-8 cell stage embryo"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16037"] = "EMAPA_16037"


class _Embryo(_MouseAnatomicalStructureModel):
    """Model embryo"""

    name: Literal["embryo"] = "embryo"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16039"] = "EMAPA_16039"


class _Compacted_Morula(_MouseAnatomicalStructureModel):
    """Model compacted morula"""

    name: Literal["compacted morula"] = "compacted morula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16040"] = "EMAPA_16040"


class _Inner_Cell_Mass(_MouseAnatomicalStructureModel):
    """Model inner cell mass"""

    name: Literal["inner cell mass"] = "inner cell mass"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16041"] = "EMAPA_16041"


class _Extraembryonic_Component(_MouseAnatomicalStructureModel):
    """Model extraembryonic component"""

    name: Literal["extraembryonic component"] = "extraembryonic component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16042"] = "EMAPA_16042"


class _Extraembryonic_Cavity(_MouseAnatomicalStructureModel):
    """Model extraembryonic cavity"""

    name: Literal["extraembryonic cavity"] = "extraembryonic cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16043"] = "EMAPA_16043"


class _Blastocoelic_Cavity(_MouseAnatomicalStructureModel):
    """Model blastocoelic cavity"""

    name: Literal["blastocoelic cavity"] = "blastocoelic cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16044"] = "EMAPA_16044"


class _Trophectoderm(_MouseAnatomicalStructureModel):
    """Model trophectoderm"""

    name: Literal["trophectoderm"] = "trophectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16046"] = "EMAPA_16046"


class _Mural_Trophectoderm(_MouseAnatomicalStructureModel):
    """Model mural trophectoderm"""

    name: Literal["mural trophectoderm"] = "mural trophectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16047"] = "EMAPA_16047"


class _Polar_Trophectoderm(_MouseAnatomicalStructureModel):
    """Model polar trophectoderm"""

    name: Literal["polar trophectoderm"] = "polar trophectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16048"] = "EMAPA_16048"


class _Epiblast(_MouseAnatomicalStructureModel):
    """Model epiblast"""

    name: Literal["epiblast"] = "epiblast"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16050"] = "EMAPA_16050"


class _Primitive_Endoderm(_MouseAnatomicalStructureModel):
    """Model primitive endoderm"""

    name: Literal["primitive endoderm"] = "primitive endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16051"] = "EMAPA_16051"


class _Extraembryonic_Endoderm(_MouseAnatomicalStructureModel):
    """Model extraembryonic endoderm"""

    name: Literal["extraembryonic endoderm"] = "extraembryonic endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16052"] = "EMAPA_16052"


class _Parietal_Endoderm(_MouseAnatomicalStructureModel):
    """Model parietal endoderm"""

    name: Literal["parietal endoderm"] = "parietal endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16053"] = "EMAPA_16053"


class _Extraembryonic_Component_Cavity(_MouseAnatomicalStructureModel):
    """Model extraembryonic component cavity"""

    name: Literal["extraembryonic component cavity"] = "extraembryonic component cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16054"] = "EMAPA_16054"


class _Yolk_Sac_Cavity(_MouseAnatomicalStructureModel):
    """Model yolk sac cavity"""

    name: Literal["yolk sac cavity"] = "yolk sac cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16055"] = "EMAPA_16055"


class _Intermediate_Endoderm(_MouseAnatomicalStructureModel):
    """Model intermediate endoderm"""

    name: Literal["intermediate endoderm"] = "intermediate endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16056"] = "EMAPA_16056"


class _Reichert_S_Membrane(_MouseAnatomicalStructureModel):
    """Model Reichert's membrane"""

    name: Literal["Reichert's membrane"] = "Reichert's membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16057"] = "EMAPA_16057"


class _Extraembryonic_Visceral_Endoderm(_MouseAnatomicalStructureModel):
    """Model extraembryonic visceral endoderm"""

    name: Literal["extraembryonic visceral endoderm"] = "extraembryonic visceral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16058"] = "EMAPA_16058"


class _Ectoplacental_Cone(_MouseAnatomicalStructureModel):
    """Model ectoplacental cone"""

    name: Literal["ectoplacental cone"] = "ectoplacental cone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16059"] = "EMAPA_16059"


class _Body_Cavity_Or_Lining(_MouseAnatomicalStructureModel):
    """Model body cavity or lining"""

    name: Literal["body cavity or lining"] = "body cavity or lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16060"] = "EMAPA_16060"


class _Proamniotic_Cavity_Embryonic_Part(_MouseAnatomicalStructureModel):
    """Model proamniotic cavity embryonic part"""

    name: Literal["proamniotic cavity embryonic part"] = "proamniotic cavity embryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16061"] = "EMAPA_16061"


class _Embryo_Endoderm(_MouseAnatomicalStructureModel):
    """Model embryo endoderm"""

    name: Literal["embryo endoderm"] = "embryo endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16062"] = "EMAPA_16062"


class _Proamniotic_Cavity_Extraembryonic_Part(_MouseAnatomicalStructureModel):
    """Model proamniotic cavity extraembryonic part"""

    name: Literal["proamniotic cavity extraembryonic part"] = "proamniotic cavity extraembryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16064"] = "EMAPA_16064"


class _Extraembryonic_Ectoderm(_MouseAnatomicalStructureModel):
    """Model extraembryonic ectoderm"""

    name: Literal["extraembryonic ectoderm"] = "extraembryonic ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16065"] = "EMAPA_16065"


class _Primary_Trophoblast_Giant_Cell(_MouseAnatomicalStructureModel):
    """Model primary trophoblast giant cell"""

    name: Literal["primary trophoblast giant cell"] = "primary trophoblast giant cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16066"] = "EMAPA_16066"


class _Cytotrophoblast(_MouseAnatomicalStructureModel):
    """Model cytotrophoblast"""

    name: Literal["cytotrophoblast"] = "cytotrophoblast"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16067"] = "EMAPA_16067"


class _Syncytiotrophoblast(_MouseAnatomicalStructureModel):
    """Model syncytiotrophoblast"""

    name: Literal["syncytiotrophoblast"] = "syncytiotrophoblast"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16068"] = "EMAPA_16068"


class _Embryo_Ectoderm(_MouseAnatomicalStructureModel):
    """Model embryo ectoderm"""

    name: Literal["embryo ectoderm"] = "embryo ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16069"] = "EMAPA_16069"


class _Definitive_Endoderm(_MouseAnatomicalStructureModel):
    """Model definitive endoderm"""

    name: Literal["definitive endoderm"] = "definitive endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16070"] = "EMAPA_16070"


class _Embryo_Mesoderm(_MouseAnatomicalStructureModel):
    """Model embryo mesoderm"""

    name: Literal["embryo mesoderm"] = "embryo mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16071"] = "EMAPA_16071"


class _Primitive_Streak(_MouseAnatomicalStructureModel):
    """Model primitive streak"""

    name: Literal["primitive streak"] = "primitive streak"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16072"] = "EMAPA_16072"


class _Neural_Ectoderm(_MouseAnatomicalStructureModel):
    """Model neural ectoderm"""

    name: Literal["neural ectoderm"] = "neural ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16073"] = "EMAPA_16073"


class _Non_Neural_Ectoderm(_MouseAnatomicalStructureModel):
    """Model non-neural ectoderm"""

    name: Literal["non-neural ectoderm"] = "non-neural ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16074"] = "EMAPA_16074"


class _Node(_MouseAnatomicalStructureModel):
    """Model node"""

    name: Literal["node"] = "node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16075"] = "EMAPA_16075"


class _Amniotic_Fold(_MouseAnatomicalStructureModel):
    """Model amniotic fold"""

    name: Literal["amniotic fold"] = "amniotic fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16076"] = "EMAPA_16076"


class _Amniotic_Fold_Ectoderm(_MouseAnatomicalStructureModel):
    """Model amniotic fold ectoderm"""

    name: Literal["amniotic fold ectoderm"] = "amniotic fold ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16077"] = "EMAPA_16077"


class _Amniotic_Fold_Mesoderm(_MouseAnatomicalStructureModel):
    """Model amniotic fold mesoderm"""

    name: Literal["amniotic fold mesoderm"] = "amniotic fold mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16078"] = "EMAPA_16078"


class _Amniotic_Cavity(_MouseAnatomicalStructureModel):
    """Model amniotic cavity"""

    name: Literal["amniotic cavity"] = "amniotic cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16079"] = "EMAPA_16079"


class _Ectoplacental_Cavity(_MouseAnatomicalStructureModel):
    """Model ectoplacental cavity"""

    name: Literal["ectoplacental cavity"] = "ectoplacental cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16080"] = "EMAPA_16080"


class _Exocoelomic_Cavity(_MouseAnatomicalStructureModel):
    """Model exocoelomic cavity"""

    name: Literal["exocoelomic cavity"] = "exocoelomic cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16081"] = "EMAPA_16081"


class _Cavity_Within_Amniotic_Fold(_MouseAnatomicalStructureModel):
    """Model cavity within amniotic fold"""

    name: Literal["cavity within amniotic fold"] = "cavity within amniotic fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16082"] = "EMAPA_16082"


class _Yolk_Sac(_MouseAnatomicalStructureModel):
    """Model yolk sac"""

    name: Literal["yolk sac"] = "yolk sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16085"] = "EMAPA_16085"


class _Yolk_Sac_Endoderm(_MouseAnatomicalStructureModel):
    """Model yolk sac endoderm"""

    name: Literal["yolk sac endoderm"] = "yolk sac endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16086"] = "EMAPA_16086"


class _Yolk_Sac_Mesoderm(_MouseAnatomicalStructureModel):
    """Model yolk sac mesoderm"""

    name: Literal["yolk sac mesoderm"] = "yolk sac mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16087"] = "EMAPA_16087"


class _Intraembryonic_Coelom(_MouseAnatomicalStructureModel):
    """Model intraembryonic coelom"""

    name: Literal["intraembryonic coelom"] = "intraembryonic coelom"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16088"] = "EMAPA_16088"


class _Future_Brain(_MouseAnatomicalStructureModel):
    """Model future brain"""

    name: Literal["future brain"] = "future brain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16089"] = "EMAPA_16089"


class _Future_Brain_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model future brain neural fold"""

    name: Literal["future brain neural fold"] = "future brain neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16090"] = "EMAPA_16090"


class _Future_Brain_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model future brain neural crest"""

    name: Literal["future brain neural crest"] = "future brain neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16091"] = "EMAPA_16091"


class _Future_Spinal_Cord(_MouseAnatomicalStructureModel):
    """Model future spinal cord"""

    name: Literal["future spinal cord"] = "future spinal cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16092"] = "EMAPA_16092"


class _Future_Spinal_Cord_Neural_Plate(_MouseAnatomicalStructureModel):
    """Model future spinal cord neural plate"""

    name: Literal["future spinal cord neural plate"] = "future spinal cord neural plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16095"] = "EMAPA_16095"


class _Surface_Ectoderm(_MouseAnatomicalStructureModel):
    """Model surface ectoderm"""

    name: Literal["surface ectoderm"] = "surface ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16096"] = "EMAPA_16096"


class _Mesenchyme(_MouseAnatomicalStructureModel):
    """Model mesenchyme"""

    name: Literal["mesenchyme"] = "mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16097"] = "EMAPA_16097"


class _Head_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model head mesenchyme"""

    name: Literal["head mesenchyme"] = "head mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16098"] = "EMAPA_16098"


class _Mesenchyme_Derived_From_Head_Mesoderm(_MouseAnatomicalStructureModel):
    """Model mesenchyme derived from head mesoderm"""

    name: Literal["mesenchyme derived from head mesoderm"] = "mesenchyme derived from head mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16099"] = "EMAPA_16099"


class _Notochordal_Plate(_MouseAnatomicalStructureModel):
    """Model notochordal plate"""

    name: Literal["notochordal plate"] = "notochordal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16101"] = "EMAPA_16101"


class _Notochordal_Process(_MouseAnatomicalStructureModel):
    """Model notochordal process"""

    name: Literal["notochordal process"] = "notochordal process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16102"] = "EMAPA_16102"


class _Organ_System(_MouseAnatomicalStructureModel):
    """Model organ system"""

    name: Literal["organ system"] = "organ system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16103"] = "EMAPA_16103"


class _Cardiovascular_System(_MouseAnatomicalStructureModel):
    """Model cardiovascular system"""

    name: Literal["cardiovascular system"] = "cardiovascular system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16104"] = "EMAPA_16104"


class _Heart(_MouseAnatomicalStructureModel):
    """Model heart"""

    name: Literal["heart"] = "heart"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16105"] = "EMAPA_16105"


class _Cardiogenic_Plate(_MouseAnatomicalStructureModel):
    """Model cardiogenic plate"""

    name: Literal["cardiogenic plate"] = "cardiogenic plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16106"] = "EMAPA_16106"


class _Allantois(_MouseAnatomicalStructureModel):
    """Model allantois"""

    name: Literal["allantois"] = "allantois"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16107"] = "EMAPA_16107"


class _Allantois_Mesoderm(_MouseAnatomicalStructureModel):
    """Model allantois mesoderm"""

    name: Literal["allantois mesoderm"] = "allantois mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16108"] = "EMAPA_16108"


class _Amnion(_MouseAnatomicalStructureModel):
    """Model amnion"""

    name: Literal["amnion"] = "amnion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16109"] = "EMAPA_16109"


class _Amnion_Ectoderm(_MouseAnatomicalStructureModel):
    """Model amnion ectoderm"""

    name: Literal["amnion ectoderm"] = "amnion ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16110"] = "EMAPA_16110"


class _Amnion_Mesoderm(_MouseAnatomicalStructureModel):
    """Model amnion mesoderm"""

    name: Literal["amnion mesoderm"] = "amnion mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16111"] = "EMAPA_16111"


class _Chorion(_MouseAnatomicalStructureModel):
    """Model chorion"""

    name: Literal["chorion"] = "chorion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16112"] = "EMAPA_16112"


class _Chorion_Ectoderm(_MouseAnatomicalStructureModel):
    """Model chorion ectoderm"""

    name: Literal["chorion ectoderm"] = "chorion ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16113"] = "EMAPA_16113"


class _Chorion_Mesoderm(_MouseAnatomicalStructureModel):
    """Model chorion mesoderm"""

    name: Literal["chorion mesoderm"] = "chorion mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16114"] = "EMAPA_16114"


class _Blood_Island(_MouseAnatomicalStructureModel):
    """Model blood island"""

    name: Literal["blood island"] = "blood island"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16115"] = "EMAPA_16115"


class _Primordial_Germ_Cell_Of_Yolk_Sac(_MouseAnatomicalStructureModel):
    """Model primordial germ cell of yolk sac"""

    name: Literal["primordial germ cell of yolk sac"] = "primordial germ cell of yolk sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16116"] = "EMAPA_16116"


class _Branchial_Arch(_MouseAnatomicalStructureModel):
    """Model branchial arch"""

    name: Literal["branchial arch"] = "branchial arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16117"] = "EMAPA_16117"


class _1St_Branchial_Arch(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch"""

    name: Literal["1st branchial arch"] = "1st branchial arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16118"] = "EMAPA_16118"


class _1St_Branchial_Groove(_MouseAnatomicalStructureModel):
    """Model 1st branchial groove"""

    name: Literal["1st branchial groove"] = "1st branchial groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16119"] = "EMAPA_16119"


class _1St_Branchial_Groove_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial groove ectoderm"""

    name: Literal["1st branchial groove ectoderm"] = "1st branchial groove ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16120"] = "EMAPA_16120"


class _1St_Branchial_Membrane(_MouseAnatomicalStructureModel):
    """Model 1st branchial membrane"""

    name: Literal["1st branchial membrane"] = "1st branchial membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16121"] = "EMAPA_16121"


class _1St_Branchial_Membrane_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial membrane ectoderm"""

    name: Literal["1st branchial membrane ectoderm"] = "1st branchial membrane ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16122"] = "EMAPA_16122"


class _1St_Branchial_Membrane_Endoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial membrane endoderm"""

    name: Literal["1st branchial membrane endoderm"] = "1st branchial membrane endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16123"] = "EMAPA_16123"


class _1St_Branchial_Pouch(_MouseAnatomicalStructureModel):
    """Model 1st branchial pouch"""

    name: Literal["1st branchial pouch"] = "1st branchial pouch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16124"] = "EMAPA_16124"


class _1St_Branchial_Pouch_Endoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial pouch endoderm"""

    name: Literal["1st branchial pouch endoderm"] = "1st branchial pouch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16125"] = "EMAPA_16125"


class _1St_Branchial_Arch_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch ectoderm"""

    name: Literal["1st branchial arch ectoderm"] = "1st branchial arch ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16126"] = "EMAPA_16126"


class _1St_Branchial_Arch_Endoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch endoderm"""

    name: Literal["1st branchial arch endoderm"] = "1st branchial arch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16127"] = "EMAPA_16127"


class _1St_Branchial_Arch_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mesenchyme"""

    name: Literal["1st branchial arch mesenchyme"] = "1st branchial arch mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16128"] = "EMAPA_16128"


class _1St_Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mesenchyme derived from neural crest"""

    name: Literal[
        "1st branchial arch mesenchyme derived from neural crest"
    ] = "1st branchial arch mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16129"] = "EMAPA_16129"


class _1St_Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mesenchyme derived from head mesoderm"""

    name: Literal[
        "1st branchial arch mesenchyme derived from head mesoderm"
    ] = "1st branchial arch mesenchyme derived from head mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16130"] = "EMAPA_16130"


class _Pericardial_Component(_MouseAnatomicalStructureModel):
    """Model pericardial component"""

    name: Literal["pericardial component"] = "pericardial component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16131"] = "EMAPA_16131"


class _Pericardial_Cavity(_MouseAnatomicalStructureModel):
    """Model pericardial cavity"""

    name: Literal["pericardial cavity"] = "pericardial cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16132"] = "EMAPA_16132"


class _Pericardium(_MouseAnatomicalStructureModel):
    """Model pericardium"""

    name: Literal["pericardium"] = "pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16133"] = "EMAPA_16133"


class _Pericardio_Peritoneal_Component(_MouseAnatomicalStructureModel):
    """Model pericardio-peritoneal component"""

    name: Literal["pericardio-peritoneal component"] = "pericardio-peritoneal component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16134"] = "EMAPA_16134"


class _Pericardio_Peritoneal_Component_Cavity(_MouseAnatomicalStructureModel):
    """Model pericardio-peritoneal component cavity"""

    name: Literal["pericardio-peritoneal component cavity"] = "pericardio-peritoneal component cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16135"] = "EMAPA_16135"


class _Pericardio_Peritoneal_Component_Mesothelium(_MouseAnatomicalStructureModel):
    """Model pericardio-peritoneal component mesothelium"""

    name: Literal["pericardio-peritoneal component mesothelium"] = "pericardio-peritoneal component mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16136"] = "EMAPA_16136"


class _Peritoneal_Component(_MouseAnatomicalStructureModel):
    """Model peritoneal component"""

    name: Literal["peritoneal component"] = "peritoneal component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16137"] = "EMAPA_16137"


class _Peritoneal_Cavity(_MouseAnatomicalStructureModel):
    """Model peritoneal cavity"""

    name: Literal["peritoneal cavity"] = "peritoneal cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16138"] = "EMAPA_16138"


class _Peritoneum(_MouseAnatomicalStructureModel):
    """Model peritoneum"""

    name: Literal["peritoneum"] = "peritoneum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16139"] = "EMAPA_16139"


class _Future_Midbrain(_MouseAnatomicalStructureModel):
    """Model future midbrain"""

    name: Literal["future midbrain"] = "future midbrain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16140"] = "EMAPA_16140"


class _Future_Midbrain_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model future midbrain floor plate"""

    name: Literal["future midbrain floor plate"] = "future midbrain floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16141"] = "EMAPA_16141"


class _Future_Midbrain_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model future midbrain neural fold"""

    name: Literal["future midbrain neural fold"] = "future midbrain neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16142"] = "EMAPA_16142"


class _Future_Midbrain_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model future midbrain neural crest"""

    name: Literal["future midbrain neural crest"] = "future midbrain neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16143"] = "EMAPA_16143"


class _Future_Prosencephalon(_MouseAnatomicalStructureModel):
    """Model future prosencephalon"""

    name: Literal["future prosencephalon"] = "future prosencephalon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16144"] = "EMAPA_16144"


class _Future_Prosencephalon_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model future prosencephalon floor plate"""

    name: Literal["future prosencephalon floor plate"] = "future prosencephalon floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16145"] = "EMAPA_16145"


class _Future_Prosencephalon_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model future prosencephalon neural fold"""

    name: Literal["future prosencephalon neural fold"] = "future prosencephalon neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16146"] = "EMAPA_16146"


class _Future_Prosencephalon_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model future prosencephalon neural crest"""

    name: Literal["future prosencephalon neural crest"] = "future prosencephalon neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16147"] = "EMAPA_16147"


class _Future_Hindbrain(_MouseAnatomicalStructureModel):
    """Model future hindbrain"""

    name: Literal["future hindbrain"] = "future hindbrain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16148"] = "EMAPA_16148"


class _Anterior_Pro_Rhombomere(_MouseAnatomicalStructureModel):
    """Model anterior pro-rhombomere"""

    name: Literal["anterior pro-rhombomere"] = "anterior pro-rhombomere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16149"] = "EMAPA_16149"


class _Anterior_Pro_Rhombomere_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model anterior pro-rhombomere floor plate"""

    name: Literal["anterior pro-rhombomere floor plate"] = "anterior pro-rhombomere floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16150"] = "EMAPA_16150"


class _Anterior_Pro_Rhombomere_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model anterior pro-rhombomere neural fold"""

    name: Literal["anterior pro-rhombomere neural fold"] = "anterior pro-rhombomere neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16151"] = "EMAPA_16151"


class _Anterior_Pro_Rhombomere_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model anterior pro-rhombomere neural crest"""

    name: Literal["anterior pro-rhombomere neural crest"] = "anterior pro-rhombomere neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16152"] = "EMAPA_16152"


class _Future_Hindbrain_Neural_Ectoderm(_MouseAnatomicalStructureModel):
    """Model future hindbrain neural ectoderm"""

    name: Literal["future hindbrain neural ectoderm"] = "future hindbrain neural ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16153"] = "EMAPA_16153"


class _Future_Hindbrain_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model future hindbrain floor plate"""

    name: Literal["future hindbrain floor plate"] = "future hindbrain floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16154"] = "EMAPA_16154"


class _Future_Hindbrain_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model future hindbrain neural fold"""

    name: Literal["future hindbrain neural fold"] = "future hindbrain neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16155"] = "EMAPA_16155"


class _Future_Hindbrain_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model future hindbrain neural crest"""

    name: Literal["future hindbrain neural crest"] = "future hindbrain neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16156"] = "EMAPA_16156"


class _Posterior_Pro_Rhombomere(_MouseAnatomicalStructureModel):
    """Model posterior pro-rhombomere"""

    name: Literal["posterior pro-rhombomere"] = "posterior pro-rhombomere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16157"] = "EMAPA_16157"


class _Posterior_Pro_Rhombomere_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model posterior pro-rhombomere floor plate"""

    name: Literal["posterior pro-rhombomere floor plate"] = "posterior pro-rhombomere floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16158"] = "EMAPA_16158"


class _Posterior_Pro_Rhombomere_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model posterior pro-rhombomere neural fold"""

    name: Literal["posterior pro-rhombomere neural fold"] = "posterior pro-rhombomere neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16159"] = "EMAPA_16159"


class _Posterior_Pro_Rhombomere_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model posterior pro-rhombomere neural crest"""

    name: Literal["posterior pro-rhombomere neural crest"] = "posterior pro-rhombomere neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16160"] = "EMAPA_16160"


class _Pre_Otic_Sulcus(_MouseAnatomicalStructureModel):
    """Model pre-otic sulcus"""

    name: Literal["pre-otic sulcus"] = "pre-otic sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16161"] = "EMAPA_16161"


class _Future_Spinal_Cord_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model future spinal cord neural fold"""

    name: Literal["future spinal cord neural fold"] = "future spinal cord neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16162"] = "EMAPA_16162"


class _Future_Spinal_Cord_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model future spinal cord neural crest"""

    name: Literal["future spinal cord neural crest"] = "future spinal cord neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16163"] = "EMAPA_16163"


class _Neural_Tube(_MouseAnatomicalStructureModel):
    """Model neural tube"""

    name: Literal["neural tube"] = "neural tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16164"] = "EMAPA_16164"


class _Neural_Tube_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model neural tube floor plate"""

    name: Literal["neural tube floor plate"] = "neural tube floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16165"] = "EMAPA_16165"


class _Neural_Tube_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model neural tube lateral wall"""

    name: Literal["neural tube lateral wall"] = "neural tube lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16166"] = "EMAPA_16166"


class _Neural_Lumen(_MouseAnatomicalStructureModel):
    """Model neural lumen"""

    name: Literal["neural lumen"] = "neural lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16167"] = "EMAPA_16167"


class _Neural_Tube_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model neural tube roof plate"""

    name: Literal["neural tube roof plate"] = "neural tube roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16168"] = "EMAPA_16168"


class _Head_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model head mesenchyme derived from neural crest"""

    name: Literal["head mesenchyme derived from neural crest"] = "head mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16169"] = "EMAPA_16169"


class _Trigeminal_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model trigeminal neural crest"""

    name: Literal["trigeminal neural crest"] = "trigeminal neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16170"] = "EMAPA_16170"


class _Head_Paraxial_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model head paraxial mesenchyme"""

    name: Literal["head paraxial mesenchyme"] = "head paraxial mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16171"] = "EMAPA_16171"


class _Head_Somite(_MouseAnatomicalStructureModel):
    """Model head somite"""

    name: Literal["head somite"] = "head somite"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16172"] = "EMAPA_16172"


class _Somite_01(_MouseAnatomicalStructureModel):
    """Model somite 01"""

    name: Literal["somite 01"] = "somite 01"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16173"] = "EMAPA_16173"


class _Somite_02(_MouseAnatomicalStructureModel):
    """Model somite 02"""

    name: Literal["somite 02"] = "somite 02"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16174"] = "EMAPA_16174"


class _Somite_03(_MouseAnatomicalStructureModel):
    """Model somite 03"""

    name: Literal["somite 03"] = "somite 03"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16175"] = "EMAPA_16175"


class _Somite_04(_MouseAnatomicalStructureModel):
    """Model somite 04"""

    name: Literal["somite 04"] = "somite 04"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16176"] = "EMAPA_16176"


class _Trunk_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model trunk mesenchyme"""

    name: Literal["trunk mesenchyme"] = "trunk mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16177"] = "EMAPA_16177"


class _Intermediate_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model intermediate mesenchyme"""

    name: Literal["intermediate mesenchyme"] = "intermediate mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16178"] = "EMAPA_16178"


class _Lateral_Plate_Mesoderm(_MouseAnatomicalStructureModel):
    """Model lateral plate mesoderm"""

    name: Literal["lateral plate mesoderm"] = "lateral plate mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16179"] = "EMAPA_16179"


class _Somatopleure(_MouseAnatomicalStructureModel):
    """Model somatopleure"""

    name: Literal["somatopleure"] = "somatopleure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16180"] = "EMAPA_16180"


class _Splanchnopleure(_MouseAnatomicalStructureModel):
    """Model splanchnopleure"""

    name: Literal["splanchnopleure"] = "splanchnopleure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16181"] = "EMAPA_16181"


class _Trunk_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model trunk mesenchyme derived from neural crest"""

    name: Literal["trunk mesenchyme derived from neural crest"] = "trunk mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16182"] = "EMAPA_16182"


class _Trunk_Paraxial_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model trunk paraxial mesenchyme"""

    name: Literal["trunk paraxial mesenchyme"] = "trunk paraxial mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16183"] = "EMAPA_16183"


class _Trunk_Somite(_MouseAnatomicalStructureModel):
    """Model trunk somite"""

    name: Literal["trunk somite"] = "trunk somite"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16184"] = "EMAPA_16184"


class _Somite_05(_MouseAnatomicalStructureModel):
    """Model somite 05"""

    name: Literal["somite 05"] = "somite 05"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16185"] = "EMAPA_16185"


class _Somite_06(_MouseAnatomicalStructureModel):
    """Model somite 06"""

    name: Literal["somite 06"] = "somite 06"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16186"] = "EMAPA_16186"


class _Somite_07(_MouseAnatomicalStructureModel):
    """Model somite 07"""

    name: Literal["somite 07"] = "somite 07"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16187"] = "EMAPA_16187"


class _Somite_08(_MouseAnatomicalStructureModel):
    """Model somite 08"""

    name: Literal["somite 08"] = "somite 08"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16188"] = "EMAPA_16188"


class _Trunk_Unsegmented_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model trunk unsegmented mesenchyme"""

    name: Literal["trunk unsegmented mesenchyme"] = "trunk unsegmented mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16189"] = "EMAPA_16189"


class _Primordial_Germ_Cell_Of_Trunk_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model primordial germ cell of trunk mesenchyme"""

    name: Literal["primordial germ cell of trunk mesenchyme"] = "primordial germ cell of trunk mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16190"] = "EMAPA_16190"


class _Notochord(_MouseAnatomicalStructureModel):
    """Model notochord"""

    name: Literal["notochord"] = "notochord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16191"] = "EMAPA_16191"


class _Sensory_Organ_System(_MouseAnatomicalStructureModel):
    """Model sensory organ system"""

    name: Literal["sensory organ system"] = "sensory organ system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16192"] = "EMAPA_16192"


class _Ear(_MouseAnatomicalStructureModel):
    """Model ear"""

    name: Literal["ear"] = "ear"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16193"] = "EMAPA_16193"


class _Inner_Ear(_MouseAnatomicalStructureModel):
    """Model inner ear"""

    name: Literal["inner ear"] = "inner ear"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16194"] = "EMAPA_16194"


class _Otic_Placode(_MouseAnatomicalStructureModel):
    """Model otic placode"""

    name: Literal["otic placode"] = "otic placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16195"] = "EMAPA_16195"


class _Otic_Placode_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model otic placode mesenchyme"""

    name: Literal["otic placode mesenchyme"] = "otic placode mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16196"] = "EMAPA_16196"


class _Otic_Placode_Epithelium(_MouseAnatomicalStructureModel):
    """Model otic placode epithelium"""

    name: Literal["otic placode epithelium"] = "otic placode epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16197"] = "EMAPA_16197"


class _Eye(_MouseAnatomicalStructureModel):
    """Model eye"""

    name: Literal["eye"] = "eye"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16198"] = "EMAPA_16198"


class _Optic_Sulcus(_MouseAnatomicalStructureModel):
    """Model optic sulcus"""

    name: Literal["optic sulcus"] = "optic sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16199"] = "EMAPA_16199"


class _Optic_Sulcus_Neural_Ectoderm(_MouseAnatomicalStructureModel):
    """Model optic sulcus neural ectoderm"""

    name: Literal["optic sulcus neural ectoderm"] = "optic sulcus neural ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16200"] = "EMAPA_16200"


class _Arterial_System(_MouseAnatomicalStructureModel):
    """Model arterial system"""

    name: Literal["arterial system"] = "arterial system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16201"] = "EMAPA_16201"


class _Dorsal_Aorta(_MouseAnatomicalStructureModel):
    """Model dorsal aorta"""

    name: Literal["dorsal aorta"] = "dorsal aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16204"] = "EMAPA_16204"


class _Left_Dorsal_Aorta(_MouseAnatomicalStructureModel):
    """Model left dorsal aorta"""

    name: Literal["left dorsal aorta"] = "left dorsal aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16205"] = "EMAPA_16205"


class _Right_Dorsal_Aorta(_MouseAnatomicalStructureModel):
    """Model right dorsal aorta"""

    name: Literal["right dorsal aorta"] = "right dorsal aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16206"] = "EMAPA_16206"


class _Vitelline_Artery(_MouseAnatomicalStructureModel):
    """Model vitelline artery"""

    name: Literal["vitelline artery"] = "vitelline artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16207"] = "EMAPA_16207"


class _Primitive_Heart_Tube_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model primitive heart tube cardiac jelly"""

    name: Literal["primitive heart tube cardiac jelly"] = "primitive heart tube cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16209"] = "EMAPA_16209"


class _Primitive_Heart_Tube_Endocardial_Tube(_MouseAnatomicalStructureModel):
    """Model primitive heart tube endocardial tube"""

    name: Literal["primitive heart tube endocardial tube"] = "primitive heart tube endocardial tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16210"] = "EMAPA_16210"


class _Primitive_Heart_Tube_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model primitive heart tube cardiac muscle"""

    name: Literal["primitive heart tube cardiac muscle"] = "primitive heart tube cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16211"] = "EMAPA_16211"


class _Heart_Mesentery(_MouseAnatomicalStructureModel):
    """Model heart mesentery"""

    name: Literal["heart mesentery"] = "heart mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16212"] = "EMAPA_16212"


class _Dorsal_Mesocardium(_MouseAnatomicalStructureModel):
    """Model dorsal mesocardium"""

    name: Literal["dorsal mesocardium"] = "dorsal mesocardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16213"] = "EMAPA_16213"


class _Transverse_Pericardial_Sinus(_MouseAnatomicalStructureModel):
    """Model transverse pericardial sinus"""

    name: Literal["transverse pericardial sinus"] = "transverse pericardial sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16214"] = "EMAPA_16214"


class _Primitive_Heart_Tube(_MouseAnatomicalStructureModel):
    """Model primitive heart tube"""

    name: Literal["primitive heart tube"] = "primitive heart tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16215"] = "EMAPA_16215"


class _Sinus_Venosus(_MouseAnatomicalStructureModel):
    """Model sinus venosus"""

    name: Literal["sinus venosus"] = "sinus venosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16237"] = "EMAPA_16237"


class _Sinus_Venosus_Left_Horn(_MouseAnatomicalStructureModel):
    """Model sinus venosus left horn"""

    name: Literal["sinus venosus left horn"] = "sinus venosus left horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16238"] = "EMAPA_16238"


class _Sinus_Venosus_Right_Horn(_MouseAnatomicalStructureModel):
    """Model sinus venosus right horn"""

    name: Literal["sinus venosus right horn"] = "sinus venosus right horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16239"] = "EMAPA_16239"


class _Venous_System(_MouseAnatomicalStructureModel):
    """Model venous system"""

    name: Literal["venous system"] = "venous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16240"] = "EMAPA_16240"


class _Anterior_Cardinal_Vein(_MouseAnatomicalStructureModel):
    """Model anterior cardinal vein"""

    name: Literal["anterior cardinal vein"] = "anterior cardinal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16241"] = "EMAPA_16241"


class _Primary_Head_Vein(_MouseAnatomicalStructureModel):
    """Model primary head vein"""

    name: Literal["primary head vein"] = "primary head vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16242"] = "EMAPA_16242"


class _Umbilical_Vein_Embryonic_Part(_MouseAnatomicalStructureModel):
    """Model umbilical vein embryonic part"""

    name: Literal["umbilical vein embryonic part"] = "umbilical vein embryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16243"] = "EMAPA_16243"


class _Vitelline_Vein_Embryonic_Part(_MouseAnatomicalStructureModel):
    """Model vitelline vein embryonic part"""

    name: Literal["vitelline vein embryonic part"] = "vitelline vein embryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16244"] = "EMAPA_16244"


class _Visceral_Organ_System(_MouseAnatomicalStructureModel):
    """Model visceral organ system"""

    name: Literal["visceral organ system"] = "visceral organ system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16245"] = "EMAPA_16245"


class _Alimentary_System(_MouseAnatomicalStructureModel):
    """Model alimentary system"""

    name: Literal["alimentary system"] = "alimentary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16246"] = "EMAPA_16246"


class _Gut(_MouseAnatomicalStructureModel):
    """Model gut"""

    name: Literal["gut"] = "gut"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16247"] = "EMAPA_16247"


class _Foregut_Diverticulum(_MouseAnatomicalStructureModel):
    """Model foregut diverticulum"""

    name: Literal["foregut diverticulum"] = "foregut diverticulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16248"] = "EMAPA_16248"


class _Foregut_Diverticulum_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model foregut diverticulum mesenchyme"""

    name: Literal["foregut diverticulum mesenchyme"] = "foregut diverticulum mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16249"] = "EMAPA_16249"


class _Foregut_Diverticulum_Endoderm(_MouseAnatomicalStructureModel):
    """Model foregut diverticulum endoderm"""

    name: Literal["foregut diverticulum endoderm"] = "foregut diverticulum endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16250"] = "EMAPA_16250"


class _Hindgut_Diverticulum(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum"""

    name: Literal["hindgut diverticulum"] = "hindgut diverticulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16251"] = "EMAPA_16251"


class _Hindgut_Diverticulum_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum mesenchyme"""

    name: Literal["hindgut diverticulum mesenchyme"] = "hindgut diverticulum mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16252"] = "EMAPA_16252"


class _Hindgut_Diverticulum_Endoderm(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum endoderm"""

    name: Literal["hindgut diverticulum endoderm"] = "hindgut diverticulum endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16253"] = "EMAPA_16253"


class _Primordial_Germ_Cell_Of_Hindgut(_MouseAnatomicalStructureModel):
    """Model primordial germ cell of hindgut"""

    name: Literal["primordial germ cell of hindgut"] = "primordial germ cell of hindgut"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16254"] = "EMAPA_16254"


class _Midgut(_MouseAnatomicalStructureModel):
    """Model midgut"""

    name: Literal["midgut"] = "midgut"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16255"] = "EMAPA_16255"


class _Midgut_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model midgut mesenchyme"""

    name: Literal["midgut mesenchyme"] = "midgut mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16256"] = "EMAPA_16256"


class _Midgut_Endoderm(_MouseAnatomicalStructureModel):
    """Model midgut endoderm"""

    name: Literal["midgut endoderm"] = "midgut endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16257"] = "EMAPA_16257"


class _Mouth_Foregut_Junction(_MouseAnatomicalStructureModel):
    """Model mouth-foregut junction"""

    name: Literal["mouth-foregut junction"] = "mouth-foregut junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16258"] = "EMAPA_16258"


class _Buccopharyngeal_Membrane(_MouseAnatomicalStructureModel):
    """Model buccopharyngeal membrane"""

    name: Literal["buccopharyngeal membrane"] = "buccopharyngeal membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16259"] = "EMAPA_16259"


class _Buccopharyngeal_Membrane_Ectoderm(_MouseAnatomicalStructureModel):
    """Model buccopharyngeal membrane ectoderm"""

    name: Literal["buccopharyngeal membrane ectoderm"] = "buccopharyngeal membrane ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16260"] = "EMAPA_16260"


class _Buccopharyngeal_Membrane_Endoderm(_MouseAnatomicalStructureModel):
    """Model buccopharyngeal membrane endoderm"""

    name: Literal["buccopharyngeal membrane endoderm"] = "buccopharyngeal membrane endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16261"] = "EMAPA_16261"


class _Oral_Region(_MouseAnatomicalStructureModel):
    """Model oral region"""

    name: Literal["oral region"] = "oral region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16262"] = "EMAPA_16262"


class _Stomatodeum(_MouseAnatomicalStructureModel):
    """Model stomatodeum"""

    name: Literal["stomatodeum"] = "stomatodeum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16263"] = "EMAPA_16263"


class _Allantois_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model allantois mesenchyme"""

    name: Literal["allantois mesenchyme"] = "allantois mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16264"] = "EMAPA_16264"


class _Amnion_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model amnion mesenchyme"""

    name: Literal["amnion mesenchyme"] = "amnion mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16265"] = "EMAPA_16265"


class _Chorion_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model chorion mesenchyme"""

    name: Literal["chorion mesenchyme"] = "chorion mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16266"] = "EMAPA_16266"


class _Yolk_Sac_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model yolk sac mesenchyme"""

    name: Literal["yolk sac mesenchyme"] = "yolk sac mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16267"] = "EMAPA_16267"


class _2Nd_Branchial_Arch(_MouseAnatomicalStructureModel):
    """Model 2nd branchial arch"""

    name: Literal["2nd branchial arch"] = "2nd branchial arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16272"] = "EMAPA_16272"


class _2Nd_Branchial_Membrane(_MouseAnatomicalStructureModel):
    """Model 2nd branchial membrane"""

    name: Literal["2nd branchial membrane"] = "2nd branchial membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16273"] = "EMAPA_16273"


class _2Nd_Branchial_Membrane_Endoderm(_MouseAnatomicalStructureModel):
    """Model 2nd branchial membrane endoderm"""

    name: Literal["2nd branchial membrane endoderm"] = "2nd branchial membrane endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16274"] = "EMAPA_16274"


class _2Nd_Branchial_Pouch(_MouseAnatomicalStructureModel):
    """Model 2nd branchial pouch"""

    name: Literal["2nd branchial pouch"] = "2nd branchial pouch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16275"] = "EMAPA_16275"


class _2Nd_Branchial_Pouch_Endoderm(_MouseAnatomicalStructureModel):
    """Model 2nd branchial pouch endoderm"""

    name: Literal["2nd branchial pouch endoderm"] = "2nd branchial pouch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16276"] = "EMAPA_16276"


class _2Nd_Branchial_Arch_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 2nd branchial arch ectoderm"""

    name: Literal["2nd branchial arch ectoderm"] = "2nd branchial arch ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16277"] = "EMAPA_16277"


class _2Nd_Branchial_Arch_Endoderm(_MouseAnatomicalStructureModel):
    """Model 2nd branchial arch endoderm"""

    name: Literal["2nd branchial arch endoderm"] = "2nd branchial arch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16278"] = "EMAPA_16278"


class _2Nd_Branchial_Arch_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model 2nd branchial arch mesenchyme"""

    name: Literal["2nd branchial arch mesenchyme"] = "2nd branchial arch mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16279"] = "EMAPA_16279"


class _2Nd_Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm(_MouseAnatomicalStructureModel):
    """Model 2nd branchial arch mesenchyme derived from head mesoderm"""

    name: Literal[
        "2nd branchial arch mesenchyme derived from head mesoderm"
    ] = "2nd branchial arch mesenchyme derived from head mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16280"] = "EMAPA_16280"


class _2Nd_Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model 2nd branchial arch mesenchyme derived from neural crest"""

    name: Literal[
        "2nd branchial arch mesenchyme derived from neural crest"
    ] = "2nd branchial arch mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16281"] = "EMAPA_16281"


class _Pericardio_Peritoneal_Canal(_MouseAnatomicalStructureModel):
    """Model pericardio-peritoneal canal"""

    name: Literal["pericardio-peritoneal canal"] = "pericardio-peritoneal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16282"] = "EMAPA_16282"


class _Pericardio_Peritoneal_Canal_Cavity(_MouseAnatomicalStructureModel):
    """Model pericardio-peritoneal canal cavity"""

    name: Literal["pericardio-peritoneal canal cavity"] = "pericardio-peritoneal canal cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16283"] = "EMAPA_16283"


class _Pericardio_Peritoneal_Canal_Mesothelium(_MouseAnatomicalStructureModel):
    """Model pericardio-peritoneal canal mesothelium"""

    name: Literal["pericardio-peritoneal canal mesothelium"] = "pericardio-peritoneal canal mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16284"] = "EMAPA_16284"


class _Future_Midbrain_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model future midbrain roof plate"""

    name: Literal["future midbrain roof plate"] = "future midbrain roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16285"] = "EMAPA_16285"


class _Future_Hindbrain_Posterior_To_Rhombomere_5(_MouseAnatomicalStructureModel):
    """Model future hindbrain posterior to rhombomere 5"""

    name: Literal["future hindbrain posterior to rhombomere 5"] = "future hindbrain posterior to rhombomere 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16286"] = "EMAPA_16286"


class _Future_Hindbrain_Posterior_To_Rhombomere_5_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model future hindbrain posterior to rhombomere 5 floor plate"""

    name: Literal[
        "future hindbrain posterior to rhombomere 5 floor plate"
    ] = "future hindbrain posterior to rhombomere 5 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16287"] = "EMAPA_16287"


class _Future_Hindbrain_Posterior_To_Rhombomere_5_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model future hindbrain posterior to rhombomere 5 neural fold"""

    name: Literal[
        "future hindbrain posterior to rhombomere 5 neural fold"
    ] = "future hindbrain posterior to rhombomere 5 neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16288"] = "EMAPA_16288"


class _Future_Hindbrain_Posterior_To_Rhombomere_5_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model future hindbrain posterior to rhombomere 5 neural crest"""

    name: Literal[
        "future hindbrain posterior to rhombomere 5 neural crest"
    ] = "future hindbrain posterior to rhombomere 5 neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16289"] = "EMAPA_16289"


class _Rhombomere_1(_MouseAnatomicalStructureModel):
    """Model rhombomere 1"""

    name: Literal["rhombomere 1"] = "rhombomere 1"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16290"] = "EMAPA_16290"


class _Rhombomere_1_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 floor plate"""

    name: Literal["rhombomere 1 floor plate"] = "rhombomere 1 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16291"] = "EMAPA_16291"


class _Rhombomere_1_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 neural fold"""

    name: Literal["rhombomere 1 neural fold"] = "rhombomere 1 neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16292"] = "EMAPA_16292"


class _Rhombomere_2(_MouseAnatomicalStructureModel):
    """Model rhombomere 2"""

    name: Literal["rhombomere 2"] = "rhombomere 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16293"] = "EMAPA_16293"


class _Rhombomere_2_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 floor plate"""

    name: Literal["rhombomere 2 floor plate"] = "rhombomere 2 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16294"] = "EMAPA_16294"


class _Rhombomere_2_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 neural fold"""

    name: Literal["rhombomere 2 neural fold"] = "rhombomere 2 neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16295"] = "EMAPA_16295"


class _Rhombomere_2_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 neural crest"""

    name: Literal["rhombomere 2 neural crest"] = "rhombomere 2 neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16296"] = "EMAPA_16296"


class _Rhombomere_3(_MouseAnatomicalStructureModel):
    """Model rhombomere 3"""

    name: Literal["rhombomere 3"] = "rhombomere 3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16297"] = "EMAPA_16297"


class _Rhombomere_3_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 floor plate"""

    name: Literal["rhombomere 3 floor plate"] = "rhombomere 3 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16298"] = "EMAPA_16298"


class _Rhombomere_3_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 neural fold"""

    name: Literal["rhombomere 3 neural fold"] = "rhombomere 3 neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16299"] = "EMAPA_16299"


class _Rhombomere_3_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 neural crest"""

    name: Literal["rhombomere 3 neural crest"] = "rhombomere 3 neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16300"] = "EMAPA_16300"


class _Rhombomere_4(_MouseAnatomicalStructureModel):
    """Model rhombomere 4"""

    name: Literal["rhombomere 4"] = "rhombomere 4"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16301"] = "EMAPA_16301"


class _Rhombomere_4_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 floor plate"""

    name: Literal["rhombomere 4 floor plate"] = "rhombomere 4 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16302"] = "EMAPA_16302"


class _Rhombomere_4_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 neural fold"""

    name: Literal["rhombomere 4 neural fold"] = "rhombomere 4 neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16303"] = "EMAPA_16303"


class _Rhombomere_4_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 neural crest"""

    name: Literal["rhombomere 4 neural crest"] = "rhombomere 4 neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16304"] = "EMAPA_16304"


class _Rhombomere_5(_MouseAnatomicalStructureModel):
    """Model rhombomere 5"""

    name: Literal["rhombomere 5"] = "rhombomere 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16305"] = "EMAPA_16305"


class _Rhombomere_5_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 floor plate"""

    name: Literal["rhombomere 5 floor plate"] = "rhombomere 5 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16306"] = "EMAPA_16306"


class _Rhombomere_5_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 neural fold"""

    name: Literal["rhombomere 5 neural fold"] = "rhombomere 5 neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16307"] = "EMAPA_16307"


class _Rhombomere_5_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 neural crest"""

    name: Literal["rhombomere 5 neural crest"] = "rhombomere 5 neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16308"] = "EMAPA_16308"


class _Rhombomere_1_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 neural crest"""

    name: Literal["rhombomere 1 neural crest"] = "rhombomere 1 neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16309"] = "EMAPA_16309"


class _Neural_Luminal_Occlusion(_MouseAnatomicalStructureModel):
    """Model neural luminal occlusion"""

    name: Literal["neural luminal occlusion"] = "neural luminal occlusion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16310"] = "EMAPA_16310"


class _Facial_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model facial neural crest"""

    name: Literal["facial neural crest"] = "facial neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16311"] = "EMAPA_16311"


class _Facio_Acoustic_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model facio-acoustic neural crest"""

    name: Literal["facio-acoustic neural crest"] = "facio-acoustic neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16312"] = "EMAPA_16312"


class _Somite_09(_MouseAnatomicalStructureModel):
    """Model somite 09"""

    name: Literal["somite 09"] = "somite 09"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16313"] = "EMAPA_16313"


class _Somite_10(_MouseAnatomicalStructureModel):
    """Model somite 10"""

    name: Literal["somite 10"] = "somite 10"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16314"] = "EMAPA_16314"


class _Somite_11(_MouseAnatomicalStructureModel):
    """Model somite 11"""

    name: Literal["somite 11"] = "somite 11"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16315"] = "EMAPA_16315"


class _Somite_12(_MouseAnatomicalStructureModel):
    """Model somite 12"""

    name: Literal["somite 12"] = "somite 12"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16316"] = "EMAPA_16316"


class _Somite_13(_MouseAnatomicalStructureModel):
    """Model somite 13"""

    name: Literal["somite 13"] = "somite 13"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16317"] = "EMAPA_16317"


class _Septum_Transversum(_MouseAnatomicalStructureModel):
    """Model septum transversum"""

    name: Literal["septum transversum"] = "septum transversum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16318"] = "EMAPA_16318"


class _Septum_Transversum_Hepatic_Component(_MouseAnatomicalStructureModel):
    """Model septum transversum hepatic component"""

    name: Literal["septum transversum hepatic component"] = "septum transversum hepatic component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16319"] = "EMAPA_16319"


class _Septum_Transversum_Non_Hepatic_Component(_MouseAnatomicalStructureModel):
    """Model septum transversum non-hepatic component"""

    name: Literal["septum transversum non-hepatic component"] = "septum transversum non-hepatic component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16320"] = "EMAPA_16320"


class _Optic_Eminence(_MouseAnatomicalStructureModel):
    """Model optic eminence"""

    name: Literal["optic eminence"] = "optic eminence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16322"] = "EMAPA_16322"


class _Optic_Eminence_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model optic eminence mesenchyme"""

    name: Literal["optic eminence mesenchyme"] = "optic eminence mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16324"] = "EMAPA_16324"


class _Optic_Pit(_MouseAnatomicalStructureModel):
    """Model optic pit"""

    name: Literal["optic pit"] = "optic pit"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16325"] = "EMAPA_16325"


class _Optic_Pit_Neural_Ectoderm(_MouseAnatomicalStructureModel):
    """Model optic pit neural ectoderm"""

    name: Literal["optic pit neural ectoderm"] = "optic pit neural ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16326"] = "EMAPA_16326"


class _Common_Dorsal_Aorta(_MouseAnatomicalStructureModel):
    """Model common dorsal aorta"""

    name: Literal["common dorsal aorta"] = "common dorsal aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16327"] = "EMAPA_16327"


class _Internal_Carotid_Artery(_MouseAnatomicalStructureModel):
    """Model internal carotid artery"""

    name: Literal["internal carotid artery"] = "internal carotid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16328"] = "EMAPA_16328"


class _Left_Internal_Carotid_Artery(_MouseAnatomicalStructureModel):
    """Model left internal carotid artery"""

    name: Literal["left internal carotid artery"] = "left internal carotid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16329"] = "EMAPA_16329"


class _Right_Internal_Carotid_Artery(_MouseAnatomicalStructureModel):
    """Model right internal carotid artery"""

    name: Literal["right internal carotid artery"] = "right internal carotid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16330"] = "EMAPA_16330"


class _Umbilical_Artery_Embryonic_Part(_MouseAnatomicalStructureModel):
    """Model umbilical artery embryonic part"""

    name: Literal["umbilical artery embryonic part"] = "umbilical artery embryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16331"] = "EMAPA_16331"


class _Blood(_MouseAnatomicalStructureModel):
    """Model blood"""

    name: Literal["blood"] = "blood"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16332"] = "EMAPA_16332"


class _Bulbus_Cordis(_MouseAnatomicalStructureModel):
    """Model bulbus cordis"""

    name: Literal["bulbus cordis"] = "bulbus cordis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16333"] = "EMAPA_16333"


class _Bulbus_Cordis_Caudal_Half(_MouseAnatomicalStructureModel):
    """Model bulbus cordis caudal half"""

    name: Literal["bulbus cordis caudal half"] = "bulbus cordis caudal half"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16334"] = "EMAPA_16334"


class _Bulbus_Cordis_Caudal_Half_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model bulbus cordis caudal half cardiac jelly"""

    name: Literal["bulbus cordis caudal half cardiac jelly"] = "bulbus cordis caudal half cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16335"] = "EMAPA_16335"


class _Bulbus_Cordis_Caudal_Half_Endocardial_Tube(_MouseAnatomicalStructureModel):
    """Model bulbus cordis caudal half endocardial tube"""

    name: Literal["bulbus cordis caudal half endocardial tube"] = "bulbus cordis caudal half endocardial tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16336"] = "EMAPA_16336"


class _Bulbus_Cordis_Caudal_Half_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model bulbus cordis caudal half cardiac muscle"""

    name: Literal["bulbus cordis caudal half cardiac muscle"] = "bulbus cordis caudal half cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16337"] = "EMAPA_16337"


class _Bulbus_Cordis_Rostral_Half(_MouseAnatomicalStructureModel):
    """Model bulbus cordis rostral half"""

    name: Literal["bulbus cordis rostral half"] = "bulbus cordis rostral half"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16338"] = "EMAPA_16338"


class _Bulbus_Cordis_Rostral_Half_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model bulbus cordis rostral half cardiac jelly"""

    name: Literal["bulbus cordis rostral half cardiac jelly"] = "bulbus cordis rostral half cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16339"] = "EMAPA_16339"


class _Bulbus_Cordis_Rostral_Half_Endocardial_Tube(_MouseAnatomicalStructureModel):
    """Model bulbus cordis rostral half endocardial tube"""

    name: Literal["bulbus cordis rostral half endocardial tube"] = "bulbus cordis rostral half endocardial tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16340"] = "EMAPA_16340"


class _Bulbus_Cordis_Rostral_Half_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model bulbus cordis rostral half cardiac muscle"""

    name: Literal["bulbus cordis rostral half cardiac muscle"] = "bulbus cordis rostral half cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16341"] = "EMAPA_16341"


class _Common_Atrial_Chamber(_MouseAnatomicalStructureModel):
    """Model common atrial chamber"""

    name: Literal["common atrial chamber"] = "common atrial chamber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16342"] = "EMAPA_16342"


class _Common_Atrial_Chamber_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model common atrial chamber cardiac jelly"""

    name: Literal["common atrial chamber cardiac jelly"] = "common atrial chamber cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16343"] = "EMAPA_16343"


class _Common_Atrial_Chamber_Endocardial_Tube(_MouseAnatomicalStructureModel):
    """Model common atrial chamber endocardial tube"""

    name: Literal["common atrial chamber endocardial tube"] = "common atrial chamber endocardial tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16344"] = "EMAPA_16344"


class _Common_Atrial_Chamber_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model common atrial chamber cardiac muscle"""

    name: Literal["common atrial chamber cardiac muscle"] = "common atrial chamber cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16345"] = "EMAPA_16345"


class _Outflow_Tract(_MouseAnatomicalStructureModel):
    """Model outflow tract"""

    name: Literal["outflow tract"] = "outflow tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16346"] = "EMAPA_16346"


class _Outflow_Tract_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model outflow tract cardiac jelly"""

    name: Literal["outflow tract cardiac jelly"] = "outflow tract cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16347"] = "EMAPA_16347"


class _Outflow_Tract_Endocardial_Tube(_MouseAnatomicalStructureModel):
    """Model outflow tract endocardial tube"""

    name: Literal["outflow tract endocardial tube"] = "outflow tract endocardial tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16348"] = "EMAPA_16348"


class _Outflow_Tract_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model outflow tract mesenchyme"""

    name: Literal["outflow tract mesenchyme"] = "outflow tract mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16349"] = "EMAPA_16349"


class _Primitive_Ventricle(_MouseAnatomicalStructureModel):
    """Model primitive ventricle"""

    name: Literal["primitive ventricle"] = "primitive ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16350"] = "EMAPA_16350"


class _Primitive_Ventricle_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model primitive ventricle cardiac jelly"""

    name: Literal["primitive ventricle cardiac jelly"] = "primitive ventricle cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16351"] = "EMAPA_16351"


class _Primitive_Ventricle_Endocardial_Tube(_MouseAnatomicalStructureModel):
    """Model primitive ventricle endocardial tube"""

    name: Literal["primitive ventricle endocardial tube"] = "primitive ventricle endocardial tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16352"] = "EMAPA_16352"


class _Primitive_Ventricle_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model primitive ventricle cardiac muscle"""

    name: Literal["primitive ventricle cardiac muscle"] = "primitive ventricle cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16353"] = "EMAPA_16353"


class _Cardinal_Vein(_MouseAnatomicalStructureModel):
    """Model cardinal vein"""

    name: Literal["cardinal vein"] = "cardinal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16354"] = "EMAPA_16354"


class _Common_Cardinal_Vein(_MouseAnatomicalStructureModel):
    """Model common cardinal vein"""

    name: Literal["common cardinal vein"] = "common cardinal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16356"] = "EMAPA_16356"


class _Posterior_Cardinal_Vein(_MouseAnatomicalStructureModel):
    """Model posterior cardinal vein"""

    name: Literal["posterior cardinal vein"] = "posterior cardinal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16357"] = "EMAPA_16357"


class _Left_Umbilical_Vein_Embryonic_Part(_MouseAnatomicalStructureModel):
    """Model left umbilical vein embryonic part"""

    name: Literal["left umbilical vein embryonic part"] = "left umbilical vein embryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16358"] = "EMAPA_16358"


class _Right_Umbilical_Vein_Embryonic_Part(_MouseAnatomicalStructureModel):
    """Model right umbilical vein embryonic part"""

    name: Literal["right umbilical vein embryonic part"] = "right umbilical vein embryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16359"] = "EMAPA_16359"


class _Thyroid_Primordium(_MouseAnatomicalStructureModel):
    """Model thyroid primordium"""

    name: Literal["thyroid primordium"] = "thyroid primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16361"] = "EMAPA_16361"


class _Thyroid_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model thyroid primordium mesenchyme"""

    name: Literal["thyroid primordium mesenchyme"] = "thyroid primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16362"] = "EMAPA_16362"


class _Foregut_Midgut_Junction(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction"""

    name: Literal["foregut-midgut junction"] = "foregut-midgut junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16363"] = "EMAPA_16363"


class _Foregut_Midgut_Junction_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction mesenchyme"""

    name: Literal["foregut-midgut junction mesenchyme"] = "foregut-midgut junction mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16364"] = "EMAPA_16364"


class _Foregut_Midgut_Junction_Mesentery(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction mesentery"""

    name: Literal["foregut-midgut junction mesentery"] = "foregut-midgut junction mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16365"] = "EMAPA_16365"


class _Foregut_Midgut_Junction_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction dorsal mesentery"""

    name: Literal["foregut-midgut junction dorsal mesentery"] = "foregut-midgut junction dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16366"] = "EMAPA_16366"


class _Genitourinary_System(_MouseAnatomicalStructureModel):
    """Model genitourinary system"""

    name: Literal["genitourinary system"] = "genitourinary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16367"] = "EMAPA_16367"


class _Nephrogenic_Cord(_MouseAnatomicalStructureModel):
    """Model nephrogenic cord"""

    name: Literal["nephrogenic cord"] = "nephrogenic cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16368"] = "EMAPA_16368"


class _Presumptive_Nephric_Duct(_MouseAnatomicalStructureModel):
    """Model presumptive nephric duct"""

    name: Literal["presumptive nephric duct"] = "presumptive nephric duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16369"] = "EMAPA_16369"


class _Extraembryonic_Vascular_System(_MouseAnatomicalStructureModel):
    """Model extraembryonic vascular system"""

    name: Literal["extraembryonic vascular system"] = "extraembryonic vascular system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16370"] = "EMAPA_16370"


class _Extraembryonic_Arterial_System(_MouseAnatomicalStructureModel):
    """Model extraembryonic arterial system"""

    name: Literal["extraembryonic arterial system"] = "extraembryonic arterial system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16371"] = "EMAPA_16371"


class _Umbilical_Artery_Extraembryonic_Part(_MouseAnatomicalStructureModel):
    """Model umbilical artery extraembryonic part"""

    name: Literal["umbilical artery extraembryonic part"] = "umbilical artery extraembryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16372"] = "EMAPA_16372"


class _Common_Umbilical_Artery(_MouseAnatomicalStructureModel):
    """Model common umbilical artery"""

    name: Literal["common umbilical artery"] = "common umbilical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16373"] = "EMAPA_16373"


class _Extraembryonic_Venous_System(_MouseAnatomicalStructureModel):
    """Model extraembryonic venous system"""

    name: Literal["extraembryonic venous system"] = "extraembryonic venous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16374"] = "EMAPA_16374"


class _Umbilical_Vein_Extraembryonic_Part(_MouseAnatomicalStructureModel):
    """Model umbilical vein extraembryonic part"""

    name: Literal["umbilical vein extraembryonic part"] = "umbilical vein extraembryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16375"] = "EMAPA_16375"


class _Common_Umbilical_Vein(_MouseAnatomicalStructureModel):
    """Model common umbilical vein"""

    name: Literal["common umbilical vein"] = "common umbilical vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16376"] = "EMAPA_16376"


class _Left_Umbilical_Vein_Extraembryonic_Part(_MouseAnatomicalStructureModel):
    """Model left umbilical vein extraembryonic part"""

    name: Literal["left umbilical vein extraembryonic part"] = "left umbilical vein extraembryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16377"] = "EMAPA_16377"


class _Right_Umbilical_Vein_Extraembryonic_Part(_MouseAnatomicalStructureModel):
    """Model right umbilical vein extraembryonic part"""

    name: Literal["right umbilical vein extraembryonic part"] = "right umbilical vein extraembryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16378"] = "EMAPA_16378"


class _Vitelline_Vein_Extraembryonic_Part(_MouseAnatomicalStructureModel):
    """Model vitelline vein extraembryonic part"""

    name: Literal["vitelline vein extraembryonic part"] = "vitelline vein extraembryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16379"] = "EMAPA_16379"


class _Left_Vitelline_Vein_Extraembryonic_Part(_MouseAnatomicalStructureModel):
    """Model left vitelline vein extraembryonic part"""

    name: Literal["left vitelline vein extraembryonic part"] = "left vitelline vein extraembryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16380"] = "EMAPA_16380"


class _Right_Vitelline_Vein_Extraembryonic_Part(_MouseAnatomicalStructureModel):
    """Model right vitelline vein extraembryonic part"""

    name: Literal["right vitelline vein extraembryonic part"] = "right vitelline vein extraembryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16381"] = "EMAPA_16381"


class _1St_Branchial_Arch_Mandibular_Component(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mandibular component"""

    name: Literal["1st branchial arch mandibular component"] = "1st branchial arch mandibular component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16382"] = "EMAPA_16382"


class _1St_Branchial_Arch_Mandibular_Component_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mandibular component ectoderm"""

    name: Literal[
        "1st branchial arch mandibular component ectoderm"
    ] = "1st branchial arch mandibular component ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16383"] = "EMAPA_16383"


class _1St_Branchial_Arch_Mandibular_Component_Endoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mandibular component endoderm"""

    name: Literal[
        "1st branchial arch mandibular component endoderm"
    ] = "1st branchial arch mandibular component endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16384"] = "EMAPA_16384"


class _1St_Branchial_Arch_Mandibular_Component_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mandibular component mesenchyme"""

    name: Literal[
        "1st branchial arch mandibular component mesenchyme"
    ] = "1st branchial arch mandibular component mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16385"] = "EMAPA_16385"


class _1St_Branchial_Arch_Mandibular_Component_Mesenchyme_Derived_From_Head_Mesoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mandibular component mesenchyme derived from head mesoderm"""

    name: Literal[
        "1st branchial arch mandibular component mesenchyme derived from head mesoderm"
    ] = "1st branchial arch mandibular component mesenchyme derived from head mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16386"] = "EMAPA_16386"


class _1St_Branchial_Arch_Mandibular_Component_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch mandibular component mesenchyme derived from neural crest"""

    name: Literal[
        "1st branchial arch mandibular component mesenchyme derived from neural crest"
    ] = "1st branchial arch mandibular component mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16387"] = "EMAPA_16387"


class _1St_Branchial_Arch_Maxillary_Component(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch maxillary component"""

    name: Literal["1st branchial arch maxillary component"] = "1st branchial arch maxillary component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16388"] = "EMAPA_16388"


class _1St_Branchial_Arch_Maxillary_Component_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch maxillary component ectoderm"""

    name: Literal["1st branchial arch maxillary component ectoderm"] = "1st branchial arch maxillary component ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16389"] = "EMAPA_16389"


class _1St_Branchial_Arch_Maxillary_Component_Endoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch maxillary component endoderm"""

    name: Literal["1st branchial arch maxillary component endoderm"] = "1st branchial arch maxillary component endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16390"] = "EMAPA_16390"


class _1St_Branchial_Arch_Maxillary_Component_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch maxillary component mesenchyme"""

    name: Literal[
        "1st branchial arch maxillary component mesenchyme"
    ] = "1st branchial arch maxillary component mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16391"] = "EMAPA_16391"


class _1St_Branchial_Arch_Maxillary_Component_Mesenchyme_Derived_From_Head_Mesoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch maxillary component mesenchyme derived from head mesoderm"""

    name: Literal[
        "1st branchial arch maxillary component mesenchyme derived from head mesoderm"
    ] = "1st branchial arch maxillary component mesenchyme derived from head mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16392"] = "EMAPA_16392"


class _1St_Branchial_Arch_Maxillary_Component_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch maxillary component mesenchyme derived from neural crest"""

    name: Literal[
        "1st branchial arch maxillary component mesenchyme derived from neural crest"
    ] = "1st branchial arch maxillary component mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16393"] = "EMAPA_16393"


class _1St_Branchial_Arch_Maxillary_Mandibular_Groove(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch maxillary-mandibular groove"""

    name: Literal["1st branchial arch maxillary-mandibular groove"] = "1st branchial arch maxillary-mandibular groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16394"] = "EMAPA_16394"


class _1St_Branchial_Arch_Maxillary_Mandibular_Groove_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 1st branchial arch maxillary-mandibular groove ectoderm"""

    name: Literal[
        "1st branchial arch maxillary-mandibular groove ectoderm"
    ] = "1st branchial arch maxillary-mandibular groove ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16395"] = "EMAPA_16395"


class _2Nd_Branchial_Groove(_MouseAnatomicalStructureModel):
    """Model 2nd branchial groove"""

    name: Literal["2nd branchial groove"] = "2nd branchial groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16396"] = "EMAPA_16396"


class _2Nd_Branchial_Groove_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 2nd branchial groove ectoderm"""

    name: Literal["2nd branchial groove ectoderm"] = "2nd branchial groove ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16397"] = "EMAPA_16397"


class _2Nd_Branchial_Membrane_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 2nd branchial membrane ectoderm"""

    name: Literal["2nd branchial membrane ectoderm"] = "2nd branchial membrane ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16398"] = "EMAPA_16398"


class _3Rd_Branchial_Arch(_MouseAnatomicalStructureModel):
    """Model 3rd branchial arch"""

    name: Literal["3rd branchial arch"] = "3rd branchial arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16399"] = "EMAPA_16399"


class _3Rd_Branchial_Arch_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial arch ectoderm"""

    name: Literal["3rd branchial arch ectoderm"] = "3rd branchial arch ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16400"] = "EMAPA_16400"


class _3Rd_Branchial_Arch_Endoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial arch endoderm"""

    name: Literal["3rd branchial arch endoderm"] = "3rd branchial arch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16401"] = "EMAPA_16401"


class _3Rd_Branchial_Arch_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model 3rd branchial arch mesenchyme"""

    name: Literal["3rd branchial arch mesenchyme"] = "3rd branchial arch mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16402"] = "EMAPA_16402"


class _3Rd_Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial arch mesenchyme derived from head mesoderm"""

    name: Literal[
        "3rd branchial arch mesenchyme derived from head mesoderm"
    ] = "3rd branchial arch mesenchyme derived from head mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16403"] = "EMAPA_16403"


class _3Rd_Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model 3rd branchial arch mesenchyme derived from neural crest"""

    name: Literal[
        "3rd branchial arch mesenchyme derived from neural crest"
    ] = "3rd branchial arch mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16404"] = "EMAPA_16404"


class _Limb(_MouseAnatomicalStructureModel):
    """Model limb"""

    name: Literal["limb"] = "limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16405"] = "EMAPA_16405"


class _Forelimb_Bud(_MouseAnatomicalStructureModel):
    """Model forelimb bud"""

    name: Literal["forelimb bud"] = "forelimb bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16406"] = "EMAPA_16406"


class _Forelimb_Bud_Ectoderm(_MouseAnatomicalStructureModel):
    """Model forelimb bud ectoderm"""

    name: Literal["forelimb bud ectoderm"] = "forelimb bud ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16407"] = "EMAPA_16407"


class _Forelimb_Bud_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb bud mesenchyme"""

    name: Literal["forelimb bud mesenchyme"] = "forelimb bud mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16408"] = "EMAPA_16408"


class _Mesenchyme_Derived_From_Lateral_Plate(_MouseAnatomicalStructureModel):
    """Model mesenchyme derived from lateral plate"""

    name: Literal["mesenchyme derived from lateral plate"] = "mesenchyme derived from lateral plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16409"] = "EMAPA_16409"


class _Mesenchyme_Derived_From_Somatopleure(_MouseAnatomicalStructureModel):
    """Model mesenchyme derived from somatopleure"""

    name: Literal["mesenchyme derived from somatopleure"] = "mesenchyme derived from somatopleure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16410"] = "EMAPA_16410"


class _Mesenchyme_Derived_From_Splanchnopleure(_MouseAnatomicalStructureModel):
    """Model mesenchyme derived from splanchnopleure"""

    name: Literal["mesenchyme derived from splanchnopleure"] = "mesenchyme derived from splanchnopleure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16411"] = "EMAPA_16411"


class _Somite_05_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 05 dermomyotome"""

    name: Literal["somite 05 dermomyotome"] = "somite 05 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16414"] = "EMAPA_16414"


class _Somite_05_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 05 myocoele"""

    name: Literal["somite 05 myocoele"] = "somite 05 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16415"] = "EMAPA_16415"


class _Somite_05_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 05 sclerotome"""

    name: Literal["somite 05 sclerotome"] = "somite 05 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16416"] = "EMAPA_16416"


class _Somite_06_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 06 dermomyotome"""

    name: Literal["somite 06 dermomyotome"] = "somite 06 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16417"] = "EMAPA_16417"


class _Somite_06_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 06 myocoele"""

    name: Literal["somite 06 myocoele"] = "somite 06 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16418"] = "EMAPA_16418"


class _Somite_06_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 06 sclerotome"""

    name: Literal["somite 06 sclerotome"] = "somite 06 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16419"] = "EMAPA_16419"


class _Somite_07_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 07 dermomyotome"""

    name: Literal["somite 07 dermomyotome"] = "somite 07 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16420"] = "EMAPA_16420"


class _Somite_07_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 07 myocoele"""

    name: Literal["somite 07 myocoele"] = "somite 07 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16421"] = "EMAPA_16421"


class _Somite_07_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 07 sclerotome"""

    name: Literal["somite 07 sclerotome"] = "somite 07 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16422"] = "EMAPA_16422"


class _Somite_08_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 08 dermomyotome"""

    name: Literal["somite 08 dermomyotome"] = "somite 08 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16423"] = "EMAPA_16423"


class _Somite_08_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 08 myocoele"""

    name: Literal["somite 08 myocoele"] = "somite 08 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16424"] = "EMAPA_16424"


class _Somite_08_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 08 sclerotome"""

    name: Literal["somite 08 sclerotome"] = "somite 08 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16425"] = "EMAPA_16425"


class _Somite_09_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 09 dermomyotome"""

    name: Literal["somite 09 dermomyotome"] = "somite 09 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16426"] = "EMAPA_16426"


class _Somite_09_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 09 myocoele"""

    name: Literal["somite 09 myocoele"] = "somite 09 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16427"] = "EMAPA_16427"


class _Somite_09_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 09 sclerotome"""

    name: Literal["somite 09 sclerotome"] = "somite 09 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16428"] = "EMAPA_16428"


class _Somite_10_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 10 dermomyotome"""

    name: Literal["somite 10 dermomyotome"] = "somite 10 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16429"] = "EMAPA_16429"


class _Somite_10_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 10 myocoele"""

    name: Literal["somite 10 myocoele"] = "somite 10 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16430"] = "EMAPA_16430"


class _Somite_10_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 10 sclerotome"""

    name: Literal["somite 10 sclerotome"] = "somite 10 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16431"] = "EMAPA_16431"


class _Somite_11_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 11 dermomyotome"""

    name: Literal["somite 11 dermomyotome"] = "somite 11 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16432"] = "EMAPA_16432"


class _Somite_11_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 11 myocoele"""

    name: Literal["somite 11 myocoele"] = "somite 11 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16433"] = "EMAPA_16433"


class _Somite_11_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 11 sclerotome"""

    name: Literal["somite 11 sclerotome"] = "somite 11 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16434"] = "EMAPA_16434"


class _Somite_12_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 12 dermomyotome"""

    name: Literal["somite 12 dermomyotome"] = "somite 12 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16435"] = "EMAPA_16435"


class _Somite_12_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 12 myocoele"""

    name: Literal["somite 12 myocoele"] = "somite 12 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16436"] = "EMAPA_16436"


class _Somite_12_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 12 sclerotome"""

    name: Literal["somite 12 sclerotome"] = "somite 12 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16437"] = "EMAPA_16437"


class _Somite_13_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 13 dermomyotome"""

    name: Literal["somite 13 dermomyotome"] = "somite 13 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16438"] = "EMAPA_16438"


class _Somite_13_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 13 myocoele"""

    name: Literal["somite 13 myocoele"] = "somite 13 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16439"] = "EMAPA_16439"


class _Somite_13_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 13 sclerotome"""

    name: Literal["somite 13 sclerotome"] = "somite 13 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16440"] = "EMAPA_16440"


class _Somite_14(_MouseAnatomicalStructureModel):
    """Model somite 14"""

    name: Literal["somite 14"] = "somite 14"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16441"] = "EMAPA_16441"


class _Somite_14_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 14 dermomyotome"""

    name: Literal["somite 14 dermomyotome"] = "somite 14 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16442"] = "EMAPA_16442"


class _Somite_14_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 14 myocoele"""

    name: Literal["somite 14 myocoele"] = "somite 14 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16443"] = "EMAPA_16443"


class _Somite_14_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 14 sclerotome"""

    name: Literal["somite 14 sclerotome"] = "somite 14 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16444"] = "EMAPA_16444"


class _Somite_15(_MouseAnatomicalStructureModel):
    """Model somite 15"""

    name: Literal["somite 15"] = "somite 15"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16445"] = "EMAPA_16445"


class _Somite_15_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 15 dermomyotome"""

    name: Literal["somite 15 dermomyotome"] = "somite 15 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16446"] = "EMAPA_16446"


class _Somite_15_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 15 myocoele"""

    name: Literal["somite 15 myocoele"] = "somite 15 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16447"] = "EMAPA_16447"


class _Somite_15_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 15 sclerotome"""

    name: Literal["somite 15 sclerotome"] = "somite 15 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16448"] = "EMAPA_16448"


class _Somite_16(_MouseAnatomicalStructureModel):
    """Model somite 16"""

    name: Literal["somite 16"] = "somite 16"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16449"] = "EMAPA_16449"


class _Somite_16_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 16 dermomyotome"""

    name: Literal["somite 16 dermomyotome"] = "somite 16 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16450"] = "EMAPA_16450"


class _Somite_16_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 16 myocoele"""

    name: Literal["somite 16 myocoele"] = "somite 16 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16451"] = "EMAPA_16451"


class _Somite_16_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 16 sclerotome"""

    name: Literal["somite 16 sclerotome"] = "somite 16 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16452"] = "EMAPA_16452"


class _Somite_17(_MouseAnatomicalStructureModel):
    """Model somite 17"""

    name: Literal["somite 17"] = "somite 17"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16453"] = "EMAPA_16453"


class _Somite_17_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 17 dermomyotome"""

    name: Literal["somite 17 dermomyotome"] = "somite 17 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16454"] = "EMAPA_16454"


class _Somite_17_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 17 myocoele"""

    name: Literal["somite 17 myocoele"] = "somite 17 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16455"] = "EMAPA_16455"


class _Somite_17_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 17 sclerotome"""

    name: Literal["somite 17 sclerotome"] = "somite 17 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16456"] = "EMAPA_16456"


class _Somite_18(_MouseAnatomicalStructureModel):
    """Model somite 18"""

    name: Literal["somite 18"] = "somite 18"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16457"] = "EMAPA_16457"


class _Somite_18_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 18 dermomyotome"""

    name: Literal["somite 18 dermomyotome"] = "somite 18 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16458"] = "EMAPA_16458"


class _Somite_18_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 18 myocoele"""

    name: Literal["somite 18 myocoele"] = "somite 18 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16459"] = "EMAPA_16459"


class _Somite_18_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 18 sclerotome"""

    name: Literal["somite 18 sclerotome"] = "somite 18 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16460"] = "EMAPA_16460"


class _Somite_19(_MouseAnatomicalStructureModel):
    """Model somite 19"""

    name: Literal["somite 19"] = "somite 19"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16461"] = "EMAPA_16461"


class _Somite_19_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 19 dermomyotome"""

    name: Literal["somite 19 dermomyotome"] = "somite 19 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16462"] = "EMAPA_16462"


class _Somite_19_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 19 myocoele"""

    name: Literal["somite 19 myocoele"] = "somite 19 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16463"] = "EMAPA_16463"


class _Somite_19_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 19 sclerotome"""

    name: Literal["somite 19 sclerotome"] = "somite 19 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16464"] = "EMAPA_16464"


class _Somite_20(_MouseAnatomicalStructureModel):
    """Model somite 20"""

    name: Literal["somite 20"] = "somite 20"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16465"] = "EMAPA_16465"


class _Somite_20_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 20 dermomyotome"""

    name: Literal["somite 20 dermomyotome"] = "somite 20 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16466"] = "EMAPA_16466"


class _Somite_20_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 20 myocoele"""

    name: Literal["somite 20 myocoele"] = "somite 20 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16467"] = "EMAPA_16467"


class _Somite_20_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 20 sclerotome"""

    name: Literal["somite 20 sclerotome"] = "somite 20 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16468"] = "EMAPA_16468"


class _Nervous_System(_MouseAnatomicalStructureModel):
    """Model nervous system"""

    name: Literal["nervous system"] = "nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16469"] = "EMAPA_16469"


class _Central_Nervous_System(_MouseAnatomicalStructureModel):
    """Model central nervous system"""

    name: Literal["central nervous system"] = "central nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16470"] = "EMAPA_16470"


class _Future_Midbrain_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model future midbrain lateral wall"""

    name: Literal["future midbrain lateral wall"] = "future midbrain lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16474"] = "EMAPA_16474"


class _Rhombomere_1_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 lateral wall"""

    name: Literal["rhombomere 1 lateral wall"] = "rhombomere 1 lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16482"] = "EMAPA_16482"


class _Rhombomere_1_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 roof plate"""

    name: Literal["rhombomere 1 roof plate"] = "rhombomere 1 roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16483"] = "EMAPA_16483"


class _Rhombomere_2_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 lateral wall"""

    name: Literal["rhombomere 2 lateral wall"] = "rhombomere 2 lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16486"] = "EMAPA_16486"


class _Rhombomere_2_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 roof plate"""

    name: Literal["rhombomere 2 roof plate"] = "rhombomere 2 roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16487"] = "EMAPA_16487"


class _Rhombomere_3_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 lateral wall"""

    name: Literal["rhombomere 3 lateral wall"] = "rhombomere 3 lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16490"] = "EMAPA_16490"


class _Rhombomere_3_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 roof plate"""

    name: Literal["rhombomere 3 roof plate"] = "rhombomere 3 roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16491"] = "EMAPA_16491"


class _Rhombomere_4_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 lateral wall"""

    name: Literal["rhombomere 4 lateral wall"] = "rhombomere 4 lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16494"] = "EMAPA_16494"


class _Rhombomere_4_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 roof plate"""

    name: Literal["rhombomere 4 roof plate"] = "rhombomere 4 roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16495"] = "EMAPA_16495"


class _Rhombomere_5_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 lateral wall"""

    name: Literal["rhombomere 5 lateral wall"] = "rhombomere 5 lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16498"] = "EMAPA_16498"


class _Rhombomere_5_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 roof plate"""

    name: Literal["rhombomere 5 roof plate"] = "rhombomere 5 roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16499"] = "EMAPA_16499"


class _Rhombomere_6(_MouseAnatomicalStructureModel):
    """Model rhombomere 6"""

    name: Literal["rhombomere 6"] = "rhombomere 6"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16500"] = "EMAPA_16500"


class _Rhombomere_6_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 6 floor plate"""

    name: Literal["rhombomere 6 floor plate"] = "rhombomere 6 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16501"] = "EMAPA_16501"


class _Rhombomere_6_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere 6 lateral wall"""

    name: Literal["rhombomere 6 lateral wall"] = "rhombomere 6 lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16502"] = "EMAPA_16502"


class _Rhombomere_6_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 6 roof plate"""

    name: Literal["rhombomere 6 roof plate"] = "rhombomere 6 roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16503"] = "EMAPA_16503"


class _Rhombomere_7(_MouseAnatomicalStructureModel):
    """Model rhombomere 7"""

    name: Literal["rhombomere 7"] = "rhombomere 7"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16504"] = "EMAPA_16504"


class _Rhombomere_7_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 7 floor plate"""

    name: Literal["rhombomere 7 floor plate"] = "rhombomere 7 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16505"] = "EMAPA_16505"


class _Rhombomere_7_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere 7 lateral wall"""

    name: Literal["rhombomere 7 lateral wall"] = "rhombomere 7 lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16506"] = "EMAPA_16506"


class _Rhombomere_7_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 7 roof plate"""

    name: Literal["rhombomere 7 roof plate"] = "rhombomere 7 roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16507"] = "EMAPA_16507"


class _Rhombomere_8(_MouseAnatomicalStructureModel):
    """Model rhombomere 8"""

    name: Literal["rhombomere 8"] = "rhombomere 8"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16508"] = "EMAPA_16508"


class _Rhombomere_8_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 8 floor plate"""

    name: Literal["rhombomere 8 floor plate"] = "rhombomere 8 floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16509"] = "EMAPA_16509"


class _Rhombomere_8_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere 8 lateral wall"""

    name: Literal["rhombomere 8 lateral wall"] = "rhombomere 8 lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16510"] = "EMAPA_16510"


class _Rhombomere_8_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere 8 roof plate"""

    name: Literal["rhombomere 8 roof plate"] = "rhombomere 8 roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16511"] = "EMAPA_16511"


class _Prosencephalon(_MouseAnatomicalStructureModel):
    """Model prosencephalon"""

    name: Literal["prosencephalon"] = "prosencephalon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16512"] = "EMAPA_16512"


class _Prosencephalon_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model prosencephalon floor plate"""

    name: Literal["prosencephalon floor plate"] = "prosencephalon floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16513"] = "EMAPA_16513"


class _Future_Diencephalon(_MouseAnatomicalStructureModel):
    """Model future diencephalon"""

    name: Literal["future diencephalon"] = "future diencephalon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16514"] = "EMAPA_16514"


class _Future_Diencephalon_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model future diencephalon floor plate"""

    name: Literal["future diencephalon floor plate"] = "future diencephalon floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16516"] = "EMAPA_16516"


class _Future_Diencephalon_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model future diencephalon lateral wall"""

    name: Literal["future diencephalon lateral wall"] = "future diencephalon lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16517"] = "EMAPA_16517"


class _Future_Diencephalon_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model future diencephalon neural crest"""

    name: Literal["future diencephalon neural crest"] = "future diencephalon neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16518"] = "EMAPA_16518"


class _Future_Diencephalon_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model future diencephalon roof plate"""

    name: Literal["future diencephalon roof plate"] = "future diencephalon roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16519"] = "EMAPA_16519"


class _Prosencephalon_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model prosencephalon lateral wall"""

    name: Literal["prosencephalon lateral wall"] = "prosencephalon lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16520"] = "EMAPA_16520"


class _Prosencephalic_Vesicle(_MouseAnatomicalStructureModel):
    """Model prosencephalic vesicle"""

    name: Literal["prosencephalic vesicle"] = "prosencephalic vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16521"] = "EMAPA_16521"


class _Prosencephalon_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model prosencephalon roof plate"""

    name: Literal["prosencephalon roof plate"] = "prosencephalon roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16522"] = "EMAPA_16522"


class _Rostral_Neuropore(_MouseAnatomicalStructureModel):
    """Model rostral neuropore"""

    name: Literal["rostral neuropore"] = "rostral neuropore"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16523"] = "EMAPA_16523"


class _Prosencephalon_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model prosencephalon neural crest"""

    name: Literal["prosencephalon neural crest"] = "prosencephalon neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16524"] = "EMAPA_16524"


class _Caudal_Neuropore(_MouseAnatomicalStructureModel):
    """Model caudal neuropore"""

    name: Literal["caudal neuropore"] = "caudal neuropore"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16526"] = "EMAPA_16526"


class _Otic_Pit(_MouseAnatomicalStructureModel):
    """Model otic pit"""

    name: Literal["otic pit"] = "otic pit"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16536"] = "EMAPA_16536"


class _Otic_Pit_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model otic pit mesenchyme"""

    name: Literal["otic pit mesenchyme"] = "otic pit mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16537"] = "EMAPA_16537"


class _Otic_Pit_Epithelium(_MouseAnatomicalStructureModel):
    """Model otic pit epithelium"""

    name: Literal["otic pit epithelium"] = "otic pit epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16538"] = "EMAPA_16538"


class _Optic_Eminence_Surface_Ectoderm(_MouseAnatomicalStructureModel):
    """Model optic eminence surface ectoderm"""

    name: Literal["optic eminence surface ectoderm"] = "optic eminence surface ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16539"] = "EMAPA_16539"


class _Optic_Vesicle(_MouseAnatomicalStructureModel):
    """Model optic vesicle"""

    name: Literal["optic vesicle"] = "optic vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16540"] = "EMAPA_16540"


class _Optic_Vesicle_Neural_Ectoderm(_MouseAnatomicalStructureModel):
    """Model optic vesicle neural ectoderm"""

    name: Literal["optic vesicle neural ectoderm"] = "optic vesicle neural ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16541"] = "EMAPA_16541"


class _Nose(_MouseAnatomicalStructureModel):
    """Model nose"""

    name: Literal["nose"] = "nose"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16542"] = "EMAPA_16542"


class _Olfactory_Placode(_MouseAnatomicalStructureModel):
    """Model olfactory placode"""

    name: Literal["olfactory placode"] = "olfactory placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16543"] = "EMAPA_16543"


class _Left_Umbilical_Artery(_MouseAnatomicalStructureModel):
    """Model left umbilical artery"""

    name: Literal["left umbilical artery"] = "left umbilical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16544"] = "EMAPA_16544"


class _Right_Umbilical_Artery(_MouseAnatomicalStructureModel):
    """Model right umbilical artery"""

    name: Literal["right umbilical artery"] = "right umbilical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16545"] = "EMAPA_16545"


class _Atrioventricular_Canal(_MouseAnatomicalStructureModel):
    """Model atrioventricular canal"""

    name: Literal["atrioventricular canal"] = "atrioventricular canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16546"] = "EMAPA_16546"


class _Vessels_Connecting_Internal_Carotid_Artery_To_Primary_Head_Veins(_MouseAnatomicalStructureModel):
    """Model vessels connecting internal carotid artery to primary head veins"""

    name: Literal[
        "vessels connecting internal carotid artery to primary head veins"
    ] = "vessels connecting internal carotid artery to primary head veins"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16547"] = "EMAPA_16547"


class _Foregut(_MouseAnatomicalStructureModel):
    """Model foregut"""

    name: Literal["foregut"] = "foregut"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16548"] = "EMAPA_16548"


class _Pharyngeal_Region(_MouseAnatomicalStructureModel):
    """Model pharyngeal region"""

    name: Literal["pharyngeal region"] = "pharyngeal region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16549"] = "EMAPA_16549"


class _Pharyngeal_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model pharyngeal region mesenchyme"""

    name: Literal["pharyngeal region mesenchyme"] = "pharyngeal region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16550"] = "EMAPA_16550"


class _Pharyngeal_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model pharyngeal region epithelium"""

    name: Literal["pharyngeal region epithelium"] = "pharyngeal region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16551"] = "EMAPA_16551"


class _Pharyngeal_Region_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model pharyngeal region vascular element"""

    name: Literal["pharyngeal region vascular element"] = "pharyngeal region vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16552"] = "EMAPA_16552"


class _Foregut_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model foregut vascular element"""

    name: Literal["foregut vascular element"] = "foregut vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16556"] = "EMAPA_16556"


class _Foregut_Gland(_MouseAnatomicalStructureModel):
    """Model foregut gland"""

    name: Literal["foregut gland"] = "foregut gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16557"] = "EMAPA_16557"


class _Biliary_Bud(_MouseAnatomicalStructureModel):
    """Model biliary bud"""

    name: Literal["biliary bud"] = "biliary bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16561"] = "EMAPA_16561"


class _Biliary_Bud_Extrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model biliary bud extrahepatic part"""

    name: Literal["biliary bud extrahepatic part"] = "biliary bud extrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16562"] = "EMAPA_16562"


class _Biliary_Bud_Intrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model biliary bud intrahepatic part"""

    name: Literal["biliary bud intrahepatic part"] = "biliary bud intrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16563"] = "EMAPA_16563"


class _Foregut_Midgut_Junction_Epithelium(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction epithelium"""

    name: Literal["foregut-midgut junction epithelium"] = "foregut-midgut junction epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16564"] = "EMAPA_16564"


class _Foregut_Midgut_Junction_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction vascular element"""

    name: Literal["foregut-midgut junction vascular element"] = "foregut-midgut junction vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16566"] = "EMAPA_16566"


class _Hindgut_Diverticulum_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum epithelium"""

    name: Literal["hindgut diverticulum epithelium"] = "hindgut diverticulum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16567"] = "EMAPA_16567"


class _Hindgut_Diverticulum_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum vascular element"""

    name: Literal["hindgut diverticulum vascular element"] = "hindgut diverticulum vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16568"] = "EMAPA_16568"


class _Midgut_Epithelium(_MouseAnatomicalStructureModel):
    """Model midgut epithelium"""

    name: Literal["midgut epithelium"] = "midgut epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16569"] = "EMAPA_16569"


class _Midgut_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model midgut vascular element"""

    name: Literal["midgut vascular element"] = "midgut vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16570"] = "EMAPA_16570"


class _Stomatodeum_Gland(_MouseAnatomicalStructureModel):
    """Model stomatodeum gland"""

    name: Literal["stomatodeum gland"] = "stomatodeum gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16572"] = "EMAPA_16572"


class _Stomatodeum_Ectoderm(_MouseAnatomicalStructureModel):
    """Model stomatodeum ectoderm"""

    name: Literal["stomatodeum ectoderm"] = "stomatodeum ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16575"] = "EMAPA_16575"


class _Genitourinary_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model genitourinary system mesenchyme"""

    name: Literal["genitourinary system mesenchyme"] = "genitourinary system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16576"] = "EMAPA_16576"


class _Nephric_Duct(_MouseAnatomicalStructureModel):
    """Model nephric duct"""

    name: Literal["nephric duct"] = "nephric duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16577"] = "EMAPA_16577"


class _Primordial_Germ_Cell_Of_Gonad(_MouseAnatomicalStructureModel):
    """Model primordial germ cell of gonad"""

    name: Literal["primordial germ cell of gonad"] = "primordial germ cell of gonad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16578"] = "EMAPA_16578"


class _Pronephros(_MouseAnatomicalStructureModel):
    """Model pronephros"""

    name: Literal["pronephros"] = "pronephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16579"] = "EMAPA_16579"


class _Tail_Bud(_MouseAnatomicalStructureModel):
    """Model tail bud"""

    name: Literal["tail bud"] = "tail bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16580"] = "EMAPA_16580"


class _3Rd_Branchial_Groove(_MouseAnatomicalStructureModel):
    """Model 3rd branchial groove"""

    name: Literal["3rd branchial groove"] = "3rd branchial groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16581"] = "EMAPA_16581"


class _3Rd_Branchial_Groove_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial groove ectoderm"""

    name: Literal["3rd branchial groove ectoderm"] = "3rd branchial groove ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16582"] = "EMAPA_16582"


class _3Rd_Branchial_Membrane(_MouseAnatomicalStructureModel):
    """Model 3rd branchial membrane"""

    name: Literal["3rd branchial membrane"] = "3rd branchial membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16583"] = "EMAPA_16583"


class _3Rd_Branchial_Membrane_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial membrane ectoderm"""

    name: Literal["3rd branchial membrane ectoderm"] = "3rd branchial membrane ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16584"] = "EMAPA_16584"


class _3Rd_Branchial_Membrane_Endoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial membrane endoderm"""

    name: Literal["3rd branchial membrane endoderm"] = "3rd branchial membrane endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16585"] = "EMAPA_16585"


class _3Rd_Branchial_Pouch(_MouseAnatomicalStructureModel):
    """Model 3rd branchial pouch"""

    name: Literal["3rd branchial pouch"] = "3rd branchial pouch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16586"] = "EMAPA_16586"


class _3Rd_Branchial_Pouch_Endoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial pouch endoderm"""

    name: Literal["3rd branchial pouch endoderm"] = "3rd branchial pouch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16587"] = "EMAPA_16587"


class _Parietal_Pericardium(_MouseAnatomicalStructureModel):
    """Model parietal pericardium"""

    name: Literal["parietal pericardium"] = "parietal pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16588"] = "EMAPA_16588"


class _Visceral_Pericardium(_MouseAnatomicalStructureModel):
    """Model visceral pericardium"""

    name: Literal["visceral pericardium"] = "visceral pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16589"] = "EMAPA_16589"


class _Pericardio_Peritoneal_Canal_Parietal_Mesothelium(_MouseAnatomicalStructureModel):
    """Model pericardio-peritoneal canal parietal mesothelium"""

    name: Literal[
        "pericardio-peritoneal canal parietal mesothelium"
    ] = "pericardio-peritoneal canal parietal mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16590"] = "EMAPA_16590"


class _Peritoneum_Parietal_Mesothelium(_MouseAnatomicalStructureModel):
    """Model peritoneum parietal mesothelium"""

    name: Literal["peritoneum parietal mesothelium"] = "peritoneum parietal mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16591"] = "EMAPA_16591"


class _Peritoneum_Visceral_Mesothelium(_MouseAnatomicalStructureModel):
    """Model peritoneum visceral mesothelium"""

    name: Literal["peritoneum visceral mesothelium"] = "peritoneum visceral mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16592"] = "EMAPA_16592"


class _Hindlimb_Ridge(_MouseAnatomicalStructureModel):
    """Model hindlimb ridge"""

    name: Literal["hindlimb ridge"] = "hindlimb ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16593"] = "EMAPA_16593"


class _Hindlimb_Ridge_Ectoderm(_MouseAnatomicalStructureModel):
    """Model hindlimb ridge ectoderm"""

    name: Literal["hindlimb ridge ectoderm"] = "hindlimb ridge ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16594"] = "EMAPA_16594"


class _Hindlimb_Ridge_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb ridge mesenchyme"""

    name: Literal["hindlimb ridge mesenchyme"] = "hindlimb ridge mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16595"] = "EMAPA_16595"


class _Trunk_Mesenchyme_Derived_From_Neural_Crest_Lateral_Migration_Pathway(_MouseAnatomicalStructureModel):
    """Model trunk mesenchyme derived from neural crest lateral migration pathway"""

    name: Literal[
        "trunk mesenchyme derived from neural crest lateral migration pathway"
    ] = "trunk mesenchyme derived from neural crest lateral migration pathway"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16596"] = "EMAPA_16596"


class _Trunk_Mesenchyme_Derived_From_Neural_Crest_Medial_Migration_Pathway(_MouseAnatomicalStructureModel):
    """Model trunk mesenchyme derived from neural crest medial migration pathway"""

    name: Literal[
        "trunk mesenchyme derived from neural crest medial migration pathway"
    ] = "trunk mesenchyme derived from neural crest medial migration pathway"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16597"] = "EMAPA_16597"


class _Somite_21(_MouseAnatomicalStructureModel):
    """Model somite 21"""

    name: Literal["somite 21"] = "somite 21"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16600"] = "EMAPA_16600"


class _Somite_21_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 21 dermomyotome"""

    name: Literal["somite 21 dermomyotome"] = "somite 21 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16601"] = "EMAPA_16601"


class _Somite_21_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 21 myocoele"""

    name: Literal["somite 21 myocoele"] = "somite 21 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16602"] = "EMAPA_16602"


class _Somite_21_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 21 sclerotome"""

    name: Literal["somite 21 sclerotome"] = "somite 21 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16603"] = "EMAPA_16603"


class _Somite_22(_MouseAnatomicalStructureModel):
    """Model somite 22"""

    name: Literal["somite 22"] = "somite 22"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16604"] = "EMAPA_16604"


class _Somite_22_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 22 dermomyotome"""

    name: Literal["somite 22 dermomyotome"] = "somite 22 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16605"] = "EMAPA_16605"


class _Somite_22_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 22 myocoele"""

    name: Literal["somite 22 myocoele"] = "somite 22 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16606"] = "EMAPA_16606"


class _Somite_22_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 22 sclerotome"""

    name: Literal["somite 22 sclerotome"] = "somite 22 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16607"] = "EMAPA_16607"


class _Somite_23(_MouseAnatomicalStructureModel):
    """Model somite 23"""

    name: Literal["somite 23"] = "somite 23"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16608"] = "EMAPA_16608"


class _Somite_23_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 23 dermomyotome"""

    name: Literal["somite 23 dermomyotome"] = "somite 23 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16609"] = "EMAPA_16609"


class _Somite_23_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 23 myocoele"""

    name: Literal["somite 23 myocoele"] = "somite 23 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16610"] = "EMAPA_16610"


class _Somite_23_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 23 sclerotome"""

    name: Literal["somite 23 sclerotome"] = "somite 23 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16611"] = "EMAPA_16611"


class _Somite_24(_MouseAnatomicalStructureModel):
    """Model somite 24"""

    name: Literal["somite 24"] = "somite 24"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16612"] = "EMAPA_16612"


class _Somite_24_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 24 dermomyotome"""

    name: Literal["somite 24 dermomyotome"] = "somite 24 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16613"] = "EMAPA_16613"


class _Somite_24_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 24 myocoele"""

    name: Literal["somite 24 myocoele"] = "somite 24 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16614"] = "EMAPA_16614"


class _Somite_24_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 24 sclerotome"""

    name: Literal["somite 24 sclerotome"] = "somite 24 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16615"] = "EMAPA_16615"


class _Somite_25(_MouseAnatomicalStructureModel):
    """Model somite 25"""

    name: Literal["somite 25"] = "somite 25"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16616"] = "EMAPA_16616"


class _Somite_25_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 25 dermomyotome"""

    name: Literal["somite 25 dermomyotome"] = "somite 25 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16617"] = "EMAPA_16617"


class _Somite_25_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 25 myocoele"""

    name: Literal["somite 25 myocoele"] = "somite 25 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16618"] = "EMAPA_16618"


class _Somite_25_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 25 sclerotome"""

    name: Literal["somite 25 sclerotome"] = "somite 25 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16619"] = "EMAPA_16619"


class _Somite_26(_MouseAnatomicalStructureModel):
    """Model somite 26"""

    name: Literal["somite 26"] = "somite 26"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16620"] = "EMAPA_16620"


class _Somite_26_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 26 dermomyotome"""

    name: Literal["somite 26 dermomyotome"] = "somite 26 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16621"] = "EMAPA_16621"


class _Somite_26_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 26 myocoele"""

    name: Literal["somite 26 myocoele"] = "somite 26 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16622"] = "EMAPA_16622"


class _Somite_26_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 26 sclerotome"""

    name: Literal["somite 26 sclerotome"] = "somite 26 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16623"] = "EMAPA_16623"


class _Somite_27(_MouseAnatomicalStructureModel):
    """Model somite 27"""

    name: Literal["somite 27"] = "somite 27"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16624"] = "EMAPA_16624"


class _Somite_27_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 27 dermomyotome"""

    name: Literal["somite 27 dermomyotome"] = "somite 27 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16625"] = "EMAPA_16625"


class _Somite_27_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 27 myocoele"""

    name: Literal["somite 27 myocoele"] = "somite 27 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16626"] = "EMAPA_16626"


class _Somite_27_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 27 sclerotome"""

    name: Literal["somite 27 sclerotome"] = "somite 27 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16627"] = "EMAPA_16627"


class _Somite_28(_MouseAnatomicalStructureModel):
    """Model somite 28"""

    name: Literal["somite 28"] = "somite 28"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16628"] = "EMAPA_16628"


class _Somite_28_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 28 dermomyotome"""

    name: Literal["somite 28 dermomyotome"] = "somite 28 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16629"] = "EMAPA_16629"


class _Somite_28_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 28 myocoele"""

    name: Literal["somite 28 myocoele"] = "somite 28 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16630"] = "EMAPA_16630"


class _Somite_28_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 28 sclerotome"""

    name: Literal["somite 28 sclerotome"] = "somite 28 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16631"] = "EMAPA_16631"


class _Somite_29(_MouseAnatomicalStructureModel):
    """Model somite 29"""

    name: Literal["somite 29"] = "somite 29"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16632"] = "EMAPA_16632"


class _Somite_29_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 29 dermomyotome"""

    name: Literal["somite 29 dermomyotome"] = "somite 29 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16633"] = "EMAPA_16633"


class _Somite_29_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 29 myocoele"""

    name: Literal["somite 29 myocoele"] = "somite 29 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16634"] = "EMAPA_16634"


class _Somite_29_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 29 sclerotome"""

    name: Literal["somite 29 sclerotome"] = "somite 29 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16635"] = "EMAPA_16635"


class _Somite_30(_MouseAnatomicalStructureModel):
    """Model somite 30"""

    name: Literal["somite 30"] = "somite 30"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16636"] = "EMAPA_16636"


class _Somite_30_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 30 dermomyotome"""

    name: Literal["somite 30 dermomyotome"] = "somite 30 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16637"] = "EMAPA_16637"


class _Somite_30_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 30 myocoele"""

    name: Literal["somite 30 myocoele"] = "somite 30 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16638"] = "EMAPA_16638"


class _Somite_30_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 30 sclerotome"""

    name: Literal["somite 30 sclerotome"] = "somite 30 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16639"] = "EMAPA_16639"


class _Future_Forebrain(_MouseAnatomicalStructureModel):
    """Model future forebrain"""

    name: Literal["future forebrain"] = "future forebrain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16640"] = "EMAPA_16640"


class _Future_Neurohypophysis(_MouseAnatomicalStructureModel):
    """Model future neurohypophysis"""

    name: Literal["future neurohypophysis"] = "future neurohypophysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16647"] = "EMAPA_16647"


class _Telencephalic_Vesicle(_MouseAnatomicalStructureModel):
    """Model telencephalic vesicle"""

    name: Literal["telencephalic vesicle"] = "telencephalic vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16653"] = "EMAPA_16653"


class _Telencephalon_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model telencephalon floor plate"""

    name: Literal["telencephalon floor plate"] = "telencephalon floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16655"] = "EMAPA_16655"


class _Telencephalon_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model telencephalon lateral wall"""

    name: Literal["telencephalon lateral wall"] = "telencephalon lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16656"] = "EMAPA_16656"


class _Telencephalon_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model telencephalon roof plate"""

    name: Literal["telencephalon roof plate"] = "telencephalon roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16657"] = "EMAPA_16657"


class _Central_Nervous_System_Ganglion(_MouseAnatomicalStructureModel):
    """Model central nervous system ganglion"""

    name: Literal["central nervous system ganglion"] = "central nervous system ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16658"] = "EMAPA_16658"


class _Cranial_Ganglion(_MouseAnatomicalStructureModel):
    """Model cranial ganglion"""

    name: Literal["cranial ganglion"] = "cranial ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16659"] = "EMAPA_16659"


class _Facio_Acoustic_Preganglion_Complex(_MouseAnatomicalStructureModel):
    """Model facio-acoustic preganglion complex"""

    name: Literal["facio-acoustic preganglion complex"] = "facio-acoustic preganglion complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16660"] = "EMAPA_16660"


class _Glossopharyngeal_Preganglion(_MouseAnatomicalStructureModel):
    """Model glossopharyngeal preganglion"""

    name: Literal["glossopharyngeal preganglion"] = "glossopharyngeal preganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16661"] = "EMAPA_16661"


class _Glossopharyngeal_Vagus_Preganglion_Complex(_MouseAnatomicalStructureModel):
    """Model glossopharyngeal-vagus preganglion complex"""

    name: Literal["glossopharyngeal-vagus preganglion complex"] = "glossopharyngeal-vagus preganglion complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16662"] = "EMAPA_16662"


class _Trigeminal_Preganglion(_MouseAnatomicalStructureModel):
    """Model trigeminal preganglion"""

    name: Literal["trigeminal preganglion"] = "trigeminal preganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16663"] = "EMAPA_16663"


class _Vagus_Preganglion(_MouseAnatomicalStructureModel):
    """Model vagus preganglion"""

    name: Literal["vagus preganglion"] = "vagus preganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16664"] = "EMAPA_16664"


class _Peripheral_Nervous_System(_MouseAnatomicalStructureModel):
    """Model peripheral nervous system"""

    name: Literal["peripheral nervous system"] = "peripheral nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16665"] = "EMAPA_16665"


class _Spinal_Component_Of_Peripheral_Nervous_System(_MouseAnatomicalStructureModel):
    """Model spinal component of peripheral nervous system"""

    name: Literal["spinal component of peripheral nervous system"] = "spinal component of peripheral nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16666"] = "EMAPA_16666"


class _Spinal_Ganglion(_MouseAnatomicalStructureModel):
    """Model spinal ganglion"""

    name: Literal["spinal ganglion"] = "spinal ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16667"] = "EMAPA_16667"


class _Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model dorsal root ganglion"""

    name: Literal["dorsal root ganglion"] = "dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16668"] = "EMAPA_16668"


class _Otocyst(_MouseAnatomicalStructureModel):
    """Model otocyst"""

    name: Literal["otocyst"] = "otocyst"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16669"] = "EMAPA_16669"


class _Otocyst_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model otocyst mesenchyme"""

    name: Literal["otocyst mesenchyme"] = "otocyst mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16670"] = "EMAPA_16670"


class _Otocyst_Epithelium(_MouseAnatomicalStructureModel):
    """Model otocyst epithelium"""

    name: Literal["otocyst epithelium"] = "otocyst epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16671"] = "EMAPA_16671"


class _Lens_Placode(_MouseAnatomicalStructureModel):
    """Model lens placode"""

    name: Literal["lens placode"] = "lens placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16672"] = "EMAPA_16672"


class _Eye_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model eye mesenchyme"""

    name: Literal["eye mesenchyme"] = "eye mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16673"] = "EMAPA_16673"


class _Optic_Cup(_MouseAnatomicalStructureModel):
    """Model optic cup"""

    name: Literal["optic cup"] = "optic cup"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16674"] = "EMAPA_16674"


class _Optic_Cup_Inner_Layer(_MouseAnatomicalStructureModel):
    """Model optic cup inner layer"""

    name: Literal["optic cup inner layer"] = "optic cup inner layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16675"] = "EMAPA_16675"


class _Optic_Cup_Intraretinal_Space(_MouseAnatomicalStructureModel):
    """Model optic cup intraretinal space"""

    name: Literal["optic cup intraretinal space"] = "optic cup intraretinal space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16676"] = "EMAPA_16676"


class _Optic_Cup_Outer_Layer(_MouseAnatomicalStructureModel):
    """Model optic cup outer layer"""

    name: Literal["optic cup outer layer"] = "optic cup outer layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16677"] = "EMAPA_16677"


class _Optic_Stalk(_MouseAnatomicalStructureModel):
    """Model optic stalk"""

    name: Literal["optic stalk"] = "optic stalk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16678"] = "EMAPA_16678"


class _Naso_Lacrimal_Groove(_MouseAnatomicalStructureModel):
    """Model naso-lacrimal groove"""

    name: Literal["naso-lacrimal groove"] = "naso-lacrimal groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16679"] = "EMAPA_16679"


class _Nasal_Process(_MouseAnatomicalStructureModel):
    """Model nasal process"""

    name: Literal["nasal process"] = "nasal process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16680"] = "EMAPA_16680"


class _Fronto_Nasal_Process(_MouseAnatomicalStructureModel):
    """Model fronto-nasal process"""

    name: Literal["fronto-nasal process"] = "fronto-nasal process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16681"] = "EMAPA_16681"


class _Fronto_Nasal_Process_Ectoderm(_MouseAnatomicalStructureModel):
    """Model fronto-nasal process ectoderm"""

    name: Literal["fronto-nasal process ectoderm"] = "fronto-nasal process ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16682"] = "EMAPA_16682"


class _Fronto_Nasal_Process_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model fronto-nasal process mesenchyme"""

    name: Literal["fronto-nasal process mesenchyme"] = "fronto-nasal process mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16683"] = "EMAPA_16683"


class _Branchial_Arch_Artery(_MouseAnatomicalStructureModel):
    """Model branchial arch artery"""

    name: Literal["branchial arch artery"] = "branchial arch artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16684"] = "EMAPA_16684"


class _1St_Arch_Artery(_MouseAnatomicalStructureModel):
    """Model 1st arch artery"""

    name: Literal["1st arch artery"] = "1st arch artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16685"] = "EMAPA_16685"


class _2Nd_Arch_Artery(_MouseAnatomicalStructureModel):
    """Model 2nd arch artery"""

    name: Literal["2nd arch artery"] = "2nd arch artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16686"] = "EMAPA_16686"


class _3Rd_Arch_Artery(_MouseAnatomicalStructureModel):
    """Model 3rd arch artery"""

    name: Literal["3rd arch artery"] = "3rd arch artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16687"] = "EMAPA_16687"


class _Heart_Atrium(_MouseAnatomicalStructureModel):
    """Model heart atrium"""

    name: Literal["heart atrium"] = "heart atrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16688"] = "EMAPA_16688"


class _Common_Atrial_Chamber_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model common atrial chamber endocardial lining"""

    name: Literal["common atrial chamber endocardial lining"] = "common atrial chamber endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16691"] = "EMAPA_16691"


class _Bulboventricular_Groove(_MouseAnatomicalStructureModel):
    """Model bulboventricular groove"""

    name: Literal["bulboventricular groove"] = "bulboventricular groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16693"] = "EMAPA_16693"


class _Bulbus_Cordis_Caudal_Half_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model bulbus cordis caudal half endocardial lining"""

    name: Literal["bulbus cordis caudal half endocardial lining"] = "bulbus cordis caudal half endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16694"] = "EMAPA_16694"


class _Bulbus_Cordis_Rostral_Half_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model bulbus cordis rostral half endocardial lining"""

    name: Literal["bulbus cordis rostral half endocardial lining"] = "bulbus cordis rostral half endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16695"] = "EMAPA_16695"


class _Endocardial_Cushion(_MouseAnatomicalStructureModel):
    """Model endocardial cushion"""

    name: Literal["endocardial cushion"] = "endocardial cushion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16696"] = "EMAPA_16696"


class _Primitive_Ventricle_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model primitive ventricle endocardial lining"""

    name: Literal["primitive ventricle endocardial lining"] = "primitive ventricle endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16697"] = "EMAPA_16697"


class _Left_Vitelline_Vein_Embryonic_Part(_MouseAnatomicalStructureModel):
    """Model left vitelline vein embryonic part"""

    name: Literal["left vitelline vein embryonic part"] = "left vitelline vein embryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16698"] = "EMAPA_16698"


class _Right_Vitelline_Vein_Embryonic_Part(_MouseAnatomicalStructureModel):
    """Model right vitelline vein embryonic part"""

    name: Literal["right vitelline vein embryonic part"] = "right vitelline vein embryonic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16699"] = "EMAPA_16699"


class _Esophageal_Region(_MouseAnatomicalStructureModel):
    """Model esophageal region"""

    name: Literal["esophageal region"] = "esophageal region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16700"] = "EMAPA_16700"


class _Esophageal_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model esophageal region mesenchyme"""

    name: Literal["esophageal region mesenchyme"] = "esophageal region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16701"] = "EMAPA_16701"


class _Esophageal_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model esophageal region epithelium"""

    name: Literal["esophageal region epithelium"] = "esophageal region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16702"] = "EMAPA_16702"


class _Esophageal_Region_Mesentery(_MouseAnatomicalStructureModel):
    """Model esophageal region mesentery"""

    name: Literal["esophageal region mesentery"] = "esophageal region mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16703"] = "EMAPA_16703"


class _Dorsal_Meso_Esophagus(_MouseAnatomicalStructureModel):
    """Model dorsal meso-esophagus"""

    name: Literal["dorsal meso-esophagus"] = "dorsal meso-esophagus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16704"] = "EMAPA_16704"


class _Esophageal_Region_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model esophageal region vascular element"""

    name: Literal["esophageal region vascular element"] = "esophageal region vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16705"] = "EMAPA_16705"


class _Pharynx(_MouseAnatomicalStructureModel):
    """Model pharynx"""

    name: Literal["pharynx"] = "pharynx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16706"] = "EMAPA_16706"


class _Pharynx_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model pharynx mesenchyme"""

    name: Literal["pharynx mesenchyme"] = "pharynx mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16707"] = "EMAPA_16707"


class _Pharynx_Epithelium(_MouseAnatomicalStructureModel):
    """Model pharynx epithelium"""

    name: Literal["pharynx epithelium"] = "pharynx epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16708"] = "EMAPA_16708"


class _Pharynx_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model pharynx vascular element"""

    name: Literal["pharynx vascular element"] = "pharynx vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16709"] = "EMAPA_16709"


class _Foregut_Mesentery(_MouseAnatomicalStructureModel):
    """Model foregut mesentery"""

    name: Literal["foregut mesentery"] = "foregut mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16710"] = "EMAPA_16710"


class _Foregut_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model foregut dorsal mesentery"""

    name: Literal["foregut dorsal mesentery"] = "foregut dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16711"] = "EMAPA_16711"


class _Foregut_Ventral_Mesentery(_MouseAnatomicalStructureModel):
    """Model foregut ventral mesentery"""

    name: Literal["foregut ventral mesentery"] = "foregut ventral mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16712"] = "EMAPA_16712"


class _Gallbladder_Primordium(_MouseAnatomicalStructureModel):
    """Model gallbladder primordium"""

    name: Literal["gallbladder primordium"] = "gallbladder primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16713"] = "EMAPA_16713"


class _Foregut_Midgut_Junction_Ventral_Mesentery(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction ventral mesentery"""

    name: Literal["foregut-midgut junction ventral mesentery"] = "foregut-midgut junction ventral mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16714"] = "EMAPA_16714"


class _Hindgut(_MouseAnatomicalStructureModel):
    """Model hindgut"""

    name: Literal["hindgut"] = "hindgut"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16715"] = "EMAPA_16715"


class _Hindgut_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindgut mesenchyme"""

    name: Literal["hindgut mesenchyme"] = "hindgut mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16716"] = "EMAPA_16716"


class _Hindgut_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindgut epithelium"""

    name: Literal["hindgut epithelium"] = "hindgut epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16717"] = "EMAPA_16717"


class _Hindgut_Mesentery(_MouseAnatomicalStructureModel):
    """Model hindgut mesentery"""

    name: Literal["hindgut mesentery"] = "hindgut mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16718"] = "EMAPA_16718"


class _Hindgut_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model hindgut dorsal mesentery"""

    name: Literal["hindgut dorsal mesentery"] = "hindgut dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16719"] = "EMAPA_16719"


class _Hindgut_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model hindgut vascular element"""

    name: Literal["hindgut vascular element"] = "hindgut vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16720"] = "EMAPA_16720"


class _Midgut_Mesentery(_MouseAnatomicalStructureModel):
    """Model midgut mesentery"""

    name: Literal["midgut mesentery"] = "midgut mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16721"] = "EMAPA_16721"


class _Midgut_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model midgut dorsal mesentery"""

    name: Literal["midgut dorsal mesentery"] = "midgut dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16722"] = "EMAPA_16722"


class _Oral_Region_Gland(_MouseAnatomicalStructureModel):
    """Model oral region gland"""

    name: Literal["oral region gland"] = "oral region gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16723"] = "EMAPA_16723"


class _Future_Adenohypophysis(_MouseAnatomicalStructureModel):
    """Model future adenohypophysis"""

    name: Literal["future adenohypophysis"] = "future adenohypophysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16724"] = "EMAPA_16724"


class _Rathke_S_Pouch(_MouseAnatomicalStructureModel):
    """Model Rathke's pouch"""

    name: Literal["Rathke's pouch"] = "Rathke's pouch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16725"] = "EMAPA_16725"


class _Oral_Region_Ectoderm(_MouseAnatomicalStructureModel):
    """Model oral region ectoderm"""

    name: Literal["oral region ectoderm"] = "oral region ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16726"] = "EMAPA_16726"


class _Respiratory_System(_MouseAnatomicalStructureModel):
    """Model respiratory system"""

    name: Literal["respiratory system"] = "respiratory system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16727"] = "EMAPA_16727"


class _Lung(_MouseAnatomicalStructureModel):
    """Model lung"""

    name: Literal["lung"] = "lung"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16728"] = "EMAPA_16728"


class _Left_Lung_Rudiment(_MouseAnatomicalStructureModel):
    """Model left lung rudiment"""

    name: Literal["left lung rudiment"] = "left lung rudiment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16729"] = "EMAPA_16729"


class _Left_Lung_Rudiment_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model left lung rudiment mesenchyme"""

    name: Literal["left lung rudiment mesenchyme"] = "left lung rudiment mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16730"] = "EMAPA_16730"


class _Left_Lung_Rudiment_Epithelium(_MouseAnatomicalStructureModel):
    """Model left lung rudiment epithelium"""

    name: Literal["left lung rudiment epithelium"] = "left lung rudiment epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16731"] = "EMAPA_16731"


class _Left_Lung_Rudiment_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model left lung rudiment vascular element"""

    name: Literal["left lung rudiment vascular element"] = "left lung rudiment vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16732"] = "EMAPA_16732"


class _Right_Lung_Rudiment(_MouseAnatomicalStructureModel):
    """Model right lung rudiment"""

    name: Literal["right lung rudiment"] = "right lung rudiment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16733"] = "EMAPA_16733"


class _Right_Lung_Rudiment_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model right lung rudiment mesenchyme"""

    name: Literal["right lung rudiment mesenchyme"] = "right lung rudiment mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16734"] = "EMAPA_16734"


class _Right_Lung_Rudiment_Epithelium(_MouseAnatomicalStructureModel):
    """Model right lung rudiment epithelium"""

    name: Literal["right lung rudiment epithelium"] = "right lung rudiment epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16735"] = "EMAPA_16735"


class _Right_Lung_Rudiment_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung rudiment vascular element"""

    name: Literal["right lung rudiment vascular element"] = "right lung rudiment vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16736"] = "EMAPA_16736"


class _Respiratory_Tract(_MouseAnatomicalStructureModel):
    """Model respiratory tract"""

    name: Literal["respiratory tract"] = "respiratory tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16737"] = "EMAPA_16737"


class _Lower_Respiratory_Tract(_MouseAnatomicalStructureModel):
    """Model lower respiratory tract"""

    name: Literal["lower respiratory tract"] = "lower respiratory tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16738"] = "EMAPA_16738"


class _Laryngo_Tracheal_Groove(_MouseAnatomicalStructureModel):
    """Model laryngo-tracheal groove"""

    name: Literal["laryngo-tracheal groove"] = "laryngo-tracheal groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16739"] = "EMAPA_16739"


class _Tracheal_Diverticulum(_MouseAnatomicalStructureModel):
    """Model tracheal diverticulum"""

    name: Literal["tracheal diverticulum"] = "tracheal diverticulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16740"] = "EMAPA_16740"


class _Tracheal_Diverticulum_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model tracheal diverticulum mesenchyme"""

    name: Literal["tracheal diverticulum mesenchyme"] = "tracheal diverticulum mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16741"] = "EMAPA_16741"


class _Tracheal_Diverticulum_Epithelium(_MouseAnatomicalStructureModel):
    """Model tracheal diverticulum epithelium"""

    name: Literal["tracheal diverticulum epithelium"] = "tracheal diverticulum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16742"] = "EMAPA_16742"


class _Tracheal_Diverticulum_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model tracheal diverticulum vascular element"""

    name: Literal["tracheal diverticulum vascular element"] = "tracheal diverticulum vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16743"] = "EMAPA_16743"


class _Mesonephros(_MouseAnatomicalStructureModel):
    """Model mesonephros"""

    name: Literal["mesonephros"] = "mesonephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16744"] = "EMAPA_16744"


class _Mesonephros_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model mesonephros mesenchyme"""

    name: Literal["mesonephros mesenchyme"] = "mesonephros mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16745"] = "EMAPA_16745"


class _Mesonephric_Tubule(_MouseAnatomicalStructureModel):
    """Model mesonephric tubule"""

    name: Literal["mesonephric tubule"] = "mesonephric tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16747"] = "EMAPA_16747"


class _Tail(_MouseAnatomicalStructureModel):
    """Model tail"""

    name: Literal["tail"] = "tail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16748"] = "EMAPA_16748"


class _Tail_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model tail mesenchyme"""

    name: Literal["tail mesenchyme"] = "tail mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16749"] = "EMAPA_16749"


class _Tail_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model tail mesenchyme derived from neural crest"""

    name: Literal["tail mesenchyme derived from neural crest"] = "tail mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16750"] = "EMAPA_16750"


class _Tail_Paraxial_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model tail paraxial mesenchyme"""

    name: Literal["tail paraxial mesenchyme"] = "tail paraxial mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16751"] = "EMAPA_16751"


class _Tail_Unsegmented_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model tail unsegmented mesenchyme"""

    name: Literal["tail unsegmented mesenchyme"] = "tail unsegmented mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16752"] = "EMAPA_16752"


class _Tail_Nervous_System(_MouseAnatomicalStructureModel):
    """Model tail nervous system"""

    name: Literal["tail nervous system"] = "tail nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16753"] = "EMAPA_16753"


class _Tail_Central_Nervous_System(_MouseAnatomicalStructureModel):
    """Model tail central nervous system"""

    name: Literal["tail central nervous system"] = "tail central nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16754"] = "EMAPA_16754"


class _Tail_Future_Spinal_Cord(_MouseAnatomicalStructureModel):
    """Model tail future spinal cord"""

    name: Literal["tail future spinal cord"] = "tail future spinal cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16755"] = "EMAPA_16755"


class _Tail_Neural_Plate(_MouseAnatomicalStructureModel):
    """Model tail neural plate"""

    name: Literal["tail neural plate"] = "tail neural plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16756"] = "EMAPA_16756"


class _Tail_Neural_Tube(_MouseAnatomicalStructureModel):
    """Model tail neural tube"""

    name: Literal["tail neural tube"] = "tail neural tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16757"] = "EMAPA_16757"


class _3Rd_Branchial_Pouch_Dorsal_Endoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial pouch dorsal endoderm"""

    name: Literal["3rd branchial pouch dorsal endoderm"] = "3rd branchial pouch dorsal endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16758"] = "EMAPA_16758"


class _3Rd_Branchial_Pouch_Ventral_Endoderm(_MouseAnatomicalStructureModel):
    """Model 3rd branchial pouch ventral endoderm"""

    name: Literal["3rd branchial pouch ventral endoderm"] = "3rd branchial pouch ventral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16759"] = "EMAPA_16759"


class _4Th_Branchial_Arch(_MouseAnatomicalStructureModel):
    """Model 4th branchial arch"""

    name: Literal["4th branchial arch"] = "4th branchial arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16760"] = "EMAPA_16760"


class _4Th_Branchial_Groove(_MouseAnatomicalStructureModel):
    """Model 4th branchial groove"""

    name: Literal["4th branchial groove"] = "4th branchial groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16761"] = "EMAPA_16761"


class _4Th_Branchial_Groove_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 4th branchial groove ectoderm"""

    name: Literal["4th branchial groove ectoderm"] = "4th branchial groove ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16762"] = "EMAPA_16762"


class _4Th_Branchial_Membrane(_MouseAnatomicalStructureModel):
    """Model 4th branchial membrane"""

    name: Literal["4th branchial membrane"] = "4th branchial membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16763"] = "EMAPA_16763"


class _4Th_Branchial_Membrane_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 4th branchial membrane ectoderm"""

    name: Literal["4th branchial membrane ectoderm"] = "4th branchial membrane ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16764"] = "EMAPA_16764"


class _4Th_Branchial_Membrane_Endoderm(_MouseAnatomicalStructureModel):
    """Model 4th branchial membrane endoderm"""

    name: Literal["4th branchial membrane endoderm"] = "4th branchial membrane endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16765"] = "EMAPA_16765"


class _4Th_Branchial_Pouch(_MouseAnatomicalStructureModel):
    """Model 4th branchial pouch"""

    name: Literal["4th branchial pouch"] = "4th branchial pouch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16766"] = "EMAPA_16766"


class _4Th_Branchial_Pouch_Endoderm(_MouseAnatomicalStructureModel):
    """Model 4th branchial pouch endoderm"""

    name: Literal["4th branchial pouch endoderm"] = "4th branchial pouch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16767"] = "EMAPA_16767"


class _4Th_Branchial_Arch_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 4th branchial arch ectoderm"""

    name: Literal["4th branchial arch ectoderm"] = "4th branchial arch ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16768"] = "EMAPA_16768"


class _4Th_Branchial_Arch_Endoderm(_MouseAnatomicalStructureModel):
    """Model 4th branchial arch endoderm"""

    name: Literal["4th branchial arch endoderm"] = "4th branchial arch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16769"] = "EMAPA_16769"


class _4Th_Branchial_Arch_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model 4th branchial arch mesenchyme"""

    name: Literal["4th branchial arch mesenchyme"] = "4th branchial arch mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16770"] = "EMAPA_16770"


class _4Th_Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm(_MouseAnatomicalStructureModel):
    """Model 4th branchial arch mesenchyme derived from head mesoderm"""

    name: Literal[
        "4th branchial arch mesenchyme derived from head mesoderm"
    ] = "4th branchial arch mesenchyme derived from head mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16771"] = "EMAPA_16771"


class _4Th_Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model 4th branchial arch mesenchyme derived from neural crest"""

    name: Literal[
        "4th branchial arch mesenchyme derived from neural crest"
    ] = "4th branchial arch mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16772"] = "EMAPA_16772"


class _Pleural_Component(_MouseAnatomicalStructureModel):
    """Model pleural component"""

    name: Literal["pleural component"] = "pleural component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16773"] = "EMAPA_16773"


class _Pleural_Cavity(_MouseAnatomicalStructureModel):
    """Model pleural cavity"""

    name: Literal["pleural cavity"] = "pleural cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16774"] = "EMAPA_16774"


class _Pleura(_MouseAnatomicalStructureModel):
    """Model pleura"""

    name: Literal["pleura"] = "pleura"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16775"] = "EMAPA_16775"


class _Parietal_Pleura(_MouseAnatomicalStructureModel):
    """Model parietal pleura"""

    name: Literal["parietal pleura"] = "parietal pleura"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16776"] = "EMAPA_16776"


class _Visceral_Pleura(_MouseAnatomicalStructureModel):
    """Model visceral pleura"""

    name: Literal["visceral pleura"] = "visceral pleura"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16777"] = "EMAPA_16777"


class _Forelimb_Bud_Apical_Ectodermal_Ridge(_MouseAnatomicalStructureModel):
    """Model forelimb bud apical ectodermal ridge"""

    name: Literal["forelimb bud apical ectodermal ridge"] = "forelimb bud apical ectodermal ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16778"] = "EMAPA_16778"


class _Hindlimb_Bud(_MouseAnatomicalStructureModel):
    """Model hindlimb bud"""

    name: Literal["hindlimb bud"] = "hindlimb bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16779"] = "EMAPA_16779"


class _Hindlimb_Bud_Ectoderm(_MouseAnatomicalStructureModel):
    """Model hindlimb bud ectoderm"""

    name: Literal["hindlimb bud ectoderm"] = "hindlimb bud ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16780"] = "EMAPA_16780"


class _Hindlimb_Bud_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb bud mesenchyme"""

    name: Literal["hindlimb bud mesenchyme"] = "hindlimb bud mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16781"] = "EMAPA_16781"


class _Future_Midbrain_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model future midbrain ventricular layer"""

    name: Literal["future midbrain ventricular layer"] = "future midbrain ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16785"] = "EMAPA_16785"


class _Rhombomere_1_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 ventricular layer"""

    name: Literal["rhombomere 1 ventricular layer"] = "rhombomere 1 ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16786"] = "EMAPA_16786"


class _Rhombomere_2_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 ventricular layer"""

    name: Literal["rhombomere 2 ventricular layer"] = "rhombomere 2 ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16787"] = "EMAPA_16787"


class _Rhombomere_3_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 ventricular layer"""

    name: Literal["rhombomere 3 ventricular layer"] = "rhombomere 3 ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16788"] = "EMAPA_16788"


class _Rhombomere_4_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 ventricular layer"""

    name: Literal["rhombomere 4 ventricular layer"] = "rhombomere 4 ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16789"] = "EMAPA_16789"


class _Rhombomere_5_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 ventricular layer"""

    name: Literal["rhombomere 5 ventricular layer"] = "rhombomere 5 ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16790"] = "EMAPA_16790"


class _Rhombomere_6_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 6 ventricular layer"""

    name: Literal["rhombomere 6 ventricular layer"] = "rhombomere 6 ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16791"] = "EMAPA_16791"


class _Rhombomere_7_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 7 ventricular layer"""

    name: Literal["rhombomere 7 ventricular layer"] = "rhombomere 7 ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16792"] = "EMAPA_16792"


class _Rhombomere_8_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 8 ventricular layer"""

    name: Literal["rhombomere 8 ventricular layer"] = "rhombomere 8 ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16793"] = "EMAPA_16793"


class _Facio_Acoustic_Ganglion_Complex(_MouseAnatomicalStructureModel):
    """Model facio-acoustic ganglion complex"""

    name: Literal["facio-acoustic ganglion complex"] = "facio-acoustic ganglion complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16794"] = "EMAPA_16794"


class _Glossopharyngeal_Ganglion(_MouseAnatomicalStructureModel):
    """Model glossopharyngeal ganglion"""

    name: Literal["glossopharyngeal ganglion"] = "glossopharyngeal ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16795"] = "EMAPA_16795"


class _Glossopharyngeal_Vagus_Ganglion_Complex(_MouseAnatomicalStructureModel):
    """Model glossopharyngeal-vagus ganglion complex"""

    name: Literal["glossopharyngeal-vagus ganglion complex"] = "glossopharyngeal-vagus ganglion complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16796"] = "EMAPA_16796"


class _Trigeminal_Ganglion(_MouseAnatomicalStructureModel):
    """Model trigeminal ganglion"""

    name: Literal["trigeminal ganglion"] = "trigeminal ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16797"] = "EMAPA_16797"


class _Vagus_Ganglion(_MouseAnatomicalStructureModel):
    """Model vagus ganglion"""

    name: Literal["vagus ganglion"] = "vagus ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16798"] = "EMAPA_16798"


class _Lens_Pit(_MouseAnatomicalStructureModel):
    """Model lens pit"""

    name: Literal["lens pit"] = "lens pit"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16799"] = "EMAPA_16799"


class _Nasal_Pit(_MouseAnatomicalStructureModel):
    """Model nasal pit"""

    name: Literal["nasal pit"] = "nasal pit"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16800"] = "EMAPA_16800"


class _Nasal_Pit_Epithelium(_MouseAnatomicalStructureModel):
    """Model nasal pit epithelium"""

    name: Literal["nasal pit epithelium"] = "nasal pit epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16801"] = "EMAPA_16801"


class _Frontal_Process(_MouseAnatomicalStructureModel):
    """Model frontal process"""

    name: Literal["frontal process"] = "frontal process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16802"] = "EMAPA_16802"


class _Frontal_Process_Ectoderm(_MouseAnatomicalStructureModel):
    """Model frontal process ectoderm"""

    name: Literal["frontal process ectoderm"] = "frontal process ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16803"] = "EMAPA_16803"


class _Frontal_Process_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model frontal process mesenchyme"""

    name: Literal["frontal process mesenchyme"] = "frontal process mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16804"] = "EMAPA_16804"


class _Latero_Nasal_Process(_MouseAnatomicalStructureModel):
    """Model latero-nasal process"""

    name: Literal["latero-nasal process"] = "latero-nasal process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16805"] = "EMAPA_16805"


class _Latero_Nasal_Process_Ectoderm(_MouseAnatomicalStructureModel):
    """Model latero-nasal process ectoderm"""

    name: Literal["latero-nasal process ectoderm"] = "latero-nasal process ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16806"] = "EMAPA_16806"


class _Latero_Nasal_Process_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model latero-nasal process mesenchyme"""

    name: Literal["latero-nasal process mesenchyme"] = "latero-nasal process mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16807"] = "EMAPA_16807"


class _Medial_Nasal_Process(_MouseAnatomicalStructureModel):
    """Model medial-nasal process"""

    name: Literal["medial-nasal process"] = "medial-nasal process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16808"] = "EMAPA_16808"


class _Medial_Nasal_Process_Ectoderm(_MouseAnatomicalStructureModel):
    """Model medial-nasal process ectoderm"""

    name: Literal["medial-nasal process ectoderm"] = "medial-nasal process ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16809"] = "EMAPA_16809"


class _Medial_Nasal_Process_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model medial-nasal process mesenchyme"""

    name: Literal["medial-nasal process mesenchyme"] = "medial-nasal process mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16810"] = "EMAPA_16810"


class _Principal_Artery_To_Forelimb(_MouseAnatomicalStructureModel):
    """Model principal artery to forelimb"""

    name: Literal["principal artery to forelimb"] = "principal artery to forelimb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16811"] = "EMAPA_16811"


class _Principal_Artery_To_Hindlimb(_MouseAnatomicalStructureModel):
    """Model principal artery to hindlimb"""

    name: Literal["principal artery to hindlimb"] = "principal artery to hindlimb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16812"] = "EMAPA_16812"


class _Common_Atrial_Chamber_Left_Part(_MouseAnatomicalStructureModel):
    """Model common atrial chamber left part"""

    name: Literal["common atrial chamber left part"] = "common atrial chamber left part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16813"] = "EMAPA_16813"


class _Common_Atrial_Chamber_Left_Part_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model common atrial chamber left part cardiac jelly"""

    name: Literal["common atrial chamber left part cardiac jelly"] = "common atrial chamber left part cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16814"] = "EMAPA_16814"


class _Common_Atrial_Chamber_Left_Part_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model common atrial chamber left part endocardial lining"""

    name: Literal[
        "common atrial chamber left part endocardial lining"
    ] = "common atrial chamber left part endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16815"] = "EMAPA_16815"


class _Left_Auricular_Region(_MouseAnatomicalStructureModel):
    """Model left auricular region"""

    name: Literal["left auricular region"] = "left auricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16816"] = "EMAPA_16816"


class _Left_Auricular_Region_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model left auricular region endocardial lining"""

    name: Literal["left auricular region endocardial lining"] = "left auricular region endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16817"] = "EMAPA_16817"


class _Left_Auricular_Region_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model left auricular region cardiac muscle"""

    name: Literal["left auricular region cardiac muscle"] = "left auricular region cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16818"] = "EMAPA_16818"


class _Common_Atrial_Chamber_Left_Part_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model common atrial chamber left part cardiac muscle"""

    name: Literal["common atrial chamber left part cardiac muscle"] = "common atrial chamber left part cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16819"] = "EMAPA_16819"


class _Common_Atrial_Chamber_Right_Part(_MouseAnatomicalStructureModel):
    """Model common atrial chamber right part"""

    name: Literal["common atrial chamber right part"] = "common atrial chamber right part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16820"] = "EMAPA_16820"


class _Common_Atrial_Chamber_Right_Part_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model common atrial chamber right part cardiac jelly"""

    name: Literal["common atrial chamber right part cardiac jelly"] = "common atrial chamber right part cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16821"] = "EMAPA_16821"


class _Common_Atrial_Chamber_Right_Part_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model common atrial chamber right part endocardial lining"""

    name: Literal[
        "common atrial chamber right part endocardial lining"
    ] = "common atrial chamber right part endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16822"] = "EMAPA_16822"


class _Common_Atrial_Chamber_Right_Part_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model common atrial chamber right part cardiac muscle"""

    name: Literal["common atrial chamber right part cardiac muscle"] = "common atrial chamber right part cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16823"] = "EMAPA_16823"


class _Right_Auricular_Region(_MouseAnatomicalStructureModel):
    """Model right auricular region"""

    name: Literal["right auricular region"] = "right auricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16824"] = "EMAPA_16824"


class _Right_Auricular_Region_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model right auricular region endocardial lining"""

    name: Literal["right auricular region endocardial lining"] = "right auricular region endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16825"] = "EMAPA_16825"


class _Right_Auricular_Region_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model right auricular region cardiac muscle"""

    name: Literal["right auricular region cardiac muscle"] = "right auricular region cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16826"] = "EMAPA_16826"


class _Aortico_Pulmonary_Spiral_Septum(_MouseAnatomicalStructureModel):
    """Model aortico-pulmonary spiral septum"""

    name: Literal["aortico-pulmonary spiral septum"] = "aortico-pulmonary spiral septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16827"] = "EMAPA_16827"


class _Inter_Subcardinal_Venous_Anastomosis(_MouseAnatomicalStructureModel):
    """Model inter-subcardinal venous anastomosis"""

    name: Literal["inter-subcardinal venous anastomosis"] = "inter-subcardinal venous anastomosis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16828"] = "EMAPA_16828"


class _Subcardinal_Vein(_MouseAnatomicalStructureModel):
    """Model subcardinal vein"""

    name: Literal["subcardinal vein"] = "subcardinal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16829"] = "EMAPA_16829"


class _Supracardinal_Vein(_MouseAnatomicalStructureModel):
    """Model supracardinal vein"""

    name: Literal["supracardinal vein"] = "supracardinal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16830"] = "EMAPA_16830"


class _Anal_Region(_MouseAnatomicalStructureModel):
    """Model anal region"""

    name: Literal["anal region"] = "anal region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16831"] = "EMAPA_16831"


class _Cloacal_Membrane(_MouseAnatomicalStructureModel):
    """Model cloacal membrane"""

    name: Literal["cloacal membrane"] = "cloacal membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16832"] = "EMAPA_16832"


class _Esophagus(_MouseAnatomicalStructureModel):
    """Model esophagus"""

    name: Literal["esophagus"] = "esophagus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16833"] = "EMAPA_16833"


class _Esophagus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model esophagus mesenchyme"""

    name: Literal["esophagus mesenchyme"] = "esophagus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16834"] = "EMAPA_16834"


class _Esophagus_Epithelium(_MouseAnatomicalStructureModel):
    """Model esophagus epithelium"""

    name: Literal["esophagus epithelium"] = "esophagus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16835"] = "EMAPA_16835"


class _Esophagus_Mesentery(_MouseAnatomicalStructureModel):
    """Model esophagus mesentery"""

    name: Literal["esophagus mesentery"] = "esophagus mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16836"] = "EMAPA_16836"


class _Esophagus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model esophagus vascular element"""

    name: Literal["esophagus vascular element"] = "esophagus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16838"] = "EMAPA_16838"


class _Oral_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model oral region epithelium"""

    name: Literal["oral region epithelium"] = "oral region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16839"] = "EMAPA_16839"


class _Liver_And_Biliary_System(_MouseAnatomicalStructureModel):
    """Model liver and biliary system"""

    name: Literal["liver and biliary system"] = "liver and biliary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16840"] = "EMAPA_16840"


class _Cystic_Duct(_MouseAnatomicalStructureModel):
    """Model cystic duct"""

    name: Literal["cystic duct"] = "cystic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16841"] = "EMAPA_16841"


class _Hepatic_Duct(_MouseAnatomicalStructureModel):
    """Model hepatic duct"""

    name: Literal["hepatic duct"] = "hepatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16843"] = "EMAPA_16843"


class _Hepatic_Duct_Extrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model hepatic duct extrahepatic part"""

    name: Literal["hepatic duct extrahepatic part"] = "hepatic duct extrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16844"] = "EMAPA_16844"


class _Hepatic_Duct_Intrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model hepatic duct intrahepatic part"""

    name: Literal["hepatic duct intrahepatic part"] = "hepatic duct intrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16845"] = "EMAPA_16845"


class _Liver(_MouseAnatomicalStructureModel):
    """Model liver"""

    name: Literal["liver"] = "liver"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16846"] = "EMAPA_16846"


class _Hepatic_Primordium(_MouseAnatomicalStructureModel):
    """Model hepatic primordium"""

    name: Literal["hepatic primordium"] = "hepatic primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16847"] = "EMAPA_16847"


class _Hepatic_Primordium_Parenchyma(_MouseAnatomicalStructureModel):
    """Model hepatic primordium parenchyma"""

    name: Literal["hepatic primordium parenchyma"] = "hepatic primordium parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16848"] = "EMAPA_16848"


class _Main_Bronchus(_MouseAnatomicalStructureModel):
    """Model main bronchus"""

    name: Literal["main bronchus"] = "main bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16849"] = "EMAPA_16849"


class _Main_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model main bronchus mesenchyme"""

    name: Literal["main bronchus mesenchyme"] = "main bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16850"] = "EMAPA_16850"


class _Main_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model main bronchus epithelium"""

    name: Literal["main bronchus epithelium"] = "main bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16851"] = "EMAPA_16851"


class _Main_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model main bronchus vascular element"""

    name: Literal["main bronchus vascular element"] = "main bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16852"] = "EMAPA_16852"


class _Trachea(_MouseAnatomicalStructureModel):
    """Model trachea"""

    name: Literal["trachea"] = "trachea"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16853"] = "EMAPA_16853"


class _Trachea_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model trachea mesenchyme"""

    name: Literal["trachea mesenchyme"] = "trachea mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16854"] = "EMAPA_16854"


class _Trachea_Epithelium(_MouseAnatomicalStructureModel):
    """Model trachea epithelium"""

    name: Literal["trachea epithelium"] = "trachea epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16855"] = "EMAPA_16855"


class _Trachea_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model trachea vascular element"""

    name: Literal["trachea vascular element"] = "trachea vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16856"] = "EMAPA_16856"


class _Gonad_Primordium(_MouseAnatomicalStructureModel):
    """Model gonad primordium"""

    name: Literal["gonad primordium"] = "gonad primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16857"] = "EMAPA_16857"


class _Gonad_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model gonad primordium mesenchyme"""

    name: Literal["gonad primordium mesenchyme"] = "gonad primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16858"] = "EMAPA_16858"


class _Tail_Somite(_MouseAnatomicalStructureModel):
    """Model tail somite"""

    name: Literal["tail somite"] = "tail somite"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16860"] = "EMAPA_16860"


class _Somite_31(_MouseAnatomicalStructureModel):
    """Model somite 31"""

    name: Literal["somite 31"] = "somite 31"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16861"] = "EMAPA_16861"


class _Somite_31_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 31 dermomyotome"""

    name: Literal["somite 31 dermomyotome"] = "somite 31 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16862"] = "EMAPA_16862"


class _Somite_31_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 31 myocoele"""

    name: Literal["somite 31 myocoele"] = "somite 31 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16863"] = "EMAPA_16863"


class _Somite_31_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 31 sclerotome"""

    name: Literal["somite 31 sclerotome"] = "somite 31 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16864"] = "EMAPA_16864"


class _Somite_32(_MouseAnatomicalStructureModel):
    """Model somite 32"""

    name: Literal["somite 32"] = "somite 32"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16865"] = "EMAPA_16865"


class _Somite_32_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 32 dermomyotome"""

    name: Literal["somite 32 dermomyotome"] = "somite 32 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16866"] = "EMAPA_16866"


class _Somite_32_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 32 myocoele"""

    name: Literal["somite 32 myocoele"] = "somite 32 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16867"] = "EMAPA_16867"


class _Somite_32_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 32 sclerotome"""

    name: Literal["somite 32 sclerotome"] = "somite 32 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16868"] = "EMAPA_16868"


class _Somite_33(_MouseAnatomicalStructureModel):
    """Model somite 33"""

    name: Literal["somite 33"] = "somite 33"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16869"] = "EMAPA_16869"


class _Somite_33_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 33 dermomyotome"""

    name: Literal["somite 33 dermomyotome"] = "somite 33 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16870"] = "EMAPA_16870"


class _Somite_33_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 33 myocoele"""

    name: Literal["somite 33 myocoele"] = "somite 33 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16871"] = "EMAPA_16871"


class _Somite_33_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 33 sclerotome"""

    name: Literal["somite 33 sclerotome"] = "somite 33 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16872"] = "EMAPA_16872"


class _Somite_34(_MouseAnatomicalStructureModel):
    """Model somite 34"""

    name: Literal["somite 34"] = "somite 34"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16873"] = "EMAPA_16873"


class _Somite_34_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 34 dermomyotome"""

    name: Literal["somite 34 dermomyotome"] = "somite 34 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16874"] = "EMAPA_16874"


class _Somite_34_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 34 myocoele"""

    name: Literal["somite 34 myocoele"] = "somite 34 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16875"] = "EMAPA_16875"


class _Somite_34_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 34 sclerotome"""

    name: Literal["somite 34 sclerotome"] = "somite 34 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16876"] = "EMAPA_16876"


class _Somite_35(_MouseAnatomicalStructureModel):
    """Model somite 35"""

    name: Literal["somite 35"] = "somite 35"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16877"] = "EMAPA_16877"


class _Somite_35_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 35 dermomyotome"""

    name: Literal["somite 35 dermomyotome"] = "somite 35 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16878"] = "EMAPA_16878"


class _Somite_35_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 35 myocoele"""

    name: Literal["somite 35 myocoele"] = "somite 35 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16879"] = "EMAPA_16879"


class _Somite_35_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 35 sclerotome"""

    name: Literal["somite 35 sclerotome"] = "somite 35 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16880"] = "EMAPA_16880"


class _Tail_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model tail neural crest"""

    name: Literal["tail neural crest"] = "tail neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16881"] = "EMAPA_16881"


class _2Nd_Branchial_Arch_Epithelium(_MouseAnatomicalStructureModel):
    """Model 2nd branchial arch epithelium"""

    name: Literal["2nd branchial arch epithelium"] = "2nd branchial arch epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16882"] = "EMAPA_16882"


class _3Rd_Branchial_Groove_Epithelium(_MouseAnatomicalStructureModel):
    """Model 3rd branchial groove epithelium"""

    name: Literal["3rd branchial groove epithelium"] = "3rd branchial groove epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16883"] = "EMAPA_16883"


class _Cervical_Sinus(_MouseAnatomicalStructureModel):
    """Model cervical sinus"""

    name: Literal["cervical sinus"] = "cervical sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16884"] = "EMAPA_16884"


class _Greater_Sac(_MouseAnatomicalStructureModel):
    """Model greater sac"""

    name: Literal["greater sac"] = "greater sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16885"] = "EMAPA_16885"


class _Greater_Sac_Cavity(_MouseAnatomicalStructureModel):
    """Model greater sac cavity"""

    name: Literal["greater sac cavity"] = "greater sac cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16886"] = "EMAPA_16886"


class _Greater_Sac_Mesothelium(_MouseAnatomicalStructureModel):
    """Model greater sac mesothelium"""

    name: Literal["greater sac mesothelium"] = "greater sac mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16887"] = "EMAPA_16887"


class _Greater_Sac_Parietal_Mesothelium(_MouseAnatomicalStructureModel):
    """Model greater sac parietal mesothelium"""

    name: Literal["greater sac parietal mesothelium"] = "greater sac parietal mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16888"] = "EMAPA_16888"


class _Omental_Bursa(_MouseAnatomicalStructureModel):
    """Model omental bursa"""

    name: Literal["omental bursa"] = "omental bursa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16889"] = "EMAPA_16889"


class _Omental_Bursa_Mesothelium(_MouseAnatomicalStructureModel):
    """Model omental bursa mesothelium"""

    name: Literal["omental bursa mesothelium"] = "omental bursa mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16890"] = "EMAPA_16890"


class _Omental_Bursa_Parietal_Mesothelium(_MouseAnatomicalStructureModel):
    """Model omental bursa parietal mesothelium"""

    name: Literal["omental bursa parietal mesothelium"] = "omental bursa parietal mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16891"] = "EMAPA_16891"


class _Hindlimb_Bud_Apical_Ectodermal_Ridge(_MouseAnatomicalStructureModel):
    """Model hindlimb bud apical ectodermal ridge"""

    name: Literal["hindlimb bud apical ectodermal ridge"] = "hindlimb bud apical ectodermal ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16892"] = "EMAPA_16892"


class _Body_Wall_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model body wall mesenchyme"""

    name: Literal["body wall mesenchyme"] = "body wall mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16893"] = "EMAPA_16893"


class _Brain(_MouseAnatomicalStructureModel):
    """Model brain"""

    name: Literal["brain"] = "brain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16894"] = "EMAPA_16894"


class _Forebrain(_MouseAnatomicalStructureModel):
    """Model forebrain"""

    name: Literal["forebrain"] = "forebrain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16895"] = "EMAPA_16895"


class _Diencephalon(_MouseAnatomicalStructureModel):
    """Model diencephalon"""

    name: Literal["diencephalon"] = "diencephalon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16896"] = "EMAPA_16896"


class _Diencephalon_Gland(_MouseAnatomicalStructureModel):
    """Model diencephalon gland"""

    name: Literal["diencephalon gland"] = "diencephalon gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16897"] = "EMAPA_16897"


class _Infundibular_Recess_Of_3Rd_Ventricle(_MouseAnatomicalStructureModel):
    """Model infundibular recess of 3rd ventricle"""

    name: Literal["infundibular recess of 3rd ventricle"] = "infundibular recess of 3rd ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16899"] = "EMAPA_16899"


class _3Rd_Ventricle(_MouseAnatomicalStructureModel):
    """Model 3rd ventricle"""

    name: Literal["3rd ventricle"] = "3rd ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16900"] = "EMAPA_16900"


class _Diencephalic_Part_Of_Interventricular_Foramen(_MouseAnatomicalStructureModel):
    """Model diencephalic part of interventricular foramen"""

    name: Literal["diencephalic part of interventricular foramen"] = "diencephalic part of interventricular foramen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16901"] = "EMAPA_16901"


class _Optic_Recess(_MouseAnatomicalStructureModel):
    """Model optic recess"""

    name: Literal["optic recess"] = "optic recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16902"] = "EMAPA_16902"


class _Diencephalon_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model diencephalon floor plate"""

    name: Literal["diencephalon floor plate"] = "diencephalon floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16903"] = "EMAPA_16903"


class _Diencephalon_Lamina_Terminalis(_MouseAnatomicalStructureModel):
    """Model diencephalon lamina terminalis"""

    name: Literal["diencephalon lamina terminalis"] = "diencephalon lamina terminalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16904"] = "EMAPA_16904"


class _Diencephalon_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model diencephalon lateral wall"""

    name: Literal["diencephalon lateral wall"] = "diencephalon lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16905"] = "EMAPA_16905"


class _Diencephalon_Lateral_Wall_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model diencephalon lateral wall mantle layer"""

    name: Literal["diencephalon lateral wall mantle layer"] = "diencephalon lateral wall mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16906"] = "EMAPA_16906"


class _Diencephalon_Lateral_Wall_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model diencephalon lateral wall marginal layer"""

    name: Literal["diencephalon lateral wall marginal layer"] = "diencephalon lateral wall marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16907"] = "EMAPA_16907"


class _Diencephalon_Lateral_Wall_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model diencephalon lateral wall ventricular layer"""

    name: Literal["diencephalon lateral wall ventricular layer"] = "diencephalon lateral wall ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16908"] = "EMAPA_16908"


class _Diencephalon_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model diencephalon roof plate"""

    name: Literal["diencephalon roof plate"] = "diencephalon roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16909"] = "EMAPA_16909"


class _Telencephalon(_MouseAnatomicalStructureModel):
    """Model telencephalon"""

    name: Literal["telencephalon"] = "telencephalon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16910"] = "EMAPA_16910"


class _Telencephalon_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model telencephalon mantle layer"""

    name: Literal["telencephalon mantle layer"] = "telencephalon mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16911"] = "EMAPA_16911"


class _Telencephalon_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model telencephalon marginal layer"""

    name: Literal["telencephalon marginal layer"] = "telencephalon marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16912"] = "EMAPA_16912"


class _Telencephalon_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model telencephalon ventricular layer"""

    name: Literal["telencephalon ventricular layer"] = "telencephalon ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16913"] = "EMAPA_16913"


class _Lateral_Ventricle(_MouseAnatomicalStructureModel):
    """Model lateral ventricle"""

    name: Literal["lateral ventricle"] = "lateral ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16914"] = "EMAPA_16914"


class _Telencephalic_Part_Of_Interventricular_Foramen(_MouseAnatomicalStructureModel):
    """Model telencephalic part of interventricular foramen"""

    name: Literal["telencephalic part of interventricular foramen"] = "telencephalic part of interventricular foramen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16915"] = "EMAPA_16915"


class _Hindbrain(_MouseAnatomicalStructureModel):
    """Model hindbrain"""

    name: Literal["hindbrain"] = "hindbrain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16916"] = "EMAPA_16916"


class _4Th_Ventricle(_MouseAnatomicalStructureModel):
    """Model 4th ventricle"""

    name: Literal["4th ventricle"] = "4th ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16917"] = "EMAPA_16917"


class _Rhombomere_1_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 mantle layer"""

    name: Literal["rhombomere 1 mantle layer"] = "rhombomere 1 mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16921"] = "EMAPA_16921"


class _Rhombomere_1_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 marginal layer"""

    name: Literal["rhombomere 1 marginal layer"] = "rhombomere 1 marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16922"] = "EMAPA_16922"


class _Rhombomere_2_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 mantle layer"""

    name: Literal["rhombomere 2 mantle layer"] = "rhombomere 2 mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16928"] = "EMAPA_16928"


class _Rhombomere_2_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 marginal layer"""

    name: Literal["rhombomere 2 marginal layer"] = "rhombomere 2 marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16929"] = "EMAPA_16929"


class _Rhombomere_3_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 mantle layer"""

    name: Literal["rhombomere 3 mantle layer"] = "rhombomere 3 mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16935"] = "EMAPA_16935"


class _Rhombomere_3_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 marginal layer"""

    name: Literal["rhombomere 3 marginal layer"] = "rhombomere 3 marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16936"] = "EMAPA_16936"


class _Rhombomere_4_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 mantle layer"""

    name: Literal["rhombomere 4 mantle layer"] = "rhombomere 4 mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16942"] = "EMAPA_16942"


class _Rhombomere_4_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 marginal layer"""

    name: Literal["rhombomere 4 marginal layer"] = "rhombomere 4 marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16943"] = "EMAPA_16943"


class _Rhombomere_5_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 mantle layer"""

    name: Literal["rhombomere 5 mantle layer"] = "rhombomere 5 mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16949"] = "EMAPA_16949"


class _Rhombomere_5_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 marginal layer"""

    name: Literal["rhombomere 5 marginal layer"] = "rhombomere 5 marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16950"] = "EMAPA_16950"


class _Rhombomere_6_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 6 mantle layer"""

    name: Literal["rhombomere 6 mantle layer"] = "rhombomere 6 mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16956"] = "EMAPA_16956"


class _Rhombomere_6_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 6 marginal layer"""

    name: Literal["rhombomere 6 marginal layer"] = "rhombomere 6 marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16957"] = "EMAPA_16957"


class _Rhombomere_7_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 7 mantle layer"""

    name: Literal["rhombomere 7 mantle layer"] = "rhombomere 7 mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16963"] = "EMAPA_16963"


class _Rhombomere_7_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 7 marginal layer"""

    name: Literal["rhombomere 7 marginal layer"] = "rhombomere 7 marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16964"] = "EMAPA_16964"


class _Rhombomere_8_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 8 mantle layer"""

    name: Literal["rhombomere 8 mantle layer"] = "rhombomere 8 mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16970"] = "EMAPA_16970"


class _Rhombomere_8_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere 8 marginal layer"""

    name: Literal["rhombomere 8 marginal layer"] = "rhombomere 8 marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16971"] = "EMAPA_16971"


class _Midbrain(_MouseAnatomicalStructureModel):
    """Model midbrain"""

    name: Literal["midbrain"] = "midbrain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16974"] = "EMAPA_16974"


class _Midbrain_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model midbrain floor plate"""

    name: Literal["midbrain floor plate"] = "midbrain floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16975"] = "EMAPA_16975"


class _Midbrain_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model midbrain lateral wall"""

    name: Literal["midbrain lateral wall"] = "midbrain lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16976"] = "EMAPA_16976"


class _Midbrain_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model midbrain mantle layer"""

    name: Literal["midbrain mantle layer"] = "midbrain mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16977"] = "EMAPA_16977"


class _Midbrain_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model midbrain marginal layer"""

    name: Literal["midbrain marginal layer"] = "midbrain marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16978"] = "EMAPA_16978"


class _Midbrain_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model midbrain ventricular layer"""

    name: Literal["midbrain ventricular layer"] = "midbrain ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16979"] = "EMAPA_16979"


class _Mesencephalic_Vesicle(_MouseAnatomicalStructureModel):
    """Model mesencephalic vesicle"""

    name: Literal["mesencephalic vesicle"] = "mesencephalic vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16980"] = "EMAPA_16980"


class _Midbrain_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model midbrain roof plate"""

    name: Literal["midbrain roof plate"] = "midbrain roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16981"] = "EMAPA_16981"


class _Acoustic_Ganglion(_MouseAnatomicalStructureModel):
    """Model acoustic ganglion"""

    name: Literal["acoustic ganglion"] = "acoustic ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16982"] = "EMAPA_16982"


class _Autonomic_Nervous_System(_MouseAnatomicalStructureModel):
    """Model autonomic nervous system"""

    name: Literal["autonomic nervous system"] = "autonomic nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16984"] = "EMAPA_16984"


class _Sympathetic_Nervous_System(_MouseAnatomicalStructureModel):
    """Model sympathetic nervous system"""

    name: Literal["sympathetic nervous system"] = "sympathetic nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16985"] = "EMAPA_16985"


class _Peripheral_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model peripheral nerve trunk"""

    name: Literal["peripheral nerve trunk"] = "peripheral nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16986"] = "EMAPA_16986"


class _Spinal_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model spinal nerve plexus"""

    name: Literal["spinal nerve plexus"] = "spinal nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16987"] = "EMAPA_16987"


class _Brachial_Plexus(_MouseAnatomicalStructureModel):
    """Model brachial plexus"""

    name: Literal["brachial plexus"] = "brachial plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16988"] = "EMAPA_16988"


class _Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model spinal nerve"""

    name: Literal["spinal nerve"] = "spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16989"] = "EMAPA_16989"


class _Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model segmental spinal nerve"""

    name: Literal["segmental spinal nerve"] = "segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16990"] = "EMAPA_16990"


class _Outer_Ear(_MouseAnatomicalStructureModel):
    """Model outer ear"""

    name: Literal["outer ear"] = "outer ear"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16991"] = "EMAPA_16991"


class _Branchial_Membrane(_MouseAnatomicalStructureModel):
    """Model branchial membrane"""

    name: Literal["branchial membrane"] = "branchial membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16992"] = "EMAPA_16992"


class _Branchial_Membrane_Epithelium(_MouseAnatomicalStructureModel):
    """Model branchial membrane epithelium"""

    name: Literal["branchial membrane epithelium"] = "branchial membrane epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16993"] = "EMAPA_16993"


class _Endolymphatic_Appendage(_MouseAnatomicalStructureModel):
    """Model endolymphatic appendage"""

    name: Literal["endolymphatic appendage"] = "endolymphatic appendage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16994"] = "EMAPA_16994"


class _Endolymphatic_Appendage_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model endolymphatic appendage mesenchyme"""

    name: Literal["endolymphatic appendage mesenchyme"] = "endolymphatic appendage mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16995"] = "EMAPA_16995"


class _Endolymphatic_Appendage_Epithelium(_MouseAnatomicalStructureModel):
    """Model endolymphatic appendage epithelium"""

    name: Literal["endolymphatic appendage epithelium"] = "endolymphatic appendage epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16996"] = "EMAPA_16996"


class _Rest_Of_Otocyst(_MouseAnatomicalStructureModel):
    """Model rest of otocyst"""

    name: Literal["rest of otocyst"] = "rest of otocyst"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16997"] = "EMAPA_16997"


class _Rest_Of_Otocyst_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model rest of otocyst mesenchyme"""

    name: Literal["rest of otocyst mesenchyme"] = "rest of otocyst mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16998"] = "EMAPA_16998"


class _Rest_Of_Otocyst_Epithelium(_MouseAnatomicalStructureModel):
    """Model rest of otocyst epithelium"""

    name: Literal["rest of otocyst epithelium"] = "rest of otocyst epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_16999"] = "EMAPA_16999"


class _Middle_Ear(_MouseAnatomicalStructureModel):
    """Model middle ear"""

    name: Literal["middle ear"] = "middle ear"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17000"] = "EMAPA_17000"


class _Middle_Ear_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model middle ear mesenchyme"""

    name: Literal["middle ear mesenchyme"] = "middle ear mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17001"] = "EMAPA_17001"


class _Tubotympanic_Recess(_MouseAnatomicalStructureModel):
    """Model tubotympanic recess"""

    name: Literal["tubotympanic recess"] = "tubotympanic recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17002"] = "EMAPA_17002"


class _Eye_Surface_Ectoderm(_MouseAnatomicalStructureModel):
    """Model eye surface ectoderm"""

    name: Literal["eye surface ectoderm"] = "eye surface ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17003"] = "EMAPA_17003"


class _4Th_Arch_Artery(_MouseAnatomicalStructureModel):
    """Model 4th arch artery"""

    name: Literal["4th arch artery"] = "4th arch artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17004"] = "EMAPA_17004"


class _6Th_Arch_Artery(_MouseAnatomicalStructureModel):
    """Model 6th arch artery"""

    name: Literal["6th arch artery"] = "6th arch artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17005"] = "EMAPA_17005"


class _Ductus_Caroticus(_MouseAnatomicalStructureModel):
    """Model ductus caroticus"""

    name: Literal["ductus caroticus"] = "ductus caroticus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17006"] = "EMAPA_17006"


class _Ophthalmic_Artery(_MouseAnatomicalStructureModel):
    """Model ophthalmic artery"""

    name: Literal["ophthalmic artery"] = "ophthalmic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17007"] = "EMAPA_17007"


class _Pulmonary_Artery(_MouseAnatomicalStructureModel):
    """Model pulmonary artery"""

    name: Literal["pulmonary artery"] = "pulmonary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17008"] = "EMAPA_17008"


class _Common_Atrial_Chamber_Right_Part_Valve(_MouseAnatomicalStructureModel):
    """Model common atrial chamber right part valve"""

    name: Literal["common atrial chamber right part valve"] = "common atrial chamber right part valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17009"] = "EMAPA_17009"


class _Common_Atrial_Chamber_Right_Part_Venous_Valve(_MouseAnatomicalStructureModel):
    """Model common atrial chamber right part venous valve"""

    name: Literal["common atrial chamber right part venous valve"] = "common atrial chamber right part venous valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17010"] = "EMAPA_17010"


class _Interatrial_Septum(_MouseAnatomicalStructureModel):
    """Model interatrial septum"""

    name: Literal["interatrial septum"] = "interatrial septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17011"] = "EMAPA_17011"


class _Foramen_Primum(_MouseAnatomicalStructureModel):
    """Model foramen primum"""

    name: Literal["foramen primum"] = "foramen primum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17012"] = "EMAPA_17012"


class _Septum_Primum(_MouseAnatomicalStructureModel):
    """Model septum primum"""

    name: Literal["septum primum"] = "septum primum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17013"] = "EMAPA_17013"


class _Ascending_Aorta(_MouseAnatomicalStructureModel):
    """Model ascending aorta"""

    name: Literal["ascending aorta"] = "ascending aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17014"] = "EMAPA_17014"


class _Pulmonary_Trunk(_MouseAnatomicalStructureModel):
    """Model pulmonary trunk"""

    name: Literal["pulmonary trunk"] = "pulmonary trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17015"] = "EMAPA_17015"


class _Marginal_Vein_Of_Forelimb(_MouseAnatomicalStructureModel):
    """Model marginal vein of forelimb"""

    name: Literal["marginal vein of forelimb"] = "marginal vein of forelimb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17016"] = "EMAPA_17016"


class _Marginal_Vein_Of_Hindlimb(_MouseAnatomicalStructureModel):
    """Model marginal vein of hindlimb"""

    name: Literal["marginal vein of hindlimb"] = "marginal vein of hindlimb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17017"] = "EMAPA_17017"


class _Principal_Vein_Of_Forelimb(_MouseAnatomicalStructureModel):
    """Model principal vein of forelimb"""

    name: Literal["principal vein of forelimb"] = "principal vein of forelimb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17018"] = "EMAPA_17018"


class _Principal_Vein_Of_Hindlimb(_MouseAnatomicalStructureModel):
    """Model principal vein of hindlimb"""

    name: Literal["principal vein of hindlimb"] = "principal vein of hindlimb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17019"] = "EMAPA_17019"


class _Vitelline_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model vitelline venous plexus"""

    name: Literal["vitelline venous plexus"] = "vitelline venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17020"] = "EMAPA_17020"


class _Stomach(_MouseAnatomicalStructureModel):
    """Model stomach"""

    name: Literal["stomach"] = "stomach"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17021"] = "EMAPA_17021"


class _Stomach_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model stomach mesenchyme"""

    name: Literal["stomach mesenchyme"] = "stomach mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17022"] = "EMAPA_17022"


class _Stomach_Epithelium(_MouseAnatomicalStructureModel):
    """Model stomach epithelium"""

    name: Literal["stomach epithelium"] = "stomach epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17023"] = "EMAPA_17023"


class _Stomach_Mesentery(_MouseAnatomicalStructureModel):
    """Model stomach mesentery"""

    name: Literal["stomach mesentery"] = "stomach mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17024"] = "EMAPA_17024"


class _Dorsal_Mesogastrium(_MouseAnatomicalStructureModel):
    """Model dorsal mesogastrium"""

    name: Literal["dorsal mesogastrium"] = "dorsal mesogastrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17025"] = "EMAPA_17025"


class _Ventral_Mesogastrium(_MouseAnatomicalStructureModel):
    """Model ventral mesogastrium"""

    name: Literal["ventral mesogastrium"] = "ventral mesogastrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17026"] = "EMAPA_17026"


class _Stomach_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model stomach vascular element"""

    name: Literal["stomach vascular element"] = "stomach vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17027"] = "EMAPA_17027"


class _Hindgut_Diverticulum_Postanal_Component(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum postanal component"""

    name: Literal["hindgut diverticulum postanal component"] = "hindgut diverticulum postanal component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17028"] = "EMAPA_17028"


class _Hindgut_Diverticulum_Postanal_Component_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum postanal component mesenchyme"""

    name: Literal[
        "hindgut diverticulum postanal component mesenchyme"
    ] = "hindgut diverticulum postanal component mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17029"] = "EMAPA_17029"


class _Hindgut_Diverticulum_Postanal_Component_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum postanal component epithelium"""

    name: Literal[
        "hindgut diverticulum postanal component epithelium"
    ] = "hindgut diverticulum postanal component epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17030"] = "EMAPA_17030"


class _Hindgut_Diverticulum_Postanal_Component_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum postanal component vascular element"""

    name: Literal[
        "hindgut diverticulum postanal component vascular element"
    ] = "hindgut diverticulum postanal component vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17031"] = "EMAPA_17031"


class _Hindgut_Diverticulum_Preanal_Component(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum preanal component"""

    name: Literal["hindgut diverticulum preanal component"] = "hindgut diverticulum preanal component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17032"] = "EMAPA_17032"


class _Hindgut_Diverticulum_Preanal_Component_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum preanal component mesenchyme"""

    name: Literal[
        "hindgut diverticulum preanal component mesenchyme"
    ] = "hindgut diverticulum preanal component mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17033"] = "EMAPA_17033"


class _Hindgut_Diverticulum_Preanal_Component_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum preanal component epithelium"""

    name: Literal[
        "hindgut diverticulum preanal component epithelium"
    ] = "hindgut diverticulum preanal component epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17034"] = "EMAPA_17034"


class _Hindgut_Diverticulum_Preanal_Component_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum preanal component vascular element"""

    name: Literal[
        "hindgut diverticulum preanal component vascular element"
    ] = "hindgut diverticulum preanal component vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17035"] = "EMAPA_17035"


class _Midgut_Loop(_MouseAnatomicalStructureModel):
    """Model midgut loop"""

    name: Literal["midgut loop"] = "midgut loop"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17036"] = "EMAPA_17036"


class _Midgut_Loop_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model midgut loop mesenchyme"""

    name: Literal["midgut loop mesenchyme"] = "midgut loop mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17037"] = "EMAPA_17037"


class _Midgut_Loop_Epithelium(_MouseAnatomicalStructureModel):
    """Model midgut loop epithelium"""

    name: Literal["midgut loop epithelium"] = "midgut loop epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17038"] = "EMAPA_17038"


class _Midgut_Loop_Mesentery(_MouseAnatomicalStructureModel):
    """Model midgut loop mesentery"""

    name: Literal["midgut loop mesentery"] = "midgut loop mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17039"] = "EMAPA_17039"


class _Midgut_Loop_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model midgut loop dorsal mesentery"""

    name: Literal["midgut loop dorsal mesentery"] = "midgut loop dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17040"] = "EMAPA_17040"


class _Midgut_Loop_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model midgut loop vascular element"""

    name: Literal["midgut loop vascular element"] = "midgut loop vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17041"] = "EMAPA_17041"


class _Somite_36(_MouseAnatomicalStructureModel):
    """Model somite 36"""

    name: Literal["somite 36"] = "somite 36"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17049"] = "EMAPA_17049"


class _Somite_36_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 36 dermomyotome"""

    name: Literal["somite 36 dermomyotome"] = "somite 36 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17050"] = "EMAPA_17050"


class _Somite_36_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 36 myocoele"""

    name: Literal["somite 36 myocoele"] = "somite 36 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17051"] = "EMAPA_17051"


class _Somite_36_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 36 sclerotome"""

    name: Literal["somite 36 sclerotome"] = "somite 36 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17052"] = "EMAPA_17052"


class _Somite_37(_MouseAnatomicalStructureModel):
    """Model somite 37"""

    name: Literal["somite 37"] = "somite 37"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17053"] = "EMAPA_17053"


class _Somite_37_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 37 dermomyotome"""

    name: Literal["somite 37 dermomyotome"] = "somite 37 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17054"] = "EMAPA_17054"


class _Somite_37_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 37 myocoele"""

    name: Literal["somite 37 myocoele"] = "somite 37 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17055"] = "EMAPA_17055"


class _Somite_37_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 37 sclerotome"""

    name: Literal["somite 37 sclerotome"] = "somite 37 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17056"] = "EMAPA_17056"


class _Somite_38(_MouseAnatomicalStructureModel):
    """Model somite 38"""

    name: Literal["somite 38"] = "somite 38"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17057"] = "EMAPA_17057"


class _Somite_38_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 38 dermomyotome"""

    name: Literal["somite 38 dermomyotome"] = "somite 38 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17058"] = "EMAPA_17058"


class _Somite_38_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 38 myocoele"""

    name: Literal["somite 38 myocoele"] = "somite 38 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17059"] = "EMAPA_17059"


class _Somite_38_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 38 sclerotome"""

    name: Literal["somite 38 sclerotome"] = "somite 38 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17060"] = "EMAPA_17060"


class _Somite_39(_MouseAnatomicalStructureModel):
    """Model somite 39"""

    name: Literal["somite 39"] = "somite 39"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17061"] = "EMAPA_17061"


class _Somite_39_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 39 dermomyotome"""

    name: Literal["somite 39 dermomyotome"] = "somite 39 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17062"] = "EMAPA_17062"


class _Somite_39_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 39 myocoele"""

    name: Literal["somite 39 myocoele"] = "somite 39 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17063"] = "EMAPA_17063"


class _Somite_39_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 39 sclerotome"""

    name: Literal["somite 39 sclerotome"] = "somite 39 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17064"] = "EMAPA_17064"


class _Foregut_Midgut_Junction_Gland(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction gland"""

    name: Literal["foregut-midgut junction gland"] = "foregut-midgut junction gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17065"] = "EMAPA_17065"


class _Pancreas_Primordium(_MouseAnatomicalStructureModel):
    """Model pancreas primordium"""

    name: Literal["pancreas primordium"] = "pancreas primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17066"] = "EMAPA_17066"


class _Pancreas_Primordium_Dorsal_Bud(_MouseAnatomicalStructureModel):
    """Model pancreas primordium dorsal bud"""

    name: Literal["pancreas primordium dorsal bud"] = "pancreas primordium dorsal bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17067"] = "EMAPA_17067"


class _Thyroid_Gland(_MouseAnatomicalStructureModel):
    """Model thyroid gland"""

    name: Literal["thyroid gland"] = "thyroid gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17068"] = "EMAPA_17068"


class _Foramen_Caecum(_MouseAnatomicalStructureModel):
    """Model foramen caecum"""

    name: Literal["foramen caecum"] = "foramen caecum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17069"] = "EMAPA_17069"


class _Thyroglossal_Duct(_MouseAnatomicalStructureModel):
    """Model thyroglossal duct"""

    name: Literal["thyroglossal duct"] = "thyroglossal duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17070"] = "EMAPA_17070"


class _Metencephalon(_MouseAnatomicalStructureModel):
    """Model metencephalon"""

    name: Literal["metencephalon"] = "metencephalon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17071"] = "EMAPA_17071"


class _Metencephalon_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model metencephalon lateral wall"""

    name: Literal["metencephalon lateral wall"] = "metencephalon lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17072"] = "EMAPA_17072"


class _Metencephalon_Alar_Plate(_MouseAnatomicalStructureModel):
    """Model metencephalon alar plate"""

    name: Literal["metencephalon alar plate"] = "metencephalon alar plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17073"] = "EMAPA_17073"


class _Cerebellum_Primordium(_MouseAnatomicalStructureModel):
    """Model cerebellum primordium"""

    name: Literal["cerebellum primordium"] = "cerebellum primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17074"] = "EMAPA_17074"


class _Metencephalon_Alar_Plate_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon alar plate mantle layer"""

    name: Literal["metencephalon alar plate mantle layer"] = "metencephalon alar plate mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17075"] = "EMAPA_17075"


class _Metencephalon_Alar_Plate_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon alar plate marginal layer"""

    name: Literal["metencephalon alar plate marginal layer"] = "metencephalon alar plate marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17076"] = "EMAPA_17076"


class _Metencephalon_Alar_Plate_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon alar plate ventricular layer"""

    name: Literal["metencephalon alar plate ventricular layer"] = "metencephalon alar plate ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17077"] = "EMAPA_17077"


class _Metencephalon_Basal_Plate(_MouseAnatomicalStructureModel):
    """Model metencephalon basal plate"""

    name: Literal["metencephalon basal plate"] = "metencephalon basal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17078"] = "EMAPA_17078"


class _Metencephalon_Basal_Plate_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon basal plate mantle layer"""

    name: Literal["metencephalon basal plate mantle layer"] = "metencephalon basal plate mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17079"] = "EMAPA_17079"


class _Metencephalon_Basal_Plate_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon basal plate marginal layer"""

    name: Literal["metencephalon basal plate marginal layer"] = "metencephalon basal plate marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17080"] = "EMAPA_17080"


class _Metencephalon_Basal_Plate_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon basal plate ventricular layer"""

    name: Literal["metencephalon basal plate ventricular layer"] = "metencephalon basal plate ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17081"] = "EMAPA_17081"


class _Myelencephalon(_MouseAnatomicalStructureModel):
    """Model myelencephalon"""

    name: Literal["myelencephalon"] = "myelencephalon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17082"] = "EMAPA_17082"


class _Myelencephalon_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model myelencephalon lateral wall"""

    name: Literal["myelencephalon lateral wall"] = "myelencephalon lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17083"] = "EMAPA_17083"


class _Myelencephalon_Alar_Plate(_MouseAnatomicalStructureModel):
    """Model myelencephalon alar plate"""

    name: Literal["myelencephalon alar plate"] = "myelencephalon alar plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17084"] = "EMAPA_17084"


class _Myelencephalon_Alar_Plate_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model myelencephalon alar plate mantle layer"""

    name: Literal["myelencephalon alar plate mantle layer"] = "myelencephalon alar plate mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17085"] = "EMAPA_17085"


class _Myelencephalon_Alar_Plate_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model myelencephalon alar plate marginal layer"""

    name: Literal["myelencephalon alar plate marginal layer"] = "myelencephalon alar plate marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17086"] = "EMAPA_17086"


class _Myelencephalon_Alar_Plate_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model myelencephalon alar plate ventricular layer"""

    name: Literal["myelencephalon alar plate ventricular layer"] = "myelencephalon alar plate ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17087"] = "EMAPA_17087"


class _Myelencephalon_Basal_Plate(_MouseAnatomicalStructureModel):
    """Model myelencephalon basal plate"""

    name: Literal["myelencephalon basal plate"] = "myelencephalon basal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17088"] = "EMAPA_17088"


class _Myelencephalon_Basal_Plate_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model myelencephalon basal plate mantle layer"""

    name: Literal["myelencephalon basal plate mantle layer"] = "myelencephalon basal plate mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17089"] = "EMAPA_17089"


class _Myelencephalon_Basal_Plate_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model myelencephalon basal plate marginal layer"""

    name: Literal["myelencephalon basal plate marginal layer"] = "myelencephalon basal plate marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17090"] = "EMAPA_17090"


class _Myelencephalon_Basal_Plate_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model myelencephalon basal plate ventricular layer"""

    name: Literal["myelencephalon basal plate ventricular layer"] = "myelencephalon basal plate ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17091"] = "EMAPA_17091"


class _Neural_Tube_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model neural tube mantle layer"""

    name: Literal["neural tube mantle layer"] = "neural tube mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17148"] = "EMAPA_17148"


class _Neural_Tube_Alar_Columns(_MouseAnatomicalStructureModel):
    """Model neural tube alar columns"""

    name: Literal["neural tube alar columns"] = "neural tube alar columns"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17149"] = "EMAPA_17149"


class _Neural_Tube_Basal_Columns(_MouseAnatomicalStructureModel):
    """Model neural tube basal columns"""

    name: Literal["neural tube basal columns"] = "neural tube basal columns"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17150"] = "EMAPA_17150"


class _Neural_Tube_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model neural tube marginal layer"""

    name: Literal["neural tube marginal layer"] = "neural tube marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17151"] = "EMAPA_17151"


class _Neural_Tube_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model neural tube ventricular layer"""

    name: Literal["neural tube ventricular layer"] = "neural tube ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17152"] = "EMAPA_17152"


class _Inferior_Glossopharyngeal_Ganglion(_MouseAnatomicalStructureModel):
    """Model inferior glossopharyngeal ganglion"""

    name: Literal["inferior glossopharyngeal ganglion"] = "inferior glossopharyngeal ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17153"] = "EMAPA_17153"


class _Superior_Glossopharyngeal_Ganglion(_MouseAnatomicalStructureModel):
    """Model superior glossopharyngeal ganglion"""

    name: Literal["superior glossopharyngeal ganglion"] = "superior glossopharyngeal ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17154"] = "EMAPA_17154"


class _Inferior_Vagus_Ganglion(_MouseAnatomicalStructureModel):
    """Model inferior vagus ganglion"""

    name: Literal["inferior vagus ganglion"] = "inferior vagus ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17155"] = "EMAPA_17155"


class _Superior_Vagus_Ganglion(_MouseAnatomicalStructureModel):
    """Model superior vagus ganglion"""

    name: Literal["superior vagus ganglion"] = "superior vagus ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17156"] = "EMAPA_17156"


class _Sympathetic_Ganglion(_MouseAnatomicalStructureModel):
    """Model sympathetic ganglion"""

    name: Literal["sympathetic ganglion"] = "sympathetic ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17157"] = "EMAPA_17157"


class _Thoracic_Ganglion(_MouseAnatomicalStructureModel):
    """Model thoracic ganglion"""

    name: Literal["thoracic ganglion"] = "thoracic ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17158"] = "EMAPA_17158"


class _Cornea(_MouseAnatomicalStructureModel):
    """Model cornea"""

    name: Literal["cornea"] = "cornea"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17161"] = "EMAPA_17161"


class _Cornea_Epithelium(_MouseAnatomicalStructureModel):
    """Model cornea epithelium"""

    name: Literal["cornea epithelium"] = "cornea epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17162"] = "EMAPA_17162"


class _Lens_Vesicle(_MouseAnatomicalStructureModel):
    """Model lens vesicle"""

    name: Literal["lens vesicle"] = "lens vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17163"] = "EMAPA_17163"


class _Lens_Vesicle_Cavity(_MouseAnatomicalStructureModel):
    """Model lens vesicle cavity"""

    name: Literal["lens vesicle cavity"] = "lens vesicle cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17164"] = "EMAPA_17164"


class _Lens_Vesicle_Epithelium(_MouseAnatomicalStructureModel):
    """Model lens vesicle epithelium"""

    name: Literal["lens vesicle epithelium"] = "lens vesicle epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17165"] = "EMAPA_17165"


class _Optic_Fissure(_MouseAnatomicalStructureModel):
    """Model optic fissure"""

    name: Literal["optic fissure"] = "optic fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17166"] = "EMAPA_17166"


class _Perioptic_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model perioptic mesenchyme"""

    name: Literal["perioptic mesenchyme"] = "perioptic mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17167"] = "EMAPA_17167"


class _Retina(_MouseAnatomicalStructureModel):
    """Model retina"""

    name: Literal["retina"] = "retina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17168"] = "EMAPA_17168"


class _Embryonic_Fissure(_MouseAnatomicalStructureModel):
    """Model embryonic fissure"""

    name: Literal["embryonic fissure"] = "embryonic fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17169"] = "EMAPA_17169"


class _Intraretinal_Space(_MouseAnatomicalStructureModel):
    """Model intraretinal space"""

    name: Literal["intraretinal space"] = "intraretinal space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17170"] = "EMAPA_17170"


class _Neural_Retinal_Epithelium(_MouseAnatomicalStructureModel):
    """Model neural retinal epithelium"""

    name: Literal["neural retinal epithelium"] = "neural retinal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17171"] = "EMAPA_17171"


class _Pigmented_Retinal_Epithelium(_MouseAnatomicalStructureModel):
    """Model pigmented retinal epithelium"""

    name: Literal["pigmented retinal epithelium"] = "pigmented retinal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17172"] = "EMAPA_17172"


class _Endoderm_Component_Of_Anal_Membrane(_MouseAnatomicalStructureModel):
    """Model endoderm component of anal membrane"""

    name: Literal["endoderm component of anal membrane"] = "endoderm component of anal membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17177"] = "EMAPA_17177"


class _Foregut_Duodenum(_MouseAnatomicalStructureModel):
    """Model foregut duodenum"""

    name: Literal["foregut duodenum"] = "foregut duodenum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17178"] = "EMAPA_17178"


class _Duodenum_Rostral_Part(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part"""

    name: Literal["duodenum rostral part"] = "duodenum rostral part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17179"] = "EMAPA_17179"


class _Duodenum_Rostral_Part_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part mesenchyme"""

    name: Literal["duodenum rostral part mesenchyme"] = "duodenum rostral part mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17180"] = "EMAPA_17180"


class _Duodenum_Rostral_Part_Epithelium(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part epithelium"""

    name: Literal["duodenum rostral part epithelium"] = "duodenum rostral part epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17181"] = "EMAPA_17181"


class _Duodenum_Rostral_Part_Mesentery(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part mesentery"""

    name: Literal["duodenum rostral part mesentery"] = "duodenum rostral part mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17182"] = "EMAPA_17182"


class _Duodenum_Rostral_Part_Mesoduodenum(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part mesoduodenum"""

    name: Literal["duodenum rostral part mesoduodenum"] = "duodenum rostral part mesoduodenum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17183"] = "EMAPA_17183"


class _Duodenum_Rostral_Part_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part vascular element"""

    name: Literal["duodenum rostral part vascular element"] = "duodenum rostral part vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17184"] = "EMAPA_17184"


class _Tongue(_MouseAnatomicalStructureModel):
    """Model tongue"""

    name: Literal["tongue"] = "tongue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17185"] = "EMAPA_17185"


class _Lingual_Swelling(_MouseAnatomicalStructureModel):
    """Model lingual swelling"""

    name: Literal["lingual swelling"] = "lingual swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17186"] = "EMAPA_17186"


class _Median_Lingual_Swelling(_MouseAnatomicalStructureModel):
    """Model median lingual swelling"""

    name: Literal["median lingual swelling"] = "median lingual swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17187"] = "EMAPA_17187"


class _Median_Lingual_Swelling_Epithelium(_MouseAnatomicalStructureModel):
    """Model median lingual swelling epithelium"""

    name: Literal["median lingual swelling epithelium"] = "median lingual swelling epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17188"] = "EMAPA_17188"


class _Lateral_Lingual_Swelling(_MouseAnatomicalStructureModel):
    """Model lateral lingual swelling"""

    name: Literal["lateral lingual swelling"] = "lateral lingual swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17189"] = "EMAPA_17189"


class _Lateral_Lingual_Swelling_Epithelium(_MouseAnatomicalStructureModel):
    """Model lateral lingual swelling epithelium"""

    name: Literal["lateral lingual swelling epithelium"] = "lateral lingual swelling epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17190"] = "EMAPA_17190"


class _Lateral_Lingual_Swelling_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lateral lingual swelling mesenchyme"""

    name: Literal["lateral lingual swelling mesenchyme"] = "lateral lingual swelling mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17191"] = "EMAPA_17191"


class _Median_Lingual_Swelling_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model median lingual swelling mesenchyme"""

    name: Literal["median lingual swelling mesenchyme"] = "median lingual swelling mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17192"] = "EMAPA_17192"


class _Midgut_Derived_Duodenum(_MouseAnatomicalStructureModel):
    """Model midgut derived duodenum"""

    name: Literal["midgut derived duodenum"] = "midgut derived duodenum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17193"] = "EMAPA_17193"


class _Duodenum_Caudal_Part(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part"""

    name: Literal["duodenum caudal part"] = "duodenum caudal part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17194"] = "EMAPA_17194"


class _Duodenum_Caudal_Part_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part mesenchyme"""

    name: Literal["duodenum caudal part mesenchyme"] = "duodenum caudal part mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17195"] = "EMAPA_17195"


class _Duodenum_Caudal_Part_Epithelium(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part epithelium"""

    name: Literal["duodenum caudal part epithelium"] = "duodenum caudal part epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17196"] = "EMAPA_17196"


class _Duodenum_Caudal_Part_Mesentery(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part mesentery"""

    name: Literal["duodenum caudal part mesentery"] = "duodenum caudal part mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17197"] = "EMAPA_17197"


class _Duodenum_Caudal_Part_Mesoduodenum(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part mesoduodenum"""

    name: Literal["duodenum caudal part mesoduodenum"] = "duodenum caudal part mesoduodenum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17198"] = "EMAPA_17198"


class _Duodenum_Caudal_Part_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part vascular element"""

    name: Literal["duodenum caudal part vascular element"] = "duodenum caudal part vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17199"] = "EMAPA_17199"


class _Oronasal_Cavity(_MouseAnatomicalStructureModel):
    """Model oronasal cavity"""

    name: Literal["oronasal cavity"] = "oronasal cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17200"] = "EMAPA_17200"


class _Common_Bile_Duct(_MouseAnatomicalStructureModel):
    """Model common bile duct"""

    name: Literal["common bile duct"] = "common bile duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17201"] = "EMAPA_17201"


class _Gallbladder(_MouseAnatomicalStructureModel):
    """Model gallbladder"""

    name: Literal["gallbladder"] = "gallbladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17202"] = "EMAPA_17202"


class _Liver_Parenchyma(_MouseAnatomicalStructureModel):
    """Model liver parenchyma"""

    name: Literal["liver parenchyma"] = "liver parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17203"] = "EMAPA_17203"


class _Stomach_Pyloric_Region_Muscularis(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region muscularis"""

    name: Literal["stomach pyloric region muscularis"] = "stomach pyloric region muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17205"] = "EMAPA_17205"


class _Ureteric_Bud(_MouseAnatomicalStructureModel):
    """Model ureteric bud"""

    name: Literal["ureteric bud"] = "ureteric bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17209"] = "EMAPA_17209"


class _Urorectal_Septum(_MouseAnatomicalStructureModel):
    """Model urorectal septum"""

    name: Literal["urorectal septum"] = "urorectal septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17212"] = "EMAPA_17212"


class _Skeleton(_MouseAnatomicalStructureModel):
    """Model skeleton"""

    name: Literal["skeleton"] = "skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17213"] = "EMAPA_17213"


class _Axial_Skeleton(_MouseAnatomicalStructureModel):
    """Model axial skeleton"""

    name: Literal["axial skeleton"] = "axial skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17214"] = "EMAPA_17214"


class _Axial_Skeleton_Cervical_Region(_MouseAnatomicalStructureModel):
    """Model axial skeleton cervical region"""

    name: Literal["axial skeleton cervical region"] = "axial skeleton cervical region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17215"] = "EMAPA_17215"


class _Cervical_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model cervical vertebral pre-cartilage condensation"""

    name: Literal["cervical vertebral pre-cartilage condensation"] = "cervical vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17216"] = "EMAPA_17216"


class _Somite_40(_MouseAnatomicalStructureModel):
    """Model somite 40"""

    name: Literal["somite 40"] = "somite 40"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17217"] = "EMAPA_17217"


class _Somite_40_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 40 dermomyotome"""

    name: Literal["somite 40 dermomyotome"] = "somite 40 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17218"] = "EMAPA_17218"


class _Somite_40_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 40 myocoele"""

    name: Literal["somite 40 myocoele"] = "somite 40 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17219"] = "EMAPA_17219"


class _Somite_40_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 40 sclerotome"""

    name: Literal["somite 40 sclerotome"] = "somite 40 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17220"] = "EMAPA_17220"


class _Somite_41(_MouseAnatomicalStructureModel):
    """Model somite 41"""

    name: Literal["somite 41"] = "somite 41"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17221"] = "EMAPA_17221"


class _Somite_41_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 41 dermomyotome"""

    name: Literal["somite 41 dermomyotome"] = "somite 41 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17222"] = "EMAPA_17222"


class _Somite_41_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 41 myocoele"""

    name: Literal["somite 41 myocoele"] = "somite 41 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17223"] = "EMAPA_17223"


class _Somite_41_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 41 sclerotome"""

    name: Literal["somite 41 sclerotome"] = "somite 41 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17224"] = "EMAPA_17224"


class _Somite_42(_MouseAnatomicalStructureModel):
    """Model somite 42"""

    name: Literal["somite 42"] = "somite 42"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17225"] = "EMAPA_17225"


class _Somite_42_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 42 dermomyotome"""

    name: Literal["somite 42 dermomyotome"] = "somite 42 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17226"] = "EMAPA_17226"


class _Somite_42_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 42 myocoele"""

    name: Literal["somite 42 myocoele"] = "somite 42 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17227"] = "EMAPA_17227"


class _Somite_42_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 42 sclerotome"""

    name: Literal["somite 42 sclerotome"] = "somite 42 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17228"] = "EMAPA_17228"


class _Somite_43(_MouseAnatomicalStructureModel):
    """Model somite 43"""

    name: Literal["somite 43"] = "somite 43"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17229"] = "EMAPA_17229"


class _Somite_43_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 43 dermomyotome"""

    name: Literal["somite 43 dermomyotome"] = "somite 43 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17230"] = "EMAPA_17230"


class _Somite_43_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 43 myocoele"""

    name: Literal["somite 43 myocoele"] = "somite 43 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17231"] = "EMAPA_17231"


class _Somite_43_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 43 sclerotome"""

    name: Literal["somite 43 sclerotome"] = "somite 43 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17232"] = "EMAPA_17232"


class _Somite_44(_MouseAnatomicalStructureModel):
    """Model somite 44"""

    name: Literal["somite 44"] = "somite 44"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17233"] = "EMAPA_17233"


class _Somite_44_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 44 dermomyotome"""

    name: Literal["somite 44 dermomyotome"] = "somite 44 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17234"] = "EMAPA_17234"


class _Somite_44_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 44 myocoele"""

    name: Literal["somite 44 myocoele"] = "somite 44 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17235"] = "EMAPA_17235"


class _Somite_44_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 44 sclerotome"""

    name: Literal["somite 44 sclerotome"] = "somite 44 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17236"] = "EMAPA_17236"


class _Somite_45(_MouseAnatomicalStructureModel):
    """Model somite 45"""

    name: Literal["somite 45"] = "somite 45"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17237"] = "EMAPA_17237"


class _Somite_45_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 45 dermomyotome"""

    name: Literal["somite 45 dermomyotome"] = "somite 45 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17238"] = "EMAPA_17238"


class _Somite_45_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 45 myocoele"""

    name: Literal["somite 45 myocoele"] = "somite 45 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17239"] = "EMAPA_17239"


class _Somite_45_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 45 sclerotome"""

    name: Literal["somite 45 sclerotome"] = "somite 45 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17240"] = "EMAPA_17240"


class _1St_Branchial_Groove_Epithelium(_MouseAnatomicalStructureModel):
    """Model 1st branchial groove epithelium"""

    name: Literal["1st branchial groove epithelium"] = "1st branchial groove epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17241"] = "EMAPA_17241"


class _Future_Arm(_MouseAnatomicalStructureModel):
    """Model future arm"""

    name: Literal["future arm"] = "future arm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17242"] = "EMAPA_17242"


class _Future_Arm_Ectoderm(_MouseAnatomicalStructureModel):
    """Model future arm ectoderm"""

    name: Literal["future arm ectoderm"] = "future arm ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17243"] = "EMAPA_17243"


class _Future_Arm_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model future arm mesenchyme"""

    name: Literal["future arm mesenchyme"] = "future arm mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17244"] = "EMAPA_17244"


class _Handplate(_MouseAnatomicalStructureModel):
    """Model handplate"""

    name: Literal["handplate"] = "handplate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17245"] = "EMAPA_17245"


class _Handplate_Ectoderm(_MouseAnatomicalStructureModel):
    """Model handplate ectoderm"""

    name: Literal["handplate ectoderm"] = "handplate ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17246"] = "EMAPA_17246"


class _Handplate_Apical_Ectodermal_Ridge(_MouseAnatomicalStructureModel):
    """Model handplate apical ectodermal ridge"""

    name: Literal["handplate apical ectodermal ridge"] = "handplate apical ectodermal ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17247"] = "EMAPA_17247"


class _Handplate_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model handplate mesenchyme"""

    name: Literal["handplate mesenchyme"] = "handplate mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17248"] = "EMAPA_17248"


class _Footplate(_MouseAnatomicalStructureModel):
    """Model footplate"""

    name: Literal["footplate"] = "footplate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17249"] = "EMAPA_17249"


class _Footplate_Ectoderm(_MouseAnatomicalStructureModel):
    """Model footplate ectoderm"""

    name: Literal["footplate ectoderm"] = "footplate ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17250"] = "EMAPA_17250"


class _Footplate_Apical_Ectodermal_Ridge(_MouseAnatomicalStructureModel):
    """Model footplate apical ectodermal ridge"""

    name: Literal["footplate apical ectodermal ridge"] = "footplate apical ectodermal ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17251"] = "EMAPA_17251"


class _Footplate_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model footplate mesenchyme"""

    name: Literal["footplate mesenchyme"] = "footplate mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17252"] = "EMAPA_17252"


class _Future_Leg(_MouseAnatomicalStructureModel):
    """Model future leg"""

    name: Literal["future leg"] = "future leg"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17253"] = "EMAPA_17253"


class _Future_Leg_Ectoderm(_MouseAnatomicalStructureModel):
    """Model future leg ectoderm"""

    name: Literal["future leg ectoderm"] = "future leg ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17254"] = "EMAPA_17254"


class _Future_Leg_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model future leg mesenchyme"""

    name: Literal["future leg mesenchyme"] = "future leg mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17255"] = "EMAPA_17255"


class _Pancreas_Primordium_Ventral_Bud(_MouseAnatomicalStructureModel):
    """Model pancreas primordium ventral bud"""

    name: Literal["pancreas primordium ventral bud"] = "pancreas primordium ventral bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17256"] = "EMAPA_17256"


class _4Th_Ventricle_Lateral_Recess(_MouseAnatomicalStructureModel):
    """Model 4th ventricle lateral recess"""

    name: Literal["4th ventricle lateral recess"] = "4th ventricle lateral recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17257"] = "EMAPA_17257"


class _Metencephalon_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model metencephalon floor plate"""

    name: Literal["metencephalon floor plate"] = "metencephalon floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17258"] = "EMAPA_17258"


class _Metencephalon_Roof(_MouseAnatomicalStructureModel):
    """Model metencephalon roof"""

    name: Literal["metencephalon roof"] = "metencephalon roof"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17259"] = "EMAPA_17259"


class _Myelencephalon_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model myelencephalon floor plate"""

    name: Literal["myelencephalon floor plate"] = "myelencephalon floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17260"] = "EMAPA_17260"


class _Myelencephalon_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model myelencephalon roof plate"""

    name: Literal["myelencephalon roof plate"] = "myelencephalon roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17261"] = "EMAPA_17261"


class _Central_Nervous_System_Nerve(_MouseAnatomicalStructureModel):
    """Model central nervous system nerve"""

    name: Literal["central nervous system nerve"] = "central nervous system nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17263"] = "EMAPA_17263"


class _Cranial_Nerve(_MouseAnatomicalStructureModel):
    """Model cranial nerve"""

    name: Literal["cranial nerve"] = "cranial nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17264"] = "EMAPA_17264"


class _Accessory_Nerve(_MouseAnatomicalStructureModel):
    """Model accessory nerve"""

    name: Literal["accessory nerve"] = "accessory nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17265"] = "EMAPA_17265"


class _Accessory_Nerve_Cranial_Component(_MouseAnatomicalStructureModel):
    """Model accessory nerve cranial component"""

    name: Literal["accessory nerve cranial component"] = "accessory nerve cranial component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17266"] = "EMAPA_17266"


class _Accessory_Nerve_Spinal_Component(_MouseAnatomicalStructureModel):
    """Model accessory nerve spinal component"""

    name: Literal["accessory nerve spinal component"] = "accessory nerve spinal component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17267"] = "EMAPA_17267"


class _Glossopharyngeal_Nerve(_MouseAnatomicalStructureModel):
    """Model glossopharyngeal nerve"""

    name: Literal["glossopharyngeal nerve"] = "glossopharyngeal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17268"] = "EMAPA_17268"


class _Hypoglossal_Nerve(_MouseAnatomicalStructureModel):
    """Model hypoglossal nerve"""

    name: Literal["hypoglossal nerve"] = "hypoglossal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17269"] = "EMAPA_17269"


class _Parasympathetic_Nervous_System(_MouseAnatomicalStructureModel):
    """Model parasympathetic nervous system"""

    name: Literal["parasympathetic nervous system"] = "parasympathetic nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17270"] = "EMAPA_17270"


class _Parasympathetic_Nerve(_MouseAnatomicalStructureModel):
    """Model parasympathetic nerve"""

    name: Literal["parasympathetic nerve"] = "parasympathetic nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17271"] = "EMAPA_17271"


class _Vagal_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model vagal nerve trunk"""

    name: Literal["vagal nerve trunk"] = "vagal nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17272"] = "EMAPA_17272"


class _Vagus_Nerve_Right_Recurrent_Laryngeal_Branch(_MouseAnatomicalStructureModel):
    """Model vagus nerve right recurrent laryngeal branch"""

    name: Literal["vagus nerve right recurrent laryngeal branch"] = "vagus nerve right recurrent laryngeal branch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17275"] = "EMAPA_17275"


class _Median_Nerve(_MouseAnatomicalStructureModel):
    """Model median nerve"""

    name: Literal["median nerve"] = "median nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17277"] = "EMAPA_17277"


class _Radial_Nerve(_MouseAnatomicalStructureModel):
    """Model radial nerve"""

    name: Literal["radial nerve"] = "radial nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17278"] = "EMAPA_17278"


class _Ulnar_Nerve(_MouseAnatomicalStructureModel):
    """Model ulnar nerve"""

    name: Literal["ulnar nerve"] = "ulnar nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17279"] = "EMAPA_17279"


class _Auditory_Hillocks(_MouseAnatomicalStructureModel):
    """Model auditory hillocks"""

    name: Literal["auditory hillocks"] = "auditory hillocks"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17280"] = "EMAPA_17280"


class _Future_Tympanic_Membrane(_MouseAnatomicalStructureModel):
    """Model future tympanic membrane"""

    name: Literal["future tympanic membrane"] = "future tympanic membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17281"] = "EMAPA_17281"


class _Future_Tympanic_Membrane_Epithelium(_MouseAnatomicalStructureModel):
    """Model future tympanic membrane epithelium"""

    name: Literal["future tympanic membrane epithelium"] = "future tympanic membrane epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17282"] = "EMAPA_17282"


class _Inner_Ear_Vestibular_Component(_MouseAnatomicalStructureModel):
    """Model inner ear vestibular component"""

    name: Literal["inner ear vestibular component"] = "inner ear vestibular component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17286"] = "EMAPA_17286"


class _Ductus_Reuniens(_MouseAnatomicalStructureModel):
    """Model ductus reuniens"""

    name: Literal["ductus reuniens"] = "ductus reuniens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17287"] = "EMAPA_17287"


class _Ductus_Reuniens_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model ductus reuniens mesenchyme"""

    name: Literal["ductus reuniens mesenchyme"] = "ductus reuniens mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17288"] = "EMAPA_17288"


class _Ductus_Reuniens_Epithelium(_MouseAnatomicalStructureModel):
    """Model ductus reuniens epithelium"""

    name: Literal["ductus reuniens epithelium"] = "ductus reuniens epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17289"] = "EMAPA_17289"


class _Saccule(_MouseAnatomicalStructureModel):
    """Model saccule"""

    name: Literal["saccule"] = "saccule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17290"] = "EMAPA_17290"


class _Saccule_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model saccule mesenchyme"""

    name: Literal["saccule mesenchyme"] = "saccule mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17291"] = "EMAPA_17291"


class _Saccule_Epithelium(_MouseAnatomicalStructureModel):
    """Model saccule epithelium"""

    name: Literal["saccule epithelium"] = "saccule epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17292"] = "EMAPA_17292"


class _Utricle(_MouseAnatomicalStructureModel):
    """Model utricle"""

    name: Literal["utricle"] = "utricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17293"] = "EMAPA_17293"


class _Utricle_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model utricle mesenchyme"""

    name: Literal["utricle mesenchyme"] = "utricle mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17294"] = "EMAPA_17294"


class _Utricle_Epithelium(_MouseAnatomicalStructureModel):
    """Model utricle epithelium"""

    name: Literal["utricle epithelium"] = "utricle epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17295"] = "EMAPA_17295"


class _Posterior_Semicircular_Canal(_MouseAnatomicalStructureModel):
    """Model posterior semicircular canal"""

    name: Literal["posterior semicircular canal"] = "posterior semicircular canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17296"] = "EMAPA_17296"


class _Posterior_Semicircular_Canal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model posterior semicircular canal mesenchyme"""

    name: Literal["posterior semicircular canal mesenchyme"] = "posterior semicircular canal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17297"] = "EMAPA_17297"


class _Posterior_Semicircular_Canal_Epithelium(_MouseAnatomicalStructureModel):
    """Model posterior semicircular canal epithelium"""

    name: Literal["posterior semicircular canal epithelium"] = "posterior semicircular canal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17298"] = "EMAPA_17298"


class _Superior_Semicircular_Canal(_MouseAnatomicalStructureModel):
    """Model superior semicircular canal"""

    name: Literal["superior semicircular canal"] = "superior semicircular canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17299"] = "EMAPA_17299"


class _Superior_Semicircular_Canal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model superior semicircular canal mesenchyme"""

    name: Literal["superior semicircular canal mesenchyme"] = "superior semicircular canal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17300"] = "EMAPA_17300"


class _Superior_Semicircular_Canal_Epithelium(_MouseAnatomicalStructureModel):
    """Model superior semicircular canal epithelium"""

    name: Literal["superior semicircular canal epithelium"] = "superior semicircular canal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17301"] = "EMAPA_17301"


class _Hyaloid_Cavity(_MouseAnatomicalStructureModel):
    """Model hyaloid cavity"""

    name: Literal["hyaloid cavity"] = "hyaloid cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17302"] = "EMAPA_17302"


class _Hyaloid_Vascular_Plexus(_MouseAnatomicalStructureModel):
    """Model hyaloid vascular plexus"""

    name: Literal["hyaloid vascular plexus"] = "hyaloid vascular plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17303"] = "EMAPA_17303"


class _Lens_Vesicle_Anterior_Epithelium(_MouseAnatomicalStructureModel):
    """Model lens vesicle anterior epithelium"""

    name: Literal["lens vesicle anterior epithelium"] = "lens vesicle anterior epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17304"] = "EMAPA_17304"


class _Lens_Vesicle_Equatorial_Epithelium(_MouseAnatomicalStructureModel):
    """Model lens vesicle equatorial epithelium"""

    name: Literal["lens vesicle equatorial epithelium"] = "lens vesicle equatorial epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17305"] = "EMAPA_17305"


class _Lens_Vesicle_Posterior_Epithelium(_MouseAnatomicalStructureModel):
    """Model lens vesicle posterior epithelium"""

    name: Literal["lens vesicle posterior epithelium"] = "lens vesicle posterior epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17306"] = "EMAPA_17306"


class _Basilar_Artery(_MouseAnatomicalStructureModel):
    """Model basilar artery"""

    name: Literal["basilar artery"] = "basilar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17307"] = "EMAPA_17307"


class _Hyoid_Artery(_MouseAnatomicalStructureModel):
    """Model hyoid artery"""

    name: Literal["hyoid artery"] = "hyoid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17308"] = "EMAPA_17308"


class _Iliac_Artery(_MouseAnatomicalStructureModel):
    """Model iliac artery"""

    name: Literal["iliac artery"] = "iliac artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17309"] = "EMAPA_17309"


class _Common_Iliac_Artery(_MouseAnatomicalStructureModel):
    """Model common iliac artery"""

    name: Literal["common iliac artery"] = "common iliac artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17310"] = "EMAPA_17310"


class _Maxillary_Artery(_MouseAnatomicalStructureModel):
    """Model maxillary artery"""

    name: Literal["maxillary artery"] = "maxillary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17311"] = "EMAPA_17311"


class _Mesenteric_Artery(_MouseAnatomicalStructureModel):
    """Model mesenteric artery"""

    name: Literal["mesenteric artery"] = "mesenteric artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17312"] = "EMAPA_17312"


class _Stapedial_Artery(_MouseAnatomicalStructureModel):
    """Model stapedial artery"""

    name: Literal["stapedial artery"] = "stapedial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17313"] = "EMAPA_17313"


class _Vertebral_Artery(_MouseAnatomicalStructureModel):
    """Model vertebral artery"""

    name: Literal["vertebral artery"] = "vertebral artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17314"] = "EMAPA_17314"


class _Left_Atrium(_MouseAnatomicalStructureModel):
    """Model left atrium"""

    name: Literal["left atrium"] = "left atrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17315"] = "EMAPA_17315"


class _Left_Atrium_Auricular_Region(_MouseAnatomicalStructureModel):
    """Model left atrium auricular region"""

    name: Literal["left atrium auricular region"] = "left atrium auricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17316"] = "EMAPA_17316"


class _Left_Atrium_Auricular_Region_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model left atrium auricular region endocardial lining"""

    name: Literal["left atrium auricular region endocardial lining"] = "left atrium auricular region endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17317"] = "EMAPA_17317"


class _Left_Atrium_Auricular_Region_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model left atrium auricular region cardiac muscle"""

    name: Literal["left atrium auricular region cardiac muscle"] = "left atrium auricular region cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17318"] = "EMAPA_17318"


class _Left_Atrium_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model left atrium endocardial lining"""

    name: Literal["left atrium endocardial lining"] = "left atrium endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17319"] = "EMAPA_17319"


class _Left_Atrium_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model left atrium cardiac muscle"""

    name: Literal["left atrium cardiac muscle"] = "left atrium cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17320"] = "EMAPA_17320"


class _Right_Atrium(_MouseAnatomicalStructureModel):
    """Model right atrium"""

    name: Literal["right atrium"] = "right atrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17321"] = "EMAPA_17321"


class _Right_Atrium_Auricular_Region(_MouseAnatomicalStructureModel):
    """Model right atrium auricular region"""

    name: Literal["right atrium auricular region"] = "right atrium auricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17322"] = "EMAPA_17322"


class _Right_Atrium_Auricular_Region_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model right atrium auricular region endocardial lining"""

    name: Literal[
        "right atrium auricular region endocardial lining"
    ] = "right atrium auricular region endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17323"] = "EMAPA_17323"


class _Right_Atrium_Auricular_Region_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model right atrium auricular region cardiac muscle"""

    name: Literal["right atrium auricular region cardiac muscle"] = "right atrium auricular region cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17324"] = "EMAPA_17324"


class _Right_Atrium_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model right atrium endocardial lining"""

    name: Literal["right atrium endocardial lining"] = "right atrium endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17325"] = "EMAPA_17325"


class _Right_Atrium_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model right atrium cardiac muscle"""

    name: Literal["right atrium cardiac muscle"] = "right atrium cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17326"] = "EMAPA_17326"


class _Right_Atrium_Valve(_MouseAnatomicalStructureModel):
    """Model right atrium valve"""

    name: Literal["right atrium valve"] = "right atrium valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17327"] = "EMAPA_17327"


class _Right_Atrium_Venous_Valve(_MouseAnatomicalStructureModel):
    """Model right atrium venous valve"""

    name: Literal["right atrium venous valve"] = "right atrium venous valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17328"] = "EMAPA_17328"


class _Outflow_Tract_Aortic_Component(_MouseAnatomicalStructureModel):
    """Model outflow tract aortic component"""

    name: Literal["outflow tract aortic component"] = "outflow tract aortic component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17329"] = "EMAPA_17329"


class _Outflow_Tract_Pulmonary_Component(_MouseAnatomicalStructureModel):
    """Model outflow tract pulmonary component"""

    name: Literal["outflow tract pulmonary component"] = "outflow tract pulmonary component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17330"] = "EMAPA_17330"


class _Heart_Ventricle(_MouseAnatomicalStructureModel):
    """Model heart ventricle"""

    name: Literal["heart ventricle"] = "heart ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17331"] = "EMAPA_17331"


class _Bulbar_Ridge(_MouseAnatomicalStructureModel):
    """Model bulbar ridge"""

    name: Literal["bulbar ridge"] = "bulbar ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17332"] = "EMAPA_17332"


class _Interventricular_Septum(_MouseAnatomicalStructureModel):
    """Model interventricular septum"""

    name: Literal["interventricular septum"] = "interventricular septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17333"] = "EMAPA_17333"


class _Interventricular_Septum_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model interventricular septum endocardial lining"""

    name: Literal["interventricular septum endocardial lining"] = "interventricular septum endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17334"] = "EMAPA_17334"


class _Interventricular_Septum_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model interventricular septum cardiac muscle"""

    name: Literal["interventricular septum cardiac muscle"] = "interventricular septum cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17335"] = "EMAPA_17335"


class _Interventricular_Groove(_MouseAnatomicalStructureModel):
    """Model interventricular groove"""

    name: Literal["interventricular groove"] = "interventricular groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17336"] = "EMAPA_17336"


class _Heart_Left_Ventricle(_MouseAnatomicalStructureModel):
    """Model heart left ventricle"""

    name: Literal["heart left ventricle"] = "heart left ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17337"] = "EMAPA_17337"


class _Left_Ventricle_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model left ventricle endocardial lining"""

    name: Literal["left ventricle endocardial lining"] = "left ventricle endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17338"] = "EMAPA_17338"


class _Left_Ventricle_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model left ventricle cardiac muscle"""

    name: Literal["left ventricle cardiac muscle"] = "left ventricle cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17339"] = "EMAPA_17339"


class _Heart_Right_Ventricle(_MouseAnatomicalStructureModel):
    """Model heart right ventricle"""

    name: Literal["heart right ventricle"] = "heart right ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17340"] = "EMAPA_17340"


class _Right_Ventricle_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model right ventricle endocardial lining"""

    name: Literal["right ventricle endocardial lining"] = "right ventricle endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17341"] = "EMAPA_17341"


class _Right_Ventricle_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model right ventricle cardiac muscle"""

    name: Literal["right ventricle cardiac muscle"] = "right ventricle cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17342"] = "EMAPA_17342"


class _Ductus_Venosus(_MouseAnatomicalStructureModel):
    """Model ductus venosus"""

    name: Literal["ductus venosus"] = "ductus venosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17343"] = "EMAPA_17343"


class _Mesenteric_Vein(_MouseAnatomicalStructureModel):
    """Model mesenteric vein"""

    name: Literal["mesenteric vein"] = "mesenteric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17348"] = "EMAPA_17348"


class _Portal_Vein(_MouseAnatomicalStructureModel):
    """Model portal vein"""

    name: Literal["portal vein"] = "portal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17349"] = "EMAPA_17349"


class _Rostral_Two_Thirds_Of_Anal_Canal(_MouseAnatomicalStructureModel):
    """Model rostral two-thirds of anal canal"""

    name: Literal["rostral two-thirds of anal canal"] = "rostral two-thirds of anal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17350"] = "EMAPA_17350"


class _Hyoid_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hyoid pre-cartilage condensation"""

    name: Literal["hyoid pre-cartilage condensation"] = "hyoid pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17351"] = "EMAPA_17351"


class _Hypobranchial_Eminence(_MouseAnatomicalStructureModel):
    """Model hypobranchial eminence"""

    name: Literal["hypobranchial eminence"] = "hypobranchial eminence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17352"] = "EMAPA_17352"


class _Occipital_Myotome(_MouseAnatomicalStructureModel):
    """Model occipital myotome"""

    name: Literal["occipital myotome"] = "occipital myotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17353"] = "EMAPA_17353"


class _Epiglottal_Primordium(_MouseAnatomicalStructureModel):
    """Model epiglottal primordium"""

    name: Literal["epiglottal primordium"] = "epiglottal primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17354"] = "EMAPA_17354"


class _Mandibular_Process(_MouseAnatomicalStructureModel):
    """Model mandibular process"""

    name: Literal["mandibular process"] = "mandibular process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17355"] = "EMAPA_17355"


class _Mandible_Primordium(_MouseAnatomicalStructureModel):
    """Model mandible primordium"""

    name: Literal["mandible primordium"] = "mandible primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17356"] = "EMAPA_17356"


class _Mandibular_Process_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model mandibular process mesenchyme"""

    name: Literal["mandibular process mesenchyme"] = "mandibular process mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17357"] = "EMAPA_17357"


class _Meckel_S_Cartilage_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Meckel's cartilage pre-cartilage condensation"""

    name: Literal["Meckel's cartilage pre-cartilage condensation"] = "Meckel's cartilage pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17358"] = "EMAPA_17358"


class _Maxillary_Process(_MouseAnatomicalStructureModel):
    """Model maxillary process"""

    name: Literal["maxillary process"] = "maxillary process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17359"] = "EMAPA_17359"


class _Maxilla_Primordium(_MouseAnatomicalStructureModel):
    """Model maxilla primordium"""

    name: Literal["maxilla primordium"] = "maxilla primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17360"] = "EMAPA_17360"


class _Maxillary_Process_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model maxillary process mesenchyme"""

    name: Literal["maxillary process mesenchyme"] = "maxillary process mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17361"] = "EMAPA_17361"


class _Palatal_Shelf(_MouseAnatomicalStructureModel):
    """Model palatal shelf"""

    name: Literal["palatal shelf"] = "palatal shelf"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17362"] = "EMAPA_17362"


class _Palatal_Shelf_Epithelium(_MouseAnatomicalStructureModel):
    """Model palatal shelf epithelium"""

    name: Literal["palatal shelf epithelium"] = "palatal shelf epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17363"] = "EMAPA_17363"


class _Palatal_Shelf_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model palatal shelf mesenchyme"""

    name: Literal["palatal shelf mesenchyme"] = "palatal shelf mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17364"] = "EMAPA_17364"


class _Liver_Sinusoid(_MouseAnatomicalStructureModel):
    """Model liver sinusoid"""

    name: Literal["liver sinusoid"] = "liver sinusoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17365"] = "EMAPA_17365"


class _Urinary_System(_MouseAnatomicalStructureModel):
    """Model urinary system"""

    name: Literal["urinary system"] = "urinary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17366"] = "EMAPA_17366"


class _Urinary_System_Mesentery(_MouseAnatomicalStructureModel):
    """Model urinary system mesentery"""

    name: Literal["urinary system mesentery"] = "urinary system mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17367"] = "EMAPA_17367"


class _Urogenital_Mesentery(_MouseAnatomicalStructureModel):
    """Model urogenital mesentery"""

    name: Literal["urogenital mesentery"] = "urogenital mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17368"] = "EMAPA_17368"


class _Metanephros(_MouseAnatomicalStructureModel):
    """Model metanephros"""

    name: Literal["metanephros"] = "metanephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17373"] = "EMAPA_17373"


class _Metanephric_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model metanephric mesenchyme"""

    name: Literal["metanephric mesenchyme"] = "metanephric mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17375"] = "EMAPA_17375"


class _Urogenital_Membrane(_MouseAnatomicalStructureModel):
    """Model urogenital membrane"""

    name: Literal["urogenital membrane"] = "urogenital membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17378"] = "EMAPA_17378"


class _Urogenital_Sinus(_MouseAnatomicalStructureModel):
    """Model urogenital sinus"""

    name: Literal["urogenital sinus"] = "urogenital sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17379"] = "EMAPA_17379"


class _Reproductive_System(_MouseAnatomicalStructureModel):
    """Model reproductive system"""

    name: Literal["reproductive system"] = "reproductive system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17381"] = "EMAPA_17381"


class _Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model genital tubercle"""

    name: Literal["genital tubercle"] = "genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17382"] = "EMAPA_17382"


class _Gonad(_MouseAnatomicalStructureModel):
    """Model gonad"""

    name: Literal["gonad"] = "gonad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17383"] = "EMAPA_17383"


class _Coelomic_Epithelium_Of_Gonad(_MouseAnatomicalStructureModel):
    """Model coelomic epithelium of gonad"""

    name: Literal["coelomic epithelium of gonad"] = "coelomic epithelium of gonad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17384"] = "EMAPA_17384"


class _Gonadal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model gonadal mesenchyme"""

    name: Literal["gonadal mesenchyme"] = "gonadal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17385"] = "EMAPA_17385"


class _Arytenoid_Swelling_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model arytenoid swelling pre-cartilage condensation"""

    name: Literal["arytenoid swelling pre-cartilage condensation"] = "arytenoid swelling pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17387"] = "EMAPA_17387"


class _Left_Lung_Rudiment_Lobar_Bronchus(_MouseAnatomicalStructureModel):
    """Model left lung rudiment lobar bronchus"""

    name: Literal["left lung rudiment lobar bronchus"] = "left lung rudiment lobar bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17388"] = "EMAPA_17388"


class _Left_Lung_Rudiment_Lobar_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model left lung rudiment lobar bronchus mesenchyme"""

    name: Literal["left lung rudiment lobar bronchus mesenchyme"] = "left lung rudiment lobar bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17389"] = "EMAPA_17389"


class _Left_Lung_Rudiment_Lobar_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model left lung rudiment lobar bronchus epithelium"""

    name: Literal["left lung rudiment lobar bronchus epithelium"] = "left lung rudiment lobar bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17390"] = "EMAPA_17390"


class _Left_Lung_Rudiment_Lobar_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model left lung rudiment lobar bronchus vascular element"""

    name: Literal[
        "left lung rudiment lobar bronchus vascular element"
    ] = "left lung rudiment lobar bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17391"] = "EMAPA_17391"


class _Cervical_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model cervical vertebral cartilage condensation"""

    name: Literal["cervical vertebral cartilage condensation"] = "cervical vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17392"] = "EMAPA_17392"


class _Axial_Skeleton_Lumbar_Region(_MouseAnatomicalStructureModel):
    """Model axial skeleton lumbar region"""

    name: Literal["axial skeleton lumbar region"] = "axial skeleton lumbar region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17393"] = "EMAPA_17393"


class _Lumbar_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model lumbar vertebral pre-cartilage condensation"""

    name: Literal["lumbar vertebral pre-cartilage condensation"] = "lumbar vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17394"] = "EMAPA_17394"


class _Sclerotome_Condensation(_MouseAnatomicalStructureModel):
    """Model sclerotome condensation"""

    name: Literal["sclerotome condensation"] = "sclerotome condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17395"] = "EMAPA_17395"


class _Axial_Skeleton_Thoracic_Region(_MouseAnatomicalStructureModel):
    """Model axial skeleton thoracic region"""

    name: Literal["axial skeleton thoracic region"] = "axial skeleton thoracic region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17396"] = "EMAPA_17396"


class _Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model rib pre-cartilage condensation"""

    name: Literal["rib pre-cartilage condensation"] = "rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17397"] = "EMAPA_17397"


class _Thoracic_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model thoracic vertebral pre-cartilage condensation"""

    name: Literal["thoracic vertebral pre-cartilage condensation"] = "thoracic vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17398"] = "EMAPA_17398"


class _Somite_46(_MouseAnatomicalStructureModel):
    """Model somite 46"""

    name: Literal["somite 46"] = "somite 46"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17399"] = "EMAPA_17399"


class _Somite_46_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 46 dermomyotome"""

    name: Literal["somite 46 dermomyotome"] = "somite 46 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17400"] = "EMAPA_17400"


class _Somite_46_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 46 myocoele"""

    name: Literal["somite 46 myocoele"] = "somite 46 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17401"] = "EMAPA_17401"


class _Somite_46_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 46 sclerotome"""

    name: Literal["somite 46 sclerotome"] = "somite 46 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17402"] = "EMAPA_17402"


class _Somite_47(_MouseAnatomicalStructureModel):
    """Model somite 47"""

    name: Literal["somite 47"] = "somite 47"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17403"] = "EMAPA_17403"


class _Somite_47_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 47 dermomyotome"""

    name: Literal["somite 47 dermomyotome"] = "somite 47 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17404"] = "EMAPA_17404"


class _Somite_47_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 47 myocoele"""

    name: Literal["somite 47 myocoele"] = "somite 47 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17405"] = "EMAPA_17405"


class _Somite_47_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 47 sclerotome"""

    name: Literal["somite 47 sclerotome"] = "somite 47 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17406"] = "EMAPA_17406"


class _Somite_48(_MouseAnatomicalStructureModel):
    """Model somite 48"""

    name: Literal["somite 48"] = "somite 48"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17407"] = "EMAPA_17407"


class _Somite_48_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 48 dermomyotome"""

    name: Literal["somite 48 dermomyotome"] = "somite 48 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17408"] = "EMAPA_17408"


class _Somite_48_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 48 myocoele"""

    name: Literal["somite 48 myocoele"] = "somite 48 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17409"] = "EMAPA_17409"


class _Somite_48_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 48 sclerotome"""

    name: Literal["somite 48 sclerotome"] = "somite 48 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17410"] = "EMAPA_17410"


class _Oral_Cavity(_MouseAnatomicalStructureModel):
    """Model oral cavity"""

    name: Literal["oral cavity"] = "oral cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17411"] = "EMAPA_17411"


class _Forelimb(_MouseAnatomicalStructureModel):
    """Model forelimb"""

    name: Literal["forelimb"] = "forelimb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17412"] = "EMAPA_17412"


class _Arm(_MouseAnatomicalStructureModel):
    """Model arm"""

    name: Literal["arm"] = "arm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17413"] = "EMAPA_17413"


class _Elbow(_MouseAnatomicalStructureModel):
    """Model elbow"""

    name: Literal["elbow"] = "elbow"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17414"] = "EMAPA_17414"


class _Elbow_Epithelium(_MouseAnatomicalStructureModel):
    """Model elbow epithelium"""

    name: Literal["elbow epithelium"] = "elbow epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17415"] = "EMAPA_17415"


class _Elbow_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model elbow mesenchyme"""

    name: Literal["elbow mesenchyme"] = "elbow mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17416"] = "EMAPA_17416"


class _Forearm(_MouseAnatomicalStructureModel):
    """Model forearm"""

    name: Literal["forearm"] = "forearm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17417"] = "EMAPA_17417"


class _Forearm_Epithelium(_MouseAnatomicalStructureModel):
    """Model forearm epithelium"""

    name: Literal["forearm epithelium"] = "forearm epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17418"] = "EMAPA_17418"


class _Forearm_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forearm mesenchyme"""

    name: Literal["forearm mesenchyme"] = "forearm mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17419"] = "EMAPA_17419"


class _Radius_Ulna_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model radius-ulna pre-cartilage condensation"""

    name: Literal["radius-ulna pre-cartilage condensation"] = "radius-ulna pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17420"] = "EMAPA_17420"


class _Shoulder(_MouseAnatomicalStructureModel):
    """Model shoulder"""

    name: Literal["shoulder"] = "shoulder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17421"] = "EMAPA_17421"


class _Shoulder_Epithelium(_MouseAnatomicalStructureModel):
    """Model shoulder epithelium"""

    name: Literal["shoulder epithelium"] = "shoulder epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17422"] = "EMAPA_17422"


class _Shoulder_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model shoulder mesenchyme"""

    name: Literal["shoulder mesenchyme"] = "shoulder mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17423"] = "EMAPA_17423"


class _Upper_Arm(_MouseAnatomicalStructureModel):
    """Model upper arm"""

    name: Literal["upper arm"] = "upper arm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17424"] = "EMAPA_17424"


class _Upper_Arm_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper arm epithelium"""

    name: Literal["upper arm epithelium"] = "upper arm epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17425"] = "EMAPA_17425"


class _Upper_Arm_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper arm mesenchyme"""

    name: Literal["upper arm mesenchyme"] = "upper arm mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17426"] = "EMAPA_17426"


class _Humerus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model humerus pre-cartilage condensation"""

    name: Literal["humerus pre-cartilage condensation"] = "humerus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17427"] = "EMAPA_17427"


class _Hand(_MouseAnatomicalStructureModel):
    """Model hand"""

    name: Literal["hand"] = "hand"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17428"] = "EMAPA_17428"


class _Forelimb_Digit_1(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1"""

    name: Literal["forelimb digit 1"] = "forelimb digit 1"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17429"] = "EMAPA_17429"


class _Forelimb_Digit_1_Epithelium(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 epithelium"""

    name: Literal["forelimb digit 1 epithelium"] = "forelimb digit 1 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17430"] = "EMAPA_17430"


class _Forelimb_Digit_1_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 mesenchyme"""

    name: Literal["forelimb digit 1 mesenchyme"] = "forelimb digit 1 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17431"] = "EMAPA_17431"


class _Forelimb_Digit_2(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2"""

    name: Literal["forelimb digit 2"] = "forelimb digit 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17432"] = "EMAPA_17432"


class _Forelimb_Digit_2_Epithelium(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 epithelium"""

    name: Literal["forelimb digit 2 epithelium"] = "forelimb digit 2 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17433"] = "EMAPA_17433"


class _Forelimb_Digit_2_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 mesenchyme"""

    name: Literal["forelimb digit 2 mesenchyme"] = "forelimb digit 2 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17434"] = "EMAPA_17434"


class _Forelimb_Digit_3(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3"""

    name: Literal["forelimb digit 3"] = "forelimb digit 3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17435"] = "EMAPA_17435"


class _Forelimb_Digit_3_Epithelium(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 epithelium"""

    name: Literal["forelimb digit 3 epithelium"] = "forelimb digit 3 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17436"] = "EMAPA_17436"


class _Forelimb_Digit_3_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 mesenchyme"""

    name: Literal["forelimb digit 3 mesenchyme"] = "forelimb digit 3 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17437"] = "EMAPA_17437"


class _Forelimb_Digit_4(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4"""

    name: Literal["forelimb digit 4"] = "forelimb digit 4"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17438"] = "EMAPA_17438"


class _Forelimb_Digit_4_Epithelium(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 epithelium"""

    name: Literal["forelimb digit 4 epithelium"] = "forelimb digit 4 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17439"] = "EMAPA_17439"


class _Forelimb_Digit_4_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 mesenchyme"""

    name: Literal["forelimb digit 4 mesenchyme"] = "forelimb digit 4 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17440"] = "EMAPA_17440"


class _Forelimb_Digit_5(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5"""

    name: Literal["forelimb digit 5"] = "forelimb digit 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17441"] = "EMAPA_17441"


class _Forelimb_Digit_5_Epithelium(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 epithelium"""

    name: Literal["forelimb digit 5 epithelium"] = "forelimb digit 5 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17442"] = "EMAPA_17442"


class _Forelimb_Digit_5_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 mesenchyme"""

    name: Literal["forelimb digit 5 mesenchyme"] = "forelimb digit 5 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17443"] = "EMAPA_17443"


class _Hand_Rest_Of_Epithelium(_MouseAnatomicalStructureModel):
    """Model hand rest of epithelium"""

    name: Literal["hand rest of epithelium"] = "hand rest of epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17444"] = "EMAPA_17444"


class _Interdigital_Region_Between_Forelimb_Digits_1_And_2(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 1 and 2"""

    name: Literal[
        "interdigital region between forelimb digits 1 and 2"
    ] = "interdigital region between forelimb digits 1 and 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17445"] = "EMAPA_17445"


class _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 1 and 2 epithelium"""

    name: Literal[
        "interdigital region between forelimb digits 1 and 2 epithelium"
    ] = "interdigital region between forelimb digits 1 and 2 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17446"] = "EMAPA_17446"


class _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 1 and 2 mesenchyme"""

    name: Literal[
        "interdigital region between forelimb digits 1 and 2 mesenchyme"
    ] = "interdigital region between forelimb digits 1 and 2 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17447"] = "EMAPA_17447"


class _Interdigital_Region_Between_Forelimb_Digits_2_And_3(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 2 and 3"""

    name: Literal[
        "interdigital region between forelimb digits 2 and 3"
    ] = "interdigital region between forelimb digits 2 and 3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17448"] = "EMAPA_17448"


class _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 2 and 3 epithelium"""

    name: Literal[
        "interdigital region between forelimb digits 2 and 3 epithelium"
    ] = "interdigital region between forelimb digits 2 and 3 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17449"] = "EMAPA_17449"


class _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 2 and 3 mesenchyme"""

    name: Literal[
        "interdigital region between forelimb digits 2 and 3 mesenchyme"
    ] = "interdigital region between forelimb digits 2 and 3 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17450"] = "EMAPA_17450"


class _Interdigital_Region_Between_Forelimb_Digits_3_And_4(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 3 and 4"""

    name: Literal[
        "interdigital region between forelimb digits 3 and 4"
    ] = "interdigital region between forelimb digits 3 and 4"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17451"] = "EMAPA_17451"


class _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 3 and 4 epithelium"""

    name: Literal[
        "interdigital region between forelimb digits 3 and 4 epithelium"
    ] = "interdigital region between forelimb digits 3 and 4 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17452"] = "EMAPA_17452"


class _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 3 and 4 mesenchyme"""

    name: Literal[
        "interdigital region between forelimb digits 3 and 4 mesenchyme"
    ] = "interdigital region between forelimb digits 3 and 4 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17453"] = "EMAPA_17453"


class _Interdigital_Region_Between_Forelimb_Digits_4_And_5(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 4 and 5"""

    name: Literal[
        "interdigital region between forelimb digits 4 and 5"
    ] = "interdigital region between forelimb digits 4 and 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17454"] = "EMAPA_17454"


class _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 4 and 5 epithelium"""

    name: Literal[
        "interdigital region between forelimb digits 4 and 5 epithelium"
    ] = "interdigital region between forelimb digits 4 and 5 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17455"] = "EMAPA_17455"


class _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 4 and 5 mesenchyme"""

    name: Literal[
        "interdigital region between forelimb digits 4 and 5 mesenchyme"
    ] = "interdigital region between forelimb digits 4 and 5 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17456"] = "EMAPA_17456"


class _Hand_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hand mesenchyme"""

    name: Literal["hand mesenchyme"] = "hand mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17457"] = "EMAPA_17457"


class _Hindlimb(_MouseAnatomicalStructureModel):
    """Model hindlimb"""

    name: Literal["hindlimb"] = "hindlimb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17458"] = "EMAPA_17458"


class _Foot(_MouseAnatomicalStructureModel):
    """Model foot"""

    name: Literal["foot"] = "foot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17459"] = "EMAPA_17459"


class _Hindlimb_Digit_1(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1"""

    name: Literal["hindlimb digit 1"] = "hindlimb digit 1"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17460"] = "EMAPA_17460"


class _Hindlimb_Digit_1_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 epithelium"""

    name: Literal["hindlimb digit 1 epithelium"] = "hindlimb digit 1 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17461"] = "EMAPA_17461"


class _Hindlimb_Digit_1_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 mesenchyme"""

    name: Literal["hindlimb digit 1 mesenchyme"] = "hindlimb digit 1 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17462"] = "EMAPA_17462"


class _Hindlimb_Digit_2(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2"""

    name: Literal["hindlimb digit 2"] = "hindlimb digit 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17463"] = "EMAPA_17463"


class _Hindlimb_Digit_2_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 epithelium"""

    name: Literal["hindlimb digit 2 epithelium"] = "hindlimb digit 2 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17464"] = "EMAPA_17464"


class _Hindlimb_Digit_2_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 mesenchyme"""

    name: Literal["hindlimb digit 2 mesenchyme"] = "hindlimb digit 2 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17465"] = "EMAPA_17465"


class _Hindlimb_Digit_3(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3"""

    name: Literal["hindlimb digit 3"] = "hindlimb digit 3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17466"] = "EMAPA_17466"


class _Hindlimb_Digit_3_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 epithelium"""

    name: Literal["hindlimb digit 3 epithelium"] = "hindlimb digit 3 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17467"] = "EMAPA_17467"


class _Hindlimb_Digit_3_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 mesenchyme"""

    name: Literal["hindlimb digit 3 mesenchyme"] = "hindlimb digit 3 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17468"] = "EMAPA_17468"


class _Hindlimb_Digit_4(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4"""

    name: Literal["hindlimb digit 4"] = "hindlimb digit 4"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17469"] = "EMAPA_17469"


class _Hindlimb_Digit_4_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 epithelium"""

    name: Literal["hindlimb digit 4 epithelium"] = "hindlimb digit 4 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17470"] = "EMAPA_17470"


class _Hindlimb_Digit_4_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 mesenchyme"""

    name: Literal["hindlimb digit 4 mesenchyme"] = "hindlimb digit 4 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17471"] = "EMAPA_17471"


class _Hindlimb_Digit_5(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5"""

    name: Literal["hindlimb digit 5"] = "hindlimb digit 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17472"] = "EMAPA_17472"


class _Hindlimb_Digit_5_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 epithelium"""

    name: Literal["hindlimb digit 5 epithelium"] = "hindlimb digit 5 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17473"] = "EMAPA_17473"


class _Hindlimb_Digit_5_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 mesenchyme"""

    name: Literal["hindlimb digit 5 mesenchyme"] = "hindlimb digit 5 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17474"] = "EMAPA_17474"


class _Foot_Rest_Of_Epithelium(_MouseAnatomicalStructureModel):
    """Model foot rest of epithelium"""

    name: Literal["foot rest of epithelium"] = "foot rest of epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17475"] = "EMAPA_17475"


class _Interdigital_Region_Between_Hindlimb_Digits_1_And_2(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 1 and 2"""

    name: Literal[
        "interdigital region between hindlimb digits 1 and 2"
    ] = "interdigital region between hindlimb digits 1 and 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17476"] = "EMAPA_17476"


class _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 1 and 2 epithelium"""

    name: Literal[
        "interdigital region between hindlimb digits 1 and 2 epithelium"
    ] = "interdigital region between hindlimb digits 1 and 2 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17477"] = "EMAPA_17477"


class _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 1 and 2 mesenchyme"""

    name: Literal[
        "interdigital region between hindlimb digits 1 and 2 mesenchyme"
    ] = "interdigital region between hindlimb digits 1 and 2 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17478"] = "EMAPA_17478"


class _Interdigital_Region_Between_Hindlimb_Digits_2_And_3(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 2 and 3"""

    name: Literal[
        "interdigital region between hindlimb digits 2 and 3"
    ] = "interdigital region between hindlimb digits 2 and 3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17479"] = "EMAPA_17479"


class _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 2 and 3 epithelium"""

    name: Literal[
        "interdigital region between hindlimb digits 2 and 3 epithelium"
    ] = "interdigital region between hindlimb digits 2 and 3 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17480"] = "EMAPA_17480"


class _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 2 and 3 mesenchyme"""

    name: Literal[
        "interdigital region between hindlimb digits 2 and 3 mesenchyme"
    ] = "interdigital region between hindlimb digits 2 and 3 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17481"] = "EMAPA_17481"


class _Interdigital_Region_Between_Hindlimb_Digits_3_And_4(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 3 and 4"""

    name: Literal[
        "interdigital region between hindlimb digits 3 and 4"
    ] = "interdigital region between hindlimb digits 3 and 4"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17482"] = "EMAPA_17482"


class _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 3 and 4 epithelium"""

    name: Literal[
        "interdigital region between hindlimb digits 3 and 4 epithelium"
    ] = "interdigital region between hindlimb digits 3 and 4 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17483"] = "EMAPA_17483"


class _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 3 and 4 mesenchyme"""

    name: Literal[
        "interdigital region between hindlimb digits 3 and 4 mesenchyme"
    ] = "interdigital region between hindlimb digits 3 and 4 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17484"] = "EMAPA_17484"


class _Interdigital_Region_Between_Hindlimb_Digits_4_And_5(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 4 and 5"""

    name: Literal[
        "interdigital region between hindlimb digits 4 and 5"
    ] = "interdigital region between hindlimb digits 4 and 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17485"] = "EMAPA_17485"


class _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 4 and 5 epithelium"""

    name: Literal[
        "interdigital region between hindlimb digits 4 and 5 epithelium"
    ] = "interdigital region between hindlimb digits 4 and 5 epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17486"] = "EMAPA_17486"


class _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 4 and 5 mesenchyme"""

    name: Literal[
        "interdigital region between hindlimb digits 4 and 5 mesenchyme"
    ] = "interdigital region between hindlimb digits 4 and 5 mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17487"] = "EMAPA_17487"


class _Foot_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model foot mesenchyme"""

    name: Literal["foot mesenchyme"] = "foot mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17488"] = "EMAPA_17488"


class _Leg(_MouseAnatomicalStructureModel):
    """Model leg"""

    name: Literal["leg"] = "leg"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17489"] = "EMAPA_17489"


class _Hip(_MouseAnatomicalStructureModel):
    """Model hip"""

    name: Literal["hip"] = "hip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17490"] = "EMAPA_17490"


class _Hip_Epithelium(_MouseAnatomicalStructureModel):
    """Model hip epithelium"""

    name: Literal["hip epithelium"] = "hip epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17491"] = "EMAPA_17491"


class _Hip_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hip mesenchyme"""

    name: Literal["hip mesenchyme"] = "hip mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17492"] = "EMAPA_17492"


class _Knee(_MouseAnatomicalStructureModel):
    """Model knee"""

    name: Literal["knee"] = "knee"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17493"] = "EMAPA_17493"


class _Knee_Epithelium(_MouseAnatomicalStructureModel):
    """Model knee epithelium"""

    name: Literal["knee epithelium"] = "knee epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17494"] = "EMAPA_17494"


class _Knee_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model knee mesenchyme"""

    name: Literal["knee mesenchyme"] = "knee mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17495"] = "EMAPA_17495"


class _Lower_Leg(_MouseAnatomicalStructureModel):
    """Model lower leg"""

    name: Literal["lower leg"] = "lower leg"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17496"] = "EMAPA_17496"


class _Lower_Leg_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower leg epithelium"""

    name: Literal["lower leg epithelium"] = "lower leg epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17497"] = "EMAPA_17497"


class _Lower_Leg_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower leg mesenchyme"""

    name: Literal["lower leg mesenchyme"] = "lower leg mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17498"] = "EMAPA_17498"


class _Upper_Leg(_MouseAnatomicalStructureModel):
    """Model upper leg"""

    name: Literal["upper leg"] = "upper leg"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17499"] = "EMAPA_17499"


class _Upper_Leg_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper leg epithelium"""

    name: Literal["upper leg epithelium"] = "upper leg epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17500"] = "EMAPA_17500"


class _Upper_Leg_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper leg mesenchyme"""

    name: Literal["upper leg mesenchyme"] = "upper leg mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17501"] = "EMAPA_17501"


class _Femur_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model femur pre-cartilage condensation"""

    name: Literal["femur pre-cartilage condensation"] = "femur pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17502"] = "EMAPA_17502"


class _Pancreas(_MouseAnatomicalStructureModel):
    """Model pancreas"""

    name: Literal["pancreas"] = "pancreas"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17503"] = "EMAPA_17503"


class _Body_Of_Pancreas(_MouseAnatomicalStructureModel):
    """Model body of pancreas"""

    name: Literal["body of pancreas"] = "body of pancreas"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17504"] = "EMAPA_17504"


class _Dorsal_Pancreatic_Duct_Of_Pancreas_Body(_MouseAnatomicalStructureModel):
    """Model dorsal pancreatic duct of pancreas body"""

    name: Literal["dorsal pancreatic duct of pancreas body"] = "dorsal pancreatic duct of pancreas body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17505"] = "EMAPA_17505"


class _Pancreas_Body_Parenchyma(_MouseAnatomicalStructureModel):
    """Model pancreas body parenchyma"""

    name: Literal["pancreas body parenchyma"] = "pancreas body parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17506"] = "EMAPA_17506"


class _Head_Of_Pancreas(_MouseAnatomicalStructureModel):
    """Model head of pancreas"""

    name: Literal["head of pancreas"] = "head of pancreas"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17507"] = "EMAPA_17507"


class _Pancreas_Head_Parenchyma(_MouseAnatomicalStructureModel):
    """Model pancreas head parenchyma"""

    name: Literal["pancreas head parenchyma"] = "pancreas head parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17508"] = "EMAPA_17508"


class _Uncinate_Process(_MouseAnatomicalStructureModel):
    """Model uncinate process"""

    name: Literal["uncinate process"] = "uncinate process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17509"] = "EMAPA_17509"


class _Ventral_Pancreatic_Duct(_MouseAnatomicalStructureModel):
    """Model ventral pancreatic duct"""

    name: Literal["ventral pancreatic duct"] = "ventral pancreatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17510"] = "EMAPA_17510"


class _Tail_Of_Pancreas(_MouseAnatomicalStructureModel):
    """Model tail of pancreas"""

    name: Literal["tail of pancreas"] = "tail of pancreas"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17511"] = "EMAPA_17511"


class _Dorsal_Pancreatic_Duct_Of_Pancreas_Tail(_MouseAnatomicalStructureModel):
    """Model dorsal pancreatic duct of pancreas tail"""

    name: Literal["dorsal pancreatic duct of pancreas tail"] = "dorsal pancreatic duct of pancreas tail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17512"] = "EMAPA_17512"


class _Pancreas_Tail_Parenchyma(_MouseAnatomicalStructureModel):
    """Model pancreas tail parenchyma"""

    name: Literal["pancreas tail parenchyma"] = "pancreas tail parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17513"] = "EMAPA_17513"


class _Adenohypophysis(_MouseAnatomicalStructureModel):
    """Model adenohypophysis"""

    name: Literal["adenohypophysis"] = "adenohypophysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17514"] = "EMAPA_17514"


class _Adenohypophysis_Pars_Anterior(_MouseAnatomicalStructureModel):
    """Model adenohypophysis pars anterior"""

    name: Literal["adenohypophysis pars anterior"] = "adenohypophysis pars anterior"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17515"] = "EMAPA_17515"


class _Adenohypophysis_Pars_Intermedia(_MouseAnatomicalStructureModel):
    """Model adenohypophysis pars intermedia"""

    name: Literal["adenohypophysis pars intermedia"] = "adenohypophysis pars intermedia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17516"] = "EMAPA_17516"


class _Adenohypophysis_Pars_Tuberalis(_MouseAnatomicalStructureModel):
    """Model adenohypophysis pars tuberalis"""

    name: Literal["adenohypophysis pars tuberalis"] = "adenohypophysis pars tuberalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17517"] = "EMAPA_17517"


class _Remnant_Of_Rathke_S_Pouch(_MouseAnatomicalStructureModel):
    """Model remnant of Rathke's pouch"""

    name: Literal["remnant of Rathke's pouch"] = "remnant of Rathke's pouch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17518"] = "EMAPA_17518"


class _Neurohypophysis(_MouseAnatomicalStructureModel):
    """Model neurohypophysis"""

    name: Literal["neurohypophysis"] = "neurohypophysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17519"] = "EMAPA_17519"


class _Neurohypophysis_Infundibulum(_MouseAnatomicalStructureModel):
    """Model neurohypophysis infundibulum"""

    name: Literal["neurohypophysis infundibulum"] = "neurohypophysis infundibulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17520"] = "EMAPA_17520"


class _Median_Eminence(_MouseAnatomicalStructureModel):
    """Model median eminence"""

    name: Literal["median eminence"] = "median eminence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17521"] = "EMAPA_17521"


class _Thymus_Primordium(_MouseAnatomicalStructureModel):
    """Model thymus primordium"""

    name: Literal["thymus primordium"] = "thymus primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17523"] = "EMAPA_17523"


class _Integumental_System(_MouseAnatomicalStructureModel):
    """Model integumental system"""

    name: Literal["integumental system"] = "integumental system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17524"] = "EMAPA_17524"


class _Skin(_MouseAnatomicalStructureModel):
    """Model skin"""

    name: Literal["skin"] = "skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17525"] = "EMAPA_17525"


class _Dermis(_MouseAnatomicalStructureModel):
    """Model dermis"""

    name: Literal["dermis"] = "dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17527"] = "EMAPA_17527"


class _Epidermis(_MouseAnatomicalStructureModel):
    """Model epidermis"""

    name: Literal["epidermis"] = "epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17528"] = "EMAPA_17528"


class _Vibrissa(_MouseAnatomicalStructureModel):
    """Model vibrissa"""

    name: Literal["vibrissa"] = "vibrissa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17529"] = "EMAPA_17529"


class _Vibrissa_Epithelium(_MouseAnatomicalStructureModel):
    """Model vibrissa epithelium"""

    name: Literal["vibrissa epithelium"] = "vibrissa epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17530"] = "EMAPA_17530"


class _Vibrissa_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model vibrissa mesenchyme"""

    name: Literal["vibrissa mesenchyme"] = "vibrissa mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17531"] = "EMAPA_17531"


class _Epithalamus(_MouseAnatomicalStructureModel):
    """Model epithalamus"""

    name: Literal["epithalamus"] = "epithalamus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17532"] = "EMAPA_17532"


class _Epithalamus_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model epithalamus mantle layer"""

    name: Literal["epithalamus mantle layer"] = "epithalamus mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17533"] = "EMAPA_17533"


class _Epithalamus_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model epithalamus marginal layer"""

    name: Literal["epithalamus marginal layer"] = "epithalamus marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17534"] = "EMAPA_17534"


class _Epithalamus_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model epithalamus ventricular layer"""

    name: Literal["epithalamus ventricular layer"] = "epithalamus ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17535"] = "EMAPA_17535"


class _Hypothalamus(_MouseAnatomicalStructureModel):
    """Model hypothalamus"""

    name: Literal["hypothalamus"] = "hypothalamus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17536"] = "EMAPA_17536"


class _Hypothalamus_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model hypothalamus mantle layer"""

    name: Literal["hypothalamus mantle layer"] = "hypothalamus mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17537"] = "EMAPA_17537"


class _Hypothalamus_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model hypothalamus marginal layer"""

    name: Literal["hypothalamus marginal layer"] = "hypothalamus marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17538"] = "EMAPA_17538"


class _Hypothalamus_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model hypothalamus ventricular layer"""

    name: Literal["hypothalamus ventricular layer"] = "hypothalamus ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17539"] = "EMAPA_17539"


class _Thalamus(_MouseAnatomicalStructureModel):
    """Model thalamus"""

    name: Literal["thalamus"] = "thalamus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17540"] = "EMAPA_17540"


class _Thalamus_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model thalamus mantle layer"""

    name: Literal["thalamus mantle layer"] = "thalamus mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17541"] = "EMAPA_17541"


class _Thalamus_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model thalamus marginal layer"""

    name: Literal["thalamus marginal layer"] = "thalamus marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17542"] = "EMAPA_17542"


class _Thalamus_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model thalamus ventricular layer"""

    name: Literal["thalamus ventricular layer"] = "thalamus ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17543"] = "EMAPA_17543"


class _Cerebral_Cortex(_MouseAnatomicalStructureModel):
    """Model cerebral cortex"""

    name: Literal["cerebral cortex"] = "cerebral cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17544"] = "EMAPA_17544"


class _Cerebral_Cortex_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model cerebral cortex mantle layer"""

    name: Literal["cerebral cortex mantle layer"] = "cerebral cortex mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17545"] = "EMAPA_17545"


class _Cerebral_Cortex_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model cerebral cortex marginal layer"""

    name: Literal["cerebral cortex marginal layer"] = "cerebral cortex marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17546"] = "EMAPA_17546"


class _Cerebral_Cortex_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model cerebral cortex ventricular layer"""

    name: Literal["cerebral cortex ventricular layer"] = "cerebral cortex ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17547"] = "EMAPA_17547"


class _Choroid_Invagination(_MouseAnatomicalStructureModel):
    """Model choroid invagination"""

    name: Literal["choroid invagination"] = "choroid invagination"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17548"] = "EMAPA_17548"


class _Corpus_Striatum(_MouseAnatomicalStructureModel):
    """Model corpus striatum"""

    name: Literal["corpus striatum"] = "corpus striatum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17549"] = "EMAPA_17549"


class _Medulla_Oblongata(_MouseAnatomicalStructureModel):
    """Model medulla oblongata"""

    name: Literal["medulla oblongata"] = "medulla oblongata"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17550"] = "EMAPA_17550"


class _Medulla_Oblongata_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model medulla oblongata floor plate"""

    name: Literal["medulla oblongata floor plate"] = "medulla oblongata floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17551"] = "EMAPA_17551"


class _Medulla_Oblongata_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model medulla oblongata lateral wall"""

    name: Literal["medulla oblongata lateral wall"] = "medulla oblongata lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17552"] = "EMAPA_17552"


class _Medulla_Oblongata_Alar_Plate(_MouseAnatomicalStructureModel):
    """Model medulla oblongata alar plate"""

    name: Literal["medulla oblongata alar plate"] = "medulla oblongata alar plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17553"] = "EMAPA_17553"


class _Medulla_Oblongata_Alar_Plate_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata alar plate mantle layer"""

    name: Literal["medulla oblongata alar plate mantle layer"] = "medulla oblongata alar plate mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17554"] = "EMAPA_17554"


class _Medulla_Oblongata_Alar_Plate_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata alar plate marginal layer"""

    name: Literal["medulla oblongata alar plate marginal layer"] = "medulla oblongata alar plate marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17555"] = "EMAPA_17555"


class _Medulla_Oblongata_Alar_Plate_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata alar plate ventricular layer"""

    name: Literal["medulla oblongata alar plate ventricular layer"] = "medulla oblongata alar plate ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17556"] = "EMAPA_17556"


class _Medulla_Oblongata_Basal_Plate(_MouseAnatomicalStructureModel):
    """Model medulla oblongata basal plate"""

    name: Literal["medulla oblongata basal plate"] = "medulla oblongata basal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17557"] = "EMAPA_17557"


class _Medulla_Oblongata_Basal_Plate_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata basal plate mantle layer"""

    name: Literal["medulla oblongata basal plate mantle layer"] = "medulla oblongata basal plate mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17558"] = "EMAPA_17558"


class _Medulla_Oblongata_Basal_Plate_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata basal plate marginal layer"""

    name: Literal["medulla oblongata basal plate marginal layer"] = "medulla oblongata basal plate marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17559"] = "EMAPA_17559"


class _Medulla_Oblongata_Basal_Plate_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata basal plate ventricular layer"""

    name: Literal["medulla oblongata basal plate ventricular layer"] = "medulla oblongata basal plate ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17560"] = "EMAPA_17560"


class _Medulla_Oblongata_Sulcus_Limitans(_MouseAnatomicalStructureModel):
    """Model medulla oblongata sulcus limitans"""

    name: Literal["medulla oblongata sulcus limitans"] = "medulla oblongata sulcus limitans"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17561"] = "EMAPA_17561"


class _Medulla_Oblongata_Roof(_MouseAnatomicalStructureModel):
    """Model medulla oblongata roof"""

    name: Literal["medulla oblongata roof"] = "medulla oblongata roof"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17562"] = "EMAPA_17562"


class _Pons(_MouseAnatomicalStructureModel):
    """Model pons"""

    name: Literal["pons"] = "pons"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17563"] = "EMAPA_17563"


class _Pons_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model pons mantle layer"""

    name: Literal["pons mantle layer"] = "pons mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17564"] = "EMAPA_17564"


class _Pons_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model pons marginal layer"""

    name: Literal["pons marginal layer"] = "pons marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17565"] = "EMAPA_17565"


class _Pons_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model pons ventricular layer"""

    name: Literal["pons ventricular layer"] = "pons ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17566"] = "EMAPA_17566"


class _Metencephalon_Sulcus_Limitans(_MouseAnatomicalStructureModel):
    """Model metencephalon sulcus limitans"""

    name: Literal["metencephalon sulcus limitans"] = "metencephalon sulcus limitans"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17567"] = "EMAPA_17567"


class _Metencephalon_Part_Of_4Th_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model metencephalon part of 4th ventricle choroid plexus"""

    name: Literal[
        "metencephalon part of 4th ventricle choroid plexus"
    ] = "metencephalon part of 4th ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17568"] = "EMAPA_17568"


class _Facial_Ganglion(_MouseAnatomicalStructureModel):
    """Model facial ganglion"""

    name: Literal["facial ganglion"] = "facial ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17569"] = "EMAPA_17569"


class _Vestibulo_Cochlear_Ganglion_Complex(_MouseAnatomicalStructureModel):
    """Model vestibulo-cochlear ganglion complex"""

    name: Literal["vestibulo-cochlear ganglion complex"] = "vestibulo-cochlear ganglion complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17570"] = "EMAPA_17570"


class _Vestibulo_Cochlear_Ganglion(_MouseAnatomicalStructureModel):
    """Model vestibulo-cochlear ganglion"""

    name: Literal["vestibulo-cochlear ganglion"] = "vestibulo-cochlear ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17571"] = "EMAPA_17571"


class _Cochlear_Ganglion(_MouseAnatomicalStructureModel):
    """Model cochlear ganglion"""

    name: Literal["cochlear ganglion"] = "cochlear ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17572"] = "EMAPA_17572"


class _Vestibular_Ganglion(_MouseAnatomicalStructureModel):
    """Model vestibular ganglion"""

    name: Literal["vestibular ganglion"] = "vestibular ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17573"] = "EMAPA_17573"


class _Oculomotor_Nerve(_MouseAnatomicalStructureModel):
    """Model oculomotor nerve"""

    name: Literal["oculomotor nerve"] = "oculomotor nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17574"] = "EMAPA_17574"


class _Optic_Nerve(_MouseAnatomicalStructureModel):
    """Model optic nerve"""

    name: Literal["optic nerve"] = "optic nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17575"] = "EMAPA_17575"


class _Trigeminal_Nerve(_MouseAnatomicalStructureModel):
    """Model trigeminal nerve"""

    name: Literal["trigeminal nerve"] = "trigeminal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17576"] = "EMAPA_17576"


class _Spinal_Cord(_MouseAnatomicalStructureModel):
    """Model spinal cord"""

    name: Literal["spinal cord"] = "spinal cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17577"] = "EMAPA_17577"


class _Spinal_Cord_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model spinal cord floor plate"""

    name: Literal["spinal cord floor plate"] = "spinal cord floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17578"] = "EMAPA_17578"


class _Spinal_Cord_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model spinal cord lateral wall"""

    name: Literal["spinal cord lateral wall"] = "spinal cord lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17579"] = "EMAPA_17579"


class _Spinal_Cord_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model spinal cord mantle layer"""

    name: Literal["spinal cord mantle layer"] = "spinal cord mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17580"] = "EMAPA_17580"


class _Alar_Columns(_MouseAnatomicalStructureModel):
    """Model alar columns"""

    name: Literal["alar columns"] = "alar columns"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17581"] = "EMAPA_17581"


class _Basal_Columns(_MouseAnatomicalStructureModel):
    """Model basal columns"""

    name: Literal["basal columns"] = "basal columns"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17582"] = "EMAPA_17582"


class _Spinal_Cord_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model spinal cord marginal layer"""

    name: Literal["spinal cord marginal layer"] = "spinal cord marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17583"] = "EMAPA_17583"


class _Spinal_Cord_Sulcus_Limitans(_MouseAnatomicalStructureModel):
    """Model spinal cord sulcus limitans"""

    name: Literal["spinal cord sulcus limitans"] = "spinal cord sulcus limitans"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17584"] = "EMAPA_17584"


class _Spinal_Cord_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model spinal cord ventricular layer"""

    name: Literal["spinal cord ventricular layer"] = "spinal cord ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17585"] = "EMAPA_17585"


class _Spinal_Cord_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model spinal cord roof plate"""

    name: Literal["spinal cord roof plate"] = "spinal cord roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17586"] = "EMAPA_17586"


class _Lumbosacral_Plexus(_MouseAnatomicalStructureModel):
    """Model lumbosacral plexus"""

    name: Literal["lumbosacral plexus"] = "lumbosacral plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17587"] = "EMAPA_17587"


class _External_Auditory_Meatus(_MouseAnatomicalStructureModel):
    """Model external auditory meatus"""

    name: Literal["external auditory meatus"] = "external auditory meatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17588"] = "EMAPA_17588"


class _Pinna(_MouseAnatomicalStructureModel):
    """Model pinna"""

    name: Literal["pinna"] = "pinna"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17589"] = "EMAPA_17589"


class _Pinna_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model pinna mesenchyme"""

    name: Literal["pinna mesenchyme"] = "pinna mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17591"] = "EMAPA_17591"


class _Pinna_Surface_Epithelium(_MouseAnatomicalStructureModel):
    """Model pinna surface epithelium"""

    name: Literal["pinna surface epithelium"] = "pinna surface epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17592"] = "EMAPA_17592"


class _Endolymphatic_Sac(_MouseAnatomicalStructureModel):
    """Model endolymphatic sac"""

    name: Literal["endolymphatic sac"] = "endolymphatic sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17593"] = "EMAPA_17593"


class _Endolymphatic_Sac_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model endolymphatic sac mesenchyme"""

    name: Literal["endolymphatic sac mesenchyme"] = "endolymphatic sac mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17594"] = "EMAPA_17594"


class _Endolymphatic_Sac_Epithelium(_MouseAnatomicalStructureModel):
    """Model endolymphatic sac epithelium"""

    name: Literal["endolymphatic sac epithelium"] = "endolymphatic sac epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17595"] = "EMAPA_17595"


class _Otic_Capsule(_MouseAnatomicalStructureModel):
    """Model otic capsule"""

    name: Literal["otic capsule"] = "otic capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17596"] = "EMAPA_17596"


class _Cochlea(_MouseAnatomicalStructureModel):
    """Model cochlea"""

    name: Literal["cochlea"] = "cochlea"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17597"] = "EMAPA_17597"


class _Cochlear_Duct(_MouseAnatomicalStructureModel):
    """Model cochlear duct"""

    name: Literal["cochlear duct"] = "cochlear duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17598"] = "EMAPA_17598"


class _Cochlear_Duct_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model cochlear duct mesenchyme"""

    name: Literal["cochlear duct mesenchyme"] = "cochlear duct mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17599"] = "EMAPA_17599"


class _Cochlear_Duct_Epithelium(_MouseAnatomicalStructureModel):
    """Model cochlear duct epithelium"""

    name: Literal["cochlear duct epithelium"] = "cochlear duct epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17600"] = "EMAPA_17600"


class _Pharyngo_Tympanic_Tube(_MouseAnatomicalStructureModel):
    """Model pharyngo-tympanic tube"""

    name: Literal["pharyngo-tympanic tube"] = "pharyngo-tympanic tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17601"] = "EMAPA_17601"


class _Cornea_Stroma(_MouseAnatomicalStructureModel):
    """Model cornea stroma"""

    name: Literal["cornea stroma"] = "cornea stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17602"] = "EMAPA_17602"


class _Optic_Chiasma(_MouseAnatomicalStructureModel):
    """Model optic chiasma"""

    name: Literal["optic chiasma"] = "optic chiasma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17603"] = "EMAPA_17603"


class _Nasal_Cavity(_MouseAnatomicalStructureModel):
    """Model nasal cavity"""

    name: Literal["nasal cavity"] = "nasal cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17604"] = "EMAPA_17604"


class _Nasal_Cavity_Epithelium(_MouseAnatomicalStructureModel):
    """Model nasal cavity epithelium"""

    name: Literal["nasal cavity epithelium"] = "nasal cavity epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17605"] = "EMAPA_17605"


class _Olfactory_Epithelium(_MouseAnatomicalStructureModel):
    """Model olfactory epithelium"""

    name: Literal["olfactory epithelium"] = "olfactory epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17606"] = "EMAPA_17606"


class _Nasal_Cavity_Respiratory_Epithelium(_MouseAnatomicalStructureModel):
    """Model nasal cavity respiratory epithelium"""

    name: Literal["nasal cavity respiratory epithelium"] = "nasal cavity respiratory epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17607"] = "EMAPA_17607"


class _Nasal_Septum(_MouseAnatomicalStructureModel):
    """Model nasal septum"""

    name: Literal["nasal septum"] = "nasal septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17608"] = "EMAPA_17608"


class _Frontal_Process_Epithelium(_MouseAnatomicalStructureModel):
    """Model frontal process epithelium"""

    name: Literal["frontal process epithelium"] = "frontal process epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17609"] = "EMAPA_17609"


class _Latero_Nasal_Process_Epithelium(_MouseAnatomicalStructureModel):
    """Model latero-nasal process epithelium"""

    name: Literal["latero-nasal process epithelium"] = "latero-nasal process epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17610"] = "EMAPA_17610"


class _Medial_Nasal_Process_Epithelium(_MouseAnatomicalStructureModel):
    """Model medial-nasal process epithelium"""

    name: Literal["medial-nasal process epithelium"] = "medial-nasal process epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17611"] = "EMAPA_17611"


class _Vomeronasal_Organ(_MouseAnatomicalStructureModel):
    """Model vomeronasal organ"""

    name: Literal["vomeronasal organ"] = "vomeronasal organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17612"] = "EMAPA_17612"


class _Arch_Of_Aorta(_MouseAnatomicalStructureModel):
    """Model arch of aorta"""

    name: Literal["arch of aorta"] = "arch of aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17613"] = "EMAPA_17613"


class _External_Iliac_Artery(_MouseAnatomicalStructureModel):
    """Model external iliac artery"""

    name: Literal["external iliac artery"] = "external iliac artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17614"] = "EMAPA_17614"


class _Innominate_Artery(_MouseAnatomicalStructureModel):
    """Model innominate artery"""

    name: Literal["innominate artery"] = "innominate artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17615"] = "EMAPA_17615"


class _Intersegmental_Artery(_MouseAnatomicalStructureModel):
    """Model intersegmental artery"""

    name: Literal["intersegmental artery"] = "intersegmental artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17616"] = "EMAPA_17616"


class _Subclavian_Artery(_MouseAnatomicalStructureModel):
    """Model subclavian artery"""

    name: Literal["subclavian artery"] = "subclavian artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17617"] = "EMAPA_17617"


class _Atrioventricular_Endocardial_Cushion(_MouseAnatomicalStructureModel):
    """Model atrioventricular endocardial cushion"""

    name: Literal["atrioventricular endocardial cushion"] = "atrioventricular endocardial cushion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17618"] = "EMAPA_17618"


class _Outflow_Tract_Pulmonary_Component_Proximal_Part(_MouseAnatomicalStructureModel):
    """Model outflow tract pulmonary component proximal part"""

    name: Literal["outflow tract pulmonary component proximal part"] = "outflow tract pulmonary component proximal part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17619"] = "EMAPA_17619"


class _Internal_Jugular_Vein(_MouseAnatomicalStructureModel):
    """Model internal jugular vein"""

    name: Literal["internal jugular vein"] = "internal jugular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17620"] = "EMAPA_17620"


class _Subclavian_Vein(_MouseAnatomicalStructureModel):
    """Model subclavian vein"""

    name: Literal["subclavian vein"] = "subclavian vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17621"] = "EMAPA_17621"


class _Hyoid_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hyoid cartilage condensation"""

    name: Literal["hyoid cartilage condensation"] = "hyoid cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17622"] = "EMAPA_17622"


class _Stomach_Glandular_Region(_MouseAnatomicalStructureModel):
    """Model stomach glandular region"""

    name: Literal["stomach glandular region"] = "stomach glandular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17623"] = "EMAPA_17623"


class _Stomach_Glandular_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model stomach glandular region mesenchyme"""

    name: Literal["stomach glandular region mesenchyme"] = "stomach glandular region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17624"] = "EMAPA_17624"


class _Stomach_Glandular_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model stomach glandular region epithelium"""

    name: Literal["stomach glandular region epithelium"] = "stomach glandular region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17625"] = "EMAPA_17625"


class _Stomach_Glandular_Region_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model stomach glandular region vascular element"""

    name: Literal["stomach glandular region vascular element"] = "stomach glandular region vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17626"] = "EMAPA_17626"


class _Stomach_Proventricular_Region(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region"""

    name: Literal["stomach proventricular region"] = "stomach proventricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17627"] = "EMAPA_17627"


class _Stomach_Proventricular_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region mesenchyme"""

    name: Literal["stomach proventricular region mesenchyme"] = "stomach proventricular region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17628"] = "EMAPA_17628"


class _Stomach_Proventricular_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region epithelium"""

    name: Literal["stomach proventricular region epithelium"] = "stomach proventricular region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17629"] = "EMAPA_17629"


class _Stomach_Proventricular_Region_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region vascular element"""

    name: Literal["stomach proventricular region vascular element"] = "stomach proventricular region vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17630"] = "EMAPA_17630"


class _Stomach_Pyloric_Region(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region"""

    name: Literal["stomach pyloric region"] = "stomach pyloric region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17631"] = "EMAPA_17631"


class _Stomach_Pyloric_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region mesenchyme"""

    name: Literal["stomach pyloric region mesenchyme"] = "stomach pyloric region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17632"] = "EMAPA_17632"


class _Stomach_Pyloric_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region epithelium"""

    name: Literal["stomach pyloric region epithelium"] = "stomach pyloric region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17633"] = "EMAPA_17633"


class _Stomach_Pyloric_Region_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region vascular element"""

    name: Literal["stomach pyloric region vascular element"] = "stomach pyloric region vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17634"] = "EMAPA_17634"


class _Meckel_S_Cartilage(_MouseAnatomicalStructureModel):
    """Model Meckel's cartilage"""

    name: Literal["Meckel's cartilage"] = "Meckel's cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17635"] = "EMAPA_17635"


class _Mandible_Primordium_Alveolar_Sulcus(_MouseAnatomicalStructureModel):
    """Model mandible primordium alveolar sulcus"""

    name: Literal["mandible primordium alveolar sulcus"] = "mandible primordium alveolar sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17636"] = "EMAPA_17636"


class _Maxillary_Process_Epithelium(_MouseAnatomicalStructureModel):
    """Model maxillary process epithelium"""

    name: Literal["maxillary process epithelium"] = "maxillary process epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17637"] = "EMAPA_17637"


class _Maxillary_Process_Skeleton(_MouseAnatomicalStructureModel):
    """Model maxillary process skeleton"""

    name: Literal["maxillary process skeleton"] = "maxillary process skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17638"] = "EMAPA_17638"


class _Maxilla(_MouseAnatomicalStructureModel):
    """Model maxilla"""

    name: Literal["maxilla"] = "maxilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17639"] = "EMAPA_17639"


class _Maxillary_Process_Alveolar_Sulcus(_MouseAnatomicalStructureModel):
    """Model maxillary process alveolar sulcus"""

    name: Literal["maxillary process alveolar sulcus"] = "maxillary process alveolar sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17640"] = "EMAPA_17640"


class _Premaxilla(_MouseAnatomicalStructureModel):
    """Model premaxilla"""

    name: Literal["premaxilla"] = "premaxilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17641"] = "EMAPA_17641"


class _Primary_Palate(_MouseAnatomicalStructureModel):
    """Model primary palate"""

    name: Literal["primary palate"] = "primary palate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17642"] = "EMAPA_17642"


class _Primary_Palate_Epithelium(_MouseAnatomicalStructureModel):
    """Model primary palate epithelium"""

    name: Literal["primary palate epithelium"] = "primary palate epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17643"] = "EMAPA_17643"


class _Primary_Palate_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model primary palate mesenchyme"""

    name: Literal["primary palate mesenchyme"] = "primary palate mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17644"] = "EMAPA_17644"


class _Primitive_Collecting_Duct(_MouseAnatomicalStructureModel):
    """Model primitive collecting duct"""

    name: Literal["primitive collecting duct"] = "primitive collecting duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17646"] = "EMAPA_17646"


class _Arytenoid_Swelling_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model arytenoid swelling cartilage condensation"""

    name: Literal["arytenoid swelling cartilage condensation"] = "arytenoid swelling cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17652"] = "EMAPA_17652"


class _Left_Lung(_MouseAnatomicalStructureModel):
    """Model left lung"""

    name: Literal["left lung"] = "left lung"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17653"] = "EMAPA_17653"


class _Left_Lung_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model left lung mesenchyme"""

    name: Literal["left lung mesenchyme"] = "left lung mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17654"] = "EMAPA_17654"


class _Left_Lung_Epithelium(_MouseAnatomicalStructureModel):
    """Model left lung epithelium"""

    name: Literal["left lung epithelium"] = "left lung epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17655"] = "EMAPA_17655"


class _Left_Lung_Lobar_Bronchus(_MouseAnatomicalStructureModel):
    """Model left lung lobar bronchus"""

    name: Literal["left lung lobar bronchus"] = "left lung lobar bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17656"] = "EMAPA_17656"


class _Left_Lung_Lobar_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model left lung lobar bronchus mesenchyme"""

    name: Literal["left lung lobar bronchus mesenchyme"] = "left lung lobar bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17657"] = "EMAPA_17657"


class _Left_Lung_Lobar_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model left lung lobar bronchus epithelium"""

    name: Literal["left lung lobar bronchus epithelium"] = "left lung lobar bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17658"] = "EMAPA_17658"


class _Left_Lung_Lobar_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model left lung lobar bronchus vascular element"""

    name: Literal["left lung lobar bronchus vascular element"] = "left lung lobar bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17659"] = "EMAPA_17659"


class _Left_Lung_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model left lung vascular element"""

    name: Literal["left lung vascular element"] = "left lung vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17660"] = "EMAPA_17660"


class _Right_Lung(_MouseAnatomicalStructureModel):
    """Model right lung"""

    name: Literal["right lung"] = "right lung"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17661"] = "EMAPA_17661"


class _Right_Lung_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model right lung mesenchyme"""

    name: Literal["right lung mesenchyme"] = "right lung mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17662"] = "EMAPA_17662"


class _Right_Lung_Epithelium(_MouseAnatomicalStructureModel):
    """Model right lung epithelium"""

    name: Literal["right lung epithelium"] = "right lung epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17663"] = "EMAPA_17663"


class _Right_Lung_Lobar_Bronchus(_MouseAnatomicalStructureModel):
    """Model right lung lobar bronchus"""

    name: Literal["right lung lobar bronchus"] = "right lung lobar bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17664"] = "EMAPA_17664"


class _Right_Lung_Lobar_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model right lung lobar bronchus mesenchyme"""

    name: Literal["right lung lobar bronchus mesenchyme"] = "right lung lobar bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17665"] = "EMAPA_17665"


class _Right_Lung_Lobar_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model right lung lobar bronchus epithelium"""

    name: Literal["right lung lobar bronchus epithelium"] = "right lung lobar bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17666"] = "EMAPA_17666"


class _Right_Lung_Lobar_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung lobar bronchus vascular element"""

    name: Literal["right lung lobar bronchus vascular element"] = "right lung lobar bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17667"] = "EMAPA_17667"


class _Right_Lung_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung vascular element"""

    name: Literal["right lung vascular element"] = "right lung vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17668"] = "EMAPA_17668"


class _Upper_Respiratory_Tract(_MouseAnatomicalStructureModel):
    """Model upper respiratory tract"""

    name: Literal["upper respiratory tract"] = "upper respiratory tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17669"] = "EMAPA_17669"


class _Nasopharynx(_MouseAnatomicalStructureModel):
    """Model nasopharynx"""

    name: Literal["nasopharynx"] = "nasopharynx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17670"] = "EMAPA_17670"


class _Nasopharynx_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model nasopharynx mesenchyme"""

    name: Literal["nasopharynx mesenchyme"] = "nasopharynx mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17671"] = "EMAPA_17671"


class _Nasopharynx_Epithelium(_MouseAnatomicalStructureModel):
    """Model nasopharynx epithelium"""

    name: Literal["nasopharynx epithelium"] = "nasopharynx epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17672"] = "EMAPA_17672"


class _Nasopharynx_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model nasopharynx vascular element"""

    name: Literal["nasopharynx vascular element"] = "nasopharynx vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17673"] = "EMAPA_17673"


class _Cervical_Vertebra(_MouseAnatomicalStructureModel):
    """Model cervical vertebra"""

    name: Literal["cervical vertebra"] = "cervical vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17674"] = "EMAPA_17674"


class _Lumbar_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model lumbar vertebral cartilage condensation"""

    name: Literal["lumbar vertebral cartilage condensation"] = "lumbar vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17675"] = "EMAPA_17675"


class _Axial_Skeleton_Sacral_Region(_MouseAnatomicalStructureModel):
    """Model axial skeleton sacral region"""

    name: Literal["axial skeleton sacral region"] = "axial skeleton sacral region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17676"] = "EMAPA_17676"


class _Sacral_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model sacral vertebral pre-cartilage condensation"""

    name: Literal["sacral vertebral pre-cartilage condensation"] = "sacral vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17677"] = "EMAPA_17677"


class _Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model rib cartilage condensation"""

    name: Literal["rib cartilage condensation"] = "rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17678"] = "EMAPA_17678"


class _Thoracic_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model thoracic vertebral cartilage condensation"""

    name: Literal["thoracic vertebral cartilage condensation"] = "thoracic vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17679"] = "EMAPA_17679"


class _Cranium(_MouseAnatomicalStructureModel):
    """Model cranium"""

    name: Literal["cranium"] = "cranium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17680"] = "EMAPA_17680"


class _Chondrocranium(_MouseAnatomicalStructureModel):
    """Model chondrocranium"""

    name: Literal["chondrocranium"] = "chondrocranium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17681"] = "EMAPA_17681"


class _Temporal_Bone(_MouseAnatomicalStructureModel):
    """Model temporal bone"""

    name: Literal["temporal bone"] = "temporal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17682"] = "EMAPA_17682"


class _Temporal_Bone_Petrous_Part(_MouseAnatomicalStructureModel):
    """Model temporal bone petrous part"""

    name: Literal["temporal bone petrous part"] = "temporal bone petrous part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17683"] = "EMAPA_17683"


class _Somite_49(_MouseAnatomicalStructureModel):
    """Model somite 49"""

    name: Literal["somite 49"] = "somite 49"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17684"] = "EMAPA_17684"


class _Somite_49_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 49 dermomyotome"""

    name: Literal["somite 49 dermomyotome"] = "somite 49 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17685"] = "EMAPA_17685"


class _Somite_49_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 49 myocoele"""

    name: Literal["somite 49 myocoele"] = "somite 49 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17686"] = "EMAPA_17686"


class _Somite_49_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 49 sclerotome"""

    name: Literal["somite 49 sclerotome"] = "somite 49 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17687"] = "EMAPA_17687"


class _Somite_50(_MouseAnatomicalStructureModel):
    """Model somite 50"""

    name: Literal["somite 50"] = "somite 50"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17688"] = "EMAPA_17688"


class _Somite_50_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 50 dermomyotome"""

    name: Literal["somite 50 dermomyotome"] = "somite 50 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17689"] = "EMAPA_17689"


class _Somite_50_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 50 myocoele"""

    name: Literal["somite 50 myocoele"] = "somite 50 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17690"] = "EMAPA_17690"


class _Somite_50_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 50 sclerotome"""

    name: Literal["somite 50 sclerotome"] = "somite 50 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17691"] = "EMAPA_17691"


class _Somite_51(_MouseAnatomicalStructureModel):
    """Model somite 51"""

    name: Literal["somite 51"] = "somite 51"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17692"] = "EMAPA_17692"


class _Somite_51_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 51 dermomyotome"""

    name: Literal["somite 51 dermomyotome"] = "somite 51 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17693"] = "EMAPA_17693"


class _Somite_51_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 51 myocoele"""

    name: Literal["somite 51 myocoele"] = "somite 51 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17694"] = "EMAPA_17694"


class _Somite_51_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 51 sclerotome"""

    name: Literal["somite 51 sclerotome"] = "somite 51 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17695"] = "EMAPA_17695"


class _Somite_52(_MouseAnatomicalStructureModel):
    """Model somite 52"""

    name: Literal["somite 52"] = "somite 52"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17696"] = "EMAPA_17696"


class _Somite_52_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 52 dermomyotome"""

    name: Literal["somite 52 dermomyotome"] = "somite 52 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17697"] = "EMAPA_17697"


class _Somite_52_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 52 myocoele"""

    name: Literal["somite 52 myocoele"] = "somite 52 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17698"] = "EMAPA_17698"


class _Somite_52_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 52 sclerotome"""

    name: Literal["somite 52 sclerotome"] = "somite 52 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17699"] = "EMAPA_17699"


class _Tail_Spinal_Cord(_MouseAnatomicalStructureModel):
    """Model tail spinal cord"""

    name: Literal["tail spinal cord"] = "tail spinal cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17700"] = "EMAPA_17700"


class _Diaphragm(_MouseAnatomicalStructureModel):
    """Model diaphragm"""

    name: Literal["diaphragm"] = "diaphragm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17701"] = "EMAPA_17701"


class _Diaphragm_Central_Tendon(_MouseAnatomicalStructureModel):
    """Model diaphragm central tendon"""

    name: Literal["diaphragm central tendon"] = "diaphragm central tendon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17702"] = "EMAPA_17702"


class _Crus_Of_Diaphragm(_MouseAnatomicalStructureModel):
    """Model crus of diaphragm"""

    name: Literal["crus of diaphragm"] = "crus of diaphragm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17703"] = "EMAPA_17703"


class _Pleuro_Pericardial_Canal(_MouseAnatomicalStructureModel):
    """Model pleuro-pericardial canal"""

    name: Literal["pleuro-pericardial canal"] = "pleuro-pericardial canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17704"] = "EMAPA_17704"


class _Pleuro_Pericardial_Canal_Mesothelial_Lining(_MouseAnatomicalStructureModel):
    """Model pleuro-pericardial canal mesothelial lining"""

    name: Literal["pleuro-pericardial canal mesothelial lining"] = "pleuro-pericardial canal mesothelial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17705"] = "EMAPA_17705"


class _Pleuro_Pericardial_Folds(_MouseAnatomicalStructureModel):
    """Model pleuro-pericardial folds"""

    name: Literal["pleuro-pericardial folds"] = "pleuro-pericardial folds"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17706"] = "EMAPA_17706"


class _Pleuro_Peritoneal_Canal(_MouseAnatomicalStructureModel):
    """Model pleuro-peritoneal canal"""

    name: Literal["pleuro-peritoneal canal"] = "pleuro-peritoneal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17707"] = "EMAPA_17707"


class _Pleuro_Peritoneal_Canal_Mesothelial_Lining(_MouseAnatomicalStructureModel):
    """Model pleuro-peritoneal canal mesothelial lining"""

    name: Literal["pleuro-peritoneal canal mesothelial lining"] = "pleuro-peritoneal canal mesothelial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17708"] = "EMAPA_17708"


class _Pleuro_Peritoneal_Membrane(_MouseAnatomicalStructureModel):
    """Model pleuro-peritoneal membrane"""

    name: Literal["pleuro-peritoneal membrane"] = "pleuro-peritoneal membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17709"] = "EMAPA_17709"


class _Elbow_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model elbow joint primordium"""

    name: Literal["elbow joint primordium"] = "elbow joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17710"] = "EMAPA_17710"


class _Radius_Ulna_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model radius-ulna cartilage condensation"""

    name: Literal["radius-ulna cartilage condensation"] = "radius-ulna cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17711"] = "EMAPA_17711"


class _Shoulder_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model shoulder joint primordium"""

    name: Literal["shoulder joint primordium"] = "shoulder joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17712"] = "EMAPA_17712"


class _Humerus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model humerus cartilage condensation"""

    name: Literal["humerus cartilage condensation"] = "humerus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17713"] = "EMAPA_17713"


class _Forelimb_Digit_1_Metacarpus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 metacarpus pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 1 metacarpus pre-cartilage condensation"
    ] = "forelimb digit 1 metacarpus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17714"] = "EMAPA_17714"


class _Forelimb_Digit_1_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 phalanx pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 1 phalanx pre-cartilage condensation"
    ] = "forelimb digit 1 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17715"] = "EMAPA_17715"


class _Forelimb_Digit_2_Metacarpus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 metacarpus pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 2 metacarpus pre-cartilage condensation"
    ] = "forelimb digit 2 metacarpus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17716"] = "EMAPA_17716"


class _Forelimb_Digit_2_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 phalanx pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 2 phalanx pre-cartilage condensation"
    ] = "forelimb digit 2 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17717"] = "EMAPA_17717"


class _Forelimb_Digit_3_Metacarpus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 metacarpus pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 3 metacarpus pre-cartilage condensation"
    ] = "forelimb digit 3 metacarpus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17718"] = "EMAPA_17718"


class _Forelimb_Digit_3_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 phalanx pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 3 phalanx pre-cartilage condensation"
    ] = "forelimb digit 3 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17719"] = "EMAPA_17719"


class _Forelimb_Digit_4_Metacarpus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 metacarpus pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 4 metacarpus pre-cartilage condensation"
    ] = "forelimb digit 4 metacarpus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17720"] = "EMAPA_17720"


class _Forelimb_Digit_4_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 phalanx pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 4 phalanx pre-cartilage condensation"
    ] = "forelimb digit 4 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17721"] = "EMAPA_17721"


class _Forelimb_Digit_5_Metacarpus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 metacarpus pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 5 metacarpus pre-cartilage condensation"
    ] = "forelimb digit 5 metacarpus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17722"] = "EMAPA_17722"


class _Forelimb_Digit_5_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 phalanx pre-cartilage condensation"""

    name: Literal[
        "forelimb digit 5 phalanx pre-cartilage condensation"
    ] = "forelimb digit 5 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17723"] = "EMAPA_17723"


class _Carpus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model carpus pre-cartilage condensation"""

    name: Literal["carpus pre-cartilage condensation"] = "carpus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17724"] = "EMAPA_17724"


class _Hindlimb_Digit_1_Metatarsus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 metatarsus pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 1 metatarsus pre-cartilage condensation"
    ] = "hindlimb digit 1 metatarsus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17725"] = "EMAPA_17725"


class _Hindlimb_Digit_1_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 phalanx pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 1 phalanx pre-cartilage condensation"
    ] = "hindlimb digit 1 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17726"] = "EMAPA_17726"


class _Hindlimb_Digit_2_Metatarsus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 metatarsus pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 2 metatarsus pre-cartilage condensation"
    ] = "hindlimb digit 2 metatarsus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17727"] = "EMAPA_17727"


class _Hindlimb_Digit_2_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 phalanx pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 2 phalanx pre-cartilage condensation"
    ] = "hindlimb digit 2 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17728"] = "EMAPA_17728"


class _Hindlimb_Digit_3_Metatarsus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 metatarsus pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 3 metatarsus pre-cartilage condensation"
    ] = "hindlimb digit 3 metatarsus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17729"] = "EMAPA_17729"


class _Hindlimb_Digit_3_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 phalanx pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 3 phalanx pre-cartilage condensation"
    ] = "hindlimb digit 3 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17730"] = "EMAPA_17730"


class _Hindlimb_Digit_4_Metatarsus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 metatarsus pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 4 metatarsus pre-cartilage condensation"
    ] = "hindlimb digit 4 metatarsus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17731"] = "EMAPA_17731"


class _Hindlimb_Digit_4_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 phalanx pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 4 phalanx pre-cartilage condensation"
    ] = "hindlimb digit 4 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17732"] = "EMAPA_17732"


class _Hindlimb_Digit_5_Metatarsus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 metatarsus pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 5 metatarsus pre-cartilage condensation"
    ] = "hindlimb digit 5 metatarsus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17733"] = "EMAPA_17733"


class _Hindlimb_Digit_5_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 phalanx pre-cartilage condensation"""

    name: Literal[
        "hindlimb digit 5 phalanx pre-cartilage condensation"
    ] = "hindlimb digit 5 phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17734"] = "EMAPA_17734"


class _Future_Tarsus(_MouseAnatomicalStructureModel):
    """Model future tarsus"""

    name: Literal["future tarsus"] = "future tarsus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17735"] = "EMAPA_17735"


class _Calcaneum_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model calcaneum pre-cartilage condensation"""

    name: Literal["calcaneum pre-cartilage condensation"] = "calcaneum pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17736"] = "EMAPA_17736"


class _Future_Tarsus_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model future tarsus rest of mesenchyme"""

    name: Literal["future tarsus rest of mesenchyme"] = "future tarsus rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17737"] = "EMAPA_17737"


class _Talus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model talus pre-cartilage condensation"""

    name: Literal["talus pre-cartilage condensation"] = "talus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17738"] = "EMAPA_17738"


class _Hip_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model hip joint primordium"""

    name: Literal["hip joint primordium"] = "hip joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17739"] = "EMAPA_17739"


class _Knee_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model knee joint primordium"""

    name: Literal["knee joint primordium"] = "knee joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17740"] = "EMAPA_17740"


class _Tibia_Fibula_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model tibia-fibula pre-cartilage condensation"""

    name: Literal["tibia-fibula pre-cartilage condensation"] = "tibia-fibula pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17741"] = "EMAPA_17741"


class _Femur_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model femur cartilage condensation"""

    name: Literal["femur cartilage condensation"] = "femur cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17742"] = "EMAPA_17742"


class _Vertebral_Axis_Musculature(_MouseAnatomicalStructureModel):
    """Model vertebral axis musculature"""

    name: Literal["vertebral axis musculature"] = "vertebral axis musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17743"] = "EMAPA_17743"


class _Anterior_Abdominal_Wall_Musculature(_MouseAnatomicalStructureModel):
    """Model anterior abdominal wall musculature"""

    name: Literal["anterior abdominal wall musculature"] = "anterior abdominal wall musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17744"] = "EMAPA_17744"


class _Anterior_Abdominal_Wall_Muscle(_MouseAnatomicalStructureModel):
    """Model anterior abdominal wall muscle"""

    name: Literal["anterior abdominal wall muscle"] = "anterior abdominal wall muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17745"] = "EMAPA_17745"


class _Anterior_Abdominal_Wall_Undifferentiated_Pre_Muscle_Mass(_MouseAnatomicalStructureModel):
    """Model anterior abdominal wall undifferentiated pre-muscle mass"""

    name: Literal[
        "anterior abdominal wall undifferentiated pre-muscle mass"
    ] = "anterior abdominal wall undifferentiated pre-muscle mass"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17746"] = "EMAPA_17746"


class _Pectoral_Girdle_And_Thoracic_Body_Wall_Musculature(_MouseAnatomicalStructureModel):
    """Model pectoral girdle and thoracic body wall musculature"""

    name: Literal[
        "pectoral girdle and thoracic body wall musculature"
    ] = "pectoral girdle and thoracic body wall musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17747"] = "EMAPA_17747"


class _Pectoral_Girdle_And_Thoracic_Body_Wall_Muscle(_MouseAnatomicalStructureModel):
    """Model pectoral girdle and thoracic body wall muscle"""

    name: Literal["pectoral girdle and thoracic body wall muscle"] = "pectoral girdle and thoracic body wall muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17748"] = "EMAPA_17748"


class _Deltoid_Pre_Muscle_Mass(_MouseAnatomicalStructureModel):
    """Model deltoid pre-muscle mass"""

    name: Literal["deltoid pre-muscle mass"] = "deltoid pre-muscle mass"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17749"] = "EMAPA_17749"


class _Subscapularis_Pre_Muscle_Mass(_MouseAnatomicalStructureModel):
    """Model subscapularis pre-muscle mass"""

    name: Literal["subscapularis pre-muscle mass"] = "subscapularis pre-muscle mass"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17750"] = "EMAPA_17750"


class _Salivary_Gland(_MouseAnatomicalStructureModel):
    """Model salivary gland"""

    name: Literal["salivary gland"] = "salivary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17751"] = "EMAPA_17751"


class _Sublingual_Gland_Primordium(_MouseAnatomicalStructureModel):
    """Model sublingual gland primordium"""

    name: Literal["sublingual gland primordium"] = "sublingual gland primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17752"] = "EMAPA_17752"


class _Sublingual_Gland_Primordium_Epithelium(_MouseAnatomicalStructureModel):
    """Model sublingual gland primordium epithelium"""

    name: Literal["sublingual gland primordium epithelium"] = "sublingual gland primordium epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17753"] = "EMAPA_17753"


class _Sublingual_Gland_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model sublingual gland primordium mesenchyme"""

    name: Literal["sublingual gland primordium mesenchyme"] = "sublingual gland primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17754"] = "EMAPA_17754"


class _Submandibular_Gland_Primordium(_MouseAnatomicalStructureModel):
    """Model submandibular gland primordium"""

    name: Literal["submandibular gland primordium"] = "submandibular gland primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17755"] = "EMAPA_17755"


class _Submandibular_Gland_Primordium_Epithelium(_MouseAnatomicalStructureModel):
    """Model submandibular gland primordium epithelium"""

    name: Literal["submandibular gland primordium epithelium"] = "submandibular gland primordium epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17756"] = "EMAPA_17756"


class _Submandibular_Gland_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model submandibular gland primordium mesenchyme"""

    name: Literal["submandibular gland primordium mesenchyme"] = "submandibular gland primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17757"] = "EMAPA_17757"


class _Integumental_System_Gland(_MouseAnatomicalStructureModel):
    """Model integumental system gland"""

    name: Literal["integumental system gland"] = "integumental system gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17758"] = "EMAPA_17758"


class _Mammary_Gland(_MouseAnatomicalStructureModel):
    """Model mammary gland"""

    name: Literal["mammary gland"] = "mammary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17759"] = "EMAPA_17759"


class _Mammary_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model mammary gland epithelium"""

    name: Literal["mammary gland epithelium"] = "mammary gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17760"] = "EMAPA_17760"


class _Mammary_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model mammary mesenchyme"""

    name: Literal["mammary mesenchyme"] = "mammary mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17761"] = "EMAPA_17761"


class _Vibrissa_Dermal_Component(_MouseAnatomicalStructureModel):
    """Model vibrissa dermal component"""

    name: Literal["vibrissa dermal component"] = "vibrissa dermal component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17762"] = "EMAPA_17762"


class _Vibrissa_Epidermal_Component(_MouseAnatomicalStructureModel):
    """Model vibrissa epidermal component"""

    name: Literal["vibrissa epidermal component"] = "vibrissa epidermal component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17763"] = "EMAPA_17763"


class _Diencephalon_Meninges(_MouseAnatomicalStructureModel):
    """Model diencephalon meninges"""

    name: Literal["diencephalon meninges"] = "diencephalon meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17764"] = "EMAPA_17764"


class _Diencephalon_Arachnoid_Mater(_MouseAnatomicalStructureModel):
    """Model diencephalon arachnoid mater"""

    name: Literal["diencephalon arachnoid mater"] = "diencephalon arachnoid mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17765"] = "EMAPA_17765"


class _Diencephalon_Dura_Mater(_MouseAnatomicalStructureModel):
    """Model diencephalon dura mater"""

    name: Literal["diencephalon dura mater"] = "diencephalon dura mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17766"] = "EMAPA_17766"


class _Diencephalon_Pia_Mater(_MouseAnatomicalStructureModel):
    """Model diencephalon pia mater"""

    name: Literal["diencephalon pia mater"] = "diencephalon pia mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17767"] = "EMAPA_17767"


class _Choroid_Fissure(_MouseAnatomicalStructureModel):
    """Model choroid fissure"""

    name: Literal["choroid fissure"] = "choroid fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17768"] = "EMAPA_17768"


class _Lateral_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model lateral ventricle choroid plexus"""

    name: Literal["lateral ventricle choroid plexus"] = "lateral ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17769"] = "EMAPA_17769"


class _Anterior_Horn_Of_Lateral_Ventricle(_MouseAnatomicalStructureModel):
    """Model anterior horn of lateral ventricle"""

    name: Literal["anterior horn of lateral ventricle"] = "anterior horn of lateral ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17770"] = "EMAPA_17770"


class _Inferior_Horn_Of_Lateral_Ventricle(_MouseAnatomicalStructureModel):
    """Model inferior horn of lateral ventricle"""

    name: Literal["inferior horn of lateral ventricle"] = "inferior horn of lateral ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17771"] = "EMAPA_17771"


class _Posterior_Horn_Of_Lateral_Ventricle(_MouseAnatomicalStructureModel):
    """Model posterior horn of lateral ventricle"""

    name: Literal["posterior horn of lateral ventricle"] = "posterior horn of lateral ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17772"] = "EMAPA_17772"


class _Superior_Horn_Of_Lateral_Ventricle(_MouseAnatomicalStructureModel):
    """Model superior horn of lateral ventricle"""

    name: Literal["superior horn of lateral ventricle"] = "superior horn of lateral ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17773"] = "EMAPA_17773"


class _Telencephalon_Meninges(_MouseAnatomicalStructureModel):
    """Model telencephalon meninges"""

    name: Literal["telencephalon meninges"] = "telencephalon meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17774"] = "EMAPA_17774"


class _Telencephalon_Arachnoid_Mater(_MouseAnatomicalStructureModel):
    """Model telencephalon arachnoid mater"""

    name: Literal["telencephalon arachnoid mater"] = "telencephalon arachnoid mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17775"] = "EMAPA_17775"


class _Telencephalon_Dura_Mater(_MouseAnatomicalStructureModel):
    """Model telencephalon dura mater"""

    name: Literal["telencephalon dura mater"] = "telencephalon dura mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17776"] = "EMAPA_17776"


class _Telencephalon_Pia_Mater(_MouseAnatomicalStructureModel):
    """Model telencephalon pia mater"""

    name: Literal["telencephalon pia mater"] = "telencephalon pia mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17777"] = "EMAPA_17777"


class _Olfactory_Lobe(_MouseAnatomicalStructureModel):
    """Model olfactory lobe"""

    name: Literal["olfactory lobe"] = "olfactory lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17778"] = "EMAPA_17778"


class _Olfactory_Cortex(_MouseAnatomicalStructureModel):
    """Model olfactory cortex"""

    name: Literal["olfactory cortex"] = "olfactory cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17779"] = "EMAPA_17779"


class _Olfactory_Cortex_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model olfactory cortex mantle layer"""

    name: Literal["olfactory cortex mantle layer"] = "olfactory cortex mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17780"] = "EMAPA_17780"


class _Olfactory_Cortex_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model olfactory cortex marginal layer"""

    name: Literal["olfactory cortex marginal layer"] = "olfactory cortex marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17781"] = "EMAPA_17781"


class _Olfactory_Cortex_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model olfactory cortex ventricular layer"""

    name: Literal["olfactory cortex ventricular layer"] = "olfactory cortex ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17782"] = "EMAPA_17782"


class _Hindbrain_Meninges(_MouseAnatomicalStructureModel):
    """Model hindbrain meninges"""

    name: Literal["hindbrain meninges"] = "hindbrain meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17783"] = "EMAPA_17783"


class _Hindbrain_Arachnoid_Mater(_MouseAnatomicalStructureModel):
    """Model hindbrain arachnoid mater"""

    name: Literal["hindbrain arachnoid mater"] = "hindbrain arachnoid mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17784"] = "EMAPA_17784"


class _Hindbrain_Dura_Mater(_MouseAnatomicalStructureModel):
    """Model hindbrain dura mater"""

    name: Literal["hindbrain dura mater"] = "hindbrain dura mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17785"] = "EMAPA_17785"


class _Hindbrain_Pia_Mater(_MouseAnatomicalStructureModel):
    """Model hindbrain pia mater"""

    name: Literal["hindbrain pia mater"] = "hindbrain pia mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17786"] = "EMAPA_17786"


class _Cerebellum(_MouseAnatomicalStructureModel):
    """Model cerebellum"""

    name: Literal["cerebellum"] = "cerebellum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17787"] = "EMAPA_17787"


class _Cerebellum_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum mantle layer"""

    name: Literal["cerebellum mantle layer"] = "cerebellum mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17788"] = "EMAPA_17788"


class _Cerebellum_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum marginal layer"""

    name: Literal["cerebellum marginal layer"] = "cerebellum marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17789"] = "EMAPA_17789"


class _Cerebellum_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum ventricular layer"""

    name: Literal["cerebellum ventricular layer"] = "cerebellum ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17790"] = "EMAPA_17790"


class _Midbrain_Meninges(_MouseAnatomicalStructureModel):
    """Model midbrain meninges"""

    name: Literal["midbrain meninges"] = "midbrain meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17791"] = "EMAPA_17791"


class _Midbrain_Arachnoid_Mater(_MouseAnatomicalStructureModel):
    """Model midbrain arachnoid mater"""

    name: Literal["midbrain arachnoid mater"] = "midbrain arachnoid mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17792"] = "EMAPA_17792"


class _Midbrain_Dura_Mater(_MouseAnatomicalStructureModel):
    """Model midbrain dura mater"""

    name: Literal["midbrain dura mater"] = "midbrain dura mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17793"] = "EMAPA_17793"


class _Midbrain_Pia_Mater(_MouseAnatomicalStructureModel):
    """Model midbrain pia mater"""

    name: Literal["midbrain pia mater"] = "midbrain pia mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17794"] = "EMAPA_17794"


class _Cerebral_Aqueduct(_MouseAnatomicalStructureModel):
    """Model cerebral aqueduct"""

    name: Literal["cerebral aqueduct"] = "cerebral aqueduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17795"] = "EMAPA_17795"


class _Facial_Nerve(_MouseAnatomicalStructureModel):
    """Model facial nerve"""

    name: Literal["facial nerve"] = "facial nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17796"] = "EMAPA_17796"


class _Olfactory_Nerve(_MouseAnatomicalStructureModel):
    """Model olfactory nerve"""

    name: Literal["olfactory nerve"] = "olfactory nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17797"] = "EMAPA_17797"


class _Trigeminal_Nerve_Mandibular_Division(_MouseAnatomicalStructureModel):
    """Model trigeminal nerve mandibular division"""

    name: Literal["trigeminal nerve mandibular division"] = "trigeminal nerve mandibular division"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17798"] = "EMAPA_17798"


class _Trigeminal_Nerve_Maxillary_Division(_MouseAnatomicalStructureModel):
    """Model trigeminal nerve maxillary division"""

    name: Literal["trigeminal nerve maxillary division"] = "trigeminal nerve maxillary division"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17799"] = "EMAPA_17799"


class _Trigeminal_Nerve_Ophthalmic_Division(_MouseAnatomicalStructureModel):
    """Model trigeminal nerve ophthalmic division"""

    name: Literal["trigeminal nerve ophthalmic division"] = "trigeminal nerve ophthalmic division"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17800"] = "EMAPA_17800"


class _Vestibulocochlear_Nerve(_MouseAnatomicalStructureModel):
    """Model vestibulocochlear nerve"""

    name: Literal["vestibulocochlear nerve"] = "vestibulocochlear nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17801"] = "EMAPA_17801"


class _Vestibulocochlear_Nerve_Cochlear_Component(_MouseAnatomicalStructureModel):
    """Model vestibulocochlear nerve cochlear component"""

    name: Literal["vestibulocochlear nerve cochlear component"] = "vestibulocochlear nerve cochlear component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17802"] = "EMAPA_17802"


class _Vestibulocochlear_Nerve_Vestibular_Component(_MouseAnatomicalStructureModel):
    """Model vestibulocochlear nerve vestibular component"""

    name: Literal["vestibulocochlear nerve vestibular component"] = "vestibulocochlear nerve vestibular component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17803"] = "EMAPA_17803"


class _Spinal_Cord_Meninges(_MouseAnatomicalStructureModel):
    """Model spinal cord meninges"""

    name: Literal["spinal cord meninges"] = "spinal cord meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17804"] = "EMAPA_17804"


class _Spinal_Cord_Arachnoid_Mater(_MouseAnatomicalStructureModel):
    """Model spinal cord arachnoid mater"""

    name: Literal["spinal cord arachnoid mater"] = "spinal cord arachnoid mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17805"] = "EMAPA_17805"


class _Spinal_Cord_Dura_Mater(_MouseAnatomicalStructureModel):
    """Model spinal cord dura mater"""

    name: Literal["spinal cord dura mater"] = "spinal cord dura mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17806"] = "EMAPA_17806"


class _Spinal_Cord_Pia_Mater(_MouseAnatomicalStructureModel):
    """Model spinal cord pia mater"""

    name: Literal["spinal cord pia mater"] = "spinal cord pia mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17807"] = "EMAPA_17807"


class _Phrenic_Nerve(_MouseAnatomicalStructureModel):
    """Model phrenic nerve"""

    name: Literal["phrenic nerve"] = "phrenic nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17813"] = "EMAPA_17813"


class _Inner_Ear_Labyrinth(_MouseAnatomicalStructureModel):
    """Model inner ear labyrinth"""

    name: Literal["inner ear labyrinth"] = "inner ear labyrinth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17815"] = "EMAPA_17815"


class _Labyrinth_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model labyrinth mesenchyme"""

    name: Literal["labyrinth mesenchyme"] = "labyrinth mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17816"] = "EMAPA_17816"


class _Labyrinth_Epithelium(_MouseAnatomicalStructureModel):
    """Model labyrinth epithelium"""

    name: Literal["labyrinth epithelium"] = "labyrinth epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17817"] = "EMAPA_17817"


class _Crus_Commune(_MouseAnatomicalStructureModel):
    """Model crus commune"""

    name: Literal["crus commune"] = "crus commune"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17818"] = "EMAPA_17818"


class _Crus_Commune_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model crus commune mesenchyme"""

    name: Literal["crus commune mesenchyme"] = "crus commune mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17819"] = "EMAPA_17819"


class _Crus_Commune_Epithelium(_MouseAnatomicalStructureModel):
    """Model crus commune epithelium"""

    name: Literal["crus commune epithelium"] = "crus commune epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17820"] = "EMAPA_17820"


class _Lateral_Semicircular_Canal(_MouseAnatomicalStructureModel):
    """Model lateral semicircular canal"""

    name: Literal["lateral semicircular canal"] = "lateral semicircular canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17821"] = "EMAPA_17821"


class _Lateral_Semicircular_Canal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lateral semicircular canal mesenchyme"""

    name: Literal["lateral semicircular canal mesenchyme"] = "lateral semicircular canal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17822"] = "EMAPA_17822"


class _Lateral_Semicircular_Canal_Epithelium(_MouseAnatomicalStructureModel):
    """Model lateral semicircular canal epithelium"""

    name: Literal["lateral semicircular canal epithelium"] = "lateral semicircular canal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17823"] = "EMAPA_17823"


class _Ossicle(_MouseAnatomicalStructureModel):
    """Model ossicle"""

    name: Literal["ossicle"] = "ossicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17824"] = "EMAPA_17824"


class _Incus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model incus pre-cartilage condensation"""

    name: Literal["incus pre-cartilage condensation"] = "incus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17825"] = "EMAPA_17825"


class _Malleus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model malleus pre-cartilage condensation"""

    name: Literal["malleus pre-cartilage condensation"] = "malleus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17826"] = "EMAPA_17826"


class _Stapes_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model stapes pre-cartilage condensation"""

    name: Literal["stapes pre-cartilage condensation"] = "stapes pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17827"] = "EMAPA_17827"


class _Choroidal_Vasculature(_MouseAnatomicalStructureModel):
    """Model choroidal vasculature"""

    name: Literal["choroidal vasculature"] = "choroidal vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17828"] = "EMAPA_17828"


class _Eyelid(_MouseAnatomicalStructureModel):
    """Model eyelid"""

    name: Literal["eyelid"] = "eyelid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17829"] = "EMAPA_17829"


class _Inner_Canthus(_MouseAnatomicalStructureModel):
    """Model inner canthus"""

    name: Literal["inner canthus"] = "inner canthus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17830"] = "EMAPA_17830"


class _Lower_Eyelid(_MouseAnatomicalStructureModel):
    """Model lower eyelid"""

    name: Literal["lower eyelid"] = "lower eyelid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17831"] = "EMAPA_17831"


class _Lower_Eyelid_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower eyelid epithelium"""

    name: Literal["lower eyelid epithelium"] = "lower eyelid epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17832"] = "EMAPA_17832"


class _Lower_Eyelid_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower eyelid mesenchyme"""

    name: Literal["lower eyelid mesenchyme"] = "lower eyelid mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17833"] = "EMAPA_17833"


class _Upper_Eyelid(_MouseAnatomicalStructureModel):
    """Model upper eyelid"""

    name: Literal["upper eyelid"] = "upper eyelid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17834"] = "EMAPA_17834"


class _Upper_Eyelid_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper eyelid epithelium"""

    name: Literal["upper eyelid epithelium"] = "upper eyelid epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17835"] = "EMAPA_17835"


class _Upper_Eyelid_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper eyelid mesenchyme"""

    name: Literal["upper eyelid mesenchyme"] = "upper eyelid mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17836"] = "EMAPA_17836"


class _Vitreous_Humour(_MouseAnatomicalStructureModel):
    """Model vitreous humour"""

    name: Literal["vitreous humour"] = "vitreous humour"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17837"] = "EMAPA_17837"


class _Lens(_MouseAnatomicalStructureModel):
    """Model lens"""

    name: Literal["lens"] = "lens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17838"] = "EMAPA_17838"


class _Lens_Anterior_Epithelium(_MouseAnatomicalStructureModel):
    """Model lens anterior epithelium"""

    name: Literal["lens anterior epithelium"] = "lens anterior epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17839"] = "EMAPA_17839"


class _Lens_Equatorial_Epithelium(_MouseAnatomicalStructureModel):
    """Model lens equatorial epithelium"""

    name: Literal["lens equatorial epithelium"] = "lens equatorial epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17840"] = "EMAPA_17840"


class _Lens_Fiber(_MouseAnatomicalStructureModel):
    """Model lens fiber"""

    name: Literal["lens fiber"] = "lens fiber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17841"] = "EMAPA_17841"


class _Anterior_Lens_Fiber(_MouseAnatomicalStructureModel):
    """Model anterior lens fiber"""

    name: Literal["anterior lens fiber"] = "anterior lens fiber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17842"] = "EMAPA_17842"


class _Posterior_Lens_Fiber(_MouseAnatomicalStructureModel):
    """Model posterior lens fiber"""

    name: Literal["posterior lens fiber"] = "posterior lens fiber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17843"] = "EMAPA_17843"


class _Eye_Skeletal_Muscle(_MouseAnatomicalStructureModel):
    """Model eye skeletal muscle"""

    name: Literal["eye skeletal muscle"] = "eye skeletal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17844"] = "EMAPA_17844"


class _Extrinsic_Ocular_Pre_Muscle_Mass(_MouseAnatomicalStructureModel):
    """Model extrinsic ocular pre-muscle mass"""

    name: Literal["extrinsic ocular pre-muscle mass"] = "extrinsic ocular pre-muscle mass"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17845"] = "EMAPA_17845"


class _Naris(_MouseAnatomicalStructureModel):
    """Model naris"""

    name: Literal["naris"] = "naris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17847"] = "EMAPA_17847"


class _External_Naris(_MouseAnatomicalStructureModel):
    """Model external naris"""

    name: Literal["external naris"] = "external naris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17848"] = "EMAPA_17848"


class _Posterior_Naris(_MouseAnatomicalStructureModel):
    """Model posterior naris"""

    name: Literal["posterior naris"] = "posterior naris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17849"] = "EMAPA_17849"


class _Posterior_Naris_Epithelium(_MouseAnatomicalStructureModel):
    """Model posterior naris epithelium"""

    name: Literal["posterior naris epithelium"] = "posterior naris epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17850"] = "EMAPA_17850"


class _Primary_Choana(_MouseAnatomicalStructureModel):
    """Model primary choana"""

    name: Literal["primary choana"] = "primary choana"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17851"] = "EMAPA_17851"


class _Nasal_Capsule(_MouseAnatomicalStructureModel):
    """Model nasal capsule"""

    name: Literal["nasal capsule"] = "nasal capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17852"] = "EMAPA_17852"


class _Naso_Lacrimal_Duct(_MouseAnatomicalStructureModel):
    """Model naso-lacrimal duct"""

    name: Literal["naso-lacrimal duct"] = "naso-lacrimal duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17853"] = "EMAPA_17853"


class _Anterior_Cerebral_Artery(_MouseAnatomicalStructureModel):
    """Model anterior cerebral artery"""

    name: Literal["anterior cerebral artery"] = "anterior cerebral artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17854"] = "EMAPA_17854"


class _Common_Carotid_Artery(_MouseAnatomicalStructureModel):
    """Model common carotid artery"""

    name: Literal["common carotid artery"] = "common carotid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17855"] = "EMAPA_17855"


class _Abdominal_Aorta(_MouseAnatomicalStructureModel):
    """Model abdominal aorta"""

    name: Literal["abdominal aorta"] = "abdominal aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17856"] = "EMAPA_17856"


class _Post_Ductal_Part_Of_Thoracic_Aorta(_MouseAnatomicalStructureModel):
    """Model post-ductal part of thoracic aorta"""

    name: Literal["post-ductal part of thoracic aorta"] = "post-ductal part of thoracic aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17857"] = "EMAPA_17857"


class _Ductus_Arteriosus(_MouseAnatomicalStructureModel):
    """Model ductus arteriosus"""

    name: Literal["ductus arteriosus"] = "ductus arteriosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17858"] = "EMAPA_17858"


class _Hepatic_Artery(_MouseAnatomicalStructureModel):
    """Model hepatic artery"""

    name: Literal["hepatic artery"] = "hepatic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17859"] = "EMAPA_17859"


class _Internal_Iliac_Artery(_MouseAnatomicalStructureModel):
    """Model internal iliac artery"""

    name: Literal["internal iliac artery"] = "internal iliac artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17860"] = "EMAPA_17860"


class _Posterior_Cerebral_Artery(_MouseAnatomicalStructureModel):
    """Model posterior cerebral artery"""

    name: Literal["posterior cerebral artery"] = "posterior cerebral artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17861"] = "EMAPA_17861"


class _Foramen_Secundum(_MouseAnatomicalStructureModel):
    """Model foramen secundum"""

    name: Literal["foramen secundum"] = "foramen secundum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17863"] = "EMAPA_17863"


class _Septum_Secundum(_MouseAnatomicalStructureModel):
    """Model septum secundum"""

    name: Literal["septum secundum"] = "septum secundum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17864"] = "EMAPA_17864"


class _Bulboventricular_Region(_MouseAnatomicalStructureModel):
    """Model bulboventricular region"""

    name: Literal["bulboventricular region"] = "bulboventricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17865"] = "EMAPA_17865"


class _Bulbar_Cushion(_MouseAnatomicalStructureModel):
    """Model bulbar cushion"""

    name: Literal["bulbar cushion"] = "bulbar cushion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17866"] = "EMAPA_17866"


class _Endocardial_Tissue(_MouseAnatomicalStructureModel):
    """Model endocardial tissue"""

    name: Literal["endocardial tissue"] = "endocardial tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17868"] = "EMAPA_17868"


class _Heart_Valve(_MouseAnatomicalStructureModel):
    """Model heart valve"""

    name: Literal["heart valve"] = "heart valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17869"] = "EMAPA_17869"


class _Aortic_Valve(_MouseAnatomicalStructureModel):
    """Model aortic valve"""

    name: Literal["aortic valve"] = "aortic valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17870"] = "EMAPA_17870"


class _Mitral_Valve(_MouseAnatomicalStructureModel):
    """Model mitral valve"""

    name: Literal["mitral valve"] = "mitral valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17871"] = "EMAPA_17871"


class _Pulmonary_Valve(_MouseAnatomicalStructureModel):
    """Model pulmonary valve"""

    name: Literal["pulmonary valve"] = "pulmonary valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17872"] = "EMAPA_17872"


class _Tricuspid_Valve(_MouseAnatomicalStructureModel):
    """Model tricuspid valve"""

    name: Literal["tricuspid valve"] = "tricuspid valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17873"] = "EMAPA_17873"


class _Common_Iliac_Vein(_MouseAnatomicalStructureModel):
    """Model common iliac vein"""

    name: Literal["common iliac vein"] = "common iliac vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17874"] = "EMAPA_17874"


class _External_Jugular_Vein(_MouseAnatomicalStructureModel):
    """Model external jugular vein"""

    name: Literal["external jugular vein"] = "external jugular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17875"] = "EMAPA_17875"


class _Femoral_Vein(_MouseAnatomicalStructureModel):
    """Model femoral vein"""

    name: Literal["femoral vein"] = "femoral vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17876"] = "EMAPA_17876"


class _Tongue_Epithelium(_MouseAnatomicalStructureModel):
    """Model tongue epithelium"""

    name: Literal["tongue epithelium"] = "tongue epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17881"] = "EMAPA_17881"


class _Tongue_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model tongue mesenchyme"""

    name: Literal["tongue mesenchyme"] = "tongue mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17882"] = "EMAPA_17882"


class _Tongue_Muscle(_MouseAnatomicalStructureModel):
    """Model tongue muscle"""

    name: Literal["tongue muscle"] = "tongue muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17883"] = "EMAPA_17883"


class _Tongue_Extrinsic_Pre_Muscle_Mass(_MouseAnatomicalStructureModel):
    """Model tongue extrinsic pre-muscle mass"""

    name: Literal["tongue extrinsic pre-muscle mass"] = "tongue extrinsic pre-muscle mass"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17884"] = "EMAPA_17884"


class _Stomach_Fundus(_MouseAnatomicalStructureModel):
    """Model stomach fundus"""

    name: Literal["stomach fundus"] = "stomach fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17886"] = "EMAPA_17886"


class _Stomach_Fundus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model stomach fundus mesenchyme"""

    name: Literal["stomach fundus mesenchyme"] = "stomach fundus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17887"] = "EMAPA_17887"


class _Stomach_Fundus_Epithelium(_MouseAnatomicalStructureModel):
    """Model stomach fundus epithelium"""

    name: Literal["stomach fundus epithelium"] = "stomach fundus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17888"] = "EMAPA_17888"


class _Stomach_Fundus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model stomach fundus vascular element"""

    name: Literal["stomach fundus vascular element"] = "stomach fundus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17889"] = "EMAPA_17889"


class _Lesser_Omentum(_MouseAnatomicalStructureModel):
    """Model lesser omentum"""

    name: Literal["lesser omentum"] = "lesser omentum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17890"] = "EMAPA_17890"


class _Pyloric_Antrum(_MouseAnatomicalStructureModel):
    """Model pyloric antrum"""

    name: Literal["pyloric antrum"] = "pyloric antrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17891"] = "EMAPA_17891"


class _Perineal_Body(_MouseAnatomicalStructureModel):
    """Model perineal body"""

    name: Literal["perineal body"] = "perineal body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17892"] = "EMAPA_17892"


class _Perineal_Body_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model perineal body mesenchyme"""

    name: Literal["perineal body mesenchyme"] = "perineal body mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17893"] = "EMAPA_17893"


class _Perineal_Body_Epithelium(_MouseAnatomicalStructureModel):
    """Model perineal body epithelium"""

    name: Literal["perineal body epithelium"] = "perineal body epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17894"] = "EMAPA_17894"


class _Perineal_Body_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model perineal body vascular element"""

    name: Literal["perineal body vascular element"] = "perineal body vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17895"] = "EMAPA_17895"


class _Rectum(_MouseAnatomicalStructureModel):
    """Model rectum"""

    name: Literal["rectum"] = "rectum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17896"] = "EMAPA_17896"


class _Rectum_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model rectum mesenchyme"""

    name: Literal["rectum mesenchyme"] = "rectum mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17897"] = "EMAPA_17897"


class _Rectum_Epithelium(_MouseAnatomicalStructureModel):
    """Model rectum epithelium"""

    name: Literal["rectum epithelium"] = "rectum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17898"] = "EMAPA_17898"


class _Rectum_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model rectum vascular element"""

    name: Literal["rectum vascular element"] = "rectum vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17899"] = "EMAPA_17899"


class _Lower_Jaw(_MouseAnatomicalStructureModel):
    """Model lower jaw"""

    name: Literal["lower jaw"] = "lower jaw"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17906"] = "EMAPA_17906"


class _Lower_Lip(_MouseAnatomicalStructureModel):
    """Model lower lip"""

    name: Literal["lower lip"] = "lower lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17909"] = "EMAPA_17909"


class _Lower_Jaw_Skeleton(_MouseAnatomicalStructureModel):
    """Model lower jaw skeleton"""

    name: Literal["lower jaw skeleton"] = "lower jaw skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17910"] = "EMAPA_17910"


class _Mandible_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model mandible mesenchyme"""

    name: Literal["mandible mesenchyme"] = "mandible mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17912"] = "EMAPA_17912"


class _Lower_Jaw_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower jaw mesenchyme"""

    name: Literal["lower jaw mesenchyme"] = "lower jaw mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17916"] = "EMAPA_17916"


class _Lower_Jaw_Tooth(_MouseAnatomicalStructureModel):
    """Model lower jaw tooth"""

    name: Literal["lower jaw tooth"] = "lower jaw tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17917"] = "EMAPA_17917"


class _Lower_Jaw_Incisor(_MouseAnatomicalStructureModel):
    """Model lower jaw incisor"""

    name: Literal["lower jaw incisor"] = "lower jaw incisor"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17918"] = "EMAPA_17918"


class _Lower_Jaw_Incisor_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower jaw incisor epithelium"""

    name: Literal["lower jaw incisor epithelium"] = "lower jaw incisor epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17919"] = "EMAPA_17919"


class _Lower_Jaw_Incisor_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower jaw incisor mesenchyme"""

    name: Literal["lower jaw incisor mesenchyme"] = "lower jaw incisor mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17920"] = "EMAPA_17920"


class _Lower_Jaw_Molar(_MouseAnatomicalStructureModel):
    """Model lower jaw molar"""

    name: Literal["lower jaw molar"] = "lower jaw molar"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17921"] = "EMAPA_17921"


class _Lower_Jaw_Molar_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower jaw molar epithelium"""

    name: Literal["lower jaw molar epithelium"] = "lower jaw molar epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17922"] = "EMAPA_17922"


class _Lower_Jaw_Molar_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower jaw molar mesenchyme"""

    name: Literal["lower jaw molar mesenchyme"] = "lower jaw molar mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17923"] = "EMAPA_17923"


class _Upper_Jaw(_MouseAnatomicalStructureModel):
    """Model upper jaw"""

    name: Literal["upper jaw"] = "upper jaw"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17924"] = "EMAPA_17924"


class _Upper_Lip(_MouseAnatomicalStructureModel):
    """Model upper lip"""

    name: Literal["upper lip"] = "upper lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17925"] = "EMAPA_17925"


class _Philtrum(_MouseAnatomicalStructureModel):
    """Model philtrum"""

    name: Literal["philtrum"] = "philtrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17926"] = "EMAPA_17926"


class _Upper_Jaw_Skeleton(_MouseAnatomicalStructureModel):
    """Model upper jaw skeleton"""

    name: Literal["upper jaw skeleton"] = "upper jaw skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17927"] = "EMAPA_17927"


class _Upper_Jaw_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper jaw mesenchyme"""

    name: Literal["upper jaw mesenchyme"] = "upper jaw mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17929"] = "EMAPA_17929"


class _Upper_Jaw_Alveolar_Sulcus(_MouseAnatomicalStructureModel):
    """Model upper jaw alveolar sulcus"""

    name: Literal["upper jaw alveolar sulcus"] = "upper jaw alveolar sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17937"] = "EMAPA_17937"


class _Upper_Jaw_Tooth(_MouseAnatomicalStructureModel):
    """Model upper jaw tooth"""

    name: Literal["upper jaw tooth"] = "upper jaw tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17938"] = "EMAPA_17938"


class _Upper_Jaw_Incisor(_MouseAnatomicalStructureModel):
    """Model upper jaw incisor"""

    name: Literal["upper jaw incisor"] = "upper jaw incisor"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17939"] = "EMAPA_17939"


class _Upper_Jaw_Incisor_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper jaw incisor epithelium"""

    name: Literal["upper jaw incisor epithelium"] = "upper jaw incisor epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17940"] = "EMAPA_17940"


class _Upper_Jaw_Incisor_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper jaw incisor mesenchyme"""

    name: Literal["upper jaw incisor mesenchyme"] = "upper jaw incisor mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17941"] = "EMAPA_17941"


class _Upper_Jaw_Molar(_MouseAnatomicalStructureModel):
    """Model upper jaw molar"""

    name: Literal["upper jaw molar"] = "upper jaw molar"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17942"] = "EMAPA_17942"


class _Upper_Jaw_Molar_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper jaw molar epithelium"""

    name: Literal["upper jaw molar epithelium"] = "upper jaw molar epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17943"] = "EMAPA_17943"


class _Upper_Jaw_Molar_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper jaw molar mesenchyme"""

    name: Literal["upper jaw molar mesenchyme"] = "upper jaw molar mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17944"] = "EMAPA_17944"


class _Liver_Bare_Area(_MouseAnatomicalStructureModel):
    """Model liver bare area"""

    name: Literal["liver bare area"] = "liver bare area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17945"] = "EMAPA_17945"


class _Renal_Pelvis(_MouseAnatomicalStructureModel):
    """Model renal pelvis"""

    name: Literal["renal pelvis"] = "renal pelvis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17948"] = "EMAPA_17948"


class _Ureter(_MouseAnatomicalStructureModel):
    """Model ureter"""

    name: Literal["ureter"] = "ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17950"] = "EMAPA_17950"


class _Renal_Cortex(_MouseAnatomicalStructureModel):
    """Model renal cortex"""

    name: Literal["renal cortex"] = "renal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17952"] = "EMAPA_17952"


class _Nephrogenic_Interstitium(_MouseAnatomicalStructureModel):
    """Model nephrogenic interstitium"""

    name: Literal["nephrogenic interstitium"] = "nephrogenic interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17953"] = "EMAPA_17953"


class _Early_Nephron(_MouseAnatomicalStructureModel):
    """Model early nephron"""

    name: Literal["early nephron"] = "early nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17954"] = "EMAPA_17954"


class _Phallic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model phallic urethra of male"""

    name: Literal["phallic urethra of male"] = "phallic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17956"] = "EMAPA_17956"


class _Female_Reproductive_System(_MouseAnatomicalStructureModel):
    """Model female reproductive system"""

    name: Literal["female reproductive system"] = "female reproductive system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17959"] = "EMAPA_17959"


class _Mesovarium(_MouseAnatomicalStructureModel):
    """Model mesovarium"""

    name: Literal["mesovarium"] = "mesovarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17961"] = "EMAPA_17961"


class _Ovary(_MouseAnatomicalStructureModel):
    """Model ovary"""

    name: Literal["ovary"] = "ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17962"] = "EMAPA_17962"


class _Surface_Epithelium_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model surface epithelium of ovary"""

    name: Literal["surface epithelium of ovary"] = "surface epithelium of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17963"] = "EMAPA_17963"


class _Germ_Cell_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model germ cell of ovary"""

    name: Literal["germ cell of ovary"] = "germ cell of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17965"] = "EMAPA_17965"


class _Rete_Ovarii_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model rete ovarii of ovary"""

    name: Literal["rete ovarii of ovary"] = "rete ovarii of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17966"] = "EMAPA_17966"


class _Male_Reproductive_System(_MouseAnatomicalStructureModel):
    """Model male reproductive system"""

    name: Literal["male reproductive system"] = "male reproductive system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17968"] = "EMAPA_17968"


class _Genital_Tubercle_Of_Male(_MouseAnatomicalStructureModel):
    """Model genital tubercle of male"""

    name: Literal["genital tubercle of male"] = "genital tubercle of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17969"] = "EMAPA_17969"


class _Nephric_Duct_Of_Male_Mesonephric_Portion(_MouseAnatomicalStructureModel):
    """Model nephric duct of male, mesonephric portion"""

    name: Literal["nephric duct of male, mesonephric portion"] = "nephric duct of male, mesonephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17970"] = "EMAPA_17970"


class _Mesorchium(_MouseAnatomicalStructureModel):
    """Model mesorchium"""

    name: Literal["mesorchium"] = "mesorchium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17971"] = "EMAPA_17971"


class _Testis(_MouseAnatomicalStructureModel):
    """Model testis"""

    name: Literal["testis"] = "testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17972"] = "EMAPA_17972"


class _Coelomic_Epithelium_Of_Testis(_MouseAnatomicalStructureModel):
    """Model coelomic epithelium of testis"""

    name: Literal["coelomic epithelium of testis"] = "coelomic epithelium of testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17973"] = "EMAPA_17973"


class _Germ_Cell_Of_Testis(_MouseAnatomicalStructureModel):
    """Model germ cell of testis"""

    name: Literal["germ cell of testis"] = "germ cell of testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17975"] = "EMAPA_17975"


class _Left_Lung_Hilus(_MouseAnatomicalStructureModel):
    """Model left lung hilus"""

    name: Literal["left lung hilus"] = "left lung hilus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17980"] = "EMAPA_17980"


class _Right_Lung_Accessory_Lobe(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe"""

    name: Literal["right lung accessory lobe"] = "right lung accessory lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17981"] = "EMAPA_17981"


class _Right_Lung_Accessory_Lobe_Lobar_Bronchus(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe lobar bronchus"""

    name: Literal["right lung accessory lobe lobar bronchus"] = "right lung accessory lobe lobar bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17982"] = "EMAPA_17982"


class _Right_Lung_Accessory_Lobe_Lobar_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe lobar bronchus mesenchyme"""

    name: Literal[
        "right lung accessory lobe lobar bronchus mesenchyme"
    ] = "right lung accessory lobe lobar bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17983"] = "EMAPA_17983"


class _Right_Lung_Accessory_Lobe_Lobar_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe lobar bronchus epithelium"""

    name: Literal[
        "right lung accessory lobe lobar bronchus epithelium"
    ] = "right lung accessory lobe lobar bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17984"] = "EMAPA_17984"


class _Right_Lung_Accessory_Lobe_Lobar_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe lobar bronchus vascular element"""

    name: Literal[
        "right lung accessory lobe lobar bronchus vascular element"
    ] = "right lung accessory lobe lobar bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17985"] = "EMAPA_17985"


class _Right_Lung_Caudal_Lobe(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe"""

    name: Literal["right lung caudal lobe"] = "right lung caudal lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17986"] = "EMAPA_17986"


class _Right_Lung_Caudal_Lobe_Lobar_Bronchus(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe lobar bronchus"""

    name: Literal["right lung caudal lobe lobar bronchus"] = "right lung caudal lobe lobar bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17987"] = "EMAPA_17987"


class _Right_Lung_Caudal_Lobe_Lobar_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe lobar bronchus mesenchyme"""

    name: Literal[
        "right lung caudal lobe lobar bronchus mesenchyme"
    ] = "right lung caudal lobe lobar bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17988"] = "EMAPA_17988"


class _Right_Lung_Caudal_Lobe_Lobar_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe lobar bronchus epithelium"""

    name: Literal[
        "right lung caudal lobe lobar bronchus epithelium"
    ] = "right lung caudal lobe lobar bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17989"] = "EMAPA_17989"


class _Right_Lung_Caudal_Lobe_Lobar_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe lobar bronchus vascular element"""

    name: Literal[
        "right lung caudal lobe lobar bronchus vascular element"
    ] = "right lung caudal lobe lobar bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17990"] = "EMAPA_17990"


class _Right_Lung_Cranial_Lobe(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe"""

    name: Literal["right lung cranial lobe"] = "right lung cranial lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17991"] = "EMAPA_17991"


class _Right_Lung_Cranial_Lobe_Lobar_Bronchus(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe lobar bronchus"""

    name: Literal["right lung cranial lobe lobar bronchus"] = "right lung cranial lobe lobar bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17992"] = "EMAPA_17992"


class _Right_Lung_Cranial_Lobe_Lobar_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe lobar bronchus mesenchyme"""

    name: Literal[
        "right lung cranial lobe lobar bronchus mesenchyme"
    ] = "right lung cranial lobe lobar bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17993"] = "EMAPA_17993"


class _Right_Lung_Cranial_Lobe_Lobar_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe lobar bronchus epithelium"""

    name: Literal[
        "right lung cranial lobe lobar bronchus epithelium"
    ] = "right lung cranial lobe lobar bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17994"] = "EMAPA_17994"


class _Right_Lung_Cranial_Lobe_Lobar_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe lobar bronchus vascular element"""

    name: Literal[
        "right lung cranial lobe lobar bronchus vascular element"
    ] = "right lung cranial lobe lobar bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17995"] = "EMAPA_17995"


class _Right_Lung_Hilus(_MouseAnatomicalStructureModel):
    """Model right lung hilus"""

    name: Literal["right lung hilus"] = "right lung hilus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17996"] = "EMAPA_17996"


class _Right_Lung_Middle_Lobe(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe"""

    name: Literal["right lung middle lobe"] = "right lung middle lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17997"] = "EMAPA_17997"


class _Right_Lung_Middle_Lobe_Lobar_Bronchus(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe lobar bronchus"""

    name: Literal["right lung middle lobe lobar bronchus"] = "right lung middle lobe lobar bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17998"] = "EMAPA_17998"


class _Right_Lung_Middle_Lobe_Lobar_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe lobar bronchus mesenchyme"""

    name: Literal[
        "right lung middle lobe lobar bronchus mesenchyme"
    ] = "right lung middle lobe lobar bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_17999"] = "EMAPA_17999"


class _Right_Lung_Middle_Lobe_Lobar_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe lobar bronchus epithelium"""

    name: Literal[
        "right lung middle lobe lobar bronchus epithelium"
    ] = "right lung middle lobe lobar bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18000"] = "EMAPA_18000"


class _Right_Lung_Middle_Lobe_Lobar_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe lobar bronchus vascular element"""

    name: Literal[
        "right lung middle lobe lobar bronchus vascular element"
    ] = "right lung middle lobe lobar bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18001"] = "EMAPA_18001"


class _Lumbar_Vertebra(_MouseAnatomicalStructureModel):
    """Model lumbar vertebra"""

    name: Literal["lumbar vertebra"] = "lumbar vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18007"] = "EMAPA_18007"


class _Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model nucleus pulposus"""

    name: Literal["nucleus pulposus"] = "nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18008"] = "EMAPA_18008"


class _Sacral_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model sacral vertebral cartilage condensation"""

    name: Literal["sacral vertebral cartilage condensation"] = "sacral vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18009"] = "EMAPA_18009"


class _Rib(_MouseAnatomicalStructureModel):
    """Model rib"""

    name: Literal["rib"] = "rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18010"] = "EMAPA_18010"


class _Thoracic_Vertebra(_MouseAnatomicalStructureModel):
    """Model thoracic vertebra"""

    name: Literal["thoracic vertebra"] = "thoracic vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18011"] = "EMAPA_18011"


class _Basioccipital_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model basioccipital pre-cartilage condensation"""

    name: Literal["basioccipital pre-cartilage condensation"] = "basioccipital pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18012"] = "EMAPA_18012"


class _Basisphenoid_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model basisphenoid pre-cartilage condensation"""

    name: Literal["basisphenoid pre-cartilage condensation"] = "basisphenoid pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18013"] = "EMAPA_18013"


class _Exoccipital_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model exoccipital pre-cartilage condensation"""

    name: Literal["exoccipital pre-cartilage condensation"] = "exoccipital pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18014"] = "EMAPA_18014"


class _Sphenoid_Bone_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model sphenoid bone pre-cartilage condensation"""

    name: Literal["sphenoid bone pre-cartilage condensation"] = "sphenoid bone pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18015"] = "EMAPA_18015"


class _Vault_Of_Skull(_MouseAnatomicalStructureModel):
    """Model vault of skull"""

    name: Literal["vault of skull"] = "vault of skull"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18016"] = "EMAPA_18016"


class _Frontal_Bone_Primordium(_MouseAnatomicalStructureModel):
    """Model frontal bone primordium"""

    name: Literal["frontal bone primordium"] = "frontal bone primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18017"] = "EMAPA_18017"


class _Inter_Parietal_Bone_Primordium(_MouseAnatomicalStructureModel):
    """Model inter-parietal bone primordium"""

    name: Literal["inter-parietal bone primordium"] = "inter-parietal bone primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18018"] = "EMAPA_18018"


class _Parietal_Bone_Primordium(_MouseAnatomicalStructureModel):
    """Model parietal bone primordium"""

    name: Literal["parietal bone primordium"] = "parietal bone primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18019"] = "EMAPA_18019"


class _Temporal_Bone_Squamous_Part(_MouseAnatomicalStructureModel):
    """Model temporal bone squamous part"""

    name: Literal["temporal bone squamous part"] = "temporal bone squamous part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18021"] = "EMAPA_18021"


class _Viscerocranium(_MouseAnatomicalStructureModel):
    """Model viscerocranium"""

    name: Literal["viscerocranium"] = "viscerocranium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18022"] = "EMAPA_18022"


class _Ethmoid_Bone_Primordium(_MouseAnatomicalStructureModel):
    """Model ethmoid bone primordium"""

    name: Literal["ethmoid bone primordium"] = "ethmoid bone primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18023"] = "EMAPA_18023"


class _Facial_Bone_Primordium(_MouseAnatomicalStructureModel):
    """Model facial bone primordium"""

    name: Literal["facial bone primordium"] = "facial bone primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18024"] = "EMAPA_18024"


class _Thoracic_Segment_Skeleton(_MouseAnatomicalStructureModel):
    """Model thoracic segment skeleton"""

    name: Literal["thoracic segment skeleton"] = "thoracic segment skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18025"] = "EMAPA_18025"


class _Clavicle_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model clavicle pre-cartilage condensation"""

    name: Literal["clavicle pre-cartilage condensation"] = "clavicle pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18026"] = "EMAPA_18026"


class _Scapula_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model scapula pre-cartilage condensation"""

    name: Literal["scapula pre-cartilage condensation"] = "scapula pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18027"] = "EMAPA_18027"


class _Pelvic_Girdle_Skeleton(_MouseAnatomicalStructureModel):
    """Model pelvic girdle skeleton"""

    name: Literal["pelvic girdle skeleton"] = "pelvic girdle skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18028"] = "EMAPA_18028"


class _Ilium_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model ilium pre-cartilage condensation"""

    name: Literal["ilium pre-cartilage condensation"] = "ilium pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18029"] = "EMAPA_18029"


class _Somite_53(_MouseAnatomicalStructureModel):
    """Model somite 53"""

    name: Literal["somite 53"] = "somite 53"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18030"] = "EMAPA_18030"


class _Somite_53_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 53 dermomyotome"""

    name: Literal["somite 53 dermomyotome"] = "somite 53 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18031"] = "EMAPA_18031"


class _Somite_53_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 53 myocoele"""

    name: Literal["somite 53 myocoele"] = "somite 53 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18032"] = "EMAPA_18032"


class _Somite_53_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 53 sclerotome"""

    name: Literal["somite 53 sclerotome"] = "somite 53 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18033"] = "EMAPA_18033"


class _Somite_54(_MouseAnatomicalStructureModel):
    """Model somite 54"""

    name: Literal["somite 54"] = "somite 54"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18034"] = "EMAPA_18034"


class _Somite_54_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 54 dermomyotome"""

    name: Literal["somite 54 dermomyotome"] = "somite 54 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18035"] = "EMAPA_18035"


class _Somite_54_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 54 myocoele"""

    name: Literal["somite 54 myocoele"] = "somite 54 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18036"] = "EMAPA_18036"


class _Somite_54_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 54 sclerotome"""

    name: Literal["somite 54 sclerotome"] = "somite 54 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18037"] = "EMAPA_18037"


class _Somite_55(_MouseAnatomicalStructureModel):
    """Model somite 55"""

    name: Literal["somite 55"] = "somite 55"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18038"] = "EMAPA_18038"


class _Somite_55_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 55 dermomyotome"""

    name: Literal["somite 55 dermomyotome"] = "somite 55 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18039"] = "EMAPA_18039"


class _Somite_55_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 55 myocoele"""

    name: Literal["somite 55 myocoele"] = "somite 55 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18040"] = "EMAPA_18040"


class _Somite_55_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 55 sclerotome"""

    name: Literal["somite 55 sclerotome"] = "somite 55 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18041"] = "EMAPA_18041"


class _Tail_Skeleton(_MouseAnatomicalStructureModel):
    """Model tail skeleton"""

    name: Literal["tail skeleton"] = "tail skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18042"] = "EMAPA_18042"


class _Axial_Skeleton_Tail_Region(_MouseAnatomicalStructureModel):
    """Model axial skeleton tail region"""

    name: Literal["axial skeleton tail region"] = "axial skeleton tail region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18043"] = "EMAPA_18043"


class _Tail_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model tail vertebral cartilage condensation"""

    name: Literal["tail vertebral cartilage condensation"] = "tail vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18044"] = "EMAPA_18044"


class _Tail_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model tail vertebral pre-cartilage condensation"""

    name: Literal["tail vertebral pre-cartilage condensation"] = "tail vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18045"] = "EMAPA_18045"


class _Diaphragm_Dome(_MouseAnatomicalStructureModel):
    """Model diaphragm dome"""

    name: Literal["diaphragm dome"] = "diaphragm dome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18046"] = "EMAPA_18046"


class _Left_Hepatic_Recess(_MouseAnatomicalStructureModel):
    """Model left hepatic recess"""

    name: Literal["left hepatic recess"] = "left hepatic recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18047"] = "EMAPA_18047"


class _Omental_Bursa_Inferior_Recess(_MouseAnatomicalStructureModel):
    """Model omental bursa inferior recess"""

    name: Literal["omental bursa inferior recess"] = "omental bursa inferior recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18048"] = "EMAPA_18048"


class _Omental_Bursa_Superior_Recess(_MouseAnatomicalStructureModel):
    """Model omental bursa superior recess"""

    name: Literal["omental bursa superior recess"] = "omental bursa superior recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18049"] = "EMAPA_18049"


class _Right_Hepatic_Recess(_MouseAnatomicalStructureModel):
    """Model right hepatic recess"""

    name: Literal["right hepatic recess"] = "right hepatic recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18050"] = "EMAPA_18050"


class _Elbow_Skin(_MouseAnatomicalStructureModel):
    """Model elbow skin"""

    name: Literal["elbow skin"] = "elbow skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18051"] = "EMAPA_18051"


class _Elbow_Dermis(_MouseAnatomicalStructureModel):
    """Model elbow dermis"""

    name: Literal["elbow dermis"] = "elbow dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18052"] = "EMAPA_18052"


class _Elbow_Epidermis(_MouseAnatomicalStructureModel):
    """Model elbow epidermis"""

    name: Literal["elbow epidermis"] = "elbow epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18053"] = "EMAPA_18053"


class _Radius_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model radius cartilage condensation"""

    name: Literal["radius cartilage condensation"] = "radius cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18054"] = "EMAPA_18054"


class _Ulna_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model ulna cartilage condensation"""

    name: Literal["ulna cartilage condensation"] = "ulna cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18055"] = "EMAPA_18055"


class _Forearm_Skin(_MouseAnatomicalStructureModel):
    """Model forearm skin"""

    name: Literal["forearm skin"] = "forearm skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18056"] = "EMAPA_18056"


class _Forearm_Dermis(_MouseAnatomicalStructureModel):
    """Model forearm dermis"""

    name: Literal["forearm dermis"] = "forearm dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18057"] = "EMAPA_18057"


class _Forearm_Epidermis(_MouseAnatomicalStructureModel):
    """Model forearm epidermis"""

    name: Literal["forearm epidermis"] = "forearm epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18058"] = "EMAPA_18058"


class _Shoulder_Skin(_MouseAnatomicalStructureModel):
    """Model shoulder skin"""

    name: Literal["shoulder skin"] = "shoulder skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18059"] = "EMAPA_18059"


class _Shoulder_Dermis(_MouseAnatomicalStructureModel):
    """Model shoulder dermis"""

    name: Literal["shoulder dermis"] = "shoulder dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18060"] = "EMAPA_18060"


class _Shoulder_Epidermis(_MouseAnatomicalStructureModel):
    """Model shoulder epidermis"""

    name: Literal["shoulder epidermis"] = "shoulder epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18061"] = "EMAPA_18061"


class _Upper_Arm_Skin(_MouseAnatomicalStructureModel):
    """Model upper arm skin"""

    name: Literal["upper arm skin"] = "upper arm skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18062"] = "EMAPA_18062"


class _Upper_Arm_Dermis(_MouseAnatomicalStructureModel):
    """Model upper arm dermis"""

    name: Literal["upper arm dermis"] = "upper arm dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18063"] = "EMAPA_18063"


class _Upper_Arm_Epidermis(_MouseAnatomicalStructureModel):
    """Model upper arm epidermis"""

    name: Literal["upper arm epidermis"] = "upper arm epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18064"] = "EMAPA_18064"


class _Forelimb_Digit_1_Metacarpus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 metacarpus cartilage condensation"""

    name: Literal[
        "forelimb digit 1 metacarpus cartilage condensation"
    ] = "forelimb digit 1 metacarpus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18065"] = "EMAPA_18065"


class _Forelimb_Digit_1_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 phalanx cartilage condensation"""

    name: Literal["forelimb digit 1 phalanx cartilage condensation"] = "forelimb digit 1 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18066"] = "EMAPA_18066"


class _Forelimb_Digit_1_Skin(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 skin"""

    name: Literal["forelimb digit 1 skin"] = "forelimb digit 1 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18067"] = "EMAPA_18067"


class _Forelimb_Digit_1_Dermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 dermis"""

    name: Literal["forelimb digit 1 dermis"] = "forelimb digit 1 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18068"] = "EMAPA_18068"


class _Forelimb_Digit_1_Epidermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 epidermis"""

    name: Literal["forelimb digit 1 epidermis"] = "forelimb digit 1 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18069"] = "EMAPA_18069"


class _Forelimb_Digit_2_Metacarpus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 metacarpus cartilage condensation"""

    name: Literal[
        "forelimb digit 2 metacarpus cartilage condensation"
    ] = "forelimb digit 2 metacarpus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18070"] = "EMAPA_18070"


class _Forelimb_Digit_2_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 phalanx cartilage condensation"""

    name: Literal["forelimb digit 2 phalanx cartilage condensation"] = "forelimb digit 2 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18071"] = "EMAPA_18071"


class _Forelimb_Digit_2_Skin(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 skin"""

    name: Literal["forelimb digit 2 skin"] = "forelimb digit 2 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18072"] = "EMAPA_18072"


class _Forelimb_Digit_2_Dermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 dermis"""

    name: Literal["forelimb digit 2 dermis"] = "forelimb digit 2 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18073"] = "EMAPA_18073"


class _Forelimb_Digit_2_Epidermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 epidermis"""

    name: Literal["forelimb digit 2 epidermis"] = "forelimb digit 2 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18074"] = "EMAPA_18074"


class _Forelimb_Digit_3_Metacarpus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 metacarpus cartilage condensation"""

    name: Literal[
        "forelimb digit 3 metacarpus cartilage condensation"
    ] = "forelimb digit 3 metacarpus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18075"] = "EMAPA_18075"


class _Forelimb_Digit_3_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 phalanx cartilage condensation"""

    name: Literal["forelimb digit 3 phalanx cartilage condensation"] = "forelimb digit 3 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18076"] = "EMAPA_18076"


class _Forelimb_Digit_3_Skin(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 skin"""

    name: Literal["forelimb digit 3 skin"] = "forelimb digit 3 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18077"] = "EMAPA_18077"


class _Forelimb_Digit_3_Dermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 dermis"""

    name: Literal["forelimb digit 3 dermis"] = "forelimb digit 3 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18078"] = "EMAPA_18078"


class _Forelimb_Digit_3_Epidermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 epidermis"""

    name: Literal["forelimb digit 3 epidermis"] = "forelimb digit 3 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18079"] = "EMAPA_18079"


class _Forelimb_Digit_4_Metacarpus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 metacarpus cartilage condensation"""

    name: Literal[
        "forelimb digit 4 metacarpus cartilage condensation"
    ] = "forelimb digit 4 metacarpus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18080"] = "EMAPA_18080"


class _Forelimb_Digit_4_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 phalanx cartilage condensation"""

    name: Literal["forelimb digit 4 phalanx cartilage condensation"] = "forelimb digit 4 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18081"] = "EMAPA_18081"


class _Forelimb_Digit_4_Skin(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 skin"""

    name: Literal["forelimb digit 4 skin"] = "forelimb digit 4 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18082"] = "EMAPA_18082"


class _Forelimb_Digit_4_Dermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 dermis"""

    name: Literal["forelimb digit 4 dermis"] = "forelimb digit 4 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18083"] = "EMAPA_18083"


class _Forelimb_Digit_4_Epidermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 epidermis"""

    name: Literal["forelimb digit 4 epidermis"] = "forelimb digit 4 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18084"] = "EMAPA_18084"


class _Forelimb_Digit_5_Metacarpus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 metacarpus cartilage condensation"""

    name: Literal[
        "forelimb digit 5 metacarpus cartilage condensation"
    ] = "forelimb digit 5 metacarpus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18085"] = "EMAPA_18085"


class _Forelimb_Digit_5_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 phalanx cartilage condensation"""

    name: Literal["forelimb digit 5 phalanx cartilage condensation"] = "forelimb digit 5 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18086"] = "EMAPA_18086"


class _Forelimb_Digit_5_Skin(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 skin"""

    name: Literal["forelimb digit 5 skin"] = "forelimb digit 5 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18087"] = "EMAPA_18087"


class _Forelimb_Digit_5_Dermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 dermis"""

    name: Literal["forelimb digit 5 dermis"] = "forelimb digit 5 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18088"] = "EMAPA_18088"


class _Forelimb_Digit_5_Epidermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 epidermis"""

    name: Literal["forelimb digit 5 epidermis"] = "forelimb digit 5 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18089"] = "EMAPA_18089"


class _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Skin(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 1 and 2 skin"""

    name: Literal[
        "interdigital region between forelimb digits 1 and 2 skin"
    ] = "interdigital region between forelimb digits 1 and 2 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18090"] = "EMAPA_18090"


class _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Dermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 1 and 2 dermis"""

    name: Literal[
        "interdigital region between forelimb digits 1 and 2 dermis"
    ] = "interdigital region between forelimb digits 1 and 2 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18091"] = "EMAPA_18091"


class _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Epidermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 1 and 2 epidermis"""

    name: Literal[
        "interdigital region between forelimb digits 1 and 2 epidermis"
    ] = "interdigital region between forelimb digits 1 and 2 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18092"] = "EMAPA_18092"


class _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Skin(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 2 and 3 skin"""

    name: Literal[
        "interdigital region between forelimb digits 2 and 3 skin"
    ] = "interdigital region between forelimb digits 2 and 3 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18093"] = "EMAPA_18093"


class _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Dermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 2 and 3 dermis"""

    name: Literal[
        "interdigital region between forelimb digits 2 and 3 dermis"
    ] = "interdigital region between forelimb digits 2 and 3 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18094"] = "EMAPA_18094"


class _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Epidermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 2 and 3 epidermis"""

    name: Literal[
        "interdigital region between forelimb digits 2 and 3 epidermis"
    ] = "interdigital region between forelimb digits 2 and 3 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18095"] = "EMAPA_18095"


class _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Skin(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 3 and 4 skin"""

    name: Literal[
        "interdigital region between forelimb digits 3 and 4 skin"
    ] = "interdigital region between forelimb digits 3 and 4 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18096"] = "EMAPA_18096"


class _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Dermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 3 and 4 dermis"""

    name: Literal[
        "interdigital region between forelimb digits 3 and 4 dermis"
    ] = "interdigital region between forelimb digits 3 and 4 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18097"] = "EMAPA_18097"


class _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Epidermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 3 and 4 epidermis"""

    name: Literal[
        "interdigital region between forelimb digits 3 and 4 epidermis"
    ] = "interdigital region between forelimb digits 3 and 4 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18098"] = "EMAPA_18098"


class _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Skin(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 4 and 5 skin"""

    name: Literal[
        "interdigital region between forelimb digits 4 and 5 skin"
    ] = "interdigital region between forelimb digits 4 and 5 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18099"] = "EMAPA_18099"


class _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Dermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 4 and 5 dermis"""

    name: Literal[
        "interdigital region between forelimb digits 4 and 5 dermis"
    ] = "interdigital region between forelimb digits 4 and 5 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18100"] = "EMAPA_18100"


class _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Epidermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between forelimb digits 4 and 5 epidermis"""

    name: Literal[
        "interdigital region between forelimb digits 4 and 5 epidermis"
    ] = "interdigital region between forelimb digits 4 and 5 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18101"] = "EMAPA_18101"


class _Carpus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model carpus cartilage condensation"""

    name: Literal["carpus cartilage condensation"] = "carpus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18102"] = "EMAPA_18102"


class _Hand_Rest_Of_Skin(_MouseAnatomicalStructureModel):
    """Model hand rest of skin"""

    name: Literal["hand rest of skin"] = "hand rest of skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18103"] = "EMAPA_18103"


class _Hand_Rest_Of_Skin_Dermis(_MouseAnatomicalStructureModel):
    """Model hand rest of skin dermis"""

    name: Literal["hand rest of skin dermis"] = "hand rest of skin dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18104"] = "EMAPA_18104"


class _Hand_Rest_Of_Skin_Epidermis(_MouseAnatomicalStructureModel):
    """Model hand rest of skin epidermis"""

    name: Literal["hand rest of skin epidermis"] = "hand rest of skin epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18105"] = "EMAPA_18105"


class _Hindlimb_Digit_1_Metatarsus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 metatarsus cartilage condensation"""

    name: Literal[
        "hindlimb digit 1 metatarsus cartilage condensation"
    ] = "hindlimb digit 1 metatarsus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18106"] = "EMAPA_18106"


class _Hindlimb_Digit_1_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 phalanx cartilage condensation"""

    name: Literal["hindlimb digit 1 phalanx cartilage condensation"] = "hindlimb digit 1 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18107"] = "EMAPA_18107"


class _Hindlimb_Digit_1_Skin(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 skin"""

    name: Literal["hindlimb digit 1 skin"] = "hindlimb digit 1 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18108"] = "EMAPA_18108"


class _Hindlimb_Digit_1_Dermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 dermis"""

    name: Literal["hindlimb digit 1 dermis"] = "hindlimb digit 1 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18109"] = "EMAPA_18109"


class _Hindlimb_Digit_1_Epidermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 epidermis"""

    name: Literal["hindlimb digit 1 epidermis"] = "hindlimb digit 1 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18110"] = "EMAPA_18110"


class _Hindlimb_Digit_2_Metatarsus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 metatarsus cartilage condensation"""

    name: Literal[
        "hindlimb digit 2 metatarsus cartilage condensation"
    ] = "hindlimb digit 2 metatarsus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18111"] = "EMAPA_18111"


class _Hindlimb_Digit_2_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 phalanx cartilage condensation"""

    name: Literal["hindlimb digit 2 phalanx cartilage condensation"] = "hindlimb digit 2 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18112"] = "EMAPA_18112"


class _Hindlimb_Digit_2_Skin(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 skin"""

    name: Literal["hindlimb digit 2 skin"] = "hindlimb digit 2 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18113"] = "EMAPA_18113"


class _Hindlimb_Digit_2_Dermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 dermis"""

    name: Literal["hindlimb digit 2 dermis"] = "hindlimb digit 2 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18114"] = "EMAPA_18114"


class _Hindlimb_Digit_2_Epidermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 epidermis"""

    name: Literal["hindlimb digit 2 epidermis"] = "hindlimb digit 2 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18115"] = "EMAPA_18115"


class _Hindlimb_Digit_3_Metatarsus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 metatarsus cartilage condensation"""

    name: Literal[
        "hindlimb digit 3 metatarsus cartilage condensation"
    ] = "hindlimb digit 3 metatarsus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18116"] = "EMAPA_18116"


class _Hindlimb_Digit_3_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 phalanx cartilage condensation"""

    name: Literal["hindlimb digit 3 phalanx cartilage condensation"] = "hindlimb digit 3 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18117"] = "EMAPA_18117"


class _Hindlimb_Digit_3_Skin(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 skin"""

    name: Literal["hindlimb digit 3 skin"] = "hindlimb digit 3 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18118"] = "EMAPA_18118"


class _Hindlimb_Digit_3_Dermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 dermis"""

    name: Literal["hindlimb digit 3 dermis"] = "hindlimb digit 3 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18119"] = "EMAPA_18119"


class _Hindlimb_Digit_3_Epidermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 epidermis"""

    name: Literal["hindlimb digit 3 epidermis"] = "hindlimb digit 3 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18120"] = "EMAPA_18120"


class _Hindlimb_Digit_4_Metatarsus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 metatarsus cartilage condensation"""

    name: Literal[
        "hindlimb digit 4 metatarsus cartilage condensation"
    ] = "hindlimb digit 4 metatarsus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18121"] = "EMAPA_18121"


class _Hindlimb_Digit_4_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 phalanx cartilage condensation"""

    name: Literal["hindlimb digit 4 phalanx cartilage condensation"] = "hindlimb digit 4 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18122"] = "EMAPA_18122"


class _Hindlimb_Digit_4_Skin(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 skin"""

    name: Literal["hindlimb digit 4 skin"] = "hindlimb digit 4 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18123"] = "EMAPA_18123"


class _Hindlimb_Digit_4_Dermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 dermis"""

    name: Literal["hindlimb digit 4 dermis"] = "hindlimb digit 4 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18124"] = "EMAPA_18124"


class _Hindlimb_Digit_4_Epidermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 epidermis"""

    name: Literal["hindlimb digit 4 epidermis"] = "hindlimb digit 4 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18125"] = "EMAPA_18125"


class _Hindlimb_Digit_5_Metatarsus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 metatarsus cartilage condensation"""

    name: Literal[
        "hindlimb digit 5 metatarsus cartilage condensation"
    ] = "hindlimb digit 5 metatarsus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18126"] = "EMAPA_18126"


class _Hindlimb_Digit_5_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 phalanx cartilage condensation"""

    name: Literal["hindlimb digit 5 phalanx cartilage condensation"] = "hindlimb digit 5 phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18127"] = "EMAPA_18127"


class _Hindlimb_Digit_5_Skin(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 skin"""

    name: Literal["hindlimb digit 5 skin"] = "hindlimb digit 5 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18128"] = "EMAPA_18128"


class _Hindlimb_Digit_5_Dermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 dermis"""

    name: Literal["hindlimb digit 5 dermis"] = "hindlimb digit 5 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18129"] = "EMAPA_18129"


class _Hindlimb_Digit_5_Epidermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 epidermis"""

    name: Literal["hindlimb digit 5 epidermis"] = "hindlimb digit 5 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18130"] = "EMAPA_18130"


class _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Skin(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 1 and 2 skin"""

    name: Literal[
        "interdigital region between hindlimb digits 1 and 2 skin"
    ] = "interdigital region between hindlimb digits 1 and 2 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18131"] = "EMAPA_18131"


class _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Dermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 1 and 2 dermis"""

    name: Literal[
        "interdigital region between hindlimb digits 1 and 2 dermis"
    ] = "interdigital region between hindlimb digits 1 and 2 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18132"] = "EMAPA_18132"


class _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Epidermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 1 and 2 epidermis"""

    name: Literal[
        "interdigital region between hindlimb digits 1 and 2 epidermis"
    ] = "interdigital region between hindlimb digits 1 and 2 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18133"] = "EMAPA_18133"


class _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Skin(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 2 and 3 skin"""

    name: Literal[
        "interdigital region between hindlimb digits 2 and 3 skin"
    ] = "interdigital region between hindlimb digits 2 and 3 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18134"] = "EMAPA_18134"


class _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Dermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 2 and 3 dermis"""

    name: Literal[
        "interdigital region between hindlimb digits 2 and 3 dermis"
    ] = "interdigital region between hindlimb digits 2 and 3 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18135"] = "EMAPA_18135"


class _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Epidermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 2 and 3 epidermis"""

    name: Literal[
        "interdigital region between hindlimb digits 2 and 3 epidermis"
    ] = "interdigital region between hindlimb digits 2 and 3 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18136"] = "EMAPA_18136"


class _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Skin(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 3 and 4 skin"""

    name: Literal[
        "interdigital region between hindlimb digits 3 and 4 skin"
    ] = "interdigital region between hindlimb digits 3 and 4 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18137"] = "EMAPA_18137"


class _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Dermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 3 and 4 dermis"""

    name: Literal[
        "interdigital region between hindlimb digits 3 and 4 dermis"
    ] = "interdigital region between hindlimb digits 3 and 4 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18138"] = "EMAPA_18138"


class _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Epidermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 3 and 4 epidermis"""

    name: Literal[
        "interdigital region between hindlimb digits 3 and 4 epidermis"
    ] = "interdigital region between hindlimb digits 3 and 4 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18139"] = "EMAPA_18139"


class _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Skin(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 4 and 5 skin"""

    name: Literal[
        "interdigital region between hindlimb digits 4 and 5 skin"
    ] = "interdigital region between hindlimb digits 4 and 5 skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18140"] = "EMAPA_18140"


class _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Dermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 4 and 5 dermis"""

    name: Literal[
        "interdigital region between hindlimb digits 4 and 5 dermis"
    ] = "interdigital region between hindlimb digits 4 and 5 dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18141"] = "EMAPA_18141"


class _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Epidermis(_MouseAnatomicalStructureModel):
    """Model interdigital region between hindlimb digits 4 and 5 epidermis"""

    name: Literal[
        "interdigital region between hindlimb digits 4 and 5 epidermis"
    ] = "interdigital region between hindlimb digits 4 and 5 epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18142"] = "EMAPA_18142"


class _Calcaneum_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model calcaneum cartilage condensation"""

    name: Literal["calcaneum cartilage condensation"] = "calcaneum cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18143"] = "EMAPA_18143"


class _Talus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model talus cartilage condensation"""

    name: Literal["talus cartilage condensation"] = "talus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18144"] = "EMAPA_18144"


class _Foot_Rest_Of_Skin(_MouseAnatomicalStructureModel):
    """Model foot rest of skin"""

    name: Literal["foot rest of skin"] = "foot rest of skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18145"] = "EMAPA_18145"


class _Foot_Rest_Of_Skin_Dermis(_MouseAnatomicalStructureModel):
    """Model foot rest of skin dermis"""

    name: Literal["foot rest of skin dermis"] = "foot rest of skin dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18146"] = "EMAPA_18146"


class _Foot_Rest_Of_Skin_Epidermis(_MouseAnatomicalStructureModel):
    """Model foot rest of skin epidermis"""

    name: Literal["foot rest of skin epidermis"] = "foot rest of skin epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18147"] = "EMAPA_18147"


class _Hip_Skin(_MouseAnatomicalStructureModel):
    """Model hip skin"""

    name: Literal["hip skin"] = "hip skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18148"] = "EMAPA_18148"


class _Hip_Dermis(_MouseAnatomicalStructureModel):
    """Model hip dermis"""

    name: Literal["hip dermis"] = "hip dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18149"] = "EMAPA_18149"


class _Hip_Epidermis(_MouseAnatomicalStructureModel):
    """Model hip epidermis"""

    name: Literal["hip epidermis"] = "hip epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18150"] = "EMAPA_18150"


class _Knee_Skin(_MouseAnatomicalStructureModel):
    """Model knee skin"""

    name: Literal["knee skin"] = "knee skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18151"] = "EMAPA_18151"


class _Knee_Dermis(_MouseAnatomicalStructureModel):
    """Model knee dermis"""

    name: Literal["knee dermis"] = "knee dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18152"] = "EMAPA_18152"


class _Knee_Epidermis(_MouseAnatomicalStructureModel):
    """Model knee epidermis"""

    name: Literal["knee epidermis"] = "knee epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18153"] = "EMAPA_18153"


class _Fibula_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model fibula cartilage condensation"""

    name: Literal["fibula cartilage condensation"] = "fibula cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18154"] = "EMAPA_18154"


class _Tibia_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model tibia cartilage condensation"""

    name: Literal["tibia cartilage condensation"] = "tibia cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18155"] = "EMAPA_18155"


class _Lower_Leg_Skin(_MouseAnatomicalStructureModel):
    """Model lower leg skin"""

    name: Literal["lower leg skin"] = "lower leg skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18156"] = "EMAPA_18156"


class _Lower_Leg_Dermis(_MouseAnatomicalStructureModel):
    """Model lower leg dermis"""

    name: Literal["lower leg dermis"] = "lower leg dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18157"] = "EMAPA_18157"


class _Lower_Leg_Epidermis(_MouseAnatomicalStructureModel):
    """Model lower leg epidermis"""

    name: Literal["lower leg epidermis"] = "lower leg epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18158"] = "EMAPA_18158"


class _Upper_Leg_Skin(_MouseAnatomicalStructureModel):
    """Model upper leg skin"""

    name: Literal["upper leg skin"] = "upper leg skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18159"] = "EMAPA_18159"


class _Upper_Leg_Dermis(_MouseAnatomicalStructureModel):
    """Model upper leg dermis"""

    name: Literal["upper leg dermis"] = "upper leg dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18160"] = "EMAPA_18160"


class _Upper_Leg_Epidermis(_MouseAnatomicalStructureModel):
    """Model upper leg epidermis"""

    name: Literal["upper leg epidermis"] = "upper leg epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18161"] = "EMAPA_18161"


class _External_Oblique_Muscle(_MouseAnatomicalStructureModel):
    """Model external oblique muscle"""

    name: Literal["external oblique muscle"] = "external oblique muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18162"] = "EMAPA_18162"


class _Internal_Oblique_Muscle(_MouseAnatomicalStructureModel):
    """Model internal oblique muscle"""

    name: Literal["internal oblique muscle"] = "internal oblique muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18163"] = "EMAPA_18163"


class _Rectus_Abdominis(_MouseAnatomicalStructureModel):
    """Model rectus abdominis"""

    name: Literal["rectus abdominis"] = "rectus abdominis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18164"] = "EMAPA_18164"


class _Transversus_Abdominis(_MouseAnatomicalStructureModel):
    """Model transversus abdominis"""

    name: Literal["transversus abdominis"] = "transversus abdominis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18165"] = "EMAPA_18165"


class _Axial_Musculature(_MouseAnatomicalStructureModel):
    """Model axial musculature"""

    name: Literal["axial musculature"] = "axial musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18166"] = "EMAPA_18166"


class _Axial_Muscle(_MouseAnatomicalStructureModel):
    """Model axial muscle"""

    name: Literal["axial muscle"] = "axial muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18167"] = "EMAPA_18167"


class _Erector_Spinae(_MouseAnatomicalStructureModel):
    """Model erector spinae"""

    name: Literal["erector spinae"] = "erector spinae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18168"] = "EMAPA_18168"


class _Psoas_Major(_MouseAnatomicalStructureModel):
    """Model psoas major"""

    name: Literal["psoas major"] = "psoas major"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18169"] = "EMAPA_18169"


class _Psoas_Minor(_MouseAnatomicalStructureModel):
    """Model psoas minor"""

    name: Literal["psoas minor"] = "psoas minor"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18170"] = "EMAPA_18170"


class _Cranial_Musculature(_MouseAnatomicalStructureModel):
    """Model cranial musculature"""

    name: Literal["cranial musculature"] = "cranial musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18171"] = "EMAPA_18171"


class _Cranial_Muscle(_MouseAnatomicalStructureModel):
    """Model cranial muscle"""

    name: Literal["cranial muscle"] = "cranial muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18172"] = "EMAPA_18172"


class _Deltoid(_MouseAnatomicalStructureModel):
    """Model deltoid"""

    name: Literal["deltoid"] = "deltoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18177"] = "EMAPA_18177"


class _Latissimus_Dorsi(_MouseAnatomicalStructureModel):
    """Model latissimus dorsi"""

    name: Literal["latissimus dorsi"] = "latissimus dorsi"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18178"] = "EMAPA_18178"


class _Pectoralis_Major(_MouseAnatomicalStructureModel):
    """Model pectoralis major"""

    name: Literal["pectoralis major"] = "pectoralis major"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18179"] = "EMAPA_18179"


class _Pectoralis_Minor(_MouseAnatomicalStructureModel):
    """Model pectoralis minor"""

    name: Literal["pectoralis minor"] = "pectoralis minor"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18180"] = "EMAPA_18180"


class _Subscapularis(_MouseAnatomicalStructureModel):
    """Model subscapularis"""

    name: Literal["subscapularis"] = "subscapularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18181"] = "EMAPA_18181"


class _Supraspinatus(_MouseAnatomicalStructureModel):
    """Model supraspinatus"""

    name: Literal["supraspinatus"] = "supraspinatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18182"] = "EMAPA_18182"


class _Trapezius(_MouseAnatomicalStructureModel):
    """Model trapezius"""

    name: Literal["trapezius"] = "trapezius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18183"] = "EMAPA_18183"


class _Pelvic_Girdle_Musculature(_MouseAnatomicalStructureModel):
    """Model pelvic girdle musculature"""

    name: Literal["pelvic girdle musculature"] = "pelvic girdle musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18184"] = "EMAPA_18184"


class _Pelvic_Girdle_Muscle(_MouseAnatomicalStructureModel):
    """Model pelvic girdle muscle"""

    name: Literal["pelvic girdle muscle"] = "pelvic girdle muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18185"] = "EMAPA_18185"


class _Gluteal_Muscle(_MouseAnatomicalStructureModel):
    """Model gluteal muscle"""

    name: Literal["gluteal muscle"] = "gluteal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18186"] = "EMAPA_18186"


class _Integumental_System_Muscle(_MouseAnatomicalStructureModel):
    """Model integumental system muscle"""

    name: Literal["integumental system muscle"] = "integumental system muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18187"] = "EMAPA_18187"


class _Integumental_System_Superficial_Muscle(_MouseAnatomicalStructureModel):
    """Model integumental system superficial muscle"""

    name: Literal["integumental system superficial muscle"] = "integumental system superficial muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18188"] = "EMAPA_18188"


class _Panniculus_Carnosus_Group(_MouseAnatomicalStructureModel):
    """Model panniculus carnosus group"""

    name: Literal["panniculus carnosus group"] = "panniculus carnosus group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18189"] = "EMAPA_18189"


class _Platysma(_MouseAnatomicalStructureModel):
    """Model platysma"""

    name: Literal["platysma"] = "platysma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18190"] = "EMAPA_18190"


class _Thyroid_Gland_Isthmus(_MouseAnatomicalStructureModel):
    """Model thyroid gland isthmus"""

    name: Literal["thyroid gland isthmus"] = "thyroid gland isthmus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18195"] = "EMAPA_18195"


class _Thyroid_Gland_Lobe(_MouseAnatomicalStructureModel):
    """Model thyroid gland lobe"""

    name: Literal["thyroid gland lobe"] = "thyroid gland lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18196"] = "EMAPA_18196"


class _Thyroid_Gland_Left_Lobe(_MouseAnatomicalStructureModel):
    """Model thyroid gland left lobe"""

    name: Literal["thyroid gland left lobe"] = "thyroid gland left lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18197"] = "EMAPA_18197"


class _Thyroid_Gland_Right_Lobe(_MouseAnatomicalStructureModel):
    """Model thyroid gland right lobe"""

    name: Literal["thyroid gland right lobe"] = "thyroid gland right lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18198"] = "EMAPA_18198"


class _Diencephalon_Internal_Capsule(_MouseAnatomicalStructureModel):
    """Model diencephalon internal capsule"""

    name: Literal["diencephalon internal capsule"] = "diencephalon internal capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18206"] = "EMAPA_18206"


class _Caudate_Nucleus(_MouseAnatomicalStructureModel):
    """Model caudate nucleus"""

    name: Literal["caudate nucleus"] = "caudate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18207"] = "EMAPA_18207"


class _Lentiform_Nucleus(_MouseAnatomicalStructureModel):
    """Model lentiform nucleus"""

    name: Literal["lentiform nucleus"] = "lentiform nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18208"] = "EMAPA_18208"


class _Tentorium_Cerebelli(_MouseAnatomicalStructureModel):
    """Model tentorium cerebelli"""

    name: Literal["tentorium cerebelli"] = "tentorium cerebelli"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18210"] = "EMAPA_18210"


class _Hindbrain_Subarachnoid_Space(_MouseAnatomicalStructureModel):
    """Model hindbrain subarachnoid space"""

    name: Literal["hindbrain subarachnoid space"] = "hindbrain subarachnoid space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18211"] = "EMAPA_18211"


class _Pontine_Cistern(_MouseAnatomicalStructureModel):
    """Model pontine cistern"""

    name: Literal["pontine cistern"] = "pontine cistern"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18212"] = "EMAPA_18212"


class _Midbrain_Tegmentum(_MouseAnatomicalStructureModel):
    """Model midbrain tegmentum"""

    name: Literal["midbrain tegmentum"] = "midbrain tegmentum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18215"] = "EMAPA_18215"


class _Abducens_Nerve(_MouseAnatomicalStructureModel):
    """Model abducens nerve"""

    name: Literal["abducens nerve"] = "abducens nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18216"] = "EMAPA_18216"


class _Facial_Nerve_Chorda_Tympani_Branch(_MouseAnatomicalStructureModel):
    """Model facial nerve chorda tympani branch"""

    name: Literal["facial nerve chorda tympani branch"] = "facial nerve chorda tympani branch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18217"] = "EMAPA_18217"


class _Trochlear_Nerve(_MouseAnatomicalStructureModel):
    """Model trochlear nerve"""

    name: Literal["trochlear nerve"] = "trochlear nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18218"] = "EMAPA_18218"


class _Conus_Medullaris(_MouseAnatomicalStructureModel):
    """Model conus medullaris"""

    name: Literal["conus medullaris"] = "conus medullaris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18219"] = "EMAPA_18219"


class _Filum_Terminale(_MouseAnatomicalStructureModel):
    """Model filum terminale"""

    name: Literal["filum terminale"] = "filum terminale"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18220"] = "EMAPA_18220"


class _Autonomic_Ganglion(_MouseAnatomicalStructureModel):
    """Model autonomic ganglion"""

    name: Literal["autonomic ganglion"] = "autonomic ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18221"] = "EMAPA_18221"


class _Ciliary_Ganglion(_MouseAnatomicalStructureModel):
    """Model ciliary ganglion"""

    name: Literal["ciliary ganglion"] = "ciliary ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18222"] = "EMAPA_18222"


class _Paraganglion_Of_Zuckerkandl(_MouseAnatomicalStructureModel):
    """Model paraganglion of Zuckerkandl"""

    name: Literal["paraganglion of Zuckerkandl"] = "paraganglion of Zuckerkandl"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18223"] = "EMAPA_18223"


class _Autonomic_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model autonomic nerve plexus"""

    name: Literal["autonomic nerve plexus"] = "autonomic nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18224"] = "EMAPA_18224"


class _Hypogastric_Plexus(_MouseAnatomicalStructureModel):
    """Model hypogastric plexus"""

    name: Literal["hypogastric plexus"] = "hypogastric plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18225"] = "EMAPA_18225"


class _Cervico_Thoracic_Ganglion(_MouseAnatomicalStructureModel):
    """Model cervico-thoracic ganglion"""

    name: Literal["cervico-thoracic ganglion"] = "cervico-thoracic ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18226"] = "EMAPA_18226"


class _Intercostal_Nerve(_MouseAnatomicalStructureModel):
    """Model intercostal nerve"""

    name: Literal["intercostal nerve"] = "intercostal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18227"] = "EMAPA_18227"


class _Incus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model incus cartilage condensation"""

    name: Literal["incus cartilage condensation"] = "incus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18228"] = "EMAPA_18228"


class _Malleus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model malleus cartilage condensation"""

    name: Literal["malleus cartilage condensation"] = "malleus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18229"] = "EMAPA_18229"


class _Stapes_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model stapes cartilage condensation"""

    name: Literal["stapes cartilage condensation"] = "stapes cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18230"] = "EMAPA_18230"


class _Eye_Anterior_Chamber(_MouseAnatomicalStructureModel):
    """Model eye anterior chamber"""

    name: Literal["eye anterior chamber"] = "eye anterior chamber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18231"] = "EMAPA_18231"


class _Aqueous_Humour(_MouseAnatomicalStructureModel):
    """Model aqueous humour"""

    name: Literal["aqueous humour"] = "aqueous humour"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18232"] = "EMAPA_18232"


class _Conjunctival_Sac(_MouseAnatomicalStructureModel):
    """Model conjunctival sac"""

    name: Literal["conjunctival sac"] = "conjunctival sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18233"] = "EMAPA_18233"


class _Extrinsic_Ocular_Muscle(_MouseAnatomicalStructureModel):
    """Model extrinsic ocular muscle"""

    name: Literal["extrinsic ocular muscle"] = "extrinsic ocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18234"] = "EMAPA_18234"


class _Tunica_Vasculosa_Lentis(_MouseAnatomicalStructureModel):
    """Model tunica vasculosa lentis"""

    name: Literal["tunica vasculosa lentis"] = "tunica vasculosa lentis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18235"] = "EMAPA_18235"


class _Vasa_Hyaloidea_Propria(_MouseAnatomicalStructureModel):
    """Model vasa hyaloidea propria"""

    name: Literal["vasa hyaloidea propria"] = "vasa hyaloidea propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18236"] = "EMAPA_18236"


class _Lens_Capsule(_MouseAnatomicalStructureModel):
    """Model lens capsule"""

    name: Literal["lens capsule"] = "lens capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18237"] = "EMAPA_18237"


class _Optic_Disc(_MouseAnatomicalStructureModel):
    """Model optic disc"""

    name: Literal["optic disc"] = "optic disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18238"] = "EMAPA_18238"


class _Middle_Cerebral_Artery(_MouseAnatomicalStructureModel):
    """Model middle cerebral artery"""

    name: Literal["middle cerebral artery"] = "middle cerebral artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18239"] = "EMAPA_18239"


class _Spinal_Artery(_MouseAnatomicalStructureModel):
    """Model spinal artery"""

    name: Literal["spinal artery"] = "spinal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18241"] = "EMAPA_18241"


class _Anterior_Spinal_Artery(_MouseAnatomicalStructureModel):
    """Model anterior spinal artery"""

    name: Literal["anterior spinal artery"] = "anterior spinal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18242"] = "EMAPA_18242"


class _Posterior_Spinal_Artery(_MouseAnatomicalStructureModel):
    """Model posterior spinal artery"""

    name: Literal["posterior spinal artery"] = "posterior spinal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18243"] = "EMAPA_18243"


class _Foramen_Ovale_Of_Interatrial_Septum(_MouseAnatomicalStructureModel):
    """Model foramen ovale of interatrial septum"""

    name: Literal["foramen ovale of interatrial septum"] = "foramen ovale of interatrial septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18244"] = "EMAPA_18244"


class _Interventricular_Septum_Membranous_Part(_MouseAnatomicalStructureModel):
    """Model interventricular septum membranous part"""

    name: Literal["interventricular septum membranous part"] = "interventricular septum membranous part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18246"] = "EMAPA_18246"


class _Interventricular_Septum_Muscular_Part(_MouseAnatomicalStructureModel):
    """Model interventricular septum muscular part"""

    name: Literal["interventricular septum muscular part"] = "interventricular septum muscular part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18247"] = "EMAPA_18247"


class _Lymphatic_System(_MouseAnatomicalStructureModel):
    """Model lymphatic system"""

    name: Literal["lymphatic system"] = "lymphatic system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18248"] = "EMAPA_18248"


class _Jugular_Lymph_Sac(_MouseAnatomicalStructureModel):
    """Model jugular lymph sac"""

    name: Literal["jugular lymph sac"] = "jugular lymph sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18249"] = "EMAPA_18249"


class _Azygos_Vein(_MouseAnatomicalStructureModel):
    """Model azygos vein"""

    name: Literal["azygos vein"] = "azygos vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18250"] = "EMAPA_18250"


class _Hemiazygos_Vein(_MouseAnatomicalStructureModel):
    """Model hemiazygos vein"""

    name: Literal["hemiazygos vein"] = "hemiazygos vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18251"] = "EMAPA_18251"


class _Hepatico_Cardiac_Vein(_MouseAnatomicalStructureModel):
    """Model hepatico-cardiac vein"""

    name: Literal["hepatico-cardiac vein"] = "hepatico-cardiac vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18252"] = "EMAPA_18252"


class _Left_Hepatico_Cardiac_Vein(_MouseAnatomicalStructureModel):
    """Model left hepatico-cardiac vein"""

    name: Literal["left hepatico-cardiac vein"] = "left hepatico-cardiac vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18253"] = "EMAPA_18253"


class _Right_Hepatico_Cardiac_Vein(_MouseAnatomicalStructureModel):
    """Model right hepatico-cardiac vein"""

    name: Literal["right hepatico-cardiac vein"] = "right hepatico-cardiac vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18254"] = "EMAPA_18254"


class _Spinal_Vein(_MouseAnatomicalStructureModel):
    """Model spinal vein"""

    name: Literal["spinal vein"] = "spinal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18255"] = "EMAPA_18255"


class _Anal_Canal(_MouseAnatomicalStructureModel):
    """Model anal canal"""

    name: Literal["anal canal"] = "anal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18256"] = "EMAPA_18256"


class _Anal_Canal_Rostral_Part(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part"""

    name: Literal["anal canal rostral part"] = "anal canal rostral part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18257"] = "EMAPA_18257"


class _Anal_Canal_Rostral_Part_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part mesenchyme"""

    name: Literal["anal canal rostral part mesenchyme"] = "anal canal rostral part mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18258"] = "EMAPA_18258"


class _Anal_Canal_Rostral_Part_Epithelium(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part epithelium"""

    name: Literal["anal canal rostral part epithelium"] = "anal canal rostral part epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18259"] = "EMAPA_18259"


class _Anal_Canal_Rostral_Part_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part vascular element"""

    name: Literal["anal canal rostral part vascular element"] = "anal canal rostral part vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18260"] = "EMAPA_18260"


class _Anal_Canal_Caudal_Part(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part"""

    name: Literal["anal canal caudal part"] = "anal canal caudal part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18261"] = "EMAPA_18261"


class _Anal_Canal_Caudal_Part_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part mesenchyme"""

    name: Literal["anal canal caudal part mesenchyme"] = "anal canal caudal part mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18262"] = "EMAPA_18262"


class _Anal_Canal_Caudal_Part_Epithelium(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part epithelium"""

    name: Literal["anal canal caudal part epithelium"] = "anal canal caudal part epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18263"] = "EMAPA_18263"


class _Anal_Canal_Caudal_Part_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part vascular element"""

    name: Literal["anal canal caudal part vascular element"] = "anal canal caudal part vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18264"] = "EMAPA_18264"


class _External_Anal_Sphincter(_MouseAnatomicalStructureModel):
    """Model external anal sphincter"""

    name: Literal["external anal sphincter"] = "external anal sphincter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18265"] = "EMAPA_18265"


class _Internal_Anal_Sphincter(_MouseAnatomicalStructureModel):
    """Model internal anal sphincter"""

    name: Literal["internal anal sphincter"] = "internal anal sphincter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18266"] = "EMAPA_18266"


class _Gastro_Esophageal_Junction(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction"""

    name: Literal["gastro-esophageal junction"] = "gastro-esophageal junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18267"] = "EMAPA_18267"


class _Gastro_Esophageal_Junction_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction mesenchyme"""

    name: Literal["gastro-esophageal junction mesenchyme"] = "gastro-esophageal junction mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18268"] = "EMAPA_18268"


class _Gastro_Esophageal_Junction_Epithelium(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction epithelium"""

    name: Literal["gastro-esophageal junction epithelium"] = "gastro-esophageal junction epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18269"] = "EMAPA_18269"


class _Gastro_Esophageal_Junction_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction vascular element"""

    name: Literal["gastro-esophageal junction vascular element"] = "gastro-esophageal junction vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18270"] = "EMAPA_18270"


class _Circumvallate_Papillae(_MouseAnatomicalStructureModel):
    """Model circumvallate papillae"""

    name: Literal["circumvallate papillae"] = "circumvallate papillae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18271"] = "EMAPA_18271"


class _Fungiform_Papillae(_MouseAnatomicalStructureModel):
    """Model fungiform papillae"""

    name: Literal["fungiform papillae"] = "fungiform papillae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18272"] = "EMAPA_18272"


class _Intermolar_Eminence(_MouseAnatomicalStructureModel):
    """Model intermolar eminence"""

    name: Literal["intermolar eminence"] = "intermolar eminence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18273"] = "EMAPA_18273"


class _Median_Fibrous_Septum(_MouseAnatomicalStructureModel):
    """Model median fibrous septum"""

    name: Literal["median fibrous septum"] = "median fibrous septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18274"] = "EMAPA_18274"


class _Tongue_Extrinsic_Muscle(_MouseAnatomicalStructureModel):
    """Model tongue extrinsic muscle"""

    name: Literal["tongue extrinsic muscle"] = "tongue extrinsic muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18275"] = "EMAPA_18275"


class _Genioglossus(_MouseAnatomicalStructureModel):
    """Model genioglossus"""

    name: Literal["genioglossus"] = "genioglossus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18276"] = "EMAPA_18276"


class _Hyoglossus(_MouseAnatomicalStructureModel):
    """Model hyoglossus"""

    name: Literal["hyoglossus"] = "hyoglossus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18277"] = "EMAPA_18277"


class _Palatoglossus(_MouseAnatomicalStructureModel):
    """Model palatoglossus"""

    name: Literal["palatoglossus"] = "palatoglossus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18278"] = "EMAPA_18278"


class _Styloglossus(_MouseAnatomicalStructureModel):
    """Model styloglossus"""

    name: Literal["styloglossus"] = "styloglossus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18279"] = "EMAPA_18279"


class _Tongue_Intrinsic_Muscle(_MouseAnatomicalStructureModel):
    """Model tongue intrinsic muscle"""

    name: Literal["tongue intrinsic muscle"] = "tongue intrinsic muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18280"] = "EMAPA_18280"


class _Tongue_Intrinsic_Muscle_Transverse_Component(_MouseAnatomicalStructureModel):
    """Model tongue intrinsic muscle transverse component"""

    name: Literal["tongue intrinsic muscle transverse component"] = "tongue intrinsic muscle transverse component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18281"] = "EMAPA_18281"


class _Tongue_Intrinsic_Muscle_Vertical_Component(_MouseAnatomicalStructureModel):
    """Model tongue intrinsic muscle vertical component"""

    name: Literal["tongue intrinsic muscle vertical component"] = "tongue intrinsic muscle vertical component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18282"] = "EMAPA_18282"


class _Stomach_Fundus_Glandular_Mucous_Membrane(_MouseAnatomicalStructureModel):
    """Model stomach fundus glandular mucous membrane"""

    name: Literal["stomach fundus glandular mucous membrane"] = "stomach fundus glandular mucous membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18284"] = "EMAPA_18284"


class _Gastro_Splenic_Ligament(_MouseAnatomicalStructureModel):
    """Model gastro-splenic ligament"""

    name: Literal["gastro-splenic ligament"] = "gastro-splenic ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18285"] = "EMAPA_18285"


class _Lieno_Renal_Ligament(_MouseAnatomicalStructureModel):
    """Model lieno-renal ligament"""

    name: Literal["lieno-renal ligament"] = "lieno-renal ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18286"] = "EMAPA_18286"


class _Falciform_Ligament(_MouseAnatomicalStructureModel):
    """Model falciform ligament"""

    name: Literal["falciform ligament"] = "falciform ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18288"] = "EMAPA_18288"


class _Epiglottis(_MouseAnatomicalStructureModel):
    """Model epiglottis"""

    name: Literal["epiglottis"] = "epiglottis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18289"] = "EMAPA_18289"


class _Mandible(_MouseAnatomicalStructureModel):
    """Model mandible"""

    name: Literal["mandible"] = "mandible"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18290"] = "EMAPA_18290"


class _Lower_Jaw_Alveolar_Sulcus(_MouseAnatomicalStructureModel):
    """Model lower jaw alveolar sulcus"""

    name: Literal["lower jaw alveolar sulcus"] = "lower jaw alveolar sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18291"] = "EMAPA_18291"


class _Lower_Jaw_Incisor_Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model lower jaw incisor dental lamina"""

    name: Literal["lower jaw incisor dental lamina"] = "lower jaw incisor dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18292"] = "EMAPA_18292"


class _Lower_Jaw_Incisor_Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model lower jaw incisor enamel organ"""

    name: Literal["lower jaw incisor enamel organ"] = "lower jaw incisor enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18293"] = "EMAPA_18293"


class _Lower_Jaw_Incisor_Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model lower jaw incisor dental papilla"""

    name: Literal["lower jaw incisor dental papilla"] = "lower jaw incisor dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18294"] = "EMAPA_18294"


class _Lower_Jaw_Molar_Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model lower jaw molar dental lamina"""

    name: Literal["lower jaw molar dental lamina"] = "lower jaw molar dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18295"] = "EMAPA_18295"


class _Lower_Jaw_Molar_Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model lower jaw molar enamel organ"""

    name: Literal["lower jaw molar enamel organ"] = "lower jaw molar enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18296"] = "EMAPA_18296"


class _Lower_Jaw_Molar_Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model lower jaw molar dental papilla"""

    name: Literal["lower jaw molar dental papilla"] = "lower jaw molar dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18297"] = "EMAPA_18297"


class _Upper_Jaw_Incisor_Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model upper jaw incisor dental lamina"""

    name: Literal["upper jaw incisor dental lamina"] = "upper jaw incisor dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18298"] = "EMAPA_18298"


class _Upper_Jaw_Incisor_Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model upper jaw incisor enamel organ"""

    name: Literal["upper jaw incisor enamel organ"] = "upper jaw incisor enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18299"] = "EMAPA_18299"


class _Upper_Jaw_Incisor_Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model upper jaw incisor dental papilla"""

    name: Literal["upper jaw incisor dental papilla"] = "upper jaw incisor dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18300"] = "EMAPA_18300"


class _Upper_Jaw_Molar_Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model upper jaw molar dental lamina"""

    name: Literal["upper jaw molar dental lamina"] = "upper jaw molar dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18301"] = "EMAPA_18301"


class _Upper_Jaw_Molar_Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model upper jaw molar enamel organ"""

    name: Literal["upper jaw molar enamel organ"] = "upper jaw molar enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18302"] = "EMAPA_18302"


class _Upper_Jaw_Molar_Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model upper jaw molar dental papilla"""

    name: Literal["upper jaw molar dental papilla"] = "upper jaw molar dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18303"] = "EMAPA_18303"


class _Left_Hepatic_Duct_Intrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model left hepatic duct intrahepatic part"""

    name: Literal["left hepatic duct intrahepatic part"] = "left hepatic duct intrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18304"] = "EMAPA_18304"


class _Right_Hepatic_Duct_Intrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model right hepatic duct intrahepatic part"""

    name: Literal["right hepatic duct intrahepatic part"] = "right hepatic duct intrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18305"] = "EMAPA_18305"


class _Liver_Lobe(_MouseAnatomicalStructureModel):
    """Model liver lobe"""

    name: Literal["liver lobe"] = "liver lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18306"] = "EMAPA_18306"


class _Liver_Left_Lobe(_MouseAnatomicalStructureModel):
    """Model liver left lobe"""

    name: Literal["liver left lobe"] = "liver left lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18307"] = "EMAPA_18307"


class _Liver_Left_Lobe_Bare_Area(_MouseAnatomicalStructureModel):
    """Model liver left lobe bare area"""

    name: Literal["liver left lobe bare area"] = "liver left lobe bare area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18308"] = "EMAPA_18308"


class _Liver_Left_Lobe_Hepatic_Sinusoid(_MouseAnatomicalStructureModel):
    """Model liver left lobe hepatic sinusoid"""

    name: Literal["liver left lobe hepatic sinusoid"] = "liver left lobe hepatic sinusoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18309"] = "EMAPA_18309"


class _Liver_Left_Lobe_Parenchyma(_MouseAnatomicalStructureModel):
    """Model liver left lobe parenchyma"""

    name: Literal["liver left lobe parenchyma"] = "liver left lobe parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18310"] = "EMAPA_18310"


class _Liver_Right_Lobe(_MouseAnatomicalStructureModel):
    """Model liver right lobe"""

    name: Literal["liver right lobe"] = "liver right lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18311"] = "EMAPA_18311"


class _Liver_Right_Lobe_Bare_Area(_MouseAnatomicalStructureModel):
    """Model liver right lobe bare area"""

    name: Literal["liver right lobe bare area"] = "liver right lobe bare area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18312"] = "EMAPA_18312"


class _Liver_Caudate_Lobe(_MouseAnatomicalStructureModel):
    """Model liver caudate lobe"""

    name: Literal["liver caudate lobe"] = "liver caudate lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18313"] = "EMAPA_18313"


class _Liver_Caudate_Lobe_Hepatic_Sinusoid(_MouseAnatomicalStructureModel):
    """Model liver caudate lobe hepatic sinusoid"""

    name: Literal["liver caudate lobe hepatic sinusoid"] = "liver caudate lobe hepatic sinusoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18314"] = "EMAPA_18314"


class _Liver_Caudate_Lobe_Parenchyma(_MouseAnatomicalStructureModel):
    """Model liver caudate lobe parenchyma"""

    name: Literal["liver caudate lobe parenchyma"] = "liver caudate lobe parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18315"] = "EMAPA_18315"


class _Liver_Right_Lobe_Hepatic_Sinusoid(_MouseAnatomicalStructureModel):
    """Model liver right lobe hepatic sinusoid"""

    name: Literal["liver right lobe hepatic sinusoid"] = "liver right lobe hepatic sinusoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18316"] = "EMAPA_18316"


class _Liver_Right_Lobe_Parenchyma(_MouseAnatomicalStructureModel):
    """Model liver right lobe parenchyma"""

    name: Literal["liver right lobe parenchyma"] = "liver right lobe parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18317"] = "EMAPA_18317"


class _Liver_Quadrate_Lobe(_MouseAnatomicalStructureModel):
    """Model liver quadrate lobe"""

    name: Literal["liver quadrate lobe"] = "liver quadrate lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18318"] = "EMAPA_18318"


class _Liver_Quadrate_Lobe_Hepatic_Sinusoid(_MouseAnatomicalStructureModel):
    """Model liver quadrate lobe hepatic sinusoid"""

    name: Literal["liver quadrate lobe hepatic sinusoid"] = "liver quadrate lobe hepatic sinusoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18319"] = "EMAPA_18319"


class _Liver_Quadrate_Lobe_Parenchyma(_MouseAnatomicalStructureModel):
    """Model liver quadrate lobe parenchyma"""

    name: Literal["liver quadrate lobe parenchyma"] = "liver quadrate lobe parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18320"] = "EMAPA_18320"


class _Bladder(_MouseAnatomicalStructureModel):
    """Model bladder"""

    name: Literal["bladder"] = "bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18321"] = "EMAPA_18321"


class _Urachus(_MouseAnatomicalStructureModel):
    """Model urachus"""

    name: Literal["urachus"] = "urachus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18323"] = "EMAPA_18323"


class _Renal_Medullary_Interstitium(_MouseAnatomicalStructureModel):
    """Model renal medullary interstitium"""

    name: Literal["renal medullary interstitium"] = "renal medullary interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18326"] = "EMAPA_18326"


class _Mullerian_Tubercle(_MouseAnatomicalStructureModel):
    """Model Mullerian tubercle"""

    name: Literal["Mullerian tubercle"] = "Mullerian tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18328"] = "EMAPA_18328"


class _Labial_Fold(_MouseAnatomicalStructureModel):
    """Model labial fold"""

    name: Literal["labial fold"] = "labial fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18329"] = "EMAPA_18329"


class _Mediastinum_Testis(_MouseAnatomicalStructureModel):
    """Model mediastinum testis"""

    name: Literal["mediastinum testis"] = "mediastinum testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18331"] = "EMAPA_18331"


class _Rete_Testis(_MouseAnatomicalStructureModel):
    """Model rete testis"""

    name: Literal["rete testis"] = "rete testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18332"] = "EMAPA_18332"


class _Larynx(_MouseAnatomicalStructureModel):
    """Model larynx"""

    name: Literal["larynx"] = "larynx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18333"] = "EMAPA_18333"


class _Larynx_Mucous_Membrane(_MouseAnatomicalStructureModel):
    """Model larynx mucous membrane"""

    name: Literal["larynx mucous membrane"] = "larynx mucous membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18334"] = "EMAPA_18334"


class _Sacral_Vertebra(_MouseAnatomicalStructureModel):
    """Model sacral vertebra"""

    name: Literal["sacral vertebra"] = "sacral vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18336"] = "EMAPA_18336"


class _Basioccipital_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model basioccipital cartilage condensation"""

    name: Literal["basioccipital cartilage condensation"] = "basioccipital cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18337"] = "EMAPA_18337"


class _Basisphenoid_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model basisphenoid cartilage condensation"""

    name: Literal["basisphenoid cartilage condensation"] = "basisphenoid cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18338"] = "EMAPA_18338"


class _Exoccipital_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model exoccipital cartilage condensation"""

    name: Literal["exoccipital cartilage condensation"] = "exoccipital cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18339"] = "EMAPA_18339"


class _Sphenoid_Bone(_MouseAnatomicalStructureModel):
    """Model sphenoid bone"""

    name: Literal["sphenoid bone"] = "sphenoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18340"] = "EMAPA_18340"


class _Supraoccipital_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model supraoccipital cartilage condensation"""

    name: Literal["supraoccipital cartilage condensation"] = "supraoccipital cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18341"] = "EMAPA_18341"


class _Clavicle_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model clavicle cartilage condensation"""

    name: Literal["clavicle cartilage condensation"] = "clavicle cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18342"] = "EMAPA_18342"


class _Scapula_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model scapula cartilage condensation"""

    name: Literal["scapula cartilage condensation"] = "scapula cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18343"] = "EMAPA_18343"


class _Sternum(_MouseAnatomicalStructureModel):
    """Model sternum"""

    name: Literal["sternum"] = "sternum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18344"] = "EMAPA_18344"


class _Sternebra_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model sternebra pre-cartilage condensation"""

    name: Literal["sternebra pre-cartilage condensation"] = "sternebra pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18345"] = "EMAPA_18345"


class _Acetabular_Region(_MouseAnatomicalStructureModel):
    """Model acetabular region"""

    name: Literal["acetabular region"] = "acetabular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18346"] = "EMAPA_18346"


class _Ilium_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model ilium cartilage condensation"""

    name: Literal["ilium cartilage condensation"] = "ilium cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18347"] = "EMAPA_18347"


class _Ischium_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model ischium pre-cartilage condensation"""

    name: Literal["ischium pre-cartilage condensation"] = "ischium pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18348"] = "EMAPA_18348"


class _Pubis_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model pubis pre-cartilage condensation"""

    name: Literal["pubis pre-cartilage condensation"] = "pubis pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18349"] = "EMAPA_18349"


class _Somite_56(_MouseAnatomicalStructureModel):
    """Model somite 56"""

    name: Literal["somite 56"] = "somite 56"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18350"] = "EMAPA_18350"


class _Somite_56_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 56 dermomyotome"""

    name: Literal["somite 56 dermomyotome"] = "somite 56 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18351"] = "EMAPA_18351"


class _Somite_56_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 56 myocoele"""

    name: Literal["somite 56 myocoele"] = "somite 56 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18352"] = "EMAPA_18352"


class _Somite_56_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 56 sclerotome"""

    name: Literal["somite 56 sclerotome"] = "somite 56 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18353"] = "EMAPA_18353"


class _Somite_57(_MouseAnatomicalStructureModel):
    """Model somite 57"""

    name: Literal["somite 57"] = "somite 57"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18354"] = "EMAPA_18354"


class _Somite_57_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 57 dermomyotome"""

    name: Literal["somite 57 dermomyotome"] = "somite 57 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18355"] = "EMAPA_18355"


class _Somite_57_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 57 myocoele"""

    name: Literal["somite 57 myocoele"] = "somite 57 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18356"] = "EMAPA_18356"


class _Somite_57_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 57 sclerotome"""

    name: Literal["somite 57 sclerotome"] = "somite 57 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18357"] = "EMAPA_18357"


class _Somite_58(_MouseAnatomicalStructureModel):
    """Model somite 58"""

    name: Literal["somite 58"] = "somite 58"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18358"] = "EMAPA_18358"


class _Somite_58_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 58 dermomyotome"""

    name: Literal["somite 58 dermomyotome"] = "somite 58 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18359"] = "EMAPA_18359"


class _Somite_58_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 58 myocoele"""

    name: Literal["somite 58 myocoele"] = "somite 58 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18360"] = "EMAPA_18360"


class _Somite_58_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 58 sclerotome"""

    name: Literal["somite 58 sclerotome"] = "somite 58 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18361"] = "EMAPA_18361"


class _Somite_59(_MouseAnatomicalStructureModel):
    """Model somite 59"""

    name: Literal["somite 59"] = "somite 59"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18362"] = "EMAPA_18362"


class _Somite_59_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 59 dermomyotome"""

    name: Literal["somite 59 dermomyotome"] = "somite 59 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18363"] = "EMAPA_18363"


class _Somite_59_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 59 myocoele"""

    name: Literal["somite 59 myocoele"] = "somite 59 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18364"] = "EMAPA_18364"


class _Somite_59_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 59 sclerotome"""

    name: Literal["somite 59 sclerotome"] = "somite 59 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18365"] = "EMAPA_18365"


class _Somite_60(_MouseAnatomicalStructureModel):
    """Model somite 60"""

    name: Literal["somite 60"] = "somite 60"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18366"] = "EMAPA_18366"


class _Somite_60_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model somite 60 dermomyotome"""

    name: Literal["somite 60 dermomyotome"] = "somite 60 dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18367"] = "EMAPA_18367"


class _Somite_60_Myocoele(_MouseAnatomicalStructureModel):
    """Model somite 60 myocoele"""

    name: Literal["somite 60 myocoele"] = "somite 60 myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18368"] = "EMAPA_18368"


class _Somite_60_Sclerotome(_MouseAnatomicalStructureModel):
    """Model somite 60 sclerotome"""

    name: Literal["somite 60 sclerotome"] = "somite 60 sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18369"] = "EMAPA_18369"


class _Tail_Peripheral_Nervous_System(_MouseAnatomicalStructureModel):
    """Model tail peripheral nervous system"""

    name: Literal["tail peripheral nervous system"] = "tail peripheral nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18370"] = "EMAPA_18370"


class _Tail_Ganglion(_MouseAnatomicalStructureModel):
    """Model tail ganglion"""

    name: Literal["tail ganglion"] = "tail ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18371"] = "EMAPA_18371"


class _Tail_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model tail dorsal root ganglion"""

    name: Literal["tail dorsal root ganglion"] = "tail dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18372"] = "EMAPA_18372"


class _Tail_Vertebra(_MouseAnatomicalStructureModel):
    """Model tail vertebra"""

    name: Literal["tail vertebra"] = "tail vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18374"] = "EMAPA_18374"


class _Foregut_Diverticulum_Lumen(_MouseAnatomicalStructureModel):
    """Model foregut diverticulum lumen"""

    name: Literal["foregut diverticulum lumen"] = "foregut diverticulum lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18375"] = "EMAPA_18375"


class _Hindgut_Diverticulum_Lumen(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum lumen"""

    name: Literal["hindgut diverticulum lumen"] = "hindgut diverticulum lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18376"] = "EMAPA_18376"


class _Midgut_Lumen(_MouseAnatomicalStructureModel):
    """Model midgut lumen"""

    name: Literal["midgut lumen"] = "midgut lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18377"] = "EMAPA_18377"


class _Duodenum_Rostral_Part_Lumen(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part lumen"""

    name: Literal["duodenum rostral part lumen"] = "duodenum rostral part lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18378"] = "EMAPA_18378"


class _Gastro_Esophageal_Junction_Lumen(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction lumen"""

    name: Literal["gastro-esophageal junction lumen"] = "gastro-esophageal junction lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18379"] = "EMAPA_18379"


class _Esophagus_Lumen(_MouseAnatomicalStructureModel):
    """Model esophagus lumen"""

    name: Literal["esophagus lumen"] = "esophagus lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18380"] = "EMAPA_18380"


class _Pharynx_Lumen(_MouseAnatomicalStructureModel):
    """Model pharynx lumen"""

    name: Literal["pharynx lumen"] = "pharynx lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18381"] = "EMAPA_18381"


class _Stomach_Fundus_Lumen(_MouseAnatomicalStructureModel):
    """Model stomach fundus lumen"""

    name: Literal["stomach fundus lumen"] = "stomach fundus lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18382"] = "EMAPA_18382"


class _Stomach_Glandular_Region_Lumen(_MouseAnatomicalStructureModel):
    """Model stomach glandular region lumen"""

    name: Literal["stomach glandular region lumen"] = "stomach glandular region lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18383"] = "EMAPA_18383"


class _Stomach_Proventricular_Region_Lumen(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region lumen"""

    name: Literal["stomach proventricular region lumen"] = "stomach proventricular region lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18384"] = "EMAPA_18384"


class _Stomach_Pyloric_Region_Lumen(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region lumen"""

    name: Literal["stomach pyloric region lumen"] = "stomach pyloric region lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18385"] = "EMAPA_18385"


class _Foregut_Midgut_Junction_Lumen(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction lumen"""

    name: Literal["foregut-midgut junction lumen"] = "foregut-midgut junction lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18386"] = "EMAPA_18386"


class _Perineal_Body_Lumen(_MouseAnatomicalStructureModel):
    """Model perineal body lumen"""

    name: Literal["perineal body lumen"] = "perineal body lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18387"] = "EMAPA_18387"


class _Rectum_Lumen(_MouseAnatomicalStructureModel):
    """Model rectum lumen"""

    name: Literal["rectum lumen"] = "rectum lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18388"] = "EMAPA_18388"


class _Duodenum_Caudal_Part_Lumen(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part lumen"""

    name: Literal["duodenum caudal part lumen"] = "duodenum caudal part lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18390"] = "EMAPA_18390"


class _Midgut_Loop_Lumen(_MouseAnatomicalStructureModel):
    """Model midgut loop lumen"""

    name: Literal["midgut loop lumen"] = "midgut loop lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18391"] = "EMAPA_18391"


class _Anal_Canal_Caudal_Part_Lumen(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part lumen"""

    name: Literal["anal canal caudal part lumen"] = "anal canal caudal part lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18393"] = "EMAPA_18393"


class _Anal_Canal_Rostral_Part_Lumen(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part lumen"""

    name: Literal["anal canal rostral part lumen"] = "anal canal rostral part lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18394"] = "EMAPA_18394"


class _Stomach_Lumen(_MouseAnatomicalStructureModel):
    """Model stomach lumen"""

    name: Literal["stomach lumen"] = "stomach lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18395"] = "EMAPA_18395"


class _Hindgut_Lumen(_MouseAnatomicalStructureModel):
    """Model hindgut lumen"""

    name: Literal["hindgut lumen"] = "hindgut lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18396"] = "EMAPA_18396"


class _Hindgut_Diverticulum_Postanal_Component_Lumen(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum postanal component lumen"""

    name: Literal["hindgut diverticulum postanal component lumen"] = "hindgut diverticulum postanal component lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18397"] = "EMAPA_18397"


class _Hindgut_Diverticulum_Preanal_Component_Lumen(_MouseAnatomicalStructureModel):
    """Model hindgut diverticulum preanal component lumen"""

    name: Literal["hindgut diverticulum preanal component lumen"] = "hindgut diverticulum preanal component lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18398"] = "EMAPA_18398"


class _Oral_Region_Cavity(_MouseAnatomicalStructureModel):
    """Model oral region cavity"""

    name: Literal["oral region cavity"] = "oral region cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18399"] = "EMAPA_18399"


class _Foregut_Lumen(_MouseAnatomicalStructureModel):
    """Model foregut lumen"""

    name: Literal["foregut lumen"] = "foregut lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18400"] = "EMAPA_18400"


class _Esophageal_Region_Lumen(_MouseAnatomicalStructureModel):
    """Model esophageal region lumen"""

    name: Literal["esophageal region lumen"] = "esophageal region lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18401"] = "EMAPA_18401"


class _Pharyngeal_Region_Lumen(_MouseAnatomicalStructureModel):
    """Model pharyngeal region lumen"""

    name: Literal["pharyngeal region lumen"] = "pharyngeal region lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18402"] = "EMAPA_18402"


class _Foregut_Midgut_Junction_Endoderm(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction endoderm"""

    name: Literal["foregut-midgut junction endoderm"] = "foregut-midgut junction endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18403"] = "EMAPA_18403"


class _Physiological_Umbilical_Hernia(_MouseAnatomicalStructureModel):
    """Model physiological umbilical hernia"""

    name: Literal["physiological umbilical hernia"] = "physiological umbilical hernia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18404"] = "EMAPA_18404"


class _Physiological_Umbilical_Hernia_Dermis(_MouseAnatomicalStructureModel):
    """Model physiological umbilical hernia dermis"""

    name: Literal["physiological umbilical hernia dermis"] = "physiological umbilical hernia dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18405"] = "EMAPA_18405"


class _Physiological_Umbilical_Hernia_Epidermis(_MouseAnatomicalStructureModel):
    """Model physiological umbilical hernia epidermis"""

    name: Literal["physiological umbilical hernia epidermis"] = "physiological umbilical hernia epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18406"] = "EMAPA_18406"


class _Carina_Trachea(_MouseAnatomicalStructureModel):
    """Model carina trachea"""

    name: Literal["carina trachea"] = "carina trachea"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18407"] = "EMAPA_18407"


class _Carina_Trachea_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model carina trachea mesenchyme"""

    name: Literal["carina trachea mesenchyme"] = "carina trachea mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18408"] = "EMAPA_18408"


class _Carina_Trachea_Epithelium(_MouseAnatomicalStructureModel):
    """Model carina trachea epithelium"""

    name: Literal["carina trachea epithelium"] = "carina trachea epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18409"] = "EMAPA_18409"


class _Carina_Trachea_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model carina trachea vascular element"""

    name: Literal["carina trachea vascular element"] = "carina trachea vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18410"] = "EMAPA_18410"


class _Greater_Sac_Visceral_Mesothelium(_MouseAnatomicalStructureModel):
    """Model greater sac visceral mesothelium"""

    name: Literal["greater sac visceral mesothelium"] = "greater sac visceral mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18414"] = "EMAPA_18414"


class _Vena_Cava(_MouseAnatomicalStructureModel):
    """Model vena cava"""

    name: Literal["vena cava"] = "vena cava"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18415"] = "EMAPA_18415"


class _Inferior_Vena_Cava(_MouseAnatomicalStructureModel):
    """Model inferior vena cava"""

    name: Literal["inferior vena cava"] = "inferior vena cava"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18416"] = "EMAPA_18416"


class _Superior_Vena_Cava(_MouseAnatomicalStructureModel):
    """Model superior vena cava"""

    name: Literal["superior vena cava"] = "superior vena cava"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18417"] = "EMAPA_18417"


class _Left_Superior_Vena_Cava(_MouseAnatomicalStructureModel):
    """Model left superior vena cava"""

    name: Literal["left superior vena cava"] = "left superior vena cava"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18418"] = "EMAPA_18418"


class _Right_Superior_Vena_Cava(_MouseAnatomicalStructureModel):
    """Model right superior vena cava"""

    name: Literal["right superior vena cava"] = "right superior vena cava"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18419"] = "EMAPA_18419"


class _Inferior_Vena_Cava_Post_Hepatic_Part(_MouseAnatomicalStructureModel):
    """Model inferior vena cava post-hepatic part"""

    name: Literal["inferior vena cava post-hepatic part"] = "inferior vena cava post-hepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18420"] = "EMAPA_18420"


class _Inferior_Vena_Cava_Pre_Hepatic_Part(_MouseAnatomicalStructureModel):
    """Model inferior vena cava pre-hepatic part"""

    name: Literal["inferior vena cava pre-hepatic part"] = "inferior vena cava pre-hepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18422"] = "EMAPA_18422"


class _Inferior_Vena_Cava_Left_Post_Hepatic_Part(_MouseAnatomicalStructureModel):
    """Model inferior vena cava left post-hepatic part"""

    name: Literal["inferior vena cava left post-hepatic part"] = "inferior vena cava left post-hepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18423"] = "EMAPA_18423"


class _Inferior_Vena_Cava_Right_Post_Hepatic_Part(_MouseAnatomicalStructureModel):
    """Model inferior vena cava right post-hepatic part"""

    name: Literal["inferior vena cava right post-hepatic part"] = "inferior vena cava right post-hepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18424"] = "EMAPA_18424"


class _Gland(_MouseAnatomicalStructureModel):
    """Model gland"""

    name: Literal["gland"] = "gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18425"] = "EMAPA_18425"


class _Adrenal_Gland(_MouseAnatomicalStructureModel):
    """Model adrenal gland"""

    name: Literal["adrenal gland"] = "adrenal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18426"] = "EMAPA_18426"


class _Adrenal_Cortex(_MouseAnatomicalStructureModel):
    """Model adrenal cortex"""

    name: Literal["adrenal cortex"] = "adrenal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18427"] = "EMAPA_18427"


class _Adrenal_Medulla(_MouseAnatomicalStructureModel):
    """Model adrenal medulla"""

    name: Literal["adrenal medulla"] = "adrenal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18428"] = "EMAPA_18428"


class _Diaphragm_Mesothelium(_MouseAnatomicalStructureModel):
    """Model diaphragm mesothelium"""

    name: Literal["diaphragm mesothelium"] = "diaphragm mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18429"] = "EMAPA_18429"


class _Elbow_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model elbow rest of mesenchyme"""

    name: Literal["elbow rest of mesenchyme"] = "elbow rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18430"] = "EMAPA_18430"


class _Forearm_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forearm rest of mesenchyme"""

    name: Literal["forearm rest of mesenchyme"] = "forearm rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18431"] = "EMAPA_18431"


class _Shoulder_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model shoulder rest of mesenchyme"""

    name: Literal["shoulder rest of mesenchyme"] = "shoulder rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18432"] = "EMAPA_18432"


class _Upper_Arm_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper arm rest of mesenchyme"""

    name: Literal["upper arm rest of mesenchyme"] = "upper arm rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18433"] = "EMAPA_18433"


class _Hip_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hip rest of mesenchyme"""

    name: Literal["hip rest of mesenchyme"] = "hip rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18434"] = "EMAPA_18434"


class _Knee_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model knee rest of mesenchyme"""

    name: Literal["knee rest of mesenchyme"] = "knee rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18435"] = "EMAPA_18435"


class _Lower_Leg_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower leg rest of mesenchyme"""

    name: Literal["lower leg rest of mesenchyme"] = "lower leg rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18436"] = "EMAPA_18436"


class _Upper_Leg_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper leg rest of mesenchyme"""

    name: Literal["upper leg rest of mesenchyme"] = "upper leg rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18437"] = "EMAPA_18437"


class _Cervical_Ganglion(_MouseAnatomicalStructureModel):
    """Model cervical ganglion"""

    name: Literal["cervical ganglion"] = "cervical ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18438"] = "EMAPA_18438"


class _Inferior_Cervical_Ganglion(_MouseAnatomicalStructureModel):
    """Model inferior cervical ganglion"""

    name: Literal["inferior cervical ganglion"] = "inferior cervical ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18439"] = "EMAPA_18439"


class _Middle_Cervical_Ganglion(_MouseAnatomicalStructureModel):
    """Model middle cervical ganglion"""

    name: Literal["middle cervical ganglion"] = "middle cervical ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18440"] = "EMAPA_18440"


class _Superior_Cervical_Ganglion(_MouseAnatomicalStructureModel):
    """Model superior cervical ganglion"""

    name: Literal["superior cervical ganglion"] = "superior cervical ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18441"] = "EMAPA_18441"


class _Nasal_Septum_Epithelium(_MouseAnatomicalStructureModel):
    """Model nasal septum epithelium"""

    name: Literal["nasal septum epithelium"] = "nasal septum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18442"] = "EMAPA_18442"


class _Nasal_Septum_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model nasal septum mesenchyme"""

    name: Literal["nasal septum mesenchyme"] = "nasal septum mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18443"] = "EMAPA_18443"


class _Vomeronasal_Organ_Epithelium(_MouseAnatomicalStructureModel):
    """Model vomeronasal organ epithelium"""

    name: Literal["vomeronasal organ epithelium"] = "vomeronasal organ epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18444"] = "EMAPA_18444"


class _Vomeronasal_Organ_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model vomeronasal organ mesenchyme"""

    name: Literal["vomeronasal organ mesenchyme"] = "vomeronasal organ mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18445"] = "EMAPA_18445"


class _Otic_Pit_Lumen(_MouseAnatomicalStructureModel):
    """Model otic pit lumen"""

    name: Literal["otic pit lumen"] = "otic pit lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18446"] = "EMAPA_18446"


class _Omental_Bursa_Cavity(_MouseAnatomicalStructureModel):
    """Model omental bursa cavity"""

    name: Literal["omental bursa cavity"] = "omental bursa cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18461"] = "EMAPA_18461"


class _Hand_Skin(_MouseAnatomicalStructureModel):
    """Model hand skin"""

    name: Literal["hand skin"] = "hand skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18486"] = "EMAPA_18486"


class _Hand_Dermis(_MouseAnatomicalStructureModel):
    """Model hand dermis"""

    name: Literal["hand dermis"] = "hand dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18487"] = "EMAPA_18487"


class _Hand_Epidermis(_MouseAnatomicalStructureModel):
    """Model hand epidermis"""

    name: Literal["hand epidermis"] = "hand epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18488"] = "EMAPA_18488"


class _Palmar_Pad(_MouseAnatomicalStructureModel):
    """Model palmar pad"""

    name: Literal["palmar pad"] = "palmar pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18489"] = "EMAPA_18489"


class _Tarsus_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model tarsus rest of mesenchyme"""

    name: Literal["tarsus rest of mesenchyme"] = "tarsus rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18502"] = "EMAPA_18502"


class _Foot_Skin(_MouseAnatomicalStructureModel):
    """Model foot skin"""

    name: Literal["foot skin"] = "foot skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18504"] = "EMAPA_18504"


class _Foot_Dermis(_MouseAnatomicalStructureModel):
    """Model foot dermis"""

    name: Literal["foot dermis"] = "foot dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18505"] = "EMAPA_18505"


class _Foot_Epidermis(_MouseAnatomicalStructureModel):
    """Model foot epidermis"""

    name: Literal["foot epidermis"] = "foot epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18506"] = "EMAPA_18506"


class _Plantar_Pad(_MouseAnatomicalStructureModel):
    """Model plantar pad"""

    name: Literal["plantar pad"] = "plantar pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18507"] = "EMAPA_18507"


class _Fabella_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model fabella pre-cartilage condensation"""

    name: Literal["fabella pre-cartilage condensation"] = "fabella pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18508"] = "EMAPA_18508"


class _Patellar_Ligament(_MouseAnatomicalStructureModel):
    """Model patellar ligament"""

    name: Literal["patellar ligament"] = "patellar ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18509"] = "EMAPA_18509"


class _Patella_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model patella pre-cartilage condensation"""

    name: Literal["patella pre-cartilage condensation"] = "patella pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18510"] = "EMAPA_18510"


class _Ilio_Psoas(_MouseAnatomicalStructureModel):
    """Model ilio-psoas"""

    name: Literal["ilio-psoas"] = "ilio-psoas"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18520"] = "EMAPA_18520"


class _Intercostal_Muscle(_MouseAnatomicalStructureModel):
    """Model intercostal muscle"""

    name: Literal["intercostal muscle"] = "intercostal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18521"] = "EMAPA_18521"


class _Intercostal_Muscle_External_Layer(_MouseAnatomicalStructureModel):
    """Model intercostal muscle external layer"""

    name: Literal["intercostal muscle external layer"] = "intercostal muscle external layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18522"] = "EMAPA_18522"


class _Intercostal_Muscle_Internal_Layer(_MouseAnatomicalStructureModel):
    """Model intercostal muscle internal layer"""

    name: Literal["intercostal muscle internal layer"] = "intercostal muscle internal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18523"] = "EMAPA_18523"


class _Quadratus_Lumborum(_MouseAnatomicalStructureModel):
    """Model quadratus lumborum"""

    name: Literal["quadratus lumborum"] = "quadratus lumborum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18524"] = "EMAPA_18524"


class _Serratus_Ventralis(_MouseAnatomicalStructureModel):
    """Model serratus ventralis"""

    name: Literal["serratus ventralis"] = "serratus ventralis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18525"] = "EMAPA_18525"


class _Infraspinatus(_MouseAnatomicalStructureModel):
    """Model infraspinatus"""

    name: Literal["infraspinatus"] = "infraspinatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18526"] = "EMAPA_18526"


class _Gluteus_Maximus(_MouseAnatomicalStructureModel):
    """Model gluteus maximus"""

    name: Literal["gluteus maximus"] = "gluteus maximus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18527"] = "EMAPA_18527"


class _Spleen_Primordium(_MouseAnatomicalStructureModel):
    """Model spleen primordium"""

    name: Literal["spleen primordium"] = "spleen primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18535"] = "EMAPA_18535"


class _Parotid_Gland(_MouseAnatomicalStructureModel):
    """Model parotid gland"""

    name: Literal["parotid gland"] = "parotid gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18537"] = "EMAPA_18537"


class _Parotid_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model parotid gland epithelium"""

    name: Literal["parotid gland epithelium"] = "parotid gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18538"] = "EMAPA_18538"


class _Parotid_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model parotid gland mesenchyme"""

    name: Literal["parotid gland mesenchyme"] = "parotid gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18539"] = "EMAPA_18539"


class _Thyroglossal_Duct_Median_Lobe(_MouseAnatomicalStructureModel):
    """Model thyroglossal duct median lobe"""

    name: Literal["thyroglossal duct median lobe"] = "thyroglossal duct median lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18540"] = "EMAPA_18540"


class _Mammary_Line(_MouseAnatomicalStructureModel):
    """Model mammary line"""

    name: Literal["mammary line"] = "mammary line"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18541"] = "EMAPA_18541"


class _Epithalamic_Recess(_MouseAnatomicalStructureModel):
    """Model epithalamic recess"""

    name: Literal["epithalamic recess"] = "epithalamic recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18542"] = "EMAPA_18542"


class _3Rd_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model 3rd ventricle choroid plexus"""

    name: Literal["3rd ventricle choroid plexus"] = "3rd ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18543"] = "EMAPA_18543"


class _Pineal_Primordium(_MouseAnatomicalStructureModel):
    """Model pineal primordium"""

    name: Literal["pineal primordium"] = "pineal primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18544"] = "EMAPA_18544"


class _Interthalamic_Adhesion(_MouseAnatomicalStructureModel):
    """Model interthalamic adhesion"""

    name: Literal["interthalamic adhesion"] = "interthalamic adhesion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18546"] = "EMAPA_18546"


class _Head_Of_Caudate_Nucleus(_MouseAnatomicalStructureModel):
    """Model head of caudate nucleus"""

    name: Literal["head of caudate nucleus"] = "head of caudate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18547"] = "EMAPA_18547"


class _Tail_Of_Caudate_Nucleus(_MouseAnatomicalStructureModel):
    """Model tail of caudate nucleus"""

    name: Literal["tail of caudate nucleus"] = "tail of caudate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18548"] = "EMAPA_18548"


class _Head_Of_Lateral_Ventricle(_MouseAnatomicalStructureModel):
    """Model head of lateral ventricle"""

    name: Literal["head of lateral ventricle"] = "head of lateral ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18549"] = "EMAPA_18549"


class _Tail_Of_Lateral_Ventricle(_MouseAnatomicalStructureModel):
    """Model tail of lateral ventricle"""

    name: Literal["tail of lateral ventricle"] = "tail of lateral ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18550"] = "EMAPA_18550"


class _Falx_Cerebri(_MouseAnatomicalStructureModel):
    """Model falx cerebri"""

    name: Literal["falx cerebri"] = "falx cerebri"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18551"] = "EMAPA_18551"


class _Medullary_Raphe(_MouseAnatomicalStructureModel):
    """Model medullary raphe"""

    name: Literal["medullary raphe"] = "medullary raphe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18553"] = "EMAPA_18553"


class _Cerebellum_Intraventricular_Portion(_MouseAnatomicalStructureModel):
    """Model cerebellum intraventricular portion"""

    name: Literal["cerebellum intraventricular portion"] = "cerebellum intraventricular portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18555"] = "EMAPA_18555"


class _Cerebellum_Intraventricular_Portion_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum intraventricular portion mantle layer"""

    name: Literal[
        "cerebellum intraventricular portion mantle layer"
    ] = "cerebellum intraventricular portion mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18556"] = "EMAPA_18556"


class _Cerebellum_Intraventricular_Portion_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum intraventricular portion marginal layer"""

    name: Literal[
        "cerebellum intraventricular portion marginal layer"
    ] = "cerebellum intraventricular portion marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18557"] = "EMAPA_18557"


class _Cerebellum_Intraventricular_Portion_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum intraventricular portion ventricular layer"""

    name: Literal[
        "cerebellum intraventricular portion ventricular layer"
    ] = "cerebellum intraventricular portion ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18558"] = "EMAPA_18558"


class _Rest_Of_Cerebellum(_MouseAnatomicalStructureModel):
    """Model rest of cerebellum"""

    name: Literal["rest of cerebellum"] = "rest of cerebellum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18559"] = "EMAPA_18559"


class _Rest_Of_Cerebellum_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rest of cerebellum mantle layer"""

    name: Literal["rest of cerebellum mantle layer"] = "rest of cerebellum mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18560"] = "EMAPA_18560"


class _Rest_Of_Cerebellum_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rest of cerebellum marginal layer"""

    name: Literal["rest of cerebellum marginal layer"] = "rest of cerebellum marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18561"] = "EMAPA_18561"


class _Rest_Of_Cerebellum_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rest of cerebellum ventricular layer"""

    name: Literal["rest of cerebellum ventricular layer"] = "rest of cerebellum ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18562"] = "EMAPA_18562"


class _Metencephalon_Rest_Of_Alar_Plate(_MouseAnatomicalStructureModel):
    """Model metencephalon rest of alar plate"""

    name: Literal["metencephalon rest of alar plate"] = "metencephalon rest of alar plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18563"] = "EMAPA_18563"


class _Metencephalon_Rest_Of_Alar_Plate_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon rest of alar plate mantle layer"""

    name: Literal["metencephalon rest of alar plate mantle layer"] = "metencephalon rest of alar plate mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18564"] = "EMAPA_18564"


class _Metencephalon_Rest_Of_Alar_Plate_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon rest of alar plate marginal layer"""

    name: Literal["metencephalon rest of alar plate marginal layer"] = "metencephalon rest of alar plate marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18565"] = "EMAPA_18565"


class _Metencephalon_Rest_Of_Alar_Plate_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon rest of alar plate ventricular layer"""

    name: Literal[
        "metencephalon rest of alar plate ventricular layer"
    ] = "metencephalon rest of alar plate ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18566"] = "EMAPA_18566"


class _Dorsal_Grey_Horn(_MouseAnatomicalStructureModel):
    """Model dorsal grey horn"""

    name: Literal["dorsal grey horn"] = "dorsal grey horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18574"] = "EMAPA_18574"


class _Ventral_Grey_Horn(_MouseAnatomicalStructureModel):
    """Model ventral grey horn"""

    name: Literal["ventral grey horn"] = "ventral grey horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18575"] = "EMAPA_18575"


class _Intermediate_Grey_Horn(_MouseAnatomicalStructureModel):
    """Model intermediate grey horn"""

    name: Literal["intermediate grey horn"] = "intermediate grey horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18576"] = "EMAPA_18576"


class _Sciatic_Nerve(_MouseAnatomicalStructureModel):
    """Model sciatic nerve"""

    name: Literal["sciatic nerve"] = "sciatic nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18577"] = "EMAPA_18577"


class _Future_Tympanic_Membrane_Endothelium(_MouseAnatomicalStructureModel):
    """Model future tympanic membrane endothelium"""

    name: Literal["future tympanic membrane endothelium"] = "future tympanic membrane endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18578"] = "EMAPA_18578"


class _Endolymphatic_Duct(_MouseAnatomicalStructureModel):
    """Model endolymphatic duct"""

    name: Literal["endolymphatic duct"] = "endolymphatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18580"] = "EMAPA_18580"


class _Endolymphatic_Duct_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model endolymphatic duct mesenchyme"""

    name: Literal["endolymphatic duct mesenchyme"] = "endolymphatic duct mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18581"] = "EMAPA_18581"


class _Endolymphatic_Duct_Epithelium(_MouseAnatomicalStructureModel):
    """Model endolymphatic duct epithelium"""

    name: Literal["endolymphatic duct epithelium"] = "endolymphatic duct epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18582"] = "EMAPA_18582"


class _Incus(_MouseAnatomicalStructureModel):
    """Model incus"""

    name: Literal["incus"] = "incus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18583"] = "EMAPA_18583"


class _Malleus(_MouseAnatomicalStructureModel):
    """Model malleus"""

    name: Literal["malleus"] = "malleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18584"] = "EMAPA_18584"


class _Stapes(_MouseAnatomicalStructureModel):
    """Model stapes"""

    name: Literal["stapes"] = "stapes"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18585"] = "EMAPA_18585"


class _Stapedius_Muscle(_MouseAnatomicalStructureModel):
    """Model stapedius muscle"""

    name: Literal["stapedius muscle"] = "stapedius muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18586"] = "EMAPA_18586"


class _Tensor_Tympani_Muscle(_MouseAnatomicalStructureModel):
    """Model tensor tympani muscle"""

    name: Literal["tensor tympani muscle"] = "tensor tympani muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18587"] = "EMAPA_18587"


class _Conjunctival_Sac_Lower_Recess(_MouseAnatomicalStructureModel):
    """Model conjunctival sac lower recess"""

    name: Literal["conjunctival sac lower recess"] = "conjunctival sac lower recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18588"] = "EMAPA_18588"


class _Conjunctival_Sac_Upper_Recess(_MouseAnatomicalStructureModel):
    """Model conjunctival sac upper recess"""

    name: Literal["conjunctival sac upper recess"] = "conjunctival sac upper recess"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18589"] = "EMAPA_18589"


class _Neural_Retina(_MouseAnatomicalStructureModel):
    """Model neural retina"""

    name: Literal["neural retina"] = "neural retina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18590"] = "EMAPA_18590"


class _Retina_Nerve_Fiber_Layer(_MouseAnatomicalStructureModel):
    """Model retina nerve fiber layer"""

    name: Literal["retina nerve fiber layer"] = "retina nerve fiber layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18591"] = "EMAPA_18591"


class _Retina_Nuclear_Layer(_MouseAnatomicalStructureModel):
    """Model retina nuclear layer"""

    name: Literal["retina nuclear layer"] = "retina nuclear layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18592"] = "EMAPA_18592"


class _Nasal_Meatus(_MouseAnatomicalStructureModel):
    """Model nasal meatus"""

    name: Literal["nasal meatus"] = "nasal meatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18593"] = "EMAPA_18593"


class _Anterior_Naris(_MouseAnatomicalStructureModel):
    """Model anterior naris"""

    name: Literal["anterior naris"] = "anterior naris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18594"] = "EMAPA_18594"


class _Anterior_Naris_Epithelium(_MouseAnatomicalStructureModel):
    """Model anterior naris epithelium"""

    name: Literal["anterior naris epithelium"] = "anterior naris epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18595"] = "EMAPA_18595"


class _External_Naris_Epithelium(_MouseAnatomicalStructureModel):
    """Model external naris epithelium"""

    name: Literal["external naris epithelium"] = "external naris epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18596"] = "EMAPA_18596"


class _Communicating_Artery(_MouseAnatomicalStructureModel):
    """Model communicating artery"""

    name: Literal["communicating artery"] = "communicating artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18598"] = "EMAPA_18598"


class _Anterior_Communicating_Artery(_MouseAnatomicalStructureModel):
    """Model anterior communicating artery"""

    name: Literal["anterior communicating artery"] = "anterior communicating artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18599"] = "EMAPA_18599"


class _Posterior_Communicating_Artery(_MouseAnatomicalStructureModel):
    """Model posterior communicating artery"""

    name: Literal["posterior communicating artery"] = "posterior communicating artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18600"] = "EMAPA_18600"


class _Aorta(_MouseAnatomicalStructureModel):
    """Model aorta"""

    name: Literal["aorta"] = "aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18601"] = "EMAPA_18601"


class _Thoracic_Aorta(_MouseAnatomicalStructureModel):
    """Model thoracic aorta"""

    name: Literal["thoracic aorta"] = "thoracic aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18603"] = "EMAPA_18603"


class _Descending_Thoracic_Aorta(_MouseAnatomicalStructureModel):
    """Model descending thoracic aorta"""

    name: Literal["descending thoracic aorta"] = "descending thoracic aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18605"] = "EMAPA_18605"


class _Descending_Aorta(_MouseAnatomicalStructureModel):
    """Model descending aorta"""

    name: Literal["descending aorta"] = "descending aorta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18606"] = "EMAPA_18606"


class _Bronchial_Artery(_MouseAnatomicalStructureModel):
    """Model bronchial artery"""

    name: Literal["bronchial artery"] = "bronchial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18608"] = "EMAPA_18608"


class _Carotid_Artery(_MouseAnatomicalStructureModel):
    """Model carotid artery"""

    name: Literal["carotid artery"] = "carotid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18609"] = "EMAPA_18609"


class _External_Carotid_Artery(_MouseAnatomicalStructureModel):
    """Model external carotid artery"""

    name: Literal["external carotid artery"] = "external carotid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18611"] = "EMAPA_18611"


class _Cerebral_Artery(_MouseAnatomicalStructureModel):
    """Model cerebral artery"""

    name: Literal["cerebral artery"] = "cerebral artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18613"] = "EMAPA_18613"


class _Internal_Thoracic_Artery(_MouseAnatomicalStructureModel):
    """Model internal thoracic artery"""

    name: Literal["internal thoracic artery"] = "internal thoracic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18617"] = "EMAPA_18617"


class _Inferior_Mesenteric_Artery(_MouseAnatomicalStructureModel):
    """Model inferior mesenteric artery"""

    name: Literal["inferior mesenteric artery"] = "inferior mesenteric artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18618"] = "EMAPA_18618"


class _Superior_Mesenteric_Artery(_MouseAnatomicalStructureModel):
    """Model superior mesenteric artery"""

    name: Literal["superior mesenteric artery"] = "superior mesenteric artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18619"] = "EMAPA_18619"


class _Ovarian_Artery(_MouseAnatomicalStructureModel):
    """Model ovarian artery"""

    name: Literal["ovarian artery"] = "ovarian artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18620"] = "EMAPA_18620"


class _Testicular_Artery(_MouseAnatomicalStructureModel):
    """Model testicular artery"""

    name: Literal["testicular artery"] = "testicular artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18621"] = "EMAPA_18621"


class _Thyroid_Artery(_MouseAnatomicalStructureModel):
    """Model thyroid artery"""

    name: Literal["thyroid artery"] = "thyroid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18622"] = "EMAPA_18622"


class _Inferior_Thyroid_Artery(_MouseAnatomicalStructureModel):
    """Model inferior thyroid artery"""

    name: Literal["inferior thyroid artery"] = "inferior thyroid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18623"] = "EMAPA_18623"


class _Superior_Thyroid_Artery(_MouseAnatomicalStructureModel):
    """Model superior thyroid artery"""

    name: Literal["superior thyroid artery"] = "superior thyroid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18624"] = "EMAPA_18624"


class _Aortic_Sinus(_MouseAnatomicalStructureModel):
    """Model aortic sinus"""

    name: Literal["aortic sinus"] = "aortic sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18625"] = "EMAPA_18625"


class _Trabeculae_Carneae(_MouseAnatomicalStructureModel):
    """Model trabeculae carneae"""

    name: Literal["trabeculae carneae"] = "trabeculae carneae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18626"] = "EMAPA_18626"


class _Aortic_Valve_Leaflet(_MouseAnatomicalStructureModel):
    """Model aortic valve leaflet"""

    name: Literal["aortic valve leaflet"] = "aortic valve leaflet"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18627"] = "EMAPA_18627"


class _Mitral_Valve_Leaflet(_MouseAnatomicalStructureModel):
    """Model mitral valve leaflet"""

    name: Literal["mitral valve leaflet"] = "mitral valve leaflet"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18628"] = "EMAPA_18628"


class _Pulmonary_Valve_Leaflet(_MouseAnatomicalStructureModel):
    """Model pulmonary valve leaflet"""

    name: Literal["pulmonary valve leaflet"] = "pulmonary valve leaflet"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18629"] = "EMAPA_18629"


class _Tricuspid_Valve_Leaflet(_MouseAnatomicalStructureModel):
    """Model tricuspid valve leaflet"""

    name: Literal["tricuspid valve leaflet"] = "tricuspid valve leaflet"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18630"] = "EMAPA_18630"


class _Brain_Venous_System(_MouseAnatomicalStructureModel):
    """Model brain venous system"""

    name: Literal["brain venous system"] = "brain venous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18631"] = "EMAPA_18631"


class _Hindbrain_Venous_System(_MouseAnatomicalStructureModel):
    """Model hindbrain venous system"""

    name: Literal["hindbrain venous system"] = "hindbrain venous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18632"] = "EMAPA_18632"


class _Hindbrain_Venous_Sinus(_MouseAnatomicalStructureModel):
    """Model hindbrain venous sinus"""

    name: Literal["hindbrain venous sinus"] = "hindbrain venous sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18633"] = "EMAPA_18633"


class _Hindbrain_Venous_Dural_Sinus(_MouseAnatomicalStructureModel):
    """Model hindbrain venous dural sinus"""

    name: Literal["hindbrain venous dural sinus"] = "hindbrain venous dural sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18634"] = "EMAPA_18634"


class _Inferior_Sagittal_Sinus(_MouseAnatomicalStructureModel):
    """Model inferior sagittal sinus"""

    name: Literal["inferior sagittal sinus"] = "inferior sagittal sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18635"] = "EMAPA_18635"


class _Superior_Sagittal_Sinus(_MouseAnatomicalStructureModel):
    """Model superior sagittal sinus"""

    name: Literal["superior sagittal sinus"] = "superior sagittal sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18636"] = "EMAPA_18636"


class _Transverse_Sinus(_MouseAnatomicalStructureModel):
    """Model transverse sinus"""

    name: Literal["transverse sinus"] = "transverse sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18637"] = "EMAPA_18637"


class _Jugular_Vein(_MouseAnatomicalStructureModel):
    """Model jugular vein"""

    name: Literal["jugular vein"] = "jugular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18638"] = "EMAPA_18638"


class _Internal_Thoracic_Vein(_MouseAnatomicalStructureModel):
    """Model internal thoracic vein"""

    name: Literal["internal thoracic vein"] = "internal thoracic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18641"] = "EMAPA_18641"


class _Inferior_Mesenteric_Vein(_MouseAnatomicalStructureModel):
    """Model inferior mesenteric vein"""

    name: Literal["inferior mesenteric vein"] = "inferior mesenteric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18642"] = "EMAPA_18642"


class _Superior_Mesenteric_Vein(_MouseAnatomicalStructureModel):
    """Model superior mesenteric vein"""

    name: Literal["superior mesenteric vein"] = "superior mesenteric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18643"] = "EMAPA_18643"


class _Ovarian_Vein(_MouseAnatomicalStructureModel):
    """Model ovarian vein"""

    name: Literal["ovarian vein"] = "ovarian vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18644"] = "EMAPA_18644"


class _Pulmonary_Vein(_MouseAnatomicalStructureModel):
    """Model pulmonary vein"""

    name: Literal["pulmonary vein"] = "pulmonary vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18645"] = "EMAPA_18645"


class _Superior_Vesical_Vein(_MouseAnatomicalStructureModel):
    """Model superior vesical vein"""

    name: Literal["superior vesical vein"] = "superior vesical vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18646"] = "EMAPA_18646"


class _Testicular_Vein(_MouseAnatomicalStructureModel):
    """Model testicular vein"""

    name: Literal["testicular vein"] = "testicular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18647"] = "EMAPA_18647"


class _Thyroid_Vein(_MouseAnatomicalStructureModel):
    """Model thyroid vein"""

    name: Literal["thyroid vein"] = "thyroid vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18648"] = "EMAPA_18648"


class _Pharynx_Skeleton(_MouseAnatomicalStructureModel):
    """Model pharynx skeleton"""

    name: Literal["pharynx skeleton"] = "pharynx skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18649"] = "EMAPA_18649"


class _Hyoid(_MouseAnatomicalStructureModel):
    """Model hyoid"""

    name: Literal["hyoid"] = "hyoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18650"] = "EMAPA_18650"


class _Hyoid_Greater_Horn(_MouseAnatomicalStructureModel):
    """Model hyoid greater horn"""

    name: Literal["hyoid greater horn"] = "hyoid greater horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18651"] = "EMAPA_18651"


class _Hyoid_Lesser_Horn(_MouseAnatomicalStructureModel):
    """Model hyoid lesser horn"""

    name: Literal["hyoid lesser horn"] = "hyoid lesser horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18652"] = "EMAPA_18652"


class _Hyoid_Body(_MouseAnatomicalStructureModel):
    """Model hyoid body"""

    name: Literal["hyoid body"] = "hyoid body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18653"] = "EMAPA_18653"


class _Frenulum(_MouseAnatomicalStructureModel):
    """Model frenulum"""

    name: Literal["frenulum"] = "frenulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18656"] = "EMAPA_18656"


class _Greater_Omentum(_MouseAnatomicalStructureModel):
    """Model greater omentum"""

    name: Literal["greater omentum"] = "greater omentum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18660"] = "EMAPA_18660"


class _Foregut_Midgut_Junction_Duodenum(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction duodenum"""

    name: Literal["foregut-midgut junction duodenum"] = "foregut-midgut junction duodenum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18661"] = "EMAPA_18661"


class _Duodenal_Papilla(_MouseAnatomicalStructureModel):
    """Model duodenal papilla"""

    name: Literal["duodenal papilla"] = "duodenal papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18662"] = "EMAPA_18662"


class _Sphincter_Of_Oddi(_MouseAnatomicalStructureModel):
    """Model sphincter of Oddi"""

    name: Literal["sphincter of Oddi"] = "sphincter of Oddi"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18663"] = "EMAPA_18663"


class _Rectum_Mesentery(_MouseAnatomicalStructureModel):
    """Model rectum mesentery"""

    name: Literal["rectum mesentery"] = "rectum mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18664"] = "EMAPA_18664"


class _Rectum_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model rectum dorsal mesentery"""

    name: Literal["rectum dorsal mesentery"] = "rectum dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18665"] = "EMAPA_18665"


class _Jejunum(_MouseAnatomicalStructureModel):
    """Model jejunum"""

    name: Literal["jejunum"] = "jejunum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18666"] = "EMAPA_18666"


class _Jejunum_Epithelium(_MouseAnatomicalStructureModel):
    """Model jejunum epithelium"""

    name: Literal["jejunum epithelium"] = "jejunum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18668"] = "EMAPA_18668"


class _Jejunum_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model jejunum vascular element"""

    name: Literal["jejunum vascular element"] = "jejunum vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18669"] = "EMAPA_18669"


class _Jejunum_Mesentery(_MouseAnatomicalStructureModel):
    """Model jejunum mesentery"""

    name: Literal["jejunum mesentery"] = "jejunum mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18670"] = "EMAPA_18670"


class _Jejunum_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model jejunum dorsal mesentery"""

    name: Literal["jejunum dorsal mesentery"] = "jejunum dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18671"] = "EMAPA_18671"


class _Liver_Left_Lobe_Hepatic_Duct(_MouseAnatomicalStructureModel):
    """Model liver left lobe hepatic duct"""

    name: Literal["liver left lobe hepatic duct"] = "liver left lobe hepatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18672"] = "EMAPA_18672"


class _Renal_Calyx(_MouseAnatomicalStructureModel):
    """Model renal calyx"""

    name: Literal["renal calyx"] = "renal calyx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18676"] = "EMAPA_18676"


class _Major_Calyx(_MouseAnatomicalStructureModel):
    """Model major calyx"""

    name: Literal["major calyx"] = "major calyx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18677"] = "EMAPA_18677"


class _Minor_Calyx(_MouseAnatomicalStructureModel):
    """Model minor calyx"""

    name: Literal["minor calyx"] = "minor calyx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18678"] = "EMAPA_18678"


class _Renal_Capsule(_MouseAnatomicalStructureModel):
    """Model renal capsule"""

    name: Literal["renal capsule"] = "renal capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18679"] = "EMAPA_18679"


class _Genital_Tubercle_Of_Female(_MouseAnatomicalStructureModel):
    """Model genital tubercle of female"""

    name: Literal["genital tubercle of female"] = "genital tubercle of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18680"] = "EMAPA_18680"


class _Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model ductus deferens"""

    name: Literal["ductus deferens"] = "ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18681"] = "EMAPA_18681"


class _Penis(_MouseAnatomicalStructureModel):
    """Model penis"""

    name: Literal["penis"] = "penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18682"] = "EMAPA_18682"


class _Seminiferous_Cord(_MouseAnatomicalStructureModel):
    """Model seminiferous cord"""

    name: Literal["seminiferous cord"] = "seminiferous cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18685"] = "EMAPA_18685"


class _Interstitium_Of_The_Testis(_MouseAnatomicalStructureModel):
    """Model interstitium of the testis"""

    name: Literal["interstitium of the testis"] = "interstitium of the testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18687"] = "EMAPA_18687"


class _Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model urethra of male"""

    name: Literal["urethra of male"] = "urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18692"] = "EMAPA_18692"


class _Urethral_Fold_Of_Male(_MouseAnatomicalStructureModel):
    """Model urethral fold of male"""

    name: Literal["urethral fold of male"] = "urethral fold of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18693"] = "EMAPA_18693"


class _Respiratory_System_Cartilage(_MouseAnatomicalStructureModel):
    """Model respiratory system cartilage"""

    name: Literal["respiratory system cartilage"] = "respiratory system cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18694"] = "EMAPA_18694"


class _Arytenoid_Cartilage(_MouseAnatomicalStructureModel):
    """Model arytenoid cartilage"""

    name: Literal["arytenoid cartilage"] = "arytenoid cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18695"] = "EMAPA_18695"


class _Cricoid_Cartilage(_MouseAnatomicalStructureModel):
    """Model cricoid cartilage"""

    name: Literal["cricoid cartilage"] = "cricoid cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18696"] = "EMAPA_18696"


class _Laryngeal_Cartilage(_MouseAnatomicalStructureModel):
    """Model laryngeal cartilage"""

    name: Literal["laryngeal cartilage"] = "laryngeal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18697"] = "EMAPA_18697"


class _Thyroid_Cartilage(_MouseAnatomicalStructureModel):
    """Model thyroid cartilage"""

    name: Literal["thyroid cartilage"] = "thyroid cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18698"] = "EMAPA_18698"


class _Trachea_Cartilaginous_Ring(_MouseAnatomicalStructureModel):
    """Model trachea cartilaginous ring"""

    name: Literal["trachea cartilaginous ring"] = "trachea cartilaginous ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18699"] = "EMAPA_18699"


class _Basioccipital_Bone(_MouseAnatomicalStructureModel):
    """Model basioccipital bone"""

    name: Literal["basioccipital bone"] = "basioccipital bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18705"] = "EMAPA_18705"


class _Basisphenoid_Bone(_MouseAnatomicalStructureModel):
    """Model basisphenoid bone"""

    name: Literal["basisphenoid bone"] = "basisphenoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18706"] = "EMAPA_18706"


class _Carotid_Canal(_MouseAnatomicalStructureModel):
    """Model carotid canal"""

    name: Literal["carotid canal"] = "carotid canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18707"] = "EMAPA_18707"


class _Exoccipital_Bone(_MouseAnatomicalStructureModel):
    """Model exoccipital bone"""

    name: Literal["exoccipital bone"] = "exoccipital bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18708"] = "EMAPA_18708"


class _Foramen_Ovale_Of_Chondrocranium(_MouseAnatomicalStructureModel):
    """Model foramen ovale of chondrocranium"""

    name: Literal["foramen ovale of chondrocranium"] = "foramen ovale of chondrocranium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18711"] = "EMAPA_18711"


class _Foramen_Rotundum(_MouseAnatomicalStructureModel):
    """Model foramen rotundum"""

    name: Literal["foramen rotundum"] = "foramen rotundum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18712"] = "EMAPA_18712"


class _Jugular_Foramen(_MouseAnatomicalStructureModel):
    """Model jugular foramen"""

    name: Literal["jugular foramen"] = "jugular foramen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18713"] = "EMAPA_18713"


class _Temporo_Mandibular_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model temporo-mandibular joint primordium"""

    name: Literal["temporo-mandibular joint primordium"] = "temporo-mandibular joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18714"] = "EMAPA_18714"


class _Parietal_Bone(_MouseAnatomicalStructureModel):
    """Model parietal bone"""

    name: Literal["parietal bone"] = "parietal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18715"] = "EMAPA_18715"


class _Optic_Foramen(_MouseAnatomicalStructureModel):
    """Model optic foramen"""

    name: Literal["optic foramen"] = "optic foramen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18716"] = "EMAPA_18716"


class _Orbital_Fissure(_MouseAnatomicalStructureModel):
    """Model orbital fissure"""

    name: Literal["orbital fissure"] = "orbital fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18717"] = "EMAPA_18717"


class _Superior_Orbital_Fissure(_MouseAnatomicalStructureModel):
    """Model superior orbital fissure"""

    name: Literal["superior orbital fissure"] = "superior orbital fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18718"] = "EMAPA_18718"


class _Orbito_Sphenoid(_MouseAnatomicalStructureModel):
    """Model orbito-sphenoid"""

    name: Literal["orbito-sphenoid"] = "orbito-sphenoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18719"] = "EMAPA_18719"


class _Clavicle(_MouseAnatomicalStructureModel):
    """Model clavicle"""

    name: Literal["clavicle"] = "clavicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18721"] = "EMAPA_18721"


class _Scapula(_MouseAnatomicalStructureModel):
    """Model scapula"""

    name: Literal["scapula"] = "scapula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18722"] = "EMAPA_18722"


class _Manubrium_Sterni(_MouseAnatomicalStructureModel):
    """Model manubrium sterni"""

    name: Literal["manubrium sterni"] = "manubrium sterni"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18723"] = "EMAPA_18723"


class _Sternebra(_MouseAnatomicalStructureModel):
    """Model sternebra"""

    name: Literal["sternebra"] = "sternebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18724"] = "EMAPA_18724"


class _Xiphisternum(_MouseAnatomicalStructureModel):
    """Model xiphisternum"""

    name: Literal["xiphisternum"] = "xiphisternum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18725"] = "EMAPA_18725"


class _Ilium(_MouseAnatomicalStructureModel):
    """Model ilium"""

    name: Literal["ilium"] = "ilium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18726"] = "EMAPA_18726"


class _Ischium(_MouseAnatomicalStructureModel):
    """Model ischium"""

    name: Literal["ischium"] = "ischium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18727"] = "EMAPA_18727"


class _Pubis(_MouseAnatomicalStructureModel):
    """Model pubis"""

    name: Literal["pubis"] = "pubis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18728"] = "EMAPA_18728"


class _Jejunum_Lumen(_MouseAnatomicalStructureModel):
    """Model jejunum lumen"""

    name: Literal["jejunum lumen"] = "jejunum lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18729"] = "EMAPA_18729"


class _Forelimb_Digit_1_Nail(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 nail"""

    name: Literal["forelimb digit 1 nail"] = "forelimb digit 1 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18734"] = "EMAPA_18734"


class _Forelimb_Digit_2_Nail(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 nail"""

    name: Literal["forelimb digit 2 nail"] = "forelimb digit 2 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18735"] = "EMAPA_18735"


class _Forelimb_Digit_3_Nail(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 nail"""

    name: Literal["forelimb digit 3 nail"] = "forelimb digit 3 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18736"] = "EMAPA_18736"


class _Forelimb_Digit_4_Nail(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 nail"""

    name: Literal["forelimb digit 4 nail"] = "forelimb digit 4 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18737"] = "EMAPA_18737"


class _Forelimb_Digit_5_Nail(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 nail"""

    name: Literal["forelimb digit 5 nail"] = "forelimb digit 5 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18738"] = "EMAPA_18738"


class _Hindlimb_Digit_1_Nail(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 nail"""

    name: Literal["hindlimb digit 1 nail"] = "hindlimb digit 1 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18739"] = "EMAPA_18739"


class _Hindlimb_Digit_2_Nail(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 nail"""

    name: Literal["hindlimb digit 2 nail"] = "hindlimb digit 2 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18740"] = "EMAPA_18740"


class _Hindlimb_Digit_3_Nail(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 nail"""

    name: Literal["hindlimb digit 3 nail"] = "hindlimb digit 3 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18741"] = "EMAPA_18741"


class _Hindlimb_Digit_4_Nail(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 nail"""

    name: Literal["hindlimb digit 4 nail"] = "hindlimb digit 4 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18742"] = "EMAPA_18742"


class _Hindlimb_Digit_5_Nail(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 nail"""

    name: Literal["hindlimb digit 5 nail"] = "hindlimb digit 5 nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18743"] = "EMAPA_18743"


class _Axillary_Artery(_MouseAnatomicalStructureModel):
    """Model axillary artery"""

    name: Literal["axillary artery"] = "axillary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18749"] = "EMAPA_18749"


class _Epigastric_Artery(_MouseAnatomicalStructureModel):
    """Model epigastric artery"""

    name: Literal["epigastric artery"] = "epigastric artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18750"] = "EMAPA_18750"


class _Inferior_Epigastric_Artery(_MouseAnatomicalStructureModel):
    """Model inferior epigastric artery"""

    name: Literal["inferior epigastric artery"] = "inferior epigastric artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18751"] = "EMAPA_18751"


class _Superior_Epigastric_Artery(_MouseAnatomicalStructureModel):
    """Model superior epigastric artery"""

    name: Literal["superior epigastric artery"] = "superior epigastric artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18752"] = "EMAPA_18752"


class _Intercostal_Artery(_MouseAnatomicalStructureModel):
    """Model intercostal artery"""

    name: Literal["intercostal artery"] = "intercostal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18753"] = "EMAPA_18753"


class _Greater_Palatine_Artery(_MouseAnatomicalStructureModel):
    """Model greater palatine artery"""

    name: Literal["greater palatine artery"] = "greater palatine artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18754"] = "EMAPA_18754"


class _Axillary_Vein(_MouseAnatomicalStructureModel):
    """Model axillary vein"""

    name: Literal["axillary vein"] = "axillary vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18758"] = "EMAPA_18758"


class _Epigastric_Vein(_MouseAnatomicalStructureModel):
    """Model epigastric vein"""

    name: Literal["epigastric vein"] = "epigastric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18759"] = "EMAPA_18759"


class _Inferior_Epigastric_Vein(_MouseAnatomicalStructureModel):
    """Model inferior epigastric vein"""

    name: Literal["inferior epigastric vein"] = "inferior epigastric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18760"] = "EMAPA_18760"


class _Superior_Epigastric_Vein(_MouseAnatomicalStructureModel):
    """Model superior epigastric vein"""

    name: Literal["superior epigastric vein"] = "superior epigastric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18761"] = "EMAPA_18761"


class _Intercostal_Vein(_MouseAnatomicalStructureModel):
    """Model intercostal vein"""

    name: Literal["intercostal vein"] = "intercostal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18762"] = "EMAPA_18762"


class _Inferior_Thyroid_Vein(_MouseAnatomicalStructureModel):
    """Model inferior thyroid vein"""

    name: Literal["inferior thyroid vein"] = "inferior thyroid vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18763"] = "EMAPA_18763"


class _Superior_Thyroid_Vein(_MouseAnatomicalStructureModel):
    """Model superior thyroid vein"""

    name: Literal["superior thyroid vein"] = "superior thyroid vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18764"] = "EMAPA_18764"


class _Hemolymphoid_System(_MouseAnatomicalStructureModel):
    """Model hemolymphoid system"""

    name: Literal["hemolymphoid system"] = "hemolymphoid system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18765"] = "EMAPA_18765"


class _Hemolymphoid_System_Gland(_MouseAnatomicalStructureModel):
    """Model hemolymphoid system gland"""

    name: Literal["hemolymphoid system gland"] = "hemolymphoid system gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18766"] = "EMAPA_18766"


class _Spleen(_MouseAnatomicalStructureModel):
    """Model spleen"""

    name: Literal["spleen"] = "spleen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18767"] = "EMAPA_18767"


class _Thymus(_MouseAnatomicalStructureModel):
    """Model thymus"""

    name: Literal["thymus"] = "thymus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18768"] = "EMAPA_18768"


class _Hair(_MouseAnatomicalStructureModel):
    """Model hair"""

    name: Literal["hair"] = "hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18769"] = "EMAPA_18769"


class _Hair_Bulb(_MouseAnatomicalStructureModel):
    """Model hair bulb"""

    name: Literal["hair bulb"] = "hair bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18770"] = "EMAPA_18770"


class _Hair_Follicle(_MouseAnatomicalStructureModel):
    """Model hair follicle"""

    name: Literal["hair follicle"] = "hair follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18771"] = "EMAPA_18771"


class _Hair_Root_Sheath(_MouseAnatomicalStructureModel):
    """Model hair root sheath"""

    name: Literal["hair root sheath"] = "hair root sheath"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18772"] = "EMAPA_18772"


class _Pineal_Gland(_MouseAnatomicalStructureModel):
    """Model pineal gland"""

    name: Literal["pineal gland"] = "pineal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18778"] = "EMAPA_18778"


class _Anterior_Horn_Of_Lateral_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model anterior horn of lateral ventricle choroid plexus"""

    name: Literal[
        "anterior horn of lateral ventricle choroid plexus"
    ] = "anterior horn of lateral ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18779"] = "EMAPA_18779"


class _Lateral_Ventricle_Inferior_Horn_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model lateral ventricle inferior horn choroid plexus"""

    name: Literal["lateral ventricle inferior horn choroid plexus"] = "lateral ventricle inferior horn choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18780"] = "EMAPA_18780"


class _Posterior_Horn_Of_Lateral_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model posterior horn of lateral ventricle choroid plexus"""

    name: Literal[
        "posterior horn of lateral ventricle choroid plexus"
    ] = "posterior horn of lateral ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18781"] = "EMAPA_18781"


class _Superior_Horn_Of_Lateral_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model superior horn of lateral ventricle choroid plexus"""

    name: Literal[
        "superior horn of lateral ventricle choroid plexus"
    ] = "superior horn of lateral ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18782"] = "EMAPA_18782"


class _Head_Of_Lateral_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model head of lateral ventricle choroid plexus"""

    name: Literal["head of lateral ventricle choroid plexus"] = "head of lateral ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18784"] = "EMAPA_18784"


class _Tail_Of_Lateral_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model tail of lateral ventricle choroid plexus"""

    name: Literal["tail of lateral ventricle choroid plexus"] = "tail of lateral ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18785"] = "EMAPA_18785"


class _Medulla_Oblongata_Rest_Of_Basal_Plate(_MouseAnatomicalStructureModel):
    """Model medulla oblongata rest of basal plate"""

    name: Literal["medulla oblongata rest of basal plate"] = "medulla oblongata rest of basal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18786"] = "EMAPA_18786"


class _Medulla_Oblongata_Rest_Of_Basal_Plate_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata rest of basal plate mantle layer"""

    name: Literal[
        "medulla oblongata rest of basal plate mantle layer"
    ] = "medulla oblongata rest of basal plate mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18787"] = "EMAPA_18787"


class _Medulla_Oblongata_Rest_Of_Basal_Plate_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata rest of basal plate marginal layer"""

    name: Literal[
        "medulla oblongata rest of basal plate marginal layer"
    ] = "medulla oblongata rest of basal plate marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18788"] = "EMAPA_18788"


class _Medulla_Oblongata_Rest_Of_Basal_Plate_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata rest of basal plate ventricular layer"""

    name: Literal[
        "medulla oblongata rest of basal plate ventricular layer"
    ] = "medulla oblongata rest of basal plate ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18789"] = "EMAPA_18789"


class _Medullary_Raphe_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model medullary raphe mantle layer"""

    name: Literal["medullary raphe mantle layer"] = "medullary raphe mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18790"] = "EMAPA_18790"


class _Medullary_Raphe_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model medullary raphe marginal layer"""

    name: Literal["medullary raphe marginal layer"] = "medullary raphe marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18791"] = "EMAPA_18791"


class _Medullary_Raphe_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model medullary raphe ventricular layer"""

    name: Literal["medullary raphe ventricular layer"] = "medullary raphe ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18792"] = "EMAPA_18792"


class _Temporal_Lobe(_MouseAnatomicalStructureModel):
    """Model temporal lobe"""

    name: Literal["temporal lobe"] = "temporal lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18797"] = "EMAPA_18797"


class _Temporal_Lobe_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model temporal lobe marginal layer"""

    name: Literal["temporal lobe marginal layer"] = "temporal lobe marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18798"] = "EMAPA_18798"


class _Temporal_Lobe_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model temporal lobe ventricular layer"""

    name: Literal["temporal lobe ventricular layer"] = "temporal lobe ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18799"] = "EMAPA_18799"


class _Axillary_Nerve(_MouseAnatomicalStructureModel):
    """Model axillary nerve"""

    name: Literal["axillary nerve"] = "axillary nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18802"] = "EMAPA_18802"


class _Otic_Cartilage(_MouseAnatomicalStructureModel):
    """Model otic cartilage"""

    name: Literal["otic cartilage"] = "otic cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18803"] = "EMAPA_18803"


class _Descemet_S_Membrane(_MouseAnatomicalStructureModel):
    """Model Descemet's membrane"""

    name: Literal["Descemet's membrane"] = "Descemet's membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18804"] = "EMAPA_18804"


class _Eye_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model eye smooth muscle"""

    name: Literal["eye smooth muscle"] = "eye smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18807"] = "EMAPA_18807"


class _Intrinsic_Ocular_Muscle(_MouseAnatomicalStructureModel):
    """Model intrinsic ocular muscle"""

    name: Literal["intrinsic ocular muscle"] = "intrinsic ocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18808"] = "EMAPA_18808"


class _Sublingual_Gland(_MouseAnatomicalStructureModel):
    """Model sublingual gland"""

    name: Literal["sublingual gland"] = "sublingual gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18809"] = "EMAPA_18809"


class _Sublingual_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model sublingual gland epithelium"""

    name: Literal["sublingual gland epithelium"] = "sublingual gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18810"] = "EMAPA_18810"


class _Sublingual_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model sublingual gland mesenchyme"""

    name: Literal["sublingual gland mesenchyme"] = "sublingual gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18811"] = "EMAPA_18811"


class _Submandibular_Gland(_MouseAnatomicalStructureModel):
    """Model submandibular gland"""

    name: Literal["submandibular gland"] = "submandibular gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18812"] = "EMAPA_18812"


class _Submandibular_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model submandibular gland epithelium"""

    name: Literal["submandibular gland epithelium"] = "submandibular gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18813"] = "EMAPA_18813"


class _Submandibular_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model submandibular gland mesenchyme"""

    name: Literal["submandibular gland mesenchyme"] = "submandibular gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18814"] = "EMAPA_18814"


class _Gut_Gland(_MouseAnatomicalStructureModel):
    """Model gut gland"""

    name: Literal["gut gland"] = "gut gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18815"] = "EMAPA_18815"


class _Anal_Canal_Epithelium(_MouseAnatomicalStructureModel):
    """Model anal canal epithelium"""

    name: Literal["anal canal epithelium"] = "anal canal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18835"] = "EMAPA_18835"


class _Anal_Canal_Lumen(_MouseAnatomicalStructureModel):
    """Model anal canal lumen"""

    name: Literal["anal canal lumen"] = "anal canal lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18836"] = "EMAPA_18836"


class _Anal_Canal_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model anal canal vascular element"""

    name: Literal["anal canal vascular element"] = "anal canal vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18837"] = "EMAPA_18837"


class _Duodenum(_MouseAnatomicalStructureModel):
    """Model duodenum"""

    name: Literal["duodenum"] = "duodenum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18852"] = "EMAPA_18852"


class _Filiform_Papillae(_MouseAnatomicalStructureModel):
    """Model filiform papillae"""

    name: Literal["filiform papillae"] = "filiform papillae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18873"] = "EMAPA_18873"


class _Perineal_Body_Muscle(_MouseAnatomicalStructureModel):
    """Model perineal body muscle"""

    name: Literal["perineal body muscle"] = "perineal body muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18923"] = "EMAPA_18923"


class _Colon(_MouseAnatomicalStructureModel):
    """Model colon"""

    name: Literal["colon"] = "colon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18939"] = "EMAPA_18939"


class _Colon_Epithelium(_MouseAnatomicalStructureModel):
    """Model colon epithelium"""

    name: Literal["colon epithelium"] = "colon epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18941"] = "EMAPA_18941"


class _Colon_Mesentery(_MouseAnatomicalStructureModel):
    """Model colon mesentery"""

    name: Literal["colon mesentery"] = "colon mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18942"] = "EMAPA_18942"


class _Colon_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model colon dorsal mesentery"""

    name: Literal["colon dorsal mesentery"] = "colon dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18943"] = "EMAPA_18943"


class _Colon_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model colon vascular element"""

    name: Literal["colon vascular element"] = "colon vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18944"] = "EMAPA_18944"


class _Colon_Lumen(_MouseAnatomicalStructureModel):
    """Model colon lumen"""

    name: Literal["colon lumen"] = "colon lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18945"] = "EMAPA_18945"


class _Secondary_Palate(_MouseAnatomicalStructureModel):
    """Model secondary palate"""

    name: Literal["secondary palate"] = "secondary palate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18948"] = "EMAPA_18948"


class _Soft_Palate(_MouseAnatomicalStructureModel):
    """Model soft palate"""

    name: Literal["soft palate"] = "soft palate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18949"] = "EMAPA_18949"


class _Soft_Palate_Epithelium(_MouseAnatomicalStructureModel):
    """Model soft palate epithelium"""

    name: Literal["soft palate epithelium"] = "soft palate epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18950"] = "EMAPA_18950"


class _Soft_Palate_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model soft palate mesenchyme"""

    name: Literal["soft palate mesenchyme"] = "soft palate mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18951"] = "EMAPA_18951"


class _Hard_Palate(_MouseAnatomicalStructureModel):
    """Model hard palate"""

    name: Literal["hard palate"] = "hard palate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18952"] = "EMAPA_18952"


class _Hard_Palate_Epithelium(_MouseAnatomicalStructureModel):
    """Model hard palate epithelium"""

    name: Literal["hard palate epithelium"] = "hard palate epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18953"] = "EMAPA_18953"


class _Hard_Palate_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hard palate mesenchyme"""

    name: Literal["hard palate mesenchyme"] = "hard palate mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18954"] = "EMAPA_18954"


class _Nasopalatine_Duct(_MouseAnatomicalStructureModel):
    """Model nasopalatine duct"""

    name: Literal["nasopalatine duct"] = "nasopalatine duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18955"] = "EMAPA_18955"


class _Sublingual_Caruncle(_MouseAnatomicalStructureModel):
    """Model sublingual caruncle"""

    name: Literal["sublingual caruncle"] = "sublingual caruncle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18961"] = "EMAPA_18961"


class _Sulcus_Terminalis(_MouseAnatomicalStructureModel):
    """Model sulcus terminalis"""

    name: Literal["sulcus terminalis"] = "sulcus terminalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18962"] = "EMAPA_18962"


class _Pharynx_Skeletal_Muscle(_MouseAnatomicalStructureModel):
    """Model pharynx skeletal muscle"""

    name: Literal["pharynx skeletal muscle"] = "pharynx skeletal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18963"] = "EMAPA_18963"


class _Pharyngeal_Constrictor_Muscle(_MouseAnatomicalStructureModel):
    """Model pharyngeal constrictor muscle"""

    name: Literal["pharyngeal constrictor muscle"] = "pharyngeal constrictor muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18964"] = "EMAPA_18964"


class _Inferior_Pharyngeal_Constrictor_Muscle(_MouseAnatomicalStructureModel):
    """Model inferior pharyngeal constrictor muscle"""

    name: Literal["inferior pharyngeal constrictor muscle"] = "inferior pharyngeal constrictor muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18965"] = "EMAPA_18965"


class _Superior_Pharyngeal_Constrictor_Muscle(_MouseAnatomicalStructureModel):
    """Model superior pharyngeal constrictor muscle"""

    name: Literal["superior pharyngeal constrictor muscle"] = "superior pharyngeal constrictor muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18966"] = "EMAPA_18966"


class _Lower_Jaw_Gum(_MouseAnatomicalStructureModel):
    """Model lower jaw gum"""

    name: Literal["lower jaw gum"] = "lower jaw gum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18967"] = "EMAPA_18967"


class _Lower_Jaw_Gum_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower jaw gum epithelium"""

    name: Literal["lower jaw gum epithelium"] = "lower jaw gum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18968"] = "EMAPA_18968"


class _Lower_Jaw_Gum_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower jaw gum mesenchyme"""

    name: Literal["lower jaw gum mesenchyme"] = "lower jaw gum mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18969"] = "EMAPA_18969"


class _Upper_Jaw_Gum(_MouseAnatomicalStructureModel):
    """Model upper jaw gum"""

    name: Literal["upper jaw gum"] = "upper jaw gum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18970"] = "EMAPA_18970"


class _Upper_Jaw_Gum_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper jaw gum epithelium"""

    name: Literal["upper jaw gum epithelium"] = "upper jaw gum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18971"] = "EMAPA_18971"


class _Upper_Jaw_Gum_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper jaw gum mesenchyme"""

    name: Literal["upper jaw gum mesenchyme"] = "upper jaw gum mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18972"] = "EMAPA_18972"


class _Cortical_Renal_Tubule(_MouseAnatomicalStructureModel):
    """Model cortical renal tubule"""

    name: Literal["cortical renal tubule"] = "cortical renal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18976"] = "EMAPA_18976"


class _Female_Cystic_Vesicular_Appendage(_MouseAnatomicalStructureModel):
    """Model female cystic vesicular appendage"""

    name: Literal["female cystic vesicular appendage"] = "female cystic vesicular appendage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18978"] = "EMAPA_18978"


class _Oviduct(_MouseAnatomicalStructureModel):
    """Model oviduct"""

    name: Literal["oviduct"] = "oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18984"] = "EMAPA_18984"


class _Uterine_Horn(_MouseAnatomicalStructureModel):
    """Model uterine horn"""

    name: Literal["uterine horn"] = "uterine horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18985"] = "EMAPA_18985"


class _Vagina(_MouseAnatomicalStructureModel):
    """Model vagina"""

    name: Literal["vagina"] = "vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18986"] = "EMAPA_18986"


class _Upper_Vagina(_MouseAnatomicalStructureModel):
    """Model upper vagina"""

    name: Literal["upper vagina"] = "upper vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18987"] = "EMAPA_18987"


class _Glans_Penis(_MouseAnatomicalStructureModel):
    """Model glans penis"""

    name: Literal["glans penis"] = "glans penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18988"] = "EMAPA_18988"


class _Prepuce_Of_Male(_MouseAnatomicalStructureModel):
    """Model prepuce of male"""

    name: Literal["prepuce of male"] = "prepuce of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18989"] = "EMAPA_18989"


class _Efferent_Duct_Of_Seminal_Vesicle(_MouseAnatomicalStructureModel):
    """Model efferent duct of seminal vesicle"""

    name: Literal["efferent duct of seminal vesicle"] = "efferent duct of seminal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18993"] = "EMAPA_18993"


class _Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model pelvic urethra of male"""

    name: Literal["pelvic urethra of male"] = "pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18995"] = "EMAPA_18995"


class _Sinovaginal_Bulb(_MouseAnatomicalStructureModel):
    """Model sinovaginal bulb"""

    name: Literal["sinovaginal bulb"] = "sinovaginal bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_18999"] = "EMAPA_18999"


class _Left_Lung_Bronchiole(_MouseAnatomicalStructureModel):
    """Model left lung bronchiole"""

    name: Literal["left lung bronchiole"] = "left lung bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19000"] = "EMAPA_19000"


class _Left_Lung_Alveolar_System(_MouseAnatomicalStructureModel):
    """Model left lung alveolar system"""

    name: Literal["left lung alveolar system"] = "left lung alveolar system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19001"] = "EMAPA_19001"


class _Right_Lung_Accessory_Lobe_Bronchiole(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe bronchiole"""

    name: Literal["right lung accessory lobe bronchiole"] = "right lung accessory lobe bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19002"] = "EMAPA_19002"


class _Right_Lung_Accessory_Lobe_Alveolar_System(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe alveolar system"""

    name: Literal["right lung accessory lobe alveolar system"] = "right lung accessory lobe alveolar system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19003"] = "EMAPA_19003"


class _Right_Lung_Caudal_Lobe_Bronchiole(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe bronchiole"""

    name: Literal["right lung caudal lobe bronchiole"] = "right lung caudal lobe bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19004"] = "EMAPA_19004"


class _Right_Lung_Caudal_Lobe_Alveolar_System(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe alveolar system"""

    name: Literal["right lung caudal lobe alveolar system"] = "right lung caudal lobe alveolar system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19005"] = "EMAPA_19005"


class _Right_Lung_Cranial_Lobe_Bronchiole(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe bronchiole"""

    name: Literal["right lung cranial lobe bronchiole"] = "right lung cranial lobe bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19006"] = "EMAPA_19006"


class _Right_Lung_Cranial_Lobe_Alveolar_System(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe alveolar system"""

    name: Literal["right lung cranial lobe alveolar system"] = "right lung cranial lobe alveolar system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19007"] = "EMAPA_19007"


class _Right_Lung_Middle_Lobe_Bronchiole(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe bronchiole"""

    name: Literal["right lung middle lobe bronchiole"] = "right lung middle lobe bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19008"] = "EMAPA_19008"


class _Right_Lung_Middle_Lobe_Alveolar_System(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe alveolar system"""

    name: Literal["right lung middle lobe alveolar system"] = "right lung middle lobe alveolar system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19009"] = "EMAPA_19009"


class _Cruciate_Ligament_Of_Atlas(_MouseAnatomicalStructureModel):
    """Model cruciate ligament of atlas"""

    name: Literal["cruciate ligament of atlas"] = "cruciate ligament of atlas"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19010"] = "EMAPA_19010"


class _Hypoglossal_Canal(_MouseAnatomicalStructureModel):
    """Model hypoglossal canal"""

    name: Literal["hypoglossal canal"] = "hypoglossal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19012"] = "EMAPA_19012"


class _Sphenoidal_Canal(_MouseAnatomicalStructureModel):
    """Model sphenoidal canal"""

    name: Literal["sphenoidal canal"] = "sphenoidal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19013"] = "EMAPA_19013"


class _Zygomatic_Process(_MouseAnatomicalStructureModel):
    """Model zygomatic process"""

    name: Literal["zygomatic process"] = "zygomatic process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19015"] = "EMAPA_19015"


class _Frontal_Bone(_MouseAnatomicalStructureModel):
    """Model frontal bone"""

    name: Literal["frontal bone"] = "frontal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19016"] = "EMAPA_19016"


class _Inter_Parietal_Bone(_MouseAnatomicalStructureModel):
    """Model inter-parietal bone"""

    name: Literal["inter-parietal bone"] = "inter-parietal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19017"] = "EMAPA_19017"


class _Ethmoid_Bone(_MouseAnatomicalStructureModel):
    """Model ethmoid bone"""

    name: Literal["ethmoid bone"] = "ethmoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19018"] = "EMAPA_19018"


class _Facial_Bone(_MouseAnatomicalStructureModel):
    """Model facial bone"""

    name: Literal["facial bone"] = "facial bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19019"] = "EMAPA_19019"


class _Costo_Vertebral_Joint(_MouseAnatomicalStructureModel):
    """Model costo-vertebral joint"""

    name: Literal["costo-vertebral joint"] = "costo-vertebral joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19020"] = "EMAPA_19020"


class _Synovial_Cavity_Of_Hip_Bone(_MouseAnatomicalStructureModel):
    """Model synovial cavity of hip bone"""

    name: Literal["synovial cavity of hip bone"] = "synovial cavity of hip bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19021"] = "EMAPA_19021"


class _Temporal_Lobe_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model temporal lobe mantle layer"""

    name: Literal["temporal lobe mantle layer"] = "temporal lobe mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19026"] = "EMAPA_19026"


class _Sclera(_MouseAnatomicalStructureModel):
    """Model sclera"""

    name: Literal["sclera"] = "sclera"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19027"] = "EMAPA_19027"


class _Peyer_S_Patch(_MouseAnatomicalStructureModel):
    """Model Peyer's patch"""

    name: Literal["Peyer's patch"] = "Peyer's patch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19028"] = "EMAPA_19028"


class _Fibrous_Pericardium(_MouseAnatomicalStructureModel):
    """Model fibrous pericardium"""

    name: Literal["fibrous pericardium"] = "fibrous pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19029"] = "EMAPA_19029"


class _Serosal_Pericardium(_MouseAnatomicalStructureModel):
    """Model serosal pericardium"""

    name: Literal["serosal pericardium"] = "serosal pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19030"] = "EMAPA_19030"


class _Parietal_Serosal_Pericardium(_MouseAnatomicalStructureModel):
    """Model parietal serosal pericardium"""

    name: Literal["parietal serosal pericardium"] = "parietal serosal pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19031"] = "EMAPA_19031"


class _Visceral_Serosal_Pericardium(_MouseAnatomicalStructureModel):
    """Model visceral serosal pericardium"""

    name: Literal["visceral serosal pericardium"] = "visceral serosal pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19032"] = "EMAPA_19032"


class _Incisive_Canal(_MouseAnatomicalStructureModel):
    """Model incisive canal"""

    name: Literal["incisive canal"] = "incisive canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19034"] = "EMAPA_19034"


class _C1_Vertebra_Hypochordal_Arch(_MouseAnatomicalStructureModel):
    """Model C1 vertebra hypochordal arch"""

    name: Literal["C1 vertebra hypochordal arch"] = "C1 vertebra hypochordal arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19035"] = "EMAPA_19035"


class _Pineal_Gland_Stalk(_MouseAnatomicalStructureModel):
    """Model pineal gland stalk"""

    name: Literal["pineal gland stalk"] = "pineal gland stalk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19036"] = "EMAPA_19036"


class _Dentate_Gyrus(_MouseAnatomicalStructureModel):
    """Model dentate gyrus"""

    name: Literal["dentate gyrus"] = "dentate gyrus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19037"] = "EMAPA_19037"


class _Anterior_Commissure(_MouseAnatomicalStructureModel):
    """Model anterior commissure"""

    name: Literal["anterior commissure"] = "anterior commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19038"] = "EMAPA_19038"


class _Hippocampus_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model hippocampus mantle layer"""

    name: Literal["hippocampus mantle layer"] = "hippocampus mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19040"] = "EMAPA_19040"


class _Hippocampus_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model hippocampus marginal layer"""

    name: Literal["hippocampus marginal layer"] = "hippocampus marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19041"] = "EMAPA_19041"


class _Allocortex(_MouseAnatomicalStructureModel):
    """Model allocortex"""

    name: Literal["allocortex"] = "allocortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19042"] = "EMAPA_19042"


class _Hippocampus_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model hippocampus ventricular layer"""

    name: Literal["hippocampus ventricular layer"] = "hippocampus ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19043"] = "EMAPA_19043"


class _Allocortex_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model allocortex mantle layer"""

    name: Literal["allocortex mantle layer"] = "allocortex mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19044"] = "EMAPA_19044"


class _Allocortex_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model allocortex marginal layer"""

    name: Literal["allocortex marginal layer"] = "allocortex marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19045"] = "EMAPA_19045"


class _Allocortex_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model allocortex ventricular layer"""

    name: Literal["allocortex ventricular layer"] = "allocortex ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19046"] = "EMAPA_19046"


class _Cerebellum_Dorsal_Part(_MouseAnatomicalStructureModel):
    """Model cerebellum dorsal part"""

    name: Literal["cerebellum dorsal part"] = "cerebellum dorsal part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19047"] = "EMAPA_19047"


class _Cerebellum_Dorsal_Part_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum dorsal part mantle layer"""

    name: Literal["cerebellum dorsal part mantle layer"] = "cerebellum dorsal part mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19048"] = "EMAPA_19048"


class _Cerebellum_Dorsal_Part_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum dorsal part marginal layer"""

    name: Literal["cerebellum dorsal part marginal layer"] = "cerebellum dorsal part marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19049"] = "EMAPA_19049"


class _Cerebellum_Dorsal_Part_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum dorsal part ventricular layer"""

    name: Literal["cerebellum dorsal part ventricular layer"] = "cerebellum dorsal part ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19050"] = "EMAPA_19050"


class _Tectum(_MouseAnatomicalStructureModel):
    """Model tectum"""

    name: Literal["tectum"] = "tectum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19051"] = "EMAPA_19051"


class _Midbrain_Roof_Plate_Caudal_Part(_MouseAnatomicalStructureModel):
    """Model midbrain roof plate caudal part"""

    name: Literal["midbrain roof plate caudal part"] = "midbrain roof plate caudal part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19052"] = "EMAPA_19052"


class _Diencephalon_Subarachnoid_Space(_MouseAnatomicalStructureModel):
    """Model diencephalon subarachnoid space"""

    name: Literal["diencephalon subarachnoid space"] = "diencephalon subarachnoid space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19053"] = "EMAPA_19053"


class _Telencephalon_Subarachnoid_Space(_MouseAnatomicalStructureModel):
    """Model telencephalon subarachnoid space"""

    name: Literal["telencephalon subarachnoid space"] = "telencephalon subarachnoid space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19054"] = "EMAPA_19054"


class _Midbrain_Subarachnoid_Space(_MouseAnatomicalStructureModel):
    """Model midbrain subarachnoid space"""

    name: Literal["midbrain subarachnoid space"] = "midbrain subarachnoid space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19055"] = "EMAPA_19055"


class _Interpeduncular_Cistern(_MouseAnatomicalStructureModel):
    """Model interpeduncular cistern"""

    name: Literal["interpeduncular cistern"] = "interpeduncular cistern"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19056"] = "EMAPA_19056"


class _Cisterna_Chiasmatica(_MouseAnatomicalStructureModel):
    """Model cisterna chiasmatica"""

    name: Literal["cisterna chiasmatica"] = "cisterna chiasmatica"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19057"] = "EMAPA_19057"


class _Cavernous_Sinus(_MouseAnatomicalStructureModel):
    """Model cavernous sinus"""

    name: Literal["cavernous sinus"] = "cavernous sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19059"] = "EMAPA_19059"


class _Sigmoid_Sinus(_MouseAnatomicalStructureModel):
    """Model sigmoid sinus"""

    name: Literal["sigmoid sinus"] = "sigmoid sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19060"] = "EMAPA_19060"


class _Organ_Of_Corti(_MouseAnatomicalStructureModel):
    """Model organ of Corti"""

    name: Literal["organ of Corti"] = "organ of Corti"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19061"] = "EMAPA_19061"


class _Tympanic_Membrane(_MouseAnatomicalStructureModel):
    """Model tympanic membrane"""

    name: Literal["tympanic membrane"] = "tympanic membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19062"] = "EMAPA_19062"


class _Tympanic_Membrane_Endothelium(_MouseAnatomicalStructureModel):
    """Model tympanic membrane endothelium"""

    name: Literal["tympanic membrane endothelium"] = "tympanic membrane endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19063"] = "EMAPA_19063"


class _Tympanic_Membrane_Epithelium(_MouseAnatomicalStructureModel):
    """Model tympanic membrane epithelium"""

    name: Literal["tympanic membrane epithelium"] = "tympanic membrane epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19064"] = "EMAPA_19064"


class _Ciliary_Body(_MouseAnatomicalStructureModel):
    """Model ciliary body"""

    name: Literal["ciliary body"] = "ciliary body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19065"] = "EMAPA_19065"


class _Medulla_Oblongata_Part_Of_4Th_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model medulla oblongata part of 4th ventricle choroid plexus"""

    name: Literal[
        "medulla oblongata part of 4th ventricle choroid plexus"
    ] = "medulla oblongata part of 4th ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19074"] = "EMAPA_19074"


class _Optic_Choroid(_MouseAnatomicalStructureModel):
    """Model optic choroid"""

    name: Literal["optic choroid"] = "optic choroid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19077"] = "EMAPA_19077"


class _Duodenum_Epithelium(_MouseAnatomicalStructureModel):
    """Model duodenum epithelium"""

    name: Literal["duodenum epithelium"] = "duodenum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19078"] = "EMAPA_19078"


class _Duodenum_Lumen(_MouseAnatomicalStructureModel):
    """Model duodenum lumen"""

    name: Literal["duodenum lumen"] = "duodenum lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19080"] = "EMAPA_19080"


class _Duodenum_Mesentery(_MouseAnatomicalStructureModel):
    """Model duodenum mesentery"""

    name: Literal["duodenum mesentery"] = "duodenum mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19081"] = "EMAPA_19081"


class _Mesoduodenum(_MouseAnatomicalStructureModel):
    """Model mesoduodenum"""

    name: Literal["mesoduodenum"] = "mesoduodenum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19082"] = "EMAPA_19082"


class _Duodenum_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model duodenum vascular element"""

    name: Literal["duodenum vascular element"] = "duodenum vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19083"] = "EMAPA_19083"


class _Gastro_Esophageal_Junction_Mesentery(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction mesentery"""

    name: Literal["gastro-esophageal junction mesentery"] = "gastro-esophageal junction mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19084"] = "EMAPA_19084"


class _Suspensory_Ligament_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model suspensory ligament of ovary"""

    name: Literal["suspensory ligament of ovary"] = "suspensory ligament of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19085"] = "EMAPA_19085"


class _Appendix_Epididymis(_MouseAnatomicalStructureModel):
    """Model appendix epididymis"""

    name: Literal["appendix epididymis"] = "appendix epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19086"] = "EMAPA_19086"


class _Appendix_Testis(_MouseAnatomicalStructureModel):
    """Model appendix testis"""

    name: Literal["appendix testis"] = "appendix testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19087"] = "EMAPA_19087"


class _Ejaculatory_Duct(_MouseAnatomicalStructureModel):
    """Model ejaculatory duct"""

    name: Literal["ejaculatory duct"] = "ejaculatory duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19088"] = "EMAPA_19088"


class _Gubernaculum_Of_Male(_MouseAnatomicalStructureModel):
    """Model gubernaculum of male"""

    name: Literal["gubernaculum of male"] = "gubernaculum of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19089"] = "EMAPA_19089"


class _Larynx_Aditus(_MouseAnatomicalStructureModel):
    """Model larynx aditus"""

    name: Literal["larynx aditus"] = "larynx aditus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19091"] = "EMAPA_19091"


class _Main_Bronchus_Cartilage(_MouseAnatomicalStructureModel):
    """Model main bronchus cartilage"""

    name: Literal["main bronchus cartilage"] = "main bronchus cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19092"] = "EMAPA_19092"


class _Caudate_Putamen(_MouseAnatomicalStructureModel):
    """Model caudate-putamen"""

    name: Literal["caudate-putamen"] = "caudate-putamen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19095"] = "EMAPA_19095"


class _Lumbar_Artery(_MouseAnatomicalStructureModel):
    """Model lumbar artery"""

    name: Literal["lumbar artery"] = "lumbar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19096"] = "EMAPA_19096"


class _Subcostal_Artery(_MouseAnatomicalStructureModel):
    """Model subcostal artery"""

    name: Literal["subcostal artery"] = "subcostal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19097"] = "EMAPA_19097"


class _Rest_Of_Upper_Lip(_MouseAnatomicalStructureModel):
    """Model rest of upper lip"""

    name: Literal["rest of upper lip"] = "rest of upper lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19098"] = "EMAPA_19098"


class _Left_Hepatic_Duct_Extrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model left hepatic duct extrahepatic part"""

    name: Literal["left hepatic duct extrahepatic part"] = "left hepatic duct extrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19099"] = "EMAPA_19099"


class _Right_Hepatic_Duct_Extrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model right hepatic duct extrahepatic part"""

    name: Literal["right hepatic duct extrahepatic part"] = "right hepatic duct extrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19100"] = "EMAPA_19100"


class _Common_Hepatic_Duct(_MouseAnatomicalStructureModel):
    """Model common hepatic duct"""

    name: Literal["common hepatic duct"] = "common hepatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19101"] = "EMAPA_19101"


class _Elbow_Joint(_MouseAnatomicalStructureModel):
    """Model elbow joint"""

    name: Literal["elbow joint"] = "elbow joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19102"] = "EMAPA_19102"


class _Radius(_MouseAnatomicalStructureModel):
    """Model radius"""

    name: Literal["radius"] = "radius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19103"] = "EMAPA_19103"


class _Ulna(_MouseAnatomicalStructureModel):
    """Model ulna"""

    name: Literal["ulna"] = "ulna"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19104"] = "EMAPA_19104"


class _Shoulder_Joint(_MouseAnatomicalStructureModel):
    """Model shoulder joint"""

    name: Literal["shoulder joint"] = "shoulder joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19105"] = "EMAPA_19105"


class _Humerus(_MouseAnatomicalStructureModel):
    """Model humerus"""

    name: Literal["humerus"] = "humerus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19106"] = "EMAPA_19106"


class _Upper_Arm_Muscle(_MouseAnatomicalStructureModel):
    """Model upper arm muscle"""

    name: Literal["upper arm muscle"] = "upper arm muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19107"] = "EMAPA_19107"


class _Biceps_Brachii(_MouseAnatomicalStructureModel):
    """Model biceps brachii"""

    name: Literal["biceps brachii"] = "biceps brachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19108"] = "EMAPA_19108"


class _Brachialis(_MouseAnatomicalStructureModel):
    """Model brachialis"""

    name: Literal["brachialis"] = "brachialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19109"] = "EMAPA_19109"


class _Teres_Major(_MouseAnatomicalStructureModel):
    """Model teres major"""

    name: Literal["teres major"] = "teres major"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19110"] = "EMAPA_19110"


class _Triceps_Brachii(_MouseAnatomicalStructureModel):
    """Model triceps brachii"""

    name: Literal["triceps brachii"] = "triceps brachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19111"] = "EMAPA_19111"


class _Forelimb_Digit_1_Metacarpal(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 metacarpal"""

    name: Literal["forelimb digit 1 metacarpal"] = "forelimb digit 1 metacarpal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19112"] = "EMAPA_19112"


class _Forelimb_Digit_1_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 phalanx"""

    name: Literal["forelimb digit 1 phalanx"] = "forelimb digit 1 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19113"] = "EMAPA_19113"


class _Forelimb_Digit_2_Metacarpal(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 metacarpal"""

    name: Literal["forelimb digit 2 metacarpal"] = "forelimb digit 2 metacarpal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19114"] = "EMAPA_19114"


class _Forelimb_Digit_2_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 phalanx"""

    name: Literal["forelimb digit 2 phalanx"] = "forelimb digit 2 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19115"] = "EMAPA_19115"


class _Forelimb_Digit_3_Metacarpal(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 metacarpal"""

    name: Literal["forelimb digit 3 metacarpal"] = "forelimb digit 3 metacarpal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19116"] = "EMAPA_19116"


class _Forelimb_Digit_3_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 phalanx"""

    name: Literal["forelimb digit 3 phalanx"] = "forelimb digit 3 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19117"] = "EMAPA_19117"


class _Forelimb_Digit_4_Metacarpal(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 metacarpal"""

    name: Literal["forelimb digit 4 metacarpal"] = "forelimb digit 4 metacarpal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19118"] = "EMAPA_19118"


class _Forelimb_Digit_4_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 phalanx"""

    name: Literal["forelimb digit 4 phalanx"] = "forelimb digit 4 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19119"] = "EMAPA_19119"


class _Forelimb_Digit_5_Metacarpal(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 metacarpal"""

    name: Literal["forelimb digit 5 metacarpal"] = "forelimb digit 5 metacarpal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19120"] = "EMAPA_19120"


class _Forelimb_Digit_5_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 phalanx"""

    name: Literal["forelimb digit 5 phalanx"] = "forelimb digit 5 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19121"] = "EMAPA_19121"


class _Carpus(_MouseAnatomicalStructureModel):
    """Model carpus"""

    name: Literal["carpus"] = "carpus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19122"] = "EMAPA_19122"


class _Hindlimb_Digit_1_Metatarsal(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 metatarsal"""

    name: Literal["hindlimb digit 1 metatarsal"] = "hindlimb digit 1 metatarsal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19123"] = "EMAPA_19123"


class _Hindlimb_Digit_1_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 phalanx"""

    name: Literal["hindlimb digit 1 phalanx"] = "hindlimb digit 1 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19124"] = "EMAPA_19124"


class _Hindlimb_Digit_2_Metatarsal(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 metatarsal"""

    name: Literal["hindlimb digit 2 metatarsal"] = "hindlimb digit 2 metatarsal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19125"] = "EMAPA_19125"


class _Hindlimb_Digit_2_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 phalanx"""

    name: Literal["hindlimb digit 2 phalanx"] = "hindlimb digit 2 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19126"] = "EMAPA_19126"


class _Hindlimb_Digit_3_Metatarsal(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 metatarsal"""

    name: Literal["hindlimb digit 3 metatarsal"] = "hindlimb digit 3 metatarsal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19127"] = "EMAPA_19127"


class _Hindlimb_Digit_3_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 phalanx"""

    name: Literal["hindlimb digit 3 phalanx"] = "hindlimb digit 3 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19128"] = "EMAPA_19128"


class _Hindlimb_Digit_4_Metatarsal(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 metatarsal"""

    name: Literal["hindlimb digit 4 metatarsal"] = "hindlimb digit 4 metatarsal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19129"] = "EMAPA_19129"


class _Hindlimb_Digit_4_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 phalanx"""

    name: Literal["hindlimb digit 4 phalanx"] = "hindlimb digit 4 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19130"] = "EMAPA_19130"


class _Hindlimb_Digit_5_Metatarsal(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 metatarsal"""

    name: Literal["hindlimb digit 5 metatarsal"] = "hindlimb digit 5 metatarsal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19131"] = "EMAPA_19131"


class _Hindlimb_Digit_5_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 phalanx"""

    name: Literal["hindlimb digit 5 phalanx"] = "hindlimb digit 5 phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19132"] = "EMAPA_19132"


class _Tarsus(_MouseAnatomicalStructureModel):
    """Model tarsus"""

    name: Literal["tarsus"] = "tarsus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19133"] = "EMAPA_19133"


class _Calcaneus(_MouseAnatomicalStructureModel):
    """Model calcaneus"""

    name: Literal["calcaneus"] = "calcaneus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19134"] = "EMAPA_19134"


class _Talus(_MouseAnatomicalStructureModel):
    """Model talus"""

    name: Literal["talus"] = "talus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19135"] = "EMAPA_19135"


class _Hip_Joint(_MouseAnatomicalStructureModel):
    """Model hip joint"""

    name: Literal["hip joint"] = "hip joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19136"] = "EMAPA_19136"


class _Knee_Joint(_MouseAnatomicalStructureModel):
    """Model knee joint"""

    name: Literal["knee joint"] = "knee joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19137"] = "EMAPA_19137"


class _Fabella_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model fabella cartilage condensation"""

    name: Literal["fabella cartilage condensation"] = "fabella cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19138"] = "EMAPA_19138"


class _Patella_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model patella cartilage condensation"""

    name: Literal["patella cartilage condensation"] = "patella cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19140"] = "EMAPA_19140"


class _Fibula(_MouseAnatomicalStructureModel):
    """Model fibula"""

    name: Literal["fibula"] = "fibula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19141"] = "EMAPA_19141"


class _Tibia(_MouseAnatomicalStructureModel):
    """Model tibia"""

    name: Literal["tibia"] = "tibia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19142"] = "EMAPA_19142"


class _Femur(_MouseAnatomicalStructureModel):
    """Model femur"""

    name: Literal["femur"] = "femur"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19143"] = "EMAPA_19143"


class _Upper_Leg_Muscle(_MouseAnatomicalStructureModel):
    """Model upper leg muscle"""

    name: Literal["upper leg muscle"] = "upper leg muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19144"] = "EMAPA_19144"


class _Hamstring_Muscle(_MouseAnatomicalStructureModel):
    """Model hamstring muscle"""

    name: Literal["hamstring muscle"] = "hamstring muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19145"] = "EMAPA_19145"


class _Quadriceps_Femoris_Muscle(_MouseAnatomicalStructureModel):
    """Model quadriceps femoris muscle"""

    name: Literal["quadriceps femoris muscle"] = "quadriceps femoris muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19146"] = "EMAPA_19146"


class _Lenticular_Nucleus(_MouseAnatomicalStructureModel):
    """Model lenticular nucleus"""

    name: Literal["lenticular nucleus"] = "lenticular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19147"] = "EMAPA_19147"


class _Orbital_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model orbital fat pad"""

    name: Literal["orbital fat pad"] = "orbital fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19152"] = "EMAPA_19152"


class _Harderian_Gland(_MouseAnatomicalStructureModel):
    """Model Harderian gland"""

    name: Literal["Harderian gland"] = "Harderian gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19153"] = "EMAPA_19153"


class _Iris(_MouseAnatomicalStructureModel):
    """Model iris"""

    name: Literal["iris"] = "iris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19154"] = "EMAPA_19154"


class _Retina_Inner_Nuclear_Layer(_MouseAnatomicalStructureModel):
    """Model retina inner nuclear layer"""

    name: Literal["retina inner nuclear layer"] = "retina inner nuclear layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19155"] = "EMAPA_19155"


class _Neural_Retina_Intermediate_Anuclear_Layer(_MouseAnatomicalStructureModel):
    """Model neural retina intermediate anuclear layer"""

    name: Literal["neural retina intermediate anuclear layer"] = "neural retina intermediate anuclear layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19156"] = "EMAPA_19156"


class _Retina_Outer_Nuclear_Layer(_MouseAnatomicalStructureModel):
    """Model retina outer nuclear layer"""

    name: Literal["retina outer nuclear layer"] = "retina outer nuclear layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19157"] = "EMAPA_19157"


class _Pectinate_Line(_MouseAnatomicalStructureModel):
    """Model pectinate line"""

    name: Literal["pectinate line"] = "pectinate line"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19159"] = "EMAPA_19159"


class _Coronary_Artery(_MouseAnatomicalStructureModel):
    """Model coronary artery"""

    name: Literal["coronary artery"] = "coronary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19160"] = "EMAPA_19160"


class _Mandibular_Canal(_MouseAnatomicalStructureModel):
    """Model mandibular canal"""

    name: Literal["mandibular canal"] = "mandibular canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19161"] = "EMAPA_19161"


class _Gluteus_Medius(_MouseAnatomicalStructureModel):
    """Model gluteus medius"""

    name: Literal["gluteus medius"] = "gluteus medius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19163"] = "EMAPA_19163"


class _Iliacus(_MouseAnatomicalStructureModel):
    """Model iliacus"""

    name: Literal["iliacus"] = "iliacus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19164"] = "EMAPA_19164"


class _Levator_Ani(_MouseAnatomicalStructureModel):
    """Model levator ani"""

    name: Literal["levator ani"] = "levator ani"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19165"] = "EMAPA_19165"


class _Adductor_Muscle_Of_Leg(_MouseAnatomicalStructureModel):
    """Model adductor muscle of leg"""

    name: Literal["adductor muscle of leg"] = "adductor muscle of leg"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19166"] = "EMAPA_19166"


class _Trigeminal_Nerve_Lingual_Branch(_MouseAnatomicalStructureModel):
    """Model trigeminal nerve lingual branch"""

    name: Literal["trigeminal nerve lingual branch"] = "trigeminal nerve lingual branch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19168"] = "EMAPA_19168"


class _Glans_Of_Female_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model glans of female genital tubercle"""

    name: Literal["glans of female genital tubercle"] = "glans of female genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19170"] = "EMAPA_19170"


class _Female_Inguinal_Canal(_MouseAnatomicalStructureModel):
    """Model female inguinal canal"""

    name: Literal["female inguinal canal"] = "female inguinal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19171"] = "EMAPA_19171"


class _Female_Inguinal_Ring(_MouseAnatomicalStructureModel):
    """Model female inguinal ring"""

    name: Literal["female inguinal ring"] = "female inguinal ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19172"] = "EMAPA_19172"


class _Female_Internal_Inguinal_Ring(_MouseAnatomicalStructureModel):
    """Model female internal inguinal ring"""

    name: Literal["female internal inguinal ring"] = "female internal inguinal ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19173"] = "EMAPA_19173"


class _Female_External_Inguinal_Ring(_MouseAnatomicalStructureModel):
    """Model female external inguinal ring"""

    name: Literal["female external inguinal ring"] = "female external inguinal ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19174"] = "EMAPA_19174"


class _Rest_Of_Interstitium_Of_The_Testis(_MouseAnatomicalStructureModel):
    """Model rest of interstitium of the testis"""

    name: Literal["rest of interstitium of the testis"] = "rest of interstitium of the testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19176"] = "EMAPA_19176"


class _Tunica_Vaginalis_Testis(_MouseAnatomicalStructureModel):
    """Model tunica vaginalis testis"""

    name: Literal["tunica vaginalis testis"] = "tunica vaginalis testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19179"] = "EMAPA_19179"


class _Seminal_Vesicle(_MouseAnatomicalStructureModel):
    """Model seminal vesicle"""

    name: Literal["seminal vesicle"] = "seminal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19180"] = "EMAPA_19180"


class _Vocal_Folds(_MouseAnatomicalStructureModel):
    """Model vocal folds"""

    name: Literal["vocal folds"] = "vocal folds"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19181"] = "EMAPA_19181"


class _Left_Lung_Alveolus(_MouseAnatomicalStructureModel):
    """Model left lung alveolus"""

    name: Literal["left lung alveolus"] = "left lung alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19182"] = "EMAPA_19182"


class _Left_Lung_Alveolar_Duct(_MouseAnatomicalStructureModel):
    """Model left lung alveolar duct"""

    name: Literal["left lung alveolar duct"] = "left lung alveolar duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19183"] = "EMAPA_19183"


class _Right_Lung_Middle_Lobe_Alveolus(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe alveolus"""

    name: Literal["right lung middle lobe alveolus"] = "right lung middle lobe alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19184"] = "EMAPA_19184"


class _Right_Lung_Middle_Lobe_Alveolar_Duct(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe alveolar duct"""

    name: Literal["right lung middle lobe alveolar duct"] = "right lung middle lobe alveolar duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19185"] = "EMAPA_19185"


class _Right_Lung_Cranial_Lobe_Alveolus(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe alveolus"""

    name: Literal["right lung cranial lobe alveolus"] = "right lung cranial lobe alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19186"] = "EMAPA_19186"


class _Right_Lung_Cranial_Lobe_Alveolar_Duct(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe alveolar duct"""

    name: Literal["right lung cranial lobe alveolar duct"] = "right lung cranial lobe alveolar duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19187"] = "EMAPA_19187"


class _Right_Lung_Caudal_Lobe_Alveolus(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe alveolus"""

    name: Literal["right lung caudal lobe alveolus"] = "right lung caudal lobe alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19188"] = "EMAPA_19188"


class _Right_Lung_Caudal_Lobe_Alveolar_Duct(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe alveolar duct"""

    name: Literal["right lung caudal lobe alveolar duct"] = "right lung caudal lobe alveolar duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19189"] = "EMAPA_19189"


class _Right_Lung_Accessory_Lobe_Alveolus(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe alveolus"""

    name: Literal["right lung accessory lobe alveolus"] = "right lung accessory lobe alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19190"] = "EMAPA_19190"


class _Right_Lung_Accessory_Lobe_Alveolar_Duct(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe alveolar duct"""

    name: Literal["right lung accessory lobe alveolar duct"] = "right lung accessory lobe alveolar duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19191"] = "EMAPA_19191"


class _Trachea_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model trachea smooth muscle"""

    name: Literal["trachea smooth muscle"] = "trachea smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19192"] = "EMAPA_19192"


class _Trachealis(_MouseAnatomicalStructureModel):
    """Model trachealis"""

    name: Literal["trachealis"] = "trachealis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19193"] = "EMAPA_19193"


class _Craniopharyngeal_Canal(_MouseAnatomicalStructureModel):
    """Model craniopharyngeal canal"""

    name: Literal["craniopharyngeal canal"] = "craniopharyngeal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19194"] = "EMAPA_19194"


class _Pituitary_Fossa(_MouseAnatomicalStructureModel):
    """Model pituitary fossa"""

    name: Literal["pituitary fossa"] = "pituitary fossa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19195"] = "EMAPA_19195"


class _Temporo_Mandibular_Joint(_MouseAnatomicalStructureModel):
    """Model temporo-mandibular joint"""

    name: Literal["temporo-mandibular joint"] = "temporo-mandibular joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19196"] = "EMAPA_19196"


class _Tympanic_Ring(_MouseAnatomicalStructureModel):
    """Model tympanic ring"""

    name: Literal["tympanic ring"] = "tympanic ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19197"] = "EMAPA_19197"


class _Suture(_MouseAnatomicalStructureModel):
    """Model suture"""

    name: Literal["suture"] = "suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19198"] = "EMAPA_19198"


class _Anterior_Fontanelle(_MouseAnatomicalStructureModel):
    """Model anterior fontanelle"""

    name: Literal["anterior fontanelle"] = "anterior fontanelle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19199"] = "EMAPA_19199"


class _Posterior_Fontanelle(_MouseAnatomicalStructureModel):
    """Model posterior fontanelle"""

    name: Literal["posterior fontanelle"] = "posterior fontanelle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19200"] = "EMAPA_19200"


class _Ethmoid_Bone_Cribriform_Plate(_MouseAnatomicalStructureModel):
    """Model ethmoid bone cribriform plate"""

    name: Literal["ethmoid bone cribriform plate"] = "ethmoid bone cribriform plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19201"] = "EMAPA_19201"


class _Nasal_Bone(_MouseAnatomicalStructureModel):
    """Model nasal bone"""

    name: Literal["nasal bone"] = "nasal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19202"] = "EMAPA_19202"


class _Sterno_Clavicular_Joint(_MouseAnatomicalStructureModel):
    """Model sterno-clavicular joint"""

    name: Literal["sterno-clavicular joint"] = "sterno-clavicular joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19203"] = "EMAPA_19203"


class _Forelimb_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb joint"""

    name: Literal["forelimb joint"] = "forelimb joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19204"] = "EMAPA_19204"


class _Radio_Carpal_Joint(_MouseAnatomicalStructureModel):
    """Model radio-carpal joint"""

    name: Literal["radio-carpal joint"] = "radio-carpal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19205"] = "EMAPA_19205"


class _Radio_Ulnar_Joint(_MouseAnatomicalStructureModel):
    """Model radio-ulnar joint"""

    name: Literal["radio-ulnar joint"] = "radio-ulnar joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19206"] = "EMAPA_19206"


class _Ligamentum_Nuchae(_MouseAnatomicalStructureModel):
    """Model ligamentum nuchae"""

    name: Literal["ligamentum nuchae"] = "ligamentum nuchae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19207"] = "EMAPA_19207"


class _Brown_Fat(_MouseAnatomicalStructureModel):
    """Model brown fat"""

    name: Literal["brown fat"] = "brown fat"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19209"] = "EMAPA_19209"


class _Epicranial_Aponeurosis(_MouseAnatomicalStructureModel):
    """Model epicranial aponeurosis"""

    name: Literal["epicranial aponeurosis"] = "epicranial aponeurosis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19210"] = "EMAPA_19210"


class _Carotid_Body(_MouseAnatomicalStructureModel):
    """Model carotid body"""

    name: Literal["carotid body"] = "carotid body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19211"] = "EMAPA_19211"


class _Celiac_Trunk(_MouseAnatomicalStructureModel):
    """Model celiac trunk"""

    name: Literal["celiac trunk"] = "celiac trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19212"] = "EMAPA_19212"


class _Facial_Artery(_MouseAnatomicalStructureModel):
    """Model facial artery"""

    name: Literal["facial artery"] = "facial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19213"] = "EMAPA_19213"


class _Median_Sacral_Artery(_MouseAnatomicalStructureModel):
    """Model median sacral artery"""

    name: Literal["median sacral artery"] = "median sacral artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19214"] = "EMAPA_19214"


class _Musculo_Phrenic_Artery(_MouseAnatomicalStructureModel):
    """Model musculo-phrenic artery"""

    name: Literal["musculo-phrenic artery"] = "musculo-phrenic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19215"] = "EMAPA_19215"


class _Splenic_Artery(_MouseAnatomicalStructureModel):
    """Model splenic artery"""

    name: Literal["splenic artery"] = "splenic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19216"] = "EMAPA_19216"


class _Accessory_Hemiazygos_Vein(_MouseAnatomicalStructureModel):
    """Model accessory hemiazygos vein"""

    name: Literal["accessory hemiazygos vein"] = "accessory hemiazygos vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19217"] = "EMAPA_19217"


class _Deep_Dorsal_Vein_Of_Clitoris(_MouseAnatomicalStructureModel):
    """Model deep dorsal vein of clitoris"""

    name: Literal["deep dorsal vein of clitoris"] = "deep dorsal vein of clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19218"] = "EMAPA_19218"


class _Deep_Dorsal_Vein_Of_Penis(_MouseAnatomicalStructureModel):
    """Model deep dorsal vein of penis"""

    name: Literal["deep dorsal vein of penis"] = "deep dorsal vein of penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19219"] = "EMAPA_19219"


class _Facial_Vein(_MouseAnatomicalStructureModel):
    """Model facial vein"""

    name: Literal["facial vein"] = "facial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19220"] = "EMAPA_19220"


class _Hepatic_Vein(_MouseAnatomicalStructureModel):
    """Model hepatic vein"""

    name: Literal["hepatic vein"] = "hepatic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19221"] = "EMAPA_19221"


class _Musculo_Phrenic_Vein(_MouseAnatomicalStructureModel):
    """Model musculo-phrenic vein"""

    name: Literal["musculo-phrenic vein"] = "musculo-phrenic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19222"] = "EMAPA_19222"


class _Sagittal_Suture(_MouseAnatomicalStructureModel):
    """Model sagittal suture"""

    name: Literal["sagittal suture"] = "sagittal suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19224"] = "EMAPA_19224"


class _Coronal_Suture(_MouseAnatomicalStructureModel):
    """Model coronal suture"""

    name: Literal["coronal suture"] = "coronal suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19225"] = "EMAPA_19225"


class _Frontal_Suture(_MouseAnatomicalStructureModel):
    """Model frontal suture"""

    name: Literal["frontal suture"] = "frontal suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19226"] = "EMAPA_19226"


class _Lambdoid_Suture(_MouseAnatomicalStructureModel):
    """Model lambdoid suture"""

    name: Literal["lambdoid suture"] = "lambdoid suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19227"] = "EMAPA_19227"


class _Squamo_Parietal_Suture(_MouseAnatomicalStructureModel):
    """Model squamo-parietal suture"""

    name: Literal["squamo-parietal suture"] = "squamo-parietal suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19228"] = "EMAPA_19228"


class _Sphenoidal_Fontanelle(_MouseAnatomicalStructureModel):
    """Model sphenoidal fontanelle"""

    name: Literal["sphenoidal fontanelle"] = "sphenoidal fontanelle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19229"] = "EMAPA_19229"


class _Inferior_Petrosal_Sinus(_MouseAnatomicalStructureModel):
    """Model inferior petrosal sinus"""

    name: Literal["inferior petrosal sinus"] = "inferior petrosal sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19234"] = "EMAPA_19234"


class _Pineal_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model pineal venous plexus"""

    name: Literal["pineal venous plexus"] = "pineal venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19235"] = "EMAPA_19235"


class _Arcuate_Ligament(_MouseAnatomicalStructureModel):
    """Model arcuate ligament"""

    name: Literal["arcuate ligament"] = "arcuate ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19236"] = "EMAPA_19236"


class _Medial_Arcuate_Ligament(_MouseAnatomicalStructureModel):
    """Model medial arcuate ligament"""

    name: Literal["medial arcuate ligament"] = "medial arcuate ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19237"] = "EMAPA_19237"


class _Lateral_Arcuate_Ligament(_MouseAnatomicalStructureModel):
    """Model lateral arcuate ligament"""

    name: Literal["lateral arcuate ligament"] = "lateral arcuate ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19238"] = "EMAPA_19238"


class _Fenestra_Cochleae(_MouseAnatomicalStructureModel):
    """Model fenestra cochleae"""

    name: Literal["fenestra cochleae"] = "fenestra cochleae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19239"] = "EMAPA_19239"


class _Fenestra_Vestibuli(_MouseAnatomicalStructureModel):
    """Model fenestra vestibuli"""

    name: Literal["fenestra vestibuli"] = "fenestra vestibuli"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19240"] = "EMAPA_19240"


class _Inferior_Olivary_Nucleus(_MouseAnatomicalStructureModel):
    """Model inferior olivary nucleus"""

    name: Literal["inferior olivary nucleus"] = "inferior olivary nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19241"] = "EMAPA_19241"


class _Hyaloid_Artery(_MouseAnatomicalStructureModel):
    """Model hyaloid artery"""

    name: Literal["hyaloid artery"] = "hyaloid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19242"] = "EMAPA_19242"


class _Lens_Embryonic_Nucleus(_MouseAnatomicalStructureModel):
    """Model lens embryonic nucleus"""

    name: Literal["lens embryonic nucleus"] = "lens embryonic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19243"] = "EMAPA_19243"


class _Lens_Posterior_Suture(_MouseAnatomicalStructureModel):
    """Model lens posterior suture"""

    name: Literal["lens posterior suture"] = "lens posterior suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19244"] = "EMAPA_19244"


class _Lacrimal_Drainage_System(_MouseAnatomicalStructureModel):
    """Model lacrimal drainage system"""

    name: Literal["lacrimal drainage system"] = "lacrimal drainage system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19245"] = "EMAPA_19245"


class _Pancreas_Body_Islets_Of_Langerhans(_MouseAnatomicalStructureModel):
    """Model pancreas body islets of Langerhans"""

    name: Literal["pancreas body islets of Langerhans"] = "pancreas body islets of Langerhans"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19246"] = "EMAPA_19246"


class _Pancreas_Head_Islets_Of_Langerhans(_MouseAnatomicalStructureModel):
    """Model pancreas head islets of Langerhans"""

    name: Literal["pancreas head islets of Langerhans"] = "pancreas head islets of Langerhans"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19247"] = "EMAPA_19247"


class _Pancreas_Tail_Islets_Of_Langerhans(_MouseAnatomicalStructureModel):
    """Model pancreas tail islets of Langerhans"""

    name: Literal["pancreas tail islets of Langerhans"] = "pancreas tail islets of Langerhans"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19248"] = "EMAPA_19248"


class _Pharyngeal_Ligament(_MouseAnatomicalStructureModel):
    """Model pharyngeal ligament"""

    name: Literal["pharyngeal ligament"] = "pharyngeal ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19249"] = "EMAPA_19249"


class _Pharyngeal_Tubercle(_MouseAnatomicalStructureModel):
    """Model pharyngeal tubercle"""

    name: Literal["pharyngeal tubercle"] = "pharyngeal tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19250"] = "EMAPA_19250"


class _Pyloric_Sphincter(_MouseAnatomicalStructureModel):
    """Model pyloric sphincter"""

    name: Literal["pyloric sphincter"] = "pyloric sphincter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19251"] = "EMAPA_19251"


class _Large_Intestine(_MouseAnatomicalStructureModel):
    """Model large intestine"""

    name: Literal["large intestine"] = "large intestine"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19252"] = "EMAPA_19252"


class _Midgut_Derived_Large_Intestine(_MouseAnatomicalStructureModel):
    """Model midgut derived large intestine"""

    name: Literal["midgut derived large intestine"] = "midgut derived large intestine"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19253"] = "EMAPA_19253"


class _Hindgut_Derived_Large_Intestine(_MouseAnatomicalStructureModel):
    """Model hindgut derived large intestine"""

    name: Literal["hindgut derived large intestine"] = "hindgut derived large intestine"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19254"] = "EMAPA_19254"


class _Midgut_Derived_Large_Intestine_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model midgut derived large intestine mesenchyme"""

    name: Literal["midgut derived large intestine mesenchyme"] = "midgut derived large intestine mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19255"] = "EMAPA_19255"


class _Hindgut_Derived_Large_Intestine_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindgut derived large intestine mesenchyme"""

    name: Literal["hindgut derived large intestine mesenchyme"] = "hindgut derived large intestine mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19256"] = "EMAPA_19256"


class _Midgut_Derived_Large_Intestine_Epithelium(_MouseAnatomicalStructureModel):
    """Model midgut derived large intestine epithelium"""

    name: Literal["midgut derived large intestine epithelium"] = "midgut derived large intestine epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19257"] = "EMAPA_19257"


class _Midgut_Derived_Large_Intestine_Lumen(_MouseAnatomicalStructureModel):
    """Model midgut derived large intestine lumen"""

    name: Literal["midgut derived large intestine lumen"] = "midgut derived large intestine lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19258"] = "EMAPA_19258"


class _Midgut_Derived_Large_Intestine_Mesentery(_MouseAnatomicalStructureModel):
    """Model midgut derived large intestine mesentery"""

    name: Literal["midgut derived large intestine mesentery"] = "midgut derived large intestine mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19259"] = "EMAPA_19259"


class _Midgut_Derived_Large_Intestine_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model midgut derived large intestine dorsal mesentery"""

    name: Literal["midgut derived large intestine dorsal mesentery"] = "midgut derived large intestine dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19260"] = "EMAPA_19260"


class _Midgut_Derived_Large_Intestine_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model midgut derived large intestine vascular element"""

    name: Literal["midgut derived large intestine vascular element"] = "midgut derived large intestine vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19261"] = "EMAPA_19261"


class _Hindgut_Derived_Large_Intestine_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindgut derived large intestine epithelium"""

    name: Literal["hindgut derived large intestine epithelium"] = "hindgut derived large intestine epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19262"] = "EMAPA_19262"


class _Hindgut_Derived_Large_Intestine_Lumen(_MouseAnatomicalStructureModel):
    """Model hindgut derived large intestine lumen"""

    name: Literal["hindgut derived large intestine lumen"] = "hindgut derived large intestine lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19263"] = "EMAPA_19263"


class _Hindgut_Derived_Large_Intestine_Mesentery(_MouseAnatomicalStructureModel):
    """Model hindgut derived large intestine mesentery"""

    name: Literal["hindgut derived large intestine mesentery"] = "hindgut derived large intestine mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19264"] = "EMAPA_19264"


class _Hindgut_Derived_Large_Intestine_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model hindgut derived large intestine dorsal mesentery"""

    name: Literal[
        "hindgut derived large intestine dorsal mesentery"
    ] = "hindgut derived large intestine dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19265"] = "EMAPA_19265"


class _Hindgut_Derived_Large_Intestine_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model hindgut derived large intestine vascular element"""

    name: Literal[
        "hindgut derived large intestine vascular element"
    ] = "hindgut derived large intestine vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19266"] = "EMAPA_19266"


class _Transversus_Thoracis(_MouseAnatomicalStructureModel):
    """Model transversus thoracis"""

    name: Literal["transversus thoracis"] = "transversus thoracis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19267"] = "EMAPA_19267"


class _Infrahyoid_Muscle(_MouseAnatomicalStructureModel):
    """Model infrahyoid muscle"""

    name: Literal["infrahyoid muscle"] = "infrahyoid muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19269"] = "EMAPA_19269"


class _Cricothyroid(_MouseAnatomicalStructureModel):
    """Model cricothyroid"""

    name: Literal["cricothyroid"] = "cricothyroid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19270"] = "EMAPA_19270"


class _Sternohyoid_Muscle(_MouseAnatomicalStructureModel):
    """Model sternohyoid muscle"""

    name: Literal["sternohyoid muscle"] = "sternohyoid muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19271"] = "EMAPA_19271"


class _Sternothyroid_Muscle(_MouseAnatomicalStructureModel):
    """Model sternothyroid muscle"""

    name: Literal["sternothyroid muscle"] = "sternothyroid muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19272"] = "EMAPA_19272"


class _Thyrohyoid_Muscle(_MouseAnatomicalStructureModel):
    """Model thyrohyoid muscle"""

    name: Literal["thyrohyoid muscle"] = "thyrohyoid muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19273"] = "EMAPA_19273"


class _Superior_Hypogastric_Plexus(_MouseAnatomicalStructureModel):
    """Model superior hypogastric plexus"""

    name: Literal["superior hypogastric plexus"] = "superior hypogastric plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19274"] = "EMAPA_19274"


class _Inferior_Hypogastric_Plexus(_MouseAnatomicalStructureModel):
    """Model inferior hypogastric plexus"""

    name: Literal["inferior hypogastric plexus"] = "inferior hypogastric plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19275"] = "EMAPA_19275"


class _Superior_Nasal_Meatus(_MouseAnatomicalStructureModel):
    """Model superior nasal meatus"""

    name: Literal["superior nasal meatus"] = "superior nasal meatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19276"] = "EMAPA_19276"


class _Middle_Nasal_Meatus(_MouseAnatomicalStructureModel):
    """Model middle nasal meatus"""

    name: Literal["middle nasal meatus"] = "middle nasal meatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19277"] = "EMAPA_19277"


class _Inferior_Nasal_Meatus(_MouseAnatomicalStructureModel):
    """Model inferior nasal meatus"""

    name: Literal["inferior nasal meatus"] = "inferior nasal meatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19278"] = "EMAPA_19278"


class _Renal_Medulla(_MouseAnatomicalStructureModel):
    """Model renal medulla"""

    name: Literal["renal medulla"] = "renal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19279"] = "EMAPA_19279"


class _Loop_Of_Henle(_MouseAnatomicalStructureModel):
    """Model loop of Henle"""

    name: Literal["loop of Henle"] = "loop of Henle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19280"] = "EMAPA_19280"


class _Male_Accessory_Gland(_MouseAnatomicalStructureModel):
    """Model male accessory gland"""

    name: Literal["male accessory gland"] = "male accessory gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19285"] = "EMAPA_19285"


class _Bulbourethral_Gland_Of_Male(_MouseAnatomicalStructureModel):
    """Model bulbourethral gland of male"""

    name: Literal["bulbourethral gland of male"] = "bulbourethral gland of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19286"] = "EMAPA_19286"


class _Prostate_Gland(_MouseAnatomicalStructureModel):
    """Model prostate gland"""

    name: Literal["prostate gland"] = "prostate gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19287"] = "EMAPA_19287"


class _Tunica_Albuginea_Of_Testis(_MouseAnatomicalStructureModel):
    """Model tunica albuginea of testis"""

    name: Literal["tunica albuginea of testis"] = "tunica albuginea of testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19289"] = "EMAPA_19289"


class _Epididymis(_MouseAnatomicalStructureModel):
    """Model epididymis"""

    name: Literal["epididymis"] = "epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19290"] = "EMAPA_19290"


class _Caput_Epididymis(_MouseAnatomicalStructureModel):
    """Model caput epididymis"""

    name: Literal["caput epididymis"] = "caput epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19291"] = "EMAPA_19291"


class _Cauda_Epididymis(_MouseAnatomicalStructureModel):
    """Model cauda epididymis"""

    name: Literal["cauda epididymis"] = "cauda epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19292"] = "EMAPA_19292"


class _Corpus_Epididymis(_MouseAnatomicalStructureModel):
    """Model corpus epididymis"""

    name: Literal["corpus epididymis"] = "corpus epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19293"] = "EMAPA_19293"


class _Penile_Body(_MouseAnatomicalStructureModel):
    """Model penile body"""

    name: Literal["penile body"] = "penile body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19294"] = "EMAPA_19294"


class _Scrotum(_MouseAnatomicalStructureModel):
    """Model scrotum"""

    name: Literal["scrotum"] = "scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19296"] = "EMAPA_19296"


class _Sacro_Iliac_Joint(_MouseAnatomicalStructureModel):
    """Model sacro-iliac joint"""

    name: Literal["sacro-iliac joint"] = "sacro-iliac joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19300"] = "EMAPA_19300"


class _Metacarpal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model metacarpal-phalangeal joint"""

    name: Literal["metacarpal-phalangeal joint"] = "metacarpal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19302"] = "EMAPA_19302"


class _Spleen_Hilum(_MouseAnatomicalStructureModel):
    """Model spleen hilum"""

    name: Literal["spleen hilum"] = "spleen hilum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19303"] = "EMAPA_19303"


class _Spleen_Medullary_Region(_MouseAnatomicalStructureModel):
    """Model spleen medullary region"""

    name: Literal["spleen medullary region"] = "spleen medullary region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19304"] = "EMAPA_19304"


class _Thymus_Medullary_Core(_MouseAnatomicalStructureModel):
    """Model thymus medullary core"""

    name: Literal["thymus medullary core"] = "thymus medullary core"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19305"] = "EMAPA_19305"


class _Thymus_Thin_Fibrous_Capsule(_MouseAnatomicalStructureModel):
    """Model thymus thin fibrous capsule"""

    name: Literal["thymus thin fibrous capsule"] = "thymus thin fibrous capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19306"] = "EMAPA_19306"


class _Thyroid_Gland_Left_Lobe_Colloid_Filled_Follicles(_MouseAnatomicalStructureModel):
    """Model thyroid gland left lobe colloid-filled follicles"""

    name: Literal[
        "thyroid gland left lobe colloid-filled follicles"
    ] = "thyroid gland left lobe colloid-filled follicles"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19307"] = "EMAPA_19307"


class _Thyroid_Gland_Right_Lobe_Colloid_Filled_Follicles(_MouseAnatomicalStructureModel):
    """Model thyroid gland right lobe colloid-filled follicles"""

    name: Literal[
        "thyroid gland right lobe colloid-filled follicles"
    ] = "thyroid gland right lobe colloid-filled follicles"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19308"] = "EMAPA_19308"


class _Superior_Cerebellar_Artery(_MouseAnatomicalStructureModel):
    """Model superior cerebellar artery"""

    name: Literal["superior cerebellar artery"] = "superior cerebellar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19309"] = "EMAPA_19309"


class _Thoracic_Duct(_MouseAnatomicalStructureModel):
    """Model thoracic duct"""

    name: Literal["thoracic duct"] = "thoracic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19310"] = "EMAPA_19310"


class _Great_Cerebral_Vein_Of_Galen(_MouseAnatomicalStructureModel):
    """Model great cerebral vein of Galen"""

    name: Literal["great cerebral vein of Galen"] = "great cerebral vein of Galen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19311"] = "EMAPA_19311"


class _Lingual_Vein(_MouseAnatomicalStructureModel):
    """Model lingual vein"""

    name: Literal["lingual vein"] = "lingual vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19312"] = "EMAPA_19312"


class _Ophthalmic_Vein(_MouseAnatomicalStructureModel):
    """Model ophthalmic vein"""

    name: Literal["ophthalmic vein"] = "ophthalmic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19313"] = "EMAPA_19313"


class _Greater_Palatine_Vein(_MouseAnatomicalStructureModel):
    """Model greater palatine vein"""

    name: Literal["greater palatine vein"] = "greater palatine vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19314"] = "EMAPA_19314"


class _Superficial_Temporal_Vein(_MouseAnatomicalStructureModel):
    """Model superficial temporal vein"""

    name: Literal["superficial temporal vein"] = "superficial temporal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19315"] = "EMAPA_19315"


class _Distal_Radio_Ulnar_Joint(_MouseAnatomicalStructureModel):
    """Model distal radio-ulnar joint"""

    name: Literal["distal radio-ulnar joint"] = "distal radio-ulnar joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19316"] = "EMAPA_19316"


class _Proximal_Radio_Ulnar_Joint(_MouseAnatomicalStructureModel):
    """Model proximal radio-ulnar joint"""

    name: Literal["proximal radio-ulnar joint"] = "proximal radio-ulnar joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19317"] = "EMAPA_19317"


class _Lower_Leg_Muscle(_MouseAnatomicalStructureModel):
    """Model lower leg muscle"""

    name: Literal["lower leg muscle"] = "lower leg muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19318"] = "EMAPA_19318"


class _Flexor_Digitorum_Profundus(_MouseAnatomicalStructureModel):
    """Model flexor digitorum profundus"""

    name: Literal["flexor digitorum profundus"] = "flexor digitorum profundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19319"] = "EMAPA_19319"


class _Carotid_Sinus(_MouseAnatomicalStructureModel):
    """Model carotid sinus"""

    name: Literal["carotid sinus"] = "carotid sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19320"] = "EMAPA_19320"


class _Celiac_Ganglion(_MouseAnatomicalStructureModel):
    """Model celiac ganglion"""

    name: Literal["celiac ganglion"] = "celiac ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19321"] = "EMAPA_19321"


class _Annular_Ligament(_MouseAnatomicalStructureModel):
    """Model annular ligament"""

    name: Literal["annular ligament"] = "annular ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19322"] = "EMAPA_19322"


class _C1_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C1 vertebral pre-cartilage condensation"""

    name: Literal["C1 vertebral pre-cartilage condensation"] = "C1 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19323"] = "EMAPA_19323"


class _C2_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C2 vertebral pre-cartilage condensation"""

    name: Literal["C2 vertebral pre-cartilage condensation"] = "C2 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19324"] = "EMAPA_19324"


class _C3_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C3 vertebral pre-cartilage condensation"""

    name: Literal["C3 vertebral pre-cartilage condensation"] = "C3 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19325"] = "EMAPA_19325"


class _C4_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C4 vertebral pre-cartilage condensation"""

    name: Literal["C4 vertebral pre-cartilage condensation"] = "C4 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19326"] = "EMAPA_19326"


class _C5_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C5 vertebral pre-cartilage condensation"""

    name: Literal["C5 vertebral pre-cartilage condensation"] = "C5 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19327"] = "EMAPA_19327"


class _C6_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C6 vertebral pre-cartilage condensation"""

    name: Literal["C6 vertebral pre-cartilage condensation"] = "C6 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19328"] = "EMAPA_19328"


class _C7_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C7 vertebral pre-cartilage condensation"""

    name: Literal["C7 vertebral pre-cartilage condensation"] = "C7 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19329"] = "EMAPA_19329"


class _T1_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T1 vertebral pre-cartilage condensation"""

    name: Literal["T1 vertebral pre-cartilage condensation"] = "T1 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19330"] = "EMAPA_19330"


class _T2_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T2 vertebral pre-cartilage condensation"""

    name: Literal["T2 vertebral pre-cartilage condensation"] = "T2 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19331"] = "EMAPA_19331"


class _T3_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T3 vertebral pre-cartilage condensation"""

    name: Literal["T3 vertebral pre-cartilage condensation"] = "T3 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19332"] = "EMAPA_19332"


class _T4_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T4 vertebral pre-cartilage condensation"""

    name: Literal["T4 vertebral pre-cartilage condensation"] = "T4 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19333"] = "EMAPA_19333"


class _T5_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T5 vertebral pre-cartilage condensation"""

    name: Literal["T5 vertebral pre-cartilage condensation"] = "T5 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19334"] = "EMAPA_19334"


class _C1_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C1 vertebral cartilage condensation"""

    name: Literal["C1 vertebral cartilage condensation"] = "C1 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19335"] = "EMAPA_19335"


class _C2_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C2 vertebral cartilage condensation"""

    name: Literal["C2 vertebral cartilage condensation"] = "C2 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19336"] = "EMAPA_19336"


class _C3_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C3 vertebral cartilage condensation"""

    name: Literal["C3 vertebral cartilage condensation"] = "C3 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19337"] = "EMAPA_19337"


class _C4_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C4 vertebral cartilage condensation"""

    name: Literal["C4 vertebral cartilage condensation"] = "C4 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19338"] = "EMAPA_19338"


class _C5_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C5 vertebral cartilage condensation"""

    name: Literal["C5 vertebral cartilage condensation"] = "C5 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19339"] = "EMAPA_19339"


class _L1_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L1 vertebral pre-cartilage condensation"""

    name: Literal["L1 vertebral pre-cartilage condensation"] = "L1 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19340"] = "EMAPA_19340"


class _T6_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T6 vertebral pre-cartilage condensation"""

    name: Literal["T6 vertebral pre-cartilage condensation"] = "T6 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19341"] = "EMAPA_19341"


class _T7_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T7 vertebral pre-cartilage condensation"""

    name: Literal["T7 vertebral pre-cartilage condensation"] = "T7 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19342"] = "EMAPA_19342"


class _T8_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T8 vertebral pre-cartilage condensation"""

    name: Literal["T8 vertebral pre-cartilage condensation"] = "T8 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19343"] = "EMAPA_19343"


class _T9_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T9 vertebral pre-cartilage condensation"""

    name: Literal["T9 vertebral pre-cartilage condensation"] = "T9 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19344"] = "EMAPA_19344"


class _T10_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T10 vertebral pre-cartilage condensation"""

    name: Literal["T10 vertebral pre-cartilage condensation"] = "T10 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19345"] = "EMAPA_19345"


class _T11_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T11 vertebral pre-cartilage condensation"""

    name: Literal["T11 vertebral pre-cartilage condensation"] = "T11 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19346"] = "EMAPA_19346"


class _T12_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T12 vertebral pre-cartilage condensation"""

    name: Literal["T12 vertebral pre-cartilage condensation"] = "T12 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19347"] = "EMAPA_19347"


class _T13_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T13 vertebral pre-cartilage condensation"""

    name: Literal["T13 vertebral pre-cartilage condensation"] = "T13 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19348"] = "EMAPA_19348"


class _C6_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C6 vertebral cartilage condensation"""

    name: Literal["C6 vertebral cartilage condensation"] = "C6 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19349"] = "EMAPA_19349"


class _C7_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model C7 vertebral cartilage condensation"""

    name: Literal["C7 vertebral cartilage condensation"] = "C7 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19350"] = "EMAPA_19350"


class _L2_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L2 vertebral pre-cartilage condensation"""

    name: Literal["L2 vertebral pre-cartilage condensation"] = "L2 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19351"] = "EMAPA_19351"


class _L3_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L3 vertebral pre-cartilage condensation"""

    name: Literal["L3 vertebral pre-cartilage condensation"] = "L3 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19352"] = "EMAPA_19352"


class _L4_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L4 vertebral pre-cartilage condensation"""

    name: Literal["L4 vertebral pre-cartilage condensation"] = "L4 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19353"] = "EMAPA_19353"


class _L5_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L5 vertebral pre-cartilage condensation"""

    name: Literal["L5 vertebral pre-cartilage condensation"] = "L5 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19354"] = "EMAPA_19354"


class _L6_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L6 vertebral pre-cartilage condensation"""

    name: Literal["L6 vertebral pre-cartilage condensation"] = "L6 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19355"] = "EMAPA_19355"


class _S1_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model S1 vertebral pre-cartilage condensation"""

    name: Literal["S1 vertebral pre-cartilage condensation"] = "S1 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19356"] = "EMAPA_19356"


class _S2_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model S2 vertebral pre-cartilage condensation"""

    name: Literal["S2 vertebral pre-cartilage condensation"] = "S2 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19357"] = "EMAPA_19357"


class _T1_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T1 vertebral cartilage condensation"""

    name: Literal["T1 vertebral cartilage condensation"] = "T1 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19358"] = "EMAPA_19358"


class _T2_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T2 vertebral cartilage condensation"""

    name: Literal["T2 vertebral cartilage condensation"] = "T2 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19359"] = "EMAPA_19359"


class _T3_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T3 vertebral cartilage condensation"""

    name: Literal["T3 vertebral cartilage condensation"] = "T3 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19360"] = "EMAPA_19360"


class _T4_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T4 vertebral cartilage condensation"""

    name: Literal["T4 vertebral cartilage condensation"] = "T4 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19361"] = "EMAPA_19361"


class _T5_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T5 vertebral cartilage condensation"""

    name: Literal["T5 vertebral cartilage condensation"] = "T5 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19362"] = "EMAPA_19362"


class _L1_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L1 vertebral cartilage condensation"""

    name: Literal["L1 vertebral cartilage condensation"] = "L1 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19363"] = "EMAPA_19363"


class _S3_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model S3 vertebral pre-cartilage condensation"""

    name: Literal["S3 vertebral pre-cartilage condensation"] = "S3 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19364"] = "EMAPA_19364"


class _S4_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model S4 vertebral pre-cartilage condensation"""

    name: Literal["S4 vertebral pre-cartilage condensation"] = "S4 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19365"] = "EMAPA_19365"


class _Tl1_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl1 vertebral pre-cartilage condensation"""

    name: Literal["Tl1 vertebral pre-cartilage condensation"] = "Tl1 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19366"] = "EMAPA_19366"


class _Tl2_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl2 vertebral pre-cartilage condensation"""

    name: Literal["Tl2 vertebral pre-cartilage condensation"] = "Tl2 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19367"] = "EMAPA_19367"


class _Tl3_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl3 vertebral pre-cartilage condensation"""

    name: Literal["Tl3 vertebral pre-cartilage condensation"] = "Tl3 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19368"] = "EMAPA_19368"


class _T1_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T1 rib pre-cartilage condensation"""

    name: Literal["T1 rib pre-cartilage condensation"] = "T1 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19369"] = "EMAPA_19369"


class _T2_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T2 rib pre-cartilage condensation"""

    name: Literal["T2 rib pre-cartilage condensation"] = "T2 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19370"] = "EMAPA_19370"


class _T3_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T3 rib pre-cartilage condensation"""

    name: Literal["T3 rib pre-cartilage condensation"] = "T3 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19371"] = "EMAPA_19371"


class _T4_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T4 rib pre-cartilage condensation"""

    name: Literal["T4 rib pre-cartilage condensation"] = "T4 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19372"] = "EMAPA_19372"


class _T5_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T5 rib pre-cartilage condensation"""

    name: Literal["T5 rib pre-cartilage condensation"] = "T5 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19373"] = "EMAPA_19373"


class _T6_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T6 vertebral cartilage condensation"""

    name: Literal["T6 vertebral cartilage condensation"] = "T6 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19374"] = "EMAPA_19374"


class _T7_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T7 vertebral cartilage condensation"""

    name: Literal["T7 vertebral cartilage condensation"] = "T7 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19375"] = "EMAPA_19375"


class _T8_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T8 vertebral cartilage condensation"""

    name: Literal["T8 vertebral cartilage condensation"] = "T8 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19376"] = "EMAPA_19376"


class _T9_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T9 vertebral cartilage condensation"""

    name: Literal["T9 vertebral cartilage condensation"] = "T9 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19377"] = "EMAPA_19377"


class _T10_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T10 vertebral cartilage condensation"""

    name: Literal["T10 vertebral cartilage condensation"] = "T10 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19378"] = "EMAPA_19378"


class _T11_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T11 vertebral cartilage condensation"""

    name: Literal["T11 vertebral cartilage condensation"] = "T11 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19379"] = "EMAPA_19379"


class _T12_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T12 vertebral cartilage condensation"""

    name: Literal["T12 vertebral cartilage condensation"] = "T12 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19380"] = "EMAPA_19380"


class _T13_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T13 vertebral cartilage condensation"""

    name: Literal["T13 vertebral cartilage condensation"] = "T13 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19381"] = "EMAPA_19381"


class _L2_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L2 vertebral cartilage condensation"""

    name: Literal["L2 vertebral cartilage condensation"] = "L2 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19382"] = "EMAPA_19382"


class _L3_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L3 vertebral cartilage condensation"""

    name: Literal["L3 vertebral cartilage condensation"] = "L3 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19383"] = "EMAPA_19383"


class _L4_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L4 vertebral cartilage condensation"""

    name: Literal["L4 vertebral cartilage condensation"] = "L4 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19384"] = "EMAPA_19384"


class _L5_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L5 vertebral cartilage condensation"""

    name: Literal["L5 vertebral cartilage condensation"] = "L5 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19385"] = "EMAPA_19385"


class _L6_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model L6 vertebral cartilage condensation"""

    name: Literal["L6 vertebral cartilage condensation"] = "L6 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19386"] = "EMAPA_19386"


class _S1_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model S1 vertebral cartilage condensation"""

    name: Literal["S1 vertebral cartilage condensation"] = "S1 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19387"] = "EMAPA_19387"


class _S2_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model S2 vertebral cartilage condensation"""

    name: Literal["S2 vertebral cartilage condensation"] = "S2 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19388"] = "EMAPA_19388"


class _Tl4_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl4 vertebral pre-cartilage condensation"""

    name: Literal["Tl4 vertebral pre-cartilage condensation"] = "Tl4 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19389"] = "EMAPA_19389"


class _Tl5_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl5 vertebral pre-cartilage condensation"""

    name: Literal["Tl5 vertebral pre-cartilage condensation"] = "Tl5 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19390"] = "EMAPA_19390"


class _Tl6_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl6 vertebral pre-cartilage condensation"""

    name: Literal["Tl6 vertebral pre-cartilage condensation"] = "Tl6 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19391"] = "EMAPA_19391"


class _Tl7_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl7 vertebral pre-cartilage condensation"""

    name: Literal["Tl7 vertebral pre-cartilage condensation"] = "Tl7 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19392"] = "EMAPA_19392"


class _Tl8_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl8 vertebral pre-cartilage condensation"""

    name: Literal["Tl8 vertebral pre-cartilage condensation"] = "Tl8 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19393"] = "EMAPA_19393"


class _T6_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T6 rib pre-cartilage condensation"""

    name: Literal["T6 rib pre-cartilage condensation"] = "T6 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19394"] = "EMAPA_19394"


class _T7_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T7 rib pre-cartilage condensation"""

    name: Literal["T7 rib pre-cartilage condensation"] = "T7 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19395"] = "EMAPA_19395"


class _T8_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T8 rib pre-cartilage condensation"""

    name: Literal["T8 rib pre-cartilage condensation"] = "T8 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19396"] = "EMAPA_19396"


class _T9_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T9 rib pre-cartilage condensation"""

    name: Literal["T9 rib pre-cartilage condensation"] = "T9 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19397"] = "EMAPA_19397"


class _T10_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T10 rib pre-cartilage condensation"""

    name: Literal["T10 rib pre-cartilage condensation"] = "T10 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19398"] = "EMAPA_19398"


class _T11_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T11 rib pre-cartilage condensation"""

    name: Literal["T11 rib pre-cartilage condensation"] = "T11 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19399"] = "EMAPA_19399"


class _T12_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T12 rib pre-cartilage condensation"""

    name: Literal["T12 rib pre-cartilage condensation"] = "T12 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19400"] = "EMAPA_19400"


class _T13_Rib_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T13 rib pre-cartilage condensation"""

    name: Literal["T13 rib pre-cartilage condensation"] = "T13 rib pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19401"] = "EMAPA_19401"


class _S3_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model S3 vertebral cartilage condensation"""

    name: Literal["S3 vertebral cartilage condensation"] = "S3 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19402"] = "EMAPA_19402"


class _S4_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model S4 vertebral cartilage condensation"""

    name: Literal["S4 vertebral cartilage condensation"] = "S4 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19403"] = "EMAPA_19403"


class _Tl1_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl1 vertebral cartilage condensation"""

    name: Literal["Tl1 vertebral cartilage condensation"] = "Tl1 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19404"] = "EMAPA_19404"


class _Tl2_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl2 vertebral cartilage condensation"""

    name: Literal["Tl2 vertebral cartilage condensation"] = "Tl2 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19405"] = "EMAPA_19405"


class _Tl3_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl3 vertebral cartilage condensation"""

    name: Literal["Tl3 vertebral cartilage condensation"] = "Tl3 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19406"] = "EMAPA_19406"


class _Tl9_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl9 vertebral pre-cartilage condensation"""

    name: Literal["Tl9 vertebral pre-cartilage condensation"] = "Tl9 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19407"] = "EMAPA_19407"


class _Tl10_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl10 vertebral pre-cartilage condensation"""

    name: Literal["Tl10 vertebral pre-cartilage condensation"] = "Tl10 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19408"] = "EMAPA_19408"


class _Tl11_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl11 vertebral pre-cartilage condensation"""

    name: Literal["Tl11 vertebral pre-cartilage condensation"] = "Tl11 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19409"] = "EMAPA_19409"


class _T1_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T1 rib cartilage condensation"""

    name: Literal["T1 rib cartilage condensation"] = "T1 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19410"] = "EMAPA_19410"


class _T2_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T2 rib cartilage condensation"""

    name: Literal["T2 rib cartilage condensation"] = "T2 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19411"] = "EMAPA_19411"


class _T3_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T3 rib cartilage condensation"""

    name: Literal["T3 rib cartilage condensation"] = "T3 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19412"] = "EMAPA_19412"


class _T4_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T4 rib cartilage condensation"""

    name: Literal["T4 rib cartilage condensation"] = "T4 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19413"] = "EMAPA_19413"


class _T5_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T5 rib cartilage condensation"""

    name: Literal["T5 rib cartilage condensation"] = "T5 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19414"] = "EMAPA_19414"


class _Cervical_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model cervical intervertebral disc"""

    name: Literal["cervical intervertebral disc"] = "cervical intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19415"] = "EMAPA_19415"


class _C1_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model C1 intervertebral disc"""

    name: Literal["C1 intervertebral disc"] = "C1 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19416"] = "EMAPA_19416"


class _C1_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model C1 nucleus pulposus"""

    name: Literal["C1 nucleus pulposus"] = "C1 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19417"] = "EMAPA_19417"


class _C1_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model C1 annulus fibrosus"""

    name: Literal["C1 annulus fibrosus"] = "C1 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19418"] = "EMAPA_19418"


class _C2_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model C2 intervertebral disc"""

    name: Literal["C2 intervertebral disc"] = "C2 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19419"] = "EMAPA_19419"


class _C2_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model C2 nucleus pulposus"""

    name: Literal["C2 nucleus pulposus"] = "C2 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19420"] = "EMAPA_19420"


class _C2_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model C2 annulus fibrosus"""

    name: Literal["C2 annulus fibrosus"] = "C2 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19421"] = "EMAPA_19421"


class _C3_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model C3 intervertebral disc"""

    name: Literal["C3 intervertebral disc"] = "C3 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19422"] = "EMAPA_19422"


class _C3_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model C3 nucleus pulposus"""

    name: Literal["C3 nucleus pulposus"] = "C3 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19423"] = "EMAPA_19423"


class _C3_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model C3 annulus fibrosus"""

    name: Literal["C3 annulus fibrosus"] = "C3 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19424"] = "EMAPA_19424"


class _C4_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model C4 intervertebral disc"""

    name: Literal["C4 intervertebral disc"] = "C4 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19425"] = "EMAPA_19425"


class _C4_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model C4 nucleus pulposus"""

    name: Literal["C4 nucleus pulposus"] = "C4 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19426"] = "EMAPA_19426"


class _C4_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model C4 annulus fibrosus"""

    name: Literal["C4 annulus fibrosus"] = "C4 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19427"] = "EMAPA_19427"


class _C5_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model C5 intervertebral disc"""

    name: Literal["C5 intervertebral disc"] = "C5 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19428"] = "EMAPA_19428"


class _C5_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model C5 nucleus pulposus"""

    name: Literal["C5 nucleus pulposus"] = "C5 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19429"] = "EMAPA_19429"


class _C5_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model C5 annulus fibrosus"""

    name: Literal["C5 annulus fibrosus"] = "C5 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19430"] = "EMAPA_19430"


class _C1_Vertebra(_MouseAnatomicalStructureModel):
    """Model C1 vertebra"""

    name: Literal["C1 vertebra"] = "C1 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19431"] = "EMAPA_19431"


class _C2_Vertebra(_MouseAnatomicalStructureModel):
    """Model C2 vertebra"""

    name: Literal["C2 vertebra"] = "C2 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19432"] = "EMAPA_19432"


class _C3_Vertebra(_MouseAnatomicalStructureModel):
    """Model C3 vertebra"""

    name: Literal["C3 vertebra"] = "C3 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19433"] = "EMAPA_19433"


class _C4_Vertebra(_MouseAnatomicalStructureModel):
    """Model C4 vertebra"""

    name: Literal["C4 vertebra"] = "C4 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19434"] = "EMAPA_19434"


class _C5_Vertebra(_MouseAnatomicalStructureModel):
    """Model C5 vertebra"""

    name: Literal["C5 vertebra"] = "C5 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19435"] = "EMAPA_19435"


class _Tl4_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl4 vertebral cartilage condensation"""

    name: Literal["Tl4 vertebral cartilage condensation"] = "Tl4 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19436"] = "EMAPA_19436"


class _Tl5_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl5 vertebral cartilage condensation"""

    name: Literal["Tl5 vertebral cartilage condensation"] = "Tl5 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19437"] = "EMAPA_19437"


class _Tl6_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl6 vertebral cartilage condensation"""

    name: Literal["Tl6 vertebral cartilage condensation"] = "Tl6 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19438"] = "EMAPA_19438"


class _Tl7_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl7 vertebral cartilage condensation"""

    name: Literal["Tl7 vertebral cartilage condensation"] = "Tl7 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19439"] = "EMAPA_19439"


class _Tl8_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl8 vertebral cartilage condensation"""

    name: Literal["Tl8 vertebral cartilage condensation"] = "Tl8 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19440"] = "EMAPA_19440"


class _Tl9_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl9 vertebral cartilage condensation"""

    name: Literal["Tl9 vertebral cartilage condensation"] = "Tl9 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19441"] = "EMAPA_19441"


class _Tl10_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl10 vertebral cartilage condensation"""

    name: Literal["Tl10 vertebral cartilage condensation"] = "Tl10 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19442"] = "EMAPA_19442"


class _Tl11_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl11 vertebral cartilage condensation"""

    name: Literal["Tl11 vertebral cartilage condensation"] = "Tl11 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19443"] = "EMAPA_19443"


class _Tl12_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl12 vertebral pre-cartilage condensation"""

    name: Literal["Tl12 vertebral pre-cartilage condensation"] = "Tl12 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19444"] = "EMAPA_19444"


class _Tl13_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl13 vertebral pre-cartilage condensation"""

    name: Literal["Tl13 vertebral pre-cartilage condensation"] = "Tl13 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19445"] = "EMAPA_19445"


class _Tl14_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl14 vertebral pre-cartilage condensation"""

    name: Literal["Tl14 vertebral pre-cartilage condensation"] = "Tl14 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19446"] = "EMAPA_19446"


class _Tl15_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl15 vertebral pre-cartilage condensation"""

    name: Literal["Tl15 vertebral pre-cartilage condensation"] = "Tl15 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19447"] = "EMAPA_19447"


class _Tl16_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl16 vertebral pre-cartilage condensation"""

    name: Literal["Tl16 vertebral pre-cartilage condensation"] = "Tl16 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19448"] = "EMAPA_19448"


class _Tl17_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl17 vertebral pre-cartilage condensation"""

    name: Literal["Tl17 vertebral pre-cartilage condensation"] = "Tl17 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19449"] = "EMAPA_19449"


class _Tl18_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl18 vertebral pre-cartilage condensation"""

    name: Literal["Tl18 vertebral pre-cartilage condensation"] = "Tl18 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19450"] = "EMAPA_19450"


class _Tl19_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl19 vertebral pre-cartilage condensation"""

    name: Literal["Tl19 vertebral pre-cartilage condensation"] = "Tl19 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19451"] = "EMAPA_19451"


class _T6_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T6 rib cartilage condensation"""

    name: Literal["T6 rib cartilage condensation"] = "T6 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19452"] = "EMAPA_19452"


class _T7_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T7 rib cartilage condensation"""

    name: Literal["T7 rib cartilage condensation"] = "T7 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19453"] = "EMAPA_19453"


class _T8_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T8 rib cartilage condensation"""

    name: Literal["T8 rib cartilage condensation"] = "T8 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19454"] = "EMAPA_19454"


class _T9_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T9 rib cartilage condensation"""

    name: Literal["T9 rib cartilage condensation"] = "T9 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19455"] = "EMAPA_19455"


class _T10_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T10 rib cartilage condensation"""

    name: Literal["T10 rib cartilage condensation"] = "T10 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19456"] = "EMAPA_19456"


class _T11_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T11 rib cartilage condensation"""

    name: Literal["T11 rib cartilage condensation"] = "T11 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19457"] = "EMAPA_19457"


class _T12_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T12 rib cartilage condensation"""

    name: Literal["T12 rib cartilage condensation"] = "T12 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19458"] = "EMAPA_19458"


class _T13_Rib_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model T13 rib cartilage condensation"""

    name: Literal["T13 rib cartilage condensation"] = "T13 rib cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19459"] = "EMAPA_19459"


class _C6_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model C6 intervertebral disc"""

    name: Literal["C6 intervertebral disc"] = "C6 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19460"] = "EMAPA_19460"


class _C6_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model C6 nucleus pulposus"""

    name: Literal["C6 nucleus pulposus"] = "C6 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19461"] = "EMAPA_19461"


class _C6_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model C6 annulus fibrosus"""

    name: Literal["C6 annulus fibrosus"] = "C6 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19462"] = "EMAPA_19462"


class _C7_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model C7 intervertebral disc"""

    name: Literal["C7 intervertebral disc"] = "C7 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19463"] = "EMAPA_19463"


class _C7_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model C7 nucleus pulposus"""

    name: Literal["C7 nucleus pulposus"] = "C7 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19464"] = "EMAPA_19464"


class _C7_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model C7 annulus fibrosus"""

    name: Literal["C7 annulus fibrosus"] = "C7 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19465"] = "EMAPA_19465"


class _C6_Vertebra(_MouseAnatomicalStructureModel):
    """Model C6 vertebra"""

    name: Literal["C6 vertebra"] = "C6 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19466"] = "EMAPA_19466"


class _C7_Vertebra(_MouseAnatomicalStructureModel):
    """Model C7 vertebra"""

    name: Literal["C7 vertebra"] = "C7 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19467"] = "EMAPA_19467"


class _Lumbar_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model lumbar intervertebral disc"""

    name: Literal["lumbar intervertebral disc"] = "lumbar intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19468"] = "EMAPA_19468"


class _L1_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model L1 intervertebral disc"""

    name: Literal["L1 intervertebral disc"] = "L1 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19469"] = "EMAPA_19469"


class _L1_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model L1 nucleus pulposus"""

    name: Literal["L1 nucleus pulposus"] = "L1 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19470"] = "EMAPA_19470"


class _L1_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model L1 annulus fibrosus"""

    name: Literal["L1 annulus fibrosus"] = "L1 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19471"] = "EMAPA_19471"


class _L1_Vertebra(_MouseAnatomicalStructureModel):
    """Model L1 vertebra"""

    name: Literal["L1 vertebra"] = "L1 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19472"] = "EMAPA_19472"


class _Tl12_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl12 vertebral cartilage condensation"""

    name: Literal["Tl12 vertebral cartilage condensation"] = "Tl12 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19473"] = "EMAPA_19473"


class _Tl13_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl13 vertebral cartilage condensation"""

    name: Literal["Tl13 vertebral cartilage condensation"] = "Tl13 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19474"] = "EMAPA_19474"


class _Tl14_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl14 vertebral cartilage condensation"""

    name: Literal["Tl14 vertebral cartilage condensation"] = "Tl14 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19475"] = "EMAPA_19475"


class _Tl15_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl15 vertebral cartilage condensation"""

    name: Literal["Tl15 vertebral cartilage condensation"] = "Tl15 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19476"] = "EMAPA_19476"


class _Tl16_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl16 vertebral cartilage condensation"""

    name: Literal["Tl16 vertebral cartilage condensation"] = "Tl16 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19477"] = "EMAPA_19477"


class _Tl17_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl17 vertebral cartilage condensation"""

    name: Literal["Tl17 vertebral cartilage condensation"] = "Tl17 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19478"] = "EMAPA_19478"


class _Tl18_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl18 vertebral cartilage condensation"""

    name: Literal["Tl18 vertebral cartilage condensation"] = "Tl18 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19479"] = "EMAPA_19479"


class _Tl19_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl19 vertebral cartilage condensation"""

    name: Literal["Tl19 vertebral cartilage condensation"] = "Tl19 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19480"] = "EMAPA_19480"


class _Tl20_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl20 vertebral pre-cartilage condensation"""

    name: Literal["Tl20 vertebral pre-cartilage condensation"] = "Tl20 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19481"] = "EMAPA_19481"


class _Tl21_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl21 vertebral pre-cartilage condensation"""

    name: Literal["Tl21 vertebral pre-cartilage condensation"] = "Tl21 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19482"] = "EMAPA_19482"


class _Tl22_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl22 vertebral pre-cartilage condensation"""

    name: Literal["Tl22 vertebral pre-cartilage condensation"] = "Tl22 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19483"] = "EMAPA_19483"


class _Tl23_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl23 vertebral pre-cartilage condensation"""

    name: Literal["Tl23 vertebral pre-cartilage condensation"] = "Tl23 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19484"] = "EMAPA_19484"


class _Tl24_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl24 vertebral pre-cartilage condensation"""

    name: Literal["Tl24 vertebral pre-cartilage condensation"] = "Tl24 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19485"] = "EMAPA_19485"


class _Tl25_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl25 vertebral pre-cartilage condensation"""

    name: Literal["Tl25 vertebral pre-cartilage condensation"] = "Tl25 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19486"] = "EMAPA_19486"


class _Tl26_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl26 vertebral pre-cartilage condensation"""

    name: Literal["Tl26 vertebral pre-cartilage condensation"] = "Tl26 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19487"] = "EMAPA_19487"


class _Tl27_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl27 vertebral pre-cartilage condensation"""

    name: Literal["Tl27 vertebral pre-cartilage condensation"] = "Tl27 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19488"] = "EMAPA_19488"


class _Thoracic_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model thoracic intervertebral disc"""

    name: Literal["thoracic intervertebral disc"] = "thoracic intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19489"] = "EMAPA_19489"


class _T1_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T1 intervertebral disc"""

    name: Literal["T1 intervertebral disc"] = "T1 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19490"] = "EMAPA_19490"


class _T1_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T1 nucleus pulposus"""

    name: Literal["T1 nucleus pulposus"] = "T1 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19491"] = "EMAPA_19491"


class _T1_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T1 annulus fibrosus"""

    name: Literal["T1 annulus fibrosus"] = "T1 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19492"] = "EMAPA_19492"


class _T2_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T2 intervertebral disc"""

    name: Literal["T2 intervertebral disc"] = "T2 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19493"] = "EMAPA_19493"


class _T2_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T2 nucleus pulposus"""

    name: Literal["T2 nucleus pulposus"] = "T2 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19494"] = "EMAPA_19494"


class _T2_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T2 annulus fibrosus"""

    name: Literal["T2 annulus fibrosus"] = "T2 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19495"] = "EMAPA_19495"


class _T3_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T3 intervertebral disc"""

    name: Literal["T3 intervertebral disc"] = "T3 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19496"] = "EMAPA_19496"


class _T3_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T3 nucleus pulposus"""

    name: Literal["T3 nucleus pulposus"] = "T3 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19497"] = "EMAPA_19497"


class _T3_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T3 annulus fibrosus"""

    name: Literal["T3 annulus fibrosus"] = "T3 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19498"] = "EMAPA_19498"


class _T4_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T4 intervertebral disc"""

    name: Literal["T4 intervertebral disc"] = "T4 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19499"] = "EMAPA_19499"


class _T4_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T4 nucleus pulposus"""

    name: Literal["T4 nucleus pulposus"] = "T4 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19500"] = "EMAPA_19500"


class _T4_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T4 annulus fibrosus"""

    name: Literal["T4 annulus fibrosus"] = "T4 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19501"] = "EMAPA_19501"


class _T5_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T5 intervertebral disc"""

    name: Literal["T5 intervertebral disc"] = "T5 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19502"] = "EMAPA_19502"


class _T5_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T5 nucleus pulposus"""

    name: Literal["T5 nucleus pulposus"] = "T5 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19503"] = "EMAPA_19503"


class _T5_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T5 annulus fibrosus"""

    name: Literal["T5 annulus fibrosus"] = "T5 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19504"] = "EMAPA_19504"


class _T6_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T6 intervertebral disc"""

    name: Literal["T6 intervertebral disc"] = "T6 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19505"] = "EMAPA_19505"


class _T6_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T6 nucleus pulposus"""

    name: Literal["T6 nucleus pulposus"] = "T6 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19506"] = "EMAPA_19506"


class _T6_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T6 annulus fibrosus"""

    name: Literal["T6 annulus fibrosus"] = "T6 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19507"] = "EMAPA_19507"


class _T7_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T7 intervertebral disc"""

    name: Literal["T7 intervertebral disc"] = "T7 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19508"] = "EMAPA_19508"


class _T7_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T7 nucleus pulposus"""

    name: Literal["T7 nucleus pulposus"] = "T7 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19509"] = "EMAPA_19509"


class _T7_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T7 annulus fibrosus"""

    name: Literal["T7 annulus fibrosus"] = "T7 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19510"] = "EMAPA_19510"


class _T8_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T8 intervertebral disc"""

    name: Literal["T8 intervertebral disc"] = "T8 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19511"] = "EMAPA_19511"


class _T8_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T8 nucleus pulposus"""

    name: Literal["T8 nucleus pulposus"] = "T8 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19512"] = "EMAPA_19512"


class _T8_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T8 annulus fibrosus"""

    name: Literal["T8 annulus fibrosus"] = "T8 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19513"] = "EMAPA_19513"


class _T9_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T9 intervertebral disc"""

    name: Literal["T9 intervertebral disc"] = "T9 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19514"] = "EMAPA_19514"


class _T9_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T9 nucleus pulposus"""

    name: Literal["T9 nucleus pulposus"] = "T9 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19515"] = "EMAPA_19515"


class _T9_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T9 annulus fibrosus"""

    name: Literal["T9 annulus fibrosus"] = "T9 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19516"] = "EMAPA_19516"


class _T10_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T10 intervertebral disc"""

    name: Literal["T10 intervertebral disc"] = "T10 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19517"] = "EMAPA_19517"


class _T10_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T10 nucleus pulposus"""

    name: Literal["T10 nucleus pulposus"] = "T10 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19518"] = "EMAPA_19518"


class _T10_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T10 annulus fibrosus"""

    name: Literal["T10 annulus fibrosus"] = "T10 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19519"] = "EMAPA_19519"


class _T11_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T11 intervertebral disc"""

    name: Literal["T11 intervertebral disc"] = "T11 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19520"] = "EMAPA_19520"


class _T11_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T11 nucleus pulposus"""

    name: Literal["T11 nucleus pulposus"] = "T11 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19521"] = "EMAPA_19521"


class _T11_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T11 annulus fibrosus"""

    name: Literal["T11 annulus fibrosus"] = "T11 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19522"] = "EMAPA_19522"


class _T12_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T12 intervertebral disc"""

    name: Literal["T12 intervertebral disc"] = "T12 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19523"] = "EMAPA_19523"


class _T12_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T12 nucleus pulposus"""

    name: Literal["T12 nucleus pulposus"] = "T12 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19524"] = "EMAPA_19524"


class _T12_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T12 annulus fibrosus"""

    name: Literal["T12 annulus fibrosus"] = "T12 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19525"] = "EMAPA_19525"


class _T13_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model T13 intervertebral disc"""

    name: Literal["T13 intervertebral disc"] = "T13 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19526"] = "EMAPA_19526"


class _T13_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model T13 nucleus pulposus"""

    name: Literal["T13 nucleus pulposus"] = "T13 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19527"] = "EMAPA_19527"


class _T13_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model T13 annulus fibrosus"""

    name: Literal["T13 annulus fibrosus"] = "T13 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19528"] = "EMAPA_19528"


class _T1_Rib(_MouseAnatomicalStructureModel):
    """Model T1 rib"""

    name: Literal["T1 rib"] = "T1 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19529"] = "EMAPA_19529"


class _T2_Rib(_MouseAnatomicalStructureModel):
    """Model T2 rib"""

    name: Literal["T2 rib"] = "T2 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19530"] = "EMAPA_19530"


class _T3_Rib(_MouseAnatomicalStructureModel):
    """Model T3 rib"""

    name: Literal["T3 rib"] = "T3 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19531"] = "EMAPA_19531"


class _T4_Rib(_MouseAnatomicalStructureModel):
    """Model T4 rib"""

    name: Literal["T4 rib"] = "T4 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19532"] = "EMAPA_19532"


class _T5_Rib(_MouseAnatomicalStructureModel):
    """Model T5 rib"""

    name: Literal["T5 rib"] = "T5 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19533"] = "EMAPA_19533"


class _T6_Rib(_MouseAnatomicalStructureModel):
    """Model T6 rib"""

    name: Literal["T6 rib"] = "T6 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19534"] = "EMAPA_19534"


class _T7_Rib(_MouseAnatomicalStructureModel):
    """Model T7 rib"""

    name: Literal["T7 rib"] = "T7 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19535"] = "EMAPA_19535"


class _T8_Rib(_MouseAnatomicalStructureModel):
    """Model T8 rib"""

    name: Literal["T8 rib"] = "T8 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19536"] = "EMAPA_19536"


class _T9_Rib(_MouseAnatomicalStructureModel):
    """Model T9 rib"""

    name: Literal["T9 rib"] = "T9 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19537"] = "EMAPA_19537"


class _T10_Rib(_MouseAnatomicalStructureModel):
    """Model T10 rib"""

    name: Literal["T10 rib"] = "T10 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19538"] = "EMAPA_19538"


class _T11_Rib(_MouseAnatomicalStructureModel):
    """Model T11 rib"""

    name: Literal["T11 rib"] = "T11 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19539"] = "EMAPA_19539"


class _T12_Rib(_MouseAnatomicalStructureModel):
    """Model T12 rib"""

    name: Literal["T12 rib"] = "T12 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19540"] = "EMAPA_19540"


class _T13_Rib(_MouseAnatomicalStructureModel):
    """Model T13 rib"""

    name: Literal["T13 rib"] = "T13 rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19541"] = "EMAPA_19541"


class _T1_Vertebra(_MouseAnatomicalStructureModel):
    """Model T1 vertebra"""

    name: Literal["T1 vertebra"] = "T1 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19542"] = "EMAPA_19542"


class _T2_Vertebra(_MouseAnatomicalStructureModel):
    """Model T2 vertebra"""

    name: Literal["T2 vertebra"] = "T2 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19543"] = "EMAPA_19543"


class _T3_Vertebra(_MouseAnatomicalStructureModel):
    """Model T3 vertebra"""

    name: Literal["T3 vertebra"] = "T3 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19544"] = "EMAPA_19544"


class _T4_Vertebra(_MouseAnatomicalStructureModel):
    """Model T4 vertebra"""

    name: Literal["T4 vertebra"] = "T4 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19545"] = "EMAPA_19545"


class _T5_Vertebra(_MouseAnatomicalStructureModel):
    """Model T5 vertebra"""

    name: Literal["T5 vertebra"] = "T5 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19546"] = "EMAPA_19546"


class _T6_Vertebra(_MouseAnatomicalStructureModel):
    """Model T6 vertebra"""

    name: Literal["T6 vertebra"] = "T6 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19547"] = "EMAPA_19547"


class _T7_Vertebra(_MouseAnatomicalStructureModel):
    """Model T7 vertebra"""

    name: Literal["T7 vertebra"] = "T7 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19548"] = "EMAPA_19548"


class _T8_Vertebra(_MouseAnatomicalStructureModel):
    """Model T8 vertebra"""

    name: Literal["T8 vertebra"] = "T8 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19549"] = "EMAPA_19549"


class _T9_Vertebra(_MouseAnatomicalStructureModel):
    """Model T9 vertebra"""

    name: Literal["T9 vertebra"] = "T9 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19550"] = "EMAPA_19550"


class _T10_Vertebra(_MouseAnatomicalStructureModel):
    """Model T10 vertebra"""

    name: Literal["T10 vertebra"] = "T10 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19551"] = "EMAPA_19551"


class _T11_Vertebra(_MouseAnatomicalStructureModel):
    """Model T11 vertebra"""

    name: Literal["T11 vertebra"] = "T11 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19552"] = "EMAPA_19552"


class _T12_Vertebra(_MouseAnatomicalStructureModel):
    """Model T12 vertebra"""

    name: Literal["T12 vertebra"] = "T12 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19553"] = "EMAPA_19553"


class _T13_Vertebra(_MouseAnatomicalStructureModel):
    """Model T13 vertebra"""

    name: Literal["T13 vertebra"] = "T13 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19554"] = "EMAPA_19554"


class _L2_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model L2 intervertebral disc"""

    name: Literal["L2 intervertebral disc"] = "L2 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19555"] = "EMAPA_19555"


class _L2_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model L2 nucleus pulposus"""

    name: Literal["L2 nucleus pulposus"] = "L2 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19556"] = "EMAPA_19556"


class _L2_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model L2 annulus fibrosus"""

    name: Literal["L2 annulus fibrosus"] = "L2 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19557"] = "EMAPA_19557"


class _L3_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model L3 intervertebral disc"""

    name: Literal["L3 intervertebral disc"] = "L3 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19558"] = "EMAPA_19558"


class _L3_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model L3 nucleus pulposus"""

    name: Literal["L3 nucleus pulposus"] = "L3 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19559"] = "EMAPA_19559"


class _L3_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model L3 annulus fibrosus"""

    name: Literal["L3 annulus fibrosus"] = "L3 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19560"] = "EMAPA_19560"


class _L4_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model L4 intervertebral disc"""

    name: Literal["L4 intervertebral disc"] = "L4 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19561"] = "EMAPA_19561"


class _L4_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model L4 nucleus pulposus"""

    name: Literal["L4 nucleus pulposus"] = "L4 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19562"] = "EMAPA_19562"


class _L4_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model L4 annulus fibrosus"""

    name: Literal["L4 annulus fibrosus"] = "L4 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19563"] = "EMAPA_19563"


class _L5_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model L5 intervertebral disc"""

    name: Literal["L5 intervertebral disc"] = "L5 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19564"] = "EMAPA_19564"


class _L5_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model L5 nucleus pulposus"""

    name: Literal["L5 nucleus pulposus"] = "L5 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19565"] = "EMAPA_19565"


class _L5_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model L5 annulus fibrosus"""

    name: Literal["L5 annulus fibrosus"] = "L5 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19566"] = "EMAPA_19566"


class _L6_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model L6 intervertebral disc"""

    name: Literal["L6 intervertebral disc"] = "L6 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19567"] = "EMAPA_19567"


class _L6_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model L6 nucleus pulposus"""

    name: Literal["L6 nucleus pulposus"] = "L6 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19568"] = "EMAPA_19568"


class _L6_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model L6 annulus fibrosus"""

    name: Literal["L6 annulus fibrosus"] = "L6 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19569"] = "EMAPA_19569"


class _L2_Vertebra(_MouseAnatomicalStructureModel):
    """Model L2 vertebra"""

    name: Literal["L2 vertebra"] = "L2 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19570"] = "EMAPA_19570"


class _L3_Vertebra(_MouseAnatomicalStructureModel):
    """Model L3 vertebra"""

    name: Literal["L3 vertebra"] = "L3 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19571"] = "EMAPA_19571"


class _L4_Vertebra(_MouseAnatomicalStructureModel):
    """Model L4 vertebra"""

    name: Literal["L4 vertebra"] = "L4 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19572"] = "EMAPA_19572"


class _L5_Vertebra(_MouseAnatomicalStructureModel):
    """Model L5 vertebra"""

    name: Literal["L5 vertebra"] = "L5 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19573"] = "EMAPA_19573"


class _L6_Vertebra(_MouseAnatomicalStructureModel):
    """Model L6 vertebra"""

    name: Literal["L6 vertebra"] = "L6 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19574"] = "EMAPA_19574"


class _Sacral_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model sacral intervertebral disc"""

    name: Literal["sacral intervertebral disc"] = "sacral intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19575"] = "EMAPA_19575"


class _S1_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model S1 intervertebral disc"""

    name: Literal["S1 intervertebral disc"] = "S1 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19576"] = "EMAPA_19576"


class _S1_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model S1 nucleus pulposus"""

    name: Literal["S1 nucleus pulposus"] = "S1 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19577"] = "EMAPA_19577"


class _S1_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model S1 annulus fibrosus"""

    name: Literal["S1 annulus fibrosus"] = "S1 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19578"] = "EMAPA_19578"


class _S2_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model S2 intervertebral disc"""

    name: Literal["S2 intervertebral disc"] = "S2 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19579"] = "EMAPA_19579"


class _S2_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model S2 nucleus pulposus"""

    name: Literal["S2 nucleus pulposus"] = "S2 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19580"] = "EMAPA_19580"


class _S2_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model S2 annulus fibrosus"""

    name: Literal["S2 annulus fibrosus"] = "S2 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19581"] = "EMAPA_19581"


class _S3_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model S3 intervertebral disc"""

    name: Literal["S3 intervertebral disc"] = "S3 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19582"] = "EMAPA_19582"


class _S3_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model S3 nucleus pulposus"""

    name: Literal["S3 nucleus pulposus"] = "S3 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19583"] = "EMAPA_19583"


class _S3_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model S3 annulus fibrosus"""

    name: Literal["S3 annulus fibrosus"] = "S3 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19584"] = "EMAPA_19584"


class _S4_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model S4 intervertebral disc"""

    name: Literal["S4 intervertebral disc"] = "S4 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19585"] = "EMAPA_19585"


class _S4_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model S4 nucleus pulposus"""

    name: Literal["S4 nucleus pulposus"] = "S4 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19586"] = "EMAPA_19586"


class _S4_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model S4 annulus fibrosus"""

    name: Literal["S4 annulus fibrosus"] = "S4 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19587"] = "EMAPA_19587"


class _S1_Vertebra(_MouseAnatomicalStructureModel):
    """Model S1 vertebra"""

    name: Literal["S1 vertebra"] = "S1 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19588"] = "EMAPA_19588"


class _S2_Vertebra(_MouseAnatomicalStructureModel):
    """Model S2 vertebra"""

    name: Literal["S2 vertebra"] = "S2 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19589"] = "EMAPA_19589"


class _S3_Vertebra(_MouseAnatomicalStructureModel):
    """Model S3 vertebra"""

    name: Literal["S3 vertebra"] = "S3 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19590"] = "EMAPA_19590"


class _S4_Vertebra(_MouseAnatomicalStructureModel):
    """Model S4 vertebra"""

    name: Literal["S4 vertebra"] = "S4 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19591"] = "EMAPA_19591"


class _Tail_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model tail intervertebral disc"""

    name: Literal["tail intervertebral disc"] = "tail intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19592"] = "EMAPA_19592"


class _Tl1_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl1 intervertebral disc"""

    name: Literal["Tl1 intervertebral disc"] = "Tl1 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19593"] = "EMAPA_19593"


class _Tl1_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl1 nucleus pulposus"""

    name: Literal["Tl1 nucleus pulposus"] = "Tl1 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19594"] = "EMAPA_19594"


class _Tl1_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl1 annulus fibrosus"""

    name: Literal["Tl1 annulus fibrosus"] = "Tl1 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19595"] = "EMAPA_19595"


class _Tl2_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl2 intervertebral disc"""

    name: Literal["Tl2 intervertebral disc"] = "Tl2 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19596"] = "EMAPA_19596"


class _Tl2_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl2 nucleus pulposus"""

    name: Literal["Tl2 nucleus pulposus"] = "Tl2 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19597"] = "EMAPA_19597"


class _Tl2_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl2 annulus fibrosus"""

    name: Literal["Tl2 annulus fibrosus"] = "Tl2 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19598"] = "EMAPA_19598"


class _Tl3_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl3 intervertebral disc"""

    name: Literal["Tl3 intervertebral disc"] = "Tl3 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19599"] = "EMAPA_19599"


class _Tl3_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl3 nucleus pulposus"""

    name: Literal["Tl3 nucleus pulposus"] = "Tl3 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19600"] = "EMAPA_19600"


class _Tl3_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl3 annulus fibrosus"""

    name: Literal["Tl3 annulus fibrosus"] = "Tl3 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19601"] = "EMAPA_19601"


class _Tl1_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl1 vertebra"""

    name: Literal["Tl1 vertebra"] = "Tl1 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19602"] = "EMAPA_19602"


class _Tl2_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl2 vertebra"""

    name: Literal["Tl2 vertebra"] = "Tl2 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19603"] = "EMAPA_19603"


class _Tl3_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl3 vertebra"""

    name: Literal["Tl3 vertebra"] = "Tl3 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19604"] = "EMAPA_19604"


class _Tl20_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl20 vertebral cartilage condensation"""

    name: Literal["Tl20 vertebral cartilage condensation"] = "Tl20 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19605"] = "EMAPA_19605"


class _Tl21_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl21 vertebral cartilage condensation"""

    name: Literal["Tl21 vertebral cartilage condensation"] = "Tl21 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19606"] = "EMAPA_19606"


class _Tl22_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl22 vertebral cartilage condensation"""

    name: Literal["Tl22 vertebral cartilage condensation"] = "Tl22 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19607"] = "EMAPA_19607"


class _Tl23_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl23 vertebral cartilage condensation"""

    name: Literal["Tl23 vertebral cartilage condensation"] = "Tl23 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19608"] = "EMAPA_19608"


class _Tl24_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl24 vertebral cartilage condensation"""

    name: Literal["Tl24 vertebral cartilage condensation"] = "Tl24 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19609"] = "EMAPA_19609"


class _Tl25_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl25 vertebral cartilage condensation"""

    name: Literal["Tl25 vertebral cartilage condensation"] = "Tl25 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19610"] = "EMAPA_19610"


class _Tl26_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl26 vertebral cartilage condensation"""

    name: Literal["Tl26 vertebral cartilage condensation"] = "Tl26 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19611"] = "EMAPA_19611"


class _Tl27_Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl27 vertebral cartilage condensation"""

    name: Literal["Tl27 vertebral cartilage condensation"] = "Tl27 vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19612"] = "EMAPA_19612"


class _Tl28_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl28 vertebral pre-cartilage condensation"""

    name: Literal["Tl28 vertebral pre-cartilage condensation"] = "Tl28 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19613"] = "EMAPA_19613"


class _Tl29_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl29 vertebral pre-cartilage condensation"""

    name: Literal["Tl29 vertebral pre-cartilage condensation"] = "Tl29 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19614"] = "EMAPA_19614"


class _Tl30_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl30 vertebral pre-cartilage condensation"""

    name: Literal["Tl30 vertebral pre-cartilage condensation"] = "Tl30 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19615"] = "EMAPA_19615"


class _Tl31_Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Tl31 vertebral pre-cartilage condensation"""

    name: Literal["Tl31 vertebral pre-cartilage condensation"] = "Tl31 vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19616"] = "EMAPA_19616"


class _Tl4_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl4 intervertebral disc"""

    name: Literal["Tl4 intervertebral disc"] = "Tl4 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19617"] = "EMAPA_19617"


class _Tl4_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl4 nucleus pulposus"""

    name: Literal["Tl4 nucleus pulposus"] = "Tl4 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19618"] = "EMAPA_19618"


class _Tl4_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl4 annulus fibrosus"""

    name: Literal["Tl4 annulus fibrosus"] = "Tl4 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19619"] = "EMAPA_19619"


class _Tl5_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl5 intervertebral disc"""

    name: Literal["Tl5 intervertebral disc"] = "Tl5 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19620"] = "EMAPA_19620"


class _Tl5_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl5 nucleus pulposus"""

    name: Literal["Tl5 nucleus pulposus"] = "Tl5 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19621"] = "EMAPA_19621"


class _Tl5_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl5 annulus fibrosus"""

    name: Literal["Tl5 annulus fibrosus"] = "Tl5 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19622"] = "EMAPA_19622"


class _Tl6_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl6 intervertebral disc"""

    name: Literal["Tl6 intervertebral disc"] = "Tl6 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19623"] = "EMAPA_19623"


class _Tl6_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl6 nucleus pulposus"""

    name: Literal["Tl6 nucleus pulposus"] = "Tl6 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19624"] = "EMAPA_19624"


class _Tl6_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl6 annulus fibrosus"""

    name: Literal["Tl6 annulus fibrosus"] = "Tl6 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19625"] = "EMAPA_19625"


class _Tl7_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl7 intervertebral disc"""

    name: Literal["Tl7 intervertebral disc"] = "Tl7 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19626"] = "EMAPA_19626"


class _Tl7_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl7 nucleus pulposus"""

    name: Literal["Tl7 nucleus pulposus"] = "Tl7 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19627"] = "EMAPA_19627"


class _Tl7_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl7 annulus fibrosus"""

    name: Literal["Tl7 annulus fibrosus"] = "Tl7 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19628"] = "EMAPA_19628"


class _Tl8_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl8 intervertebral disc"""

    name: Literal["Tl8 intervertebral disc"] = "Tl8 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19629"] = "EMAPA_19629"


class _Tl8_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl8 nucleus pulposus"""

    name: Literal["Tl8 nucleus pulposus"] = "Tl8 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19630"] = "EMAPA_19630"


class _Tl8_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl8 annulus fibrosus"""

    name: Literal["Tl8 annulus fibrosus"] = "Tl8 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19631"] = "EMAPA_19631"


class _Tl9_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl9 intervertebral disc"""

    name: Literal["Tl9 intervertebral disc"] = "Tl9 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19632"] = "EMAPA_19632"


class _Tl9_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl9 nucleus pulposus"""

    name: Literal["Tl9 nucleus pulposus"] = "Tl9 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19633"] = "EMAPA_19633"


class _Tl9_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl9 annulus fibrosus"""

    name: Literal["Tl9 annulus fibrosus"] = "Tl9 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19634"] = "EMAPA_19634"


class _Tl10_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl10 intervertebral disc"""

    name: Literal["Tl10 intervertebral disc"] = "Tl10 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19635"] = "EMAPA_19635"


class _Tl10_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl10 nucleus pulposus"""

    name: Literal["Tl10 nucleus pulposus"] = "Tl10 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19636"] = "EMAPA_19636"


class _Tl10_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl10 annulus fibrosus"""

    name: Literal["Tl10 annulus fibrosus"] = "Tl10 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19637"] = "EMAPA_19637"


class _Tl11_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl11 intervertebral disc"""

    name: Literal["Tl11 intervertebral disc"] = "Tl11 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19638"] = "EMAPA_19638"


class _Tl11_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl11 nucleus pulposus"""

    name: Literal["Tl11 nucleus pulposus"] = "Tl11 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19639"] = "EMAPA_19639"


class _Tl11_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl11 annulus fibrosus"""

    name: Literal["Tl11 annulus fibrosus"] = "Tl11 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19640"] = "EMAPA_19640"


class _Tl4_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl4 vertebra"""

    name: Literal["Tl4 vertebra"] = "Tl4 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19641"] = "EMAPA_19641"


class _Tl5_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl5 vertebra"""

    name: Literal["Tl5 vertebra"] = "Tl5 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19642"] = "EMAPA_19642"


class _Tl6_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl6 vertebra"""

    name: Literal["Tl6 vertebra"] = "Tl6 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19643"] = "EMAPA_19643"


class _Tl7_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl7 vertebra"""

    name: Literal["Tl7 vertebra"] = "Tl7 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19644"] = "EMAPA_19644"


class _Tl8_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl8 vertebra"""

    name: Literal["Tl8 vertebra"] = "Tl8 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19645"] = "EMAPA_19645"


class _Tl9_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl9 vertebra"""

    name: Literal["Tl9 vertebra"] = "Tl9 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19646"] = "EMAPA_19646"


class _Tl10_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl10 vertebra"""

    name: Literal["Tl10 vertebra"] = "Tl10 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19647"] = "EMAPA_19647"


class _Tl11_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl11 vertebra"""

    name: Literal["Tl11 vertebra"] = "Tl11 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19648"] = "EMAPA_19648"


class _Tl12_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl12 intervertebral disc"""

    name: Literal["Tl12 intervertebral disc"] = "Tl12 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19649"] = "EMAPA_19649"


class _Tl12_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl12 nucleus pulposus"""

    name: Literal["Tl12 nucleus pulposus"] = "Tl12 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19650"] = "EMAPA_19650"


class _Tl12_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl12 annulus fibrosus"""

    name: Literal["Tl12 annulus fibrosus"] = "Tl12 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19651"] = "EMAPA_19651"


class _Tl13_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl13 intervertebral disc"""

    name: Literal["Tl13 intervertebral disc"] = "Tl13 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19652"] = "EMAPA_19652"


class _Tl13_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl13 nucleus pulposus"""

    name: Literal["Tl13 nucleus pulposus"] = "Tl13 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19653"] = "EMAPA_19653"


class _Tl13_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl13 annulus fibrosus"""

    name: Literal["Tl13 annulus fibrosus"] = "Tl13 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19654"] = "EMAPA_19654"


class _Tl14_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl14 intervertebral disc"""

    name: Literal["Tl14 intervertebral disc"] = "Tl14 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19655"] = "EMAPA_19655"


class _Tl14_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl14 nucleus pulposus"""

    name: Literal["Tl14 nucleus pulposus"] = "Tl14 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19656"] = "EMAPA_19656"


class _Tl14_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl14 annulus fibrosus"""

    name: Literal["Tl14 annulus fibrosus"] = "Tl14 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19657"] = "EMAPA_19657"


class _Tl15_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl15 intervertebral disc"""

    name: Literal["Tl15 intervertebral disc"] = "Tl15 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19658"] = "EMAPA_19658"


class _Tl15_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl15 nucleus pulposus"""

    name: Literal["Tl15 nucleus pulposus"] = "Tl15 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19659"] = "EMAPA_19659"


class _Tl15_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl15 annulus fibrosus"""

    name: Literal["Tl15 annulus fibrosus"] = "Tl15 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19660"] = "EMAPA_19660"


class _Tl16_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl16 intervertebral disc"""

    name: Literal["Tl16 intervertebral disc"] = "Tl16 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19661"] = "EMAPA_19661"


class _Tl16_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl16 nucleus pulposus"""

    name: Literal["Tl16 nucleus pulposus"] = "Tl16 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19662"] = "EMAPA_19662"


class _Tl16_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl16 annulus fibrosus"""

    name: Literal["Tl16 annulus fibrosus"] = "Tl16 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19663"] = "EMAPA_19663"


class _Tl17_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl17 intervertebral disc"""

    name: Literal["Tl17 intervertebral disc"] = "Tl17 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19664"] = "EMAPA_19664"


class _Tl17_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl17 nucleus pulposus"""

    name: Literal["Tl17 nucleus pulposus"] = "Tl17 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19665"] = "EMAPA_19665"


class _Tl17_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl17 annulus fibrosus"""

    name: Literal["Tl17 annulus fibrosus"] = "Tl17 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19666"] = "EMAPA_19666"


class _Tl18_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl18 intervertebral disc"""

    name: Literal["Tl18 intervertebral disc"] = "Tl18 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19667"] = "EMAPA_19667"


class _Tl18_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl18 nucleus pulposus"""

    name: Literal["Tl18 nucleus pulposus"] = "Tl18 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19668"] = "EMAPA_19668"


class _Tl18_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl18 annulus fibrosus"""

    name: Literal["Tl18 annulus fibrosus"] = "Tl18 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19669"] = "EMAPA_19669"


class _Tl19_Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model Tl19 intervertebral disc"""

    name: Literal["Tl19 intervertebral disc"] = "Tl19 intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19670"] = "EMAPA_19670"


class _Tl19_Nucleus_Pulposus(_MouseAnatomicalStructureModel):
    """Model Tl19 nucleus pulposus"""

    name: Literal["Tl19 nucleus pulposus"] = "Tl19 nucleus pulposus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19671"] = "EMAPA_19671"


class _Tl19_Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model Tl19 annulus fibrosus"""

    name: Literal["Tl19 annulus fibrosus"] = "Tl19 annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19672"] = "EMAPA_19672"


class _Tl12_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl12 vertebra"""

    name: Literal["Tl12 vertebra"] = "Tl12 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19673"] = "EMAPA_19673"


class _Tl13_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl13 vertebra"""

    name: Literal["Tl13 vertebra"] = "Tl13 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19674"] = "EMAPA_19674"


class _Tl14_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl14 vertebra"""

    name: Literal["Tl14 vertebra"] = "Tl14 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19675"] = "EMAPA_19675"


class _Tl15_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl15 vertebra"""

    name: Literal["Tl15 vertebra"] = "Tl15 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19676"] = "EMAPA_19676"


class _Tl16_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl16 vertebra"""

    name: Literal["Tl16 vertebra"] = "Tl16 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19677"] = "EMAPA_19677"


class _Tl17_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl17 vertebra"""

    name: Literal["Tl17 vertebra"] = "Tl17 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19678"] = "EMAPA_19678"


class _Tl18_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl18 vertebra"""

    name: Literal["Tl18 vertebra"] = "Tl18 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19679"] = "EMAPA_19679"


class _Tl19_Vertebra(_MouseAnatomicalStructureModel):
    """Model Tl19 vertebra"""

    name: Literal["Tl19 vertebra"] = "Tl19 vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_19680"] = "EMAPA_19680"


class _Pleuro_Peritoneal_Canal_Mesothelium(_MouseAnatomicalStructureModel):
    """Model pleuro-peritoneal canal mesothelium"""

    name: Literal["pleuro-peritoneal canal mesothelium"] = "pleuro-peritoneal canal mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25032"] = "EMAPA_25032"


class _Pleuro_Peritoneal_Canal_Parietal_Mesothelium(_MouseAnatomicalStructureModel):
    """Model pleuro-peritoneal canal parietal mesothelium"""

    name: Literal["pleuro-peritoneal canal parietal mesothelium"] = "pleuro-peritoneal canal parietal mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25033"] = "EMAPA_25033"


class _Pleuro_Peritoneal_Canal_Cavity(_MouseAnatomicalStructureModel):
    """Model pleuro-peritoneal canal cavity"""

    name: Literal["pleuro-peritoneal canal cavity"] = "pleuro-peritoneal canal cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25034"] = "EMAPA_25034"


class _Future_Central_Tendon(_MouseAnatomicalStructureModel):
    """Model future central tendon"""

    name: Literal["future central tendon"] = "future central tendon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25035"] = "EMAPA_25035"


class _Rathke_S_Pouch_Wall(_MouseAnatomicalStructureModel):
    """Model Rathke's pouch wall"""

    name: Literal["Rathke's pouch wall"] = "Rathke's pouch wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25036"] = "EMAPA_25036"


class _Rathke_S_Pouch_Lumen(_MouseAnatomicalStructureModel):
    """Model Rathke's pouch lumen"""

    name: Literal["Rathke's pouch lumen"] = "Rathke's pouch lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25037"] = "EMAPA_25037"


class _Proctodeum(_MouseAnatomicalStructureModel):
    """Model proctodeum"""

    name: Literal["proctodeum"] = "proctodeum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25038"] = "EMAPA_25038"


class _Caudal_One_Third_Of_Anal_Canal(_MouseAnatomicalStructureModel):
    """Model caudal one-third of anal canal"""

    name: Literal["caudal one-third of anal canal"] = "caudal one-third of anal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25039"] = "EMAPA_25039"


class _Ectoderm_Component_Of_Anal_Membrane(_MouseAnatomicalStructureModel):
    """Model ectoderm component of anal membrane"""

    name: Literal["ectoderm component of anal membrane"] = "ectoderm component of anal membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25040"] = "EMAPA_25040"


class _Future_Dome(_MouseAnatomicalStructureModel):
    """Model future dome"""

    name: Literal["future dome"] = "future dome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25041"] = "EMAPA_25041"


class _Spinal_Cord_Lumen(_MouseAnatomicalStructureModel):
    """Model spinal cord lumen"""

    name: Literal["spinal cord lumen"] = "spinal cord lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25042"] = "EMAPA_25042"


class _Diaphragm_Left_Dome(_MouseAnatomicalStructureModel):
    """Model diaphragm left dome"""

    name: Literal["diaphragm left dome"] = "diaphragm left dome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25047"] = "EMAPA_25047"


class _Diaphragm_Right_Dome(_MouseAnatomicalStructureModel):
    """Model diaphragm right dome"""

    name: Literal["diaphragm right dome"] = "diaphragm right dome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25048"] = "EMAPA_25048"


class _Humerus_Crest(_MouseAnatomicalStructureModel):
    """Model humerus crest"""

    name: Literal["humerus crest"] = "humerus crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25049"] = "EMAPA_25049"


class _Head_Of_Humerus(_MouseAnatomicalStructureModel):
    """Model head of humerus"""

    name: Literal["head of humerus"] = "head of humerus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25050"] = "EMAPA_25050"


class _Humerus_Shaft(_MouseAnatomicalStructureModel):
    """Model humerus shaft"""

    name: Literal["humerus shaft"] = "humerus shaft"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25051"] = "EMAPA_25051"


class _Humerus_Deltoid_Tuberosity(_MouseAnatomicalStructureModel):
    """Model humerus deltoid tuberosity"""

    name: Literal["humerus deltoid tuberosity"] = "humerus deltoid tuberosity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25052"] = "EMAPA_25052"


class _Tendon_Of_Biceps_Brachii(_MouseAnatomicalStructureModel):
    """Model tendon of biceps brachii"""

    name: Literal["tendon of biceps brachii"] = "tendon of biceps brachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25053"] = "EMAPA_25053"


class _Long_Head_Of_Biceps_Brachii(_MouseAnatomicalStructureModel):
    """Model long head of biceps brachii"""

    name: Literal["long head of biceps brachii"] = "long head of biceps brachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25054"] = "EMAPA_25054"


class _Short_Head_Of_Biceps_Brachii(_MouseAnatomicalStructureModel):
    """Model short head of biceps brachii"""

    name: Literal["short head of biceps brachii"] = "short head of biceps brachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25055"] = "EMAPA_25055"


class _Carpal_Bone(_MouseAnatomicalStructureModel):
    """Model carpal bone"""

    name: Literal["carpal bone"] = "carpal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25056"] = "EMAPA_25056"


class _Forelimb_Digit_1_Metacarpal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 metacarpal-phalangeal joint"""

    name: Literal["forelimb digit 1 metacarpal-phalangeal joint"] = "forelimb digit 1 metacarpal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25057"] = "EMAPA_25057"


class _Forelimb_Digit_1_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 interphalangeal joint"""

    name: Literal["forelimb digit 1 interphalangeal joint"] = "forelimb digit 1 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25058"] = "EMAPA_25058"


class _Forelimb_Digit_1_Epiphyseal_Plate(_MouseAnatomicalStructureModel):
    """Model forelimb digit 1 epiphyseal plate"""

    name: Literal["forelimb digit 1 epiphyseal plate"] = "forelimb digit 1 epiphyseal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25059"] = "EMAPA_25059"


class _Forelimb_Digit_2_Metacarpal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 metacarpal-phalangeal joint"""

    name: Literal["forelimb digit 2 metacarpal-phalangeal joint"] = "forelimb digit 2 metacarpal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25060"] = "EMAPA_25060"


class _Forelimb_Digit_2_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 interphalangeal joint"""

    name: Literal["forelimb digit 2 interphalangeal joint"] = "forelimb digit 2 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25061"] = "EMAPA_25061"


class _Forelimb_Digit_2_Epiphyseal_Plate(_MouseAnatomicalStructureModel):
    """Model forelimb digit 2 epiphyseal plate"""

    name: Literal["forelimb digit 2 epiphyseal plate"] = "forelimb digit 2 epiphyseal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25062"] = "EMAPA_25062"


class _Forelimb_Digit_3_Metacarpal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 metacarpal-phalangeal joint"""

    name: Literal["forelimb digit 3 metacarpal-phalangeal joint"] = "forelimb digit 3 metacarpal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25063"] = "EMAPA_25063"


class _Forelimb_Digit_3_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 interphalangeal joint"""

    name: Literal["forelimb digit 3 interphalangeal joint"] = "forelimb digit 3 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25064"] = "EMAPA_25064"


class _Forelimb_Digit_3_Epiphyseal_Plate(_MouseAnatomicalStructureModel):
    """Model forelimb digit 3 epiphyseal plate"""

    name: Literal["forelimb digit 3 epiphyseal plate"] = "forelimb digit 3 epiphyseal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25065"] = "EMAPA_25065"


class _Forelimb_Digit_4_Metacarpal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 metacarpal-phalangeal joint"""

    name: Literal["forelimb digit 4 metacarpal-phalangeal joint"] = "forelimb digit 4 metacarpal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25066"] = "EMAPA_25066"


class _Forelimb_Digit_4_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 interphalangeal joint"""

    name: Literal["forelimb digit 4 interphalangeal joint"] = "forelimb digit 4 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25067"] = "EMAPA_25067"


class _Forelimb_Digit_4_Epiphyseal_Plate(_MouseAnatomicalStructureModel):
    """Model forelimb digit 4 epiphyseal plate"""

    name: Literal["forelimb digit 4 epiphyseal plate"] = "forelimb digit 4 epiphyseal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25068"] = "EMAPA_25068"


class _Forelimb_Digit_5_Metacarpal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 metacarpal-phalangeal joint"""

    name: Literal["forelimb digit 5 metacarpal-phalangeal joint"] = "forelimb digit 5 metacarpal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25069"] = "EMAPA_25069"


class _Forelimb_Digit_5_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 interphalangeal joint"""

    name: Literal["forelimb digit 5 interphalangeal joint"] = "forelimb digit 5 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25070"] = "EMAPA_25070"


class _Forelimb_Digit_5_Epiphyseal_Plate(_MouseAnatomicalStructureModel):
    """Model forelimb digit 5 epiphyseal plate"""

    name: Literal["forelimb digit 5 epiphyseal plate"] = "forelimb digit 5 epiphyseal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25071"] = "EMAPA_25071"


class _Tarsal_Bone(_MouseAnatomicalStructureModel):
    """Model tarsal bone"""

    name: Literal["tarsal bone"] = "tarsal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25072"] = "EMAPA_25072"


class _Cephalic_Vein(_MouseAnatomicalStructureModel):
    """Model cephalic vein"""

    name: Literal["cephalic vein"] = "cephalic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25075"] = "EMAPA_25075"


class _Cerebellum_Lateral_Part(_MouseAnatomicalStructureModel):
    """Model cerebellum lateral part"""

    name: Literal["cerebellum lateral part"] = "cerebellum lateral part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25083"] = "EMAPA_25083"


class _Cerebellum_Lateral_Part_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum lateral part mantle layer"""

    name: Literal["cerebellum lateral part mantle layer"] = "cerebellum lateral part mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25084"] = "EMAPA_25084"


class _Cerebellum_Lateral_Part_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum lateral part marginal layer"""

    name: Literal["cerebellum lateral part marginal layer"] = "cerebellum lateral part marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25085"] = "EMAPA_25085"


class _Cerebellum_Lateral_Part_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum lateral part ventricular layer"""

    name: Literal["cerebellum lateral part ventricular layer"] = "cerebellum lateral part ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25086"] = "EMAPA_25086"


class _Choroid_Layer(_MouseAnatomicalStructureModel):
    """Model choroid layer"""

    name: Literal["choroid layer"] = "choroid layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25087"] = "EMAPA_25087"


class _Serous_Gland_Epithelial_Component(_MouseAnatomicalStructureModel):
    """Model serous gland epithelial component"""

    name: Literal["serous gland epithelial component"] = "serous gland epithelial component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25090"] = "EMAPA_25090"


class _Nasal_Septum_Cartilage(_MouseAnatomicalStructureModel):
    """Model nasal septum cartilage"""

    name: Literal["nasal septum cartilage"] = "nasal septum cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25091"] = "EMAPA_25091"


class _Turbinate_Bone(_MouseAnatomicalStructureModel):
    """Model turbinate bone"""

    name: Literal["turbinate bone"] = "turbinate bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25093"] = "EMAPA_25093"


class _Oropharynx(_MouseAnatomicalStructureModel):
    """Model oropharynx"""

    name: Literal["oropharynx"] = "oropharynx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25094"] = "EMAPA_25094"


class _Oropharynx_Gland(_MouseAnatomicalStructureModel):
    """Model oropharynx gland"""

    name: Literal["oropharynx gland"] = "oropharynx gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25095"] = "EMAPA_25095"


class _Oropharynx_Gland_Duct(_MouseAnatomicalStructureModel):
    """Model oropharynx gland duct"""

    name: Literal["oropharynx gland duct"] = "oropharynx gland duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25096"] = "EMAPA_25096"


class _Tongue_Gland(_MouseAnatomicalStructureModel):
    """Model tongue gland"""

    name: Literal["tongue gland"] = "tongue gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25097"] = "EMAPA_25097"


class _Tongue_Gland_Duct(_MouseAnatomicalStructureModel):
    """Model tongue gland duct"""

    name: Literal["tongue gland duct"] = "tongue gland duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25098"] = "EMAPA_25098"


class _Lower_Jaw_Alveolar_Canal(_MouseAnatomicalStructureModel):
    """Model lower jaw alveolar canal"""

    name: Literal["lower jaw alveolar canal"] = "lower jaw alveolar canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25099"] = "EMAPA_25099"


class _Mandible_Ramus(_MouseAnatomicalStructureModel):
    """Model mandible ramus"""

    name: Literal["mandible ramus"] = "mandible ramus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25100"] = "EMAPA_25100"


class _L1_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model L1 vertebra centrum"""

    name: Literal["L1 vertebra centrum"] = "L1 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25101"] = "EMAPA_25101"


class _L1_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model L1 vertebra neural arch"""

    name: Literal["L1 vertebra neural arch"] = "L1 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25102"] = "EMAPA_25102"


class _L1_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model L1 future vertebral canal"""

    name: Literal["L1 future vertebral canal"] = "L1 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25103"] = "EMAPA_25103"


class _L1_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model L1 neural arch lamina"""

    name: Literal["L1 neural arch lamina"] = "L1 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25104"] = "EMAPA_25104"


class _L1_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model L1 neural arch pedicle"""

    name: Literal["L1 neural arch pedicle"] = "L1 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25105"] = "EMAPA_25105"


class _L1_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model L1 neural arch transverse process"""

    name: Literal["L1 neural arch transverse process"] = "L1 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25106"] = "EMAPA_25106"


class _Cartilage_Primordium_Of_Future_L1_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future L1 spinous process"""

    name: Literal[
        "cartilage primordium of future L1 spinous process"
    ] = "cartilage primordium of future L1 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25107"] = "EMAPA_25107"


class _Zygomatic_Bone(_MouseAnatomicalStructureModel):
    """Model zygomatic bone"""

    name: Literal["zygomatic bone"] = "zygomatic bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25111"] = "EMAPA_25111"


class _Occipital_Bone(_MouseAnatomicalStructureModel):
    """Model occipital bone"""

    name: Literal["occipital bone"] = "occipital bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25112"] = "EMAPA_25112"


class _Occipital_Bone_Squamous_Part(_MouseAnatomicalStructureModel):
    """Model occipital bone squamous part"""

    name: Literal["occipital bone squamous part"] = "occipital bone squamous part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25113"] = "EMAPA_25113"


class _Ethmoid_Bone_Perpendicular_Plate(_MouseAnatomicalStructureModel):
    """Model ethmoid bone perpendicular plate"""

    name: Literal["ethmoid bone perpendicular plate"] = "ethmoid bone perpendicular plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25114"] = "EMAPA_25114"


class _T1_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T1 rib costal cartilage"""

    name: Literal["T1 rib costal cartilage"] = "T1 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25116"] = "EMAPA_25116"


class _T1_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T1 rib head cartilage"""

    name: Literal["T1 rib head cartilage"] = "T1 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25117"] = "EMAPA_25117"


class _T1_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T1 rib neck cartilage"""

    name: Literal["T1 rib neck cartilage"] = "T1 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25118"] = "EMAPA_25118"


class _Acromion(_MouseAnatomicalStructureModel):
    """Model acromion"""

    name: Literal["acromion"] = "acromion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25119"] = "EMAPA_25119"


class _Blade_Of_Scapula(_MouseAnatomicalStructureModel):
    """Model blade of scapula"""

    name: Literal["blade of scapula"] = "blade of scapula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25120"] = "EMAPA_25120"


class _Coracoid_Process(_MouseAnatomicalStructureModel):
    """Model coracoid process"""

    name: Literal["coracoid process"] = "coracoid process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25121"] = "EMAPA_25121"


class _Glenoid_Fossa_Of_Scapula(_MouseAnatomicalStructureModel):
    """Model glenoid fossa of scapula"""

    name: Literal["glenoid fossa of scapula"] = "glenoid fossa of scapula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25122"] = "EMAPA_25122"


class _Scapula_Spine(_MouseAnatomicalStructureModel):
    """Model scapula spine"""

    name: Literal["scapula spine"] = "scapula spine"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25123"] = "EMAPA_25123"


class _Scapula_Border(_MouseAnatomicalStructureModel):
    """Model scapula border"""

    name: Literal["scapula border"] = "scapula border"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25124"] = "EMAPA_25124"


class _Scapula_Angle(_MouseAnatomicalStructureModel):
    """Model scapula angle"""

    name: Literal["scapula angle"] = "scapula angle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25125"] = "EMAPA_25125"


class _Scapula_Lateral_Border(_MouseAnatomicalStructureModel):
    """Model scapula lateral border"""

    name: Literal["scapula lateral border"] = "scapula lateral border"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25126"] = "EMAPA_25126"


class _Scapula_Medial_Border(_MouseAnatomicalStructureModel):
    """Model scapula medial border"""

    name: Literal["scapula medial border"] = "scapula medial border"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25127"] = "EMAPA_25127"


class _Scapula_Inferior_Angle(_MouseAnatomicalStructureModel):
    """Model scapula inferior angle"""

    name: Literal["scapula inferior angle"] = "scapula inferior angle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25128"] = "EMAPA_25128"


class _Scapula_Superior_Angle(_MouseAnatomicalStructureModel):
    """Model scapula superior angle"""

    name: Literal["scapula superior angle"] = "scapula superior angle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25129"] = "EMAPA_25129"


class _Pre_Vertebral_Muscle_Of_Neck(_MouseAnatomicalStructureModel):
    """Model pre-vertebral muscle of neck"""

    name: Literal["pre-vertebral muscle of neck"] = "pre-vertebral muscle of neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25130"] = "EMAPA_25130"


class _Longus_Capitis(_MouseAnatomicalStructureModel):
    """Model longus capitis"""

    name: Literal["longus capitis"] = "longus capitis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25131"] = "EMAPA_25131"


class _Longus_Cervicis(_MouseAnatomicalStructureModel):
    """Model longus cervicis"""

    name: Literal["longus cervicis"] = "longus cervicis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25132"] = "EMAPA_25132"


class _Facial_Muscle(_MouseAnatomicalStructureModel):
    """Model facial muscle"""

    name: Literal["facial muscle"] = "facial muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25133"] = "EMAPA_25133"


class _Digastric(_MouseAnatomicalStructureModel):
    """Model digastric"""

    name: Literal["digastric"] = "digastric"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25134"] = "EMAPA_25134"


class _Masseter(_MouseAnatomicalStructureModel):
    """Model masseter"""

    name: Literal["masseter"] = "masseter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25135"] = "EMAPA_25135"


class _Mylohyoid(_MouseAnatomicalStructureModel):
    """Model mylohyoid"""

    name: Literal["mylohyoid"] = "mylohyoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25136"] = "EMAPA_25136"


class _Sterno_Mastoid(_MouseAnatomicalStructureModel):
    """Model sterno-mastoid"""

    name: Literal["sterno-mastoid"] = "sterno-mastoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25137"] = "EMAPA_25137"


class _Temporalis(_MouseAnatomicalStructureModel):
    """Model temporalis"""

    name: Literal["temporalis"] = "temporalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25138"] = "EMAPA_25138"


class _Pterygoid(_MouseAnatomicalStructureModel):
    """Model pterygoid"""

    name: Literal["pterygoid"] = "pterygoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25139"] = "EMAPA_25139"


class _Lateral_Pterygoid(_MouseAnatomicalStructureModel):
    """Model lateral pterygoid"""

    name: Literal["lateral pterygoid"] = "lateral pterygoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25140"] = "EMAPA_25140"


class _Medial_Pterygoid(_MouseAnatomicalStructureModel):
    """Model medial pterygoid"""

    name: Literal["medial pterygoid"] = "medial pterygoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25141"] = "EMAPA_25141"


class _C1_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model C1 dorsal root ganglion"""

    name: Literal["C1 dorsal root ganglion"] = "C1 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25144"] = "EMAPA_25144"


class _C1_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C1 segmental spinal nerve"""

    name: Literal["C1 segmental spinal nerve"] = "C1 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25145"] = "EMAPA_25145"


class _C1_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model C1 dorsal root"""

    name: Literal["C1 dorsal root"] = "C1 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25146"] = "EMAPA_25146"


class _C1_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model C1 ventral root"""

    name: Literal["C1 ventral root"] = "C1 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25147"] = "EMAPA_25147"


class _Tail_Nerve(_MouseAnatomicalStructureModel):
    """Model tail nerve"""

    name: Literal["tail nerve"] = "tail nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25148"] = "EMAPA_25148"


class _Tail_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model tail segmental spinal nerve"""

    name: Literal["tail segmental spinal nerve"] = "tail segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25149"] = "EMAPA_25149"


class _Tl1_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl1 segmental spinal nerve"""

    name: Literal["Tl1 segmental spinal nerve"] = "Tl1 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25150"] = "EMAPA_25150"


class _Tl1_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl1 dorsal root"""

    name: Literal["Tl1 dorsal root"] = "Tl1 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25151"] = "EMAPA_25151"


class _Tl1_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl1 ventral root"""

    name: Literal["Tl1 ventral root"] = "Tl1 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25153"] = "EMAPA_25153"


class _Tl1_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl1 dorsal root ganglion"""

    name: Literal["Tl1 dorsal root ganglion"] = "Tl1 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25154"] = "EMAPA_25154"


class _C2_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model C2 dorsal root ganglion"""

    name: Literal["C2 dorsal root ganglion"] = "C2 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25155"] = "EMAPA_25155"


class _C3_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model C3 dorsal root ganglion"""

    name: Literal["C3 dorsal root ganglion"] = "C3 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25156"] = "EMAPA_25156"


class _C4_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model C4 dorsal root ganglion"""

    name: Literal["C4 dorsal root ganglion"] = "C4 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25157"] = "EMAPA_25157"


class _C5_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model C5 dorsal root ganglion"""

    name: Literal["C5 dorsal root ganglion"] = "C5 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25158"] = "EMAPA_25158"


class _C6_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model C6 dorsal root ganglion"""

    name: Literal["C6 dorsal root ganglion"] = "C6 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25159"] = "EMAPA_25159"


class _C7_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model C7 dorsal root ganglion"""

    name: Literal["C7 dorsal root ganglion"] = "C7 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25160"] = "EMAPA_25160"


class _L1_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model L1 dorsal root ganglion"""

    name: Literal["L1 dorsal root ganglion"] = "L1 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25164"] = "EMAPA_25164"


class _L2_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model L2 dorsal root ganglion"""

    name: Literal["L2 dorsal root ganglion"] = "L2 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25165"] = "EMAPA_25165"


class _L3_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model L3 dorsal root ganglion"""

    name: Literal["L3 dorsal root ganglion"] = "L3 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25166"] = "EMAPA_25166"


class _L4_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model L4 dorsal root ganglion"""

    name: Literal["L4 dorsal root ganglion"] = "L4 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25167"] = "EMAPA_25167"


class _L5_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model L5 dorsal root ganglion"""

    name: Literal["L5 dorsal root ganglion"] = "L5 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25168"] = "EMAPA_25168"


class _L6_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model L6 dorsal root ganglion"""

    name: Literal["L6 dorsal root ganglion"] = "L6 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25169"] = "EMAPA_25169"


class _S1_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model S1 dorsal root ganglion"""

    name: Literal["S1 dorsal root ganglion"] = "S1 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25170"] = "EMAPA_25170"


class _S2_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model S2 dorsal root ganglion"""

    name: Literal["S2 dorsal root ganglion"] = "S2 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25171"] = "EMAPA_25171"


class _S3_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model S3 dorsal root ganglion"""

    name: Literal["S3 dorsal root ganglion"] = "S3 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25172"] = "EMAPA_25172"


class _S4_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model S4 dorsal root ganglion"""

    name: Literal["S4 dorsal root ganglion"] = "S4 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25173"] = "EMAPA_25173"


class _T1_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T1 dorsal root ganglion"""

    name: Literal["T1 dorsal root ganglion"] = "T1 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25174"] = "EMAPA_25174"


class _T2_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T2 dorsal root ganglion"""

    name: Literal["T2 dorsal root ganglion"] = "T2 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25175"] = "EMAPA_25175"


class _T3_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T3 dorsal root ganglion"""

    name: Literal["T3 dorsal root ganglion"] = "T3 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25176"] = "EMAPA_25176"


class _T4_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T4 dorsal root ganglion"""

    name: Literal["T4 dorsal root ganglion"] = "T4 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25177"] = "EMAPA_25177"


class _T6_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T6 dorsal root ganglion"""

    name: Literal["T6 dorsal root ganglion"] = "T6 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25178"] = "EMAPA_25178"


class _T5_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T5 dorsal root ganglion"""

    name: Literal["T5 dorsal root ganglion"] = "T5 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25179"] = "EMAPA_25179"


class _T7_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T7 dorsal root ganglion"""

    name: Literal["T7 dorsal root ganglion"] = "T7 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25180"] = "EMAPA_25180"


class _T8_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T8 dorsal root ganglion"""

    name: Literal["T8 dorsal root ganglion"] = "T8 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25181"] = "EMAPA_25181"


class _T9_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T9 dorsal root ganglion"""

    name: Literal["T9 dorsal root ganglion"] = "T9 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25182"] = "EMAPA_25182"


class _T10_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T10 dorsal root ganglion"""

    name: Literal["T10 dorsal root ganglion"] = "T10 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25183"] = "EMAPA_25183"


class _T11_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T11 dorsal root ganglion"""

    name: Literal["T11 dorsal root ganglion"] = "T11 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25184"] = "EMAPA_25184"


class _T12_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T12 dorsal root ganglion"""

    name: Literal["T12 dorsal root ganglion"] = "T12 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25185"] = "EMAPA_25185"


class _T13_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model T13 dorsal root ganglion"""

    name: Literal["T13 dorsal root ganglion"] = "T13 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25186"] = "EMAPA_25186"


class _Tl2_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl2 dorsal root ganglion"""

    name: Literal["Tl2 dorsal root ganglion"] = "Tl2 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25187"] = "EMAPA_25187"


class _Tl3_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl3 dorsal root ganglion"""

    name: Literal["Tl3 dorsal root ganglion"] = "Tl3 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25188"] = "EMAPA_25188"


class _Tl4_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl4 dorsal root ganglion"""

    name: Literal["Tl4 dorsal root ganglion"] = "Tl4 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25189"] = "EMAPA_25189"


class _Tl5_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl5 dorsal root ganglion"""

    name: Literal["Tl5 dorsal root ganglion"] = "Tl5 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25190"] = "EMAPA_25190"


class _Tl6_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl6 dorsal root ganglion"""

    name: Literal["Tl6 dorsal root ganglion"] = "Tl6 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25191"] = "EMAPA_25191"


class _Tl7_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl7 dorsal root ganglion"""

    name: Literal["Tl7 dorsal root ganglion"] = "Tl7 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25192"] = "EMAPA_25192"


class _Tl8_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl8 dorsal root ganglion"""

    name: Literal["Tl8 dorsal root ganglion"] = "Tl8 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25193"] = "EMAPA_25193"


class _Tl9_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl9 dorsal root ganglion"""

    name: Literal["Tl9 dorsal root ganglion"] = "Tl9 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25194"] = "EMAPA_25194"


class _Tl10_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl10 dorsal root ganglion"""

    name: Literal["Tl10 dorsal root ganglion"] = "Tl10 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25195"] = "EMAPA_25195"


class _Tl11_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl11 dorsal root ganglion"""

    name: Literal["Tl11 dorsal root ganglion"] = "Tl11 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25196"] = "EMAPA_25196"


class _Tl12_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl12 dorsal root ganglion"""

    name: Literal["Tl12 dorsal root ganglion"] = "Tl12 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25197"] = "EMAPA_25197"


class _Tl13_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl13 dorsal root ganglion"""

    name: Literal["Tl13 dorsal root ganglion"] = "Tl13 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25198"] = "EMAPA_25198"


class _Tl14_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl14 dorsal root ganglion"""

    name: Literal["Tl14 dorsal root ganglion"] = "Tl14 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25199"] = "EMAPA_25199"


class _Tl15_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl15 dorsal root ganglion"""

    name: Literal["Tl15 dorsal root ganglion"] = "Tl15 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25200"] = "EMAPA_25200"


class _Tl16_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl16 dorsal root ganglion"""

    name: Literal["Tl16 dorsal root ganglion"] = "Tl16 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25201"] = "EMAPA_25201"


class _Tl17_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl17 dorsal root ganglion"""

    name: Literal["Tl17 dorsal root ganglion"] = "Tl17 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25202"] = "EMAPA_25202"


class _Tl18_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl18 dorsal root ganglion"""

    name: Literal["Tl18 dorsal root ganglion"] = "Tl18 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25203"] = "EMAPA_25203"


class _Tl19_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model Tl19 dorsal root ganglion"""

    name: Literal["Tl19 dorsal root ganglion"] = "Tl19 dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25204"] = "EMAPA_25204"


class _Tl2_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl2 segmental spinal nerve"""

    name: Literal["Tl2 segmental spinal nerve"] = "Tl2 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25205"] = "EMAPA_25205"


class _Tl3_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl3 segmental spinal nerve"""

    name: Literal["Tl3 segmental spinal nerve"] = "Tl3 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25206"] = "EMAPA_25206"


class _Tl4_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl4 segmental spinal nerve"""

    name: Literal["Tl4 segmental spinal nerve"] = "Tl4 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25207"] = "EMAPA_25207"


class _Tl5_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl5 segmental spinal nerve"""

    name: Literal["Tl5 segmental spinal nerve"] = "Tl5 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25208"] = "EMAPA_25208"


class _Tl6_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl6 segmental spinal nerve"""

    name: Literal["Tl6 segmental spinal nerve"] = "Tl6 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25209"] = "EMAPA_25209"


class _Tl7_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl7 segmental spinal nerve"""

    name: Literal["Tl7 segmental spinal nerve"] = "Tl7 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25210"] = "EMAPA_25210"


class _Tl8_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl8 segmental spinal nerve"""

    name: Literal["Tl8 segmental spinal nerve"] = "Tl8 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25211"] = "EMAPA_25211"


class _Tl9_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl9 segmental spinal nerve"""

    name: Literal["Tl9 segmental spinal nerve"] = "Tl9 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25212"] = "EMAPA_25212"


class _Tl10_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl10 segmental spinal nerve"""

    name: Literal["Tl10 segmental spinal nerve"] = "Tl10 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25213"] = "EMAPA_25213"


class _Tl11_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl11 segmental spinal nerve"""

    name: Literal["Tl11 segmental spinal nerve"] = "Tl11 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25214"] = "EMAPA_25214"


class _Tl12_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl12 segmental spinal nerve"""

    name: Literal["Tl12 segmental spinal nerve"] = "Tl12 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25215"] = "EMAPA_25215"


class _Tl13_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl13 segmental spinal nerve"""

    name: Literal["Tl13 segmental spinal nerve"] = "Tl13 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25216"] = "EMAPA_25216"


class _Tl14_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl14 segmental spinal nerve"""

    name: Literal["Tl14 segmental spinal nerve"] = "Tl14 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25217"] = "EMAPA_25217"


class _Tl15_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl15 segmental spinal nerve"""

    name: Literal["Tl15 segmental spinal nerve"] = "Tl15 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25218"] = "EMAPA_25218"


class _Tl16_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl16 segmental spinal nerve"""

    name: Literal["Tl16 segmental spinal nerve"] = "Tl16 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25219"] = "EMAPA_25219"


class _Tl17_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl17 segmental spinal nerve"""

    name: Literal["Tl17 segmental spinal nerve"] = "Tl17 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25220"] = "EMAPA_25220"


class _Tl18_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl18 segmental spinal nerve"""

    name: Literal["Tl18 segmental spinal nerve"] = "Tl18 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25221"] = "EMAPA_25221"


class _Tl19_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model Tl19 segmental spinal nerve"""

    name: Literal["Tl19 segmental spinal nerve"] = "Tl19 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25222"] = "EMAPA_25222"


class _C2_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C2 segmental spinal nerve"""

    name: Literal["C2 segmental spinal nerve"] = "C2 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25223"] = "EMAPA_25223"


class _C3_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C3 segmental spinal nerve"""

    name: Literal["C3 segmental spinal nerve"] = "C3 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25224"] = "EMAPA_25224"


class _C4_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C4 segmental spinal nerve"""

    name: Literal["C4 segmental spinal nerve"] = "C4 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25225"] = "EMAPA_25225"


class _C5_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C5 segmental spinal nerve"""

    name: Literal["C5 segmental spinal nerve"] = "C5 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25226"] = "EMAPA_25226"


class _C6_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C6 segmental spinal nerve"""

    name: Literal["C6 segmental spinal nerve"] = "C6 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25227"] = "EMAPA_25227"


class _C7_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C7 segmental spinal nerve"""

    name: Literal["C7 segmental spinal nerve"] = "C7 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25228"] = "EMAPA_25228"


class _L1_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L1 segmental spinal nerve"""

    name: Literal["L1 segmental spinal nerve"] = "L1 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25230"] = "EMAPA_25230"


class _L2_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L2 segmental spinal nerve"""

    name: Literal["L2 segmental spinal nerve"] = "L2 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25231"] = "EMAPA_25231"


class _L3_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L3 segmental spinal nerve"""

    name: Literal["L3 segmental spinal nerve"] = "L3 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25232"] = "EMAPA_25232"


class _L4_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L4 segmental spinal nerve"""

    name: Literal["L4 segmental spinal nerve"] = "L4 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25233"] = "EMAPA_25233"


class _L5_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L5 segmental spinal nerve"""

    name: Literal["L5 segmental spinal nerve"] = "L5 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25234"] = "EMAPA_25234"


class _L6_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L6 segmental spinal nerve"""

    name: Literal["L6 segmental spinal nerve"] = "L6 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25235"] = "EMAPA_25235"


class _S1_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model S1 segmental spinal nerve"""

    name: Literal["S1 segmental spinal nerve"] = "S1 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25236"] = "EMAPA_25236"


class _S2_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model S2 segmental spinal nerve"""

    name: Literal["S2 segmental spinal nerve"] = "S2 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25237"] = "EMAPA_25237"


class _S3_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model S3 segmental spinal nerve"""

    name: Literal["S3 segmental spinal nerve"] = "S3 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25238"] = "EMAPA_25238"


class _S4_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model S4 segmental spinal nerve"""

    name: Literal["S4 segmental spinal nerve"] = "S4 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25239"] = "EMAPA_25239"


class _T1_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T1 segmental spinal nerve"""

    name: Literal["T1 segmental spinal nerve"] = "T1 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25240"] = "EMAPA_25240"


class _T2_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T2 segmental spinal nerve"""

    name: Literal["T2 segmental spinal nerve"] = "T2 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25241"] = "EMAPA_25241"


class _T3_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T3 segmental spinal nerve"""

    name: Literal["T3 segmental spinal nerve"] = "T3 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25242"] = "EMAPA_25242"


class _T4_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T4 segmental spinal nerve"""

    name: Literal["T4 segmental spinal nerve"] = "T4 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25243"] = "EMAPA_25243"


class _T5_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T5 segmental spinal nerve"""

    name: Literal["T5 segmental spinal nerve"] = "T5 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25244"] = "EMAPA_25244"


class _T6_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T6 segmental spinal nerve"""

    name: Literal["T6 segmental spinal nerve"] = "T6 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25245"] = "EMAPA_25245"


class _T7_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T7 segmental spinal nerve"""

    name: Literal["T7 segmental spinal nerve"] = "T7 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25246"] = "EMAPA_25246"


class _T8_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T8 segmental spinal nerve"""

    name: Literal["T8 segmental spinal nerve"] = "T8 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25247"] = "EMAPA_25247"


class _T9_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T9 segmental spinal nerve"""

    name: Literal["T9 segmental spinal nerve"] = "T9 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25248"] = "EMAPA_25248"


class _T10_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T10 segmental spinal nerve"""

    name: Literal["T10 segmental spinal nerve"] = "T10 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25249"] = "EMAPA_25249"


class _T11_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T11 segmental spinal nerve"""

    name: Literal["T11 segmental spinal nerve"] = "T11 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25250"] = "EMAPA_25250"


class _T12_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T12 segmental spinal nerve"""

    name: Literal["T12 segmental spinal nerve"] = "T12 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25251"] = "EMAPA_25251"


class _T13_Segmental_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T13 segmental spinal nerve"""

    name: Literal["T13 segmental spinal nerve"] = "T13 segmental spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25252"] = "EMAPA_25252"


class _C2_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model C2 dorsal root"""

    name: Literal["C2 dorsal root"] = "C2 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25256"] = "EMAPA_25256"


class _C2_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model C2 ventral root"""

    name: Literal["C2 ventral root"] = "C2 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25257"] = "EMAPA_25257"


class _C3_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model C3 dorsal root"""

    name: Literal["C3 dorsal root"] = "C3 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25258"] = "EMAPA_25258"


class _C3_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model C3 ventral root"""

    name: Literal["C3 ventral root"] = "C3 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25259"] = "EMAPA_25259"


class _C4_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model C4 dorsal root"""

    name: Literal["C4 dorsal root"] = "C4 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25260"] = "EMAPA_25260"


class _C4_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model C4 ventral root"""

    name: Literal["C4 ventral root"] = "C4 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25261"] = "EMAPA_25261"


class _C5_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model C5 dorsal root"""

    name: Literal["C5 dorsal root"] = "C5 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25262"] = "EMAPA_25262"


class _C5_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model C5 ventral root"""

    name: Literal["C5 ventral root"] = "C5 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25263"] = "EMAPA_25263"


class _C6_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model C6 dorsal root"""

    name: Literal["C6 dorsal root"] = "C6 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25264"] = "EMAPA_25264"


class _C6_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model C6 ventral root"""

    name: Literal["C6 ventral root"] = "C6 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25265"] = "EMAPA_25265"


class _C7_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model C7 dorsal root"""

    name: Literal["C7 dorsal root"] = "C7 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25266"] = "EMAPA_25266"


class _C7_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model C7 ventral root"""

    name: Literal["C7 ventral root"] = "C7 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25267"] = "EMAPA_25267"


class _L1_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model L1 dorsal root"""

    name: Literal["L1 dorsal root"] = "L1 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25268"] = "EMAPA_25268"


class _L1_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model L1 ventral root"""

    name: Literal["L1 ventral root"] = "L1 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25269"] = "EMAPA_25269"


class _L2_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model L2 dorsal root"""

    name: Literal["L2 dorsal root"] = "L2 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25270"] = "EMAPA_25270"


class _L2_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model L2 ventral root"""

    name: Literal["L2 ventral root"] = "L2 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25271"] = "EMAPA_25271"


class _L3_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model L3 dorsal root"""

    name: Literal["L3 dorsal root"] = "L3 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25272"] = "EMAPA_25272"


class _L3_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model L3 ventral root"""

    name: Literal["L3 ventral root"] = "L3 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25273"] = "EMAPA_25273"


class _L4_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model L4 dorsal root"""

    name: Literal["L4 dorsal root"] = "L4 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25274"] = "EMAPA_25274"


class _L4_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model L4 ventral root"""

    name: Literal["L4 ventral root"] = "L4 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25275"] = "EMAPA_25275"


class _L5_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model L5 dorsal root"""

    name: Literal["L5 dorsal root"] = "L5 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25276"] = "EMAPA_25276"


class _L5_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model L5 ventral root"""

    name: Literal["L5 ventral root"] = "L5 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25277"] = "EMAPA_25277"


class _L6_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model L6 dorsal root"""

    name: Literal["L6 dorsal root"] = "L6 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25278"] = "EMAPA_25278"


class _L6_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model L6 ventral root"""

    name: Literal["L6 ventral root"] = "L6 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25279"] = "EMAPA_25279"


class _S1_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model S1 dorsal root"""

    name: Literal["S1 dorsal root"] = "S1 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25280"] = "EMAPA_25280"


class _S1_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model S1 ventral root"""

    name: Literal["S1 ventral root"] = "S1 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25281"] = "EMAPA_25281"


class _S2_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model S2 dorsal root"""

    name: Literal["S2 dorsal root"] = "S2 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25282"] = "EMAPA_25282"


class _S2_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model S2 ventral root"""

    name: Literal["S2 ventral root"] = "S2 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25283"] = "EMAPA_25283"


class _S3_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model S3 dorsal root"""

    name: Literal["S3 dorsal root"] = "S3 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25284"] = "EMAPA_25284"


class _S3_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model S3 ventral root"""

    name: Literal["S3 ventral root"] = "S3 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25285"] = "EMAPA_25285"


class _S4_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model S4 dorsal root"""

    name: Literal["S4 dorsal root"] = "S4 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25286"] = "EMAPA_25286"


class _S4_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model S4 ventral root"""

    name: Literal["S4 ventral root"] = "S4 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25287"] = "EMAPA_25287"


class _T1_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T1 dorsal root"""

    name: Literal["T1 dorsal root"] = "T1 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25288"] = "EMAPA_25288"


class _T1_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T1 ventral root"""

    name: Literal["T1 ventral root"] = "T1 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25289"] = "EMAPA_25289"


class _T10_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T10 dorsal root"""

    name: Literal["T10 dorsal root"] = "T10 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25290"] = "EMAPA_25290"


class _T11_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T11 dorsal root"""

    name: Literal["T11 dorsal root"] = "T11 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25291"] = "EMAPA_25291"


class _T11_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T11 ventral root"""

    name: Literal["T11 ventral root"] = "T11 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25292"] = "EMAPA_25292"


class _T10_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T10 ventral root"""

    name: Literal["T10 ventral root"] = "T10 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25293"] = "EMAPA_25293"


class _T12_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T12 dorsal root"""

    name: Literal["T12 dorsal root"] = "T12 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25294"] = "EMAPA_25294"


class _T12_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T12 ventral root"""

    name: Literal["T12 ventral root"] = "T12 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25295"] = "EMAPA_25295"


class _T13_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T13 dorsal root"""

    name: Literal["T13 dorsal root"] = "T13 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25296"] = "EMAPA_25296"


class _T2_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T2 dorsal root"""

    name: Literal["T2 dorsal root"] = "T2 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25297"] = "EMAPA_25297"


class _T2_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T2 ventral root"""

    name: Literal["T2 ventral root"] = "T2 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25298"] = "EMAPA_25298"


class _T3_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T3 dorsal root"""

    name: Literal["T3 dorsal root"] = "T3 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25299"] = "EMAPA_25299"


class _T3_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T3 ventral root"""

    name: Literal["T3 ventral root"] = "T3 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25300"] = "EMAPA_25300"


class _T4_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T4 dorsal root"""

    name: Literal["T4 dorsal root"] = "T4 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25301"] = "EMAPA_25301"


class _T4_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T4 ventral root"""

    name: Literal["T4 ventral root"] = "T4 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25302"] = "EMAPA_25302"


class _T5_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T5 dorsal root"""

    name: Literal["T5 dorsal root"] = "T5 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25303"] = "EMAPA_25303"


class _T5_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T5 ventral root"""

    name: Literal["T5 ventral root"] = "T5 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25304"] = "EMAPA_25304"


class _T6_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T6 dorsal root"""

    name: Literal["T6 dorsal root"] = "T6 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25305"] = "EMAPA_25305"


class _T6_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T6 ventral root"""

    name: Literal["T6 ventral root"] = "T6 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25306"] = "EMAPA_25306"


class _T7_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T7 dorsal root"""

    name: Literal["T7 dorsal root"] = "T7 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25307"] = "EMAPA_25307"


class _T7_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T7 ventral root"""

    name: Literal["T7 ventral root"] = "T7 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25308"] = "EMAPA_25308"


class _T8_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T8 dorsal root"""

    name: Literal["T8 dorsal root"] = "T8 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25309"] = "EMAPA_25309"


class _T8_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T8 ventral root"""

    name: Literal["T8 ventral root"] = "T8 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25310"] = "EMAPA_25310"


class _T9_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model T9 dorsal root"""

    name: Literal["T9 dorsal root"] = "T9 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25311"] = "EMAPA_25311"


class _T9_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T9 ventral root"""

    name: Literal["T9 ventral root"] = "T9 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25312"] = "EMAPA_25312"


class _T13_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model T13 ventral root"""

    name: Literal["T13 ventral root"] = "T13 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25313"] = "EMAPA_25313"


class _Tl10_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl10 dorsal root"""

    name: Literal["Tl10 dorsal root"] = "Tl10 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25314"] = "EMAPA_25314"


class _Tl10_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl10 ventral root"""

    name: Literal["Tl10 ventral root"] = "Tl10 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25315"] = "EMAPA_25315"


class _Tl11_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl11 dorsal root"""

    name: Literal["Tl11 dorsal root"] = "Tl11 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25316"] = "EMAPA_25316"


class _Tl11_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl11 ventral root"""

    name: Literal["Tl11 ventral root"] = "Tl11 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25317"] = "EMAPA_25317"


class _Tl12_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl12 dorsal root"""

    name: Literal["Tl12 dorsal root"] = "Tl12 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25318"] = "EMAPA_25318"


class _Tl12_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl12 ventral root"""

    name: Literal["Tl12 ventral root"] = "Tl12 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25319"] = "EMAPA_25319"


class _Tl13_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl13 dorsal root"""

    name: Literal["Tl13 dorsal root"] = "Tl13 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25320"] = "EMAPA_25320"


class _Tl13_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl13 ventral root"""

    name: Literal["Tl13 ventral root"] = "Tl13 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25321"] = "EMAPA_25321"


class _Tl14_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl14 dorsal root"""

    name: Literal["Tl14 dorsal root"] = "Tl14 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25322"] = "EMAPA_25322"


class _Tl14_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl14 ventral root"""

    name: Literal["Tl14 ventral root"] = "Tl14 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25323"] = "EMAPA_25323"


class _Tl15_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl15 dorsal root"""

    name: Literal["Tl15 dorsal root"] = "Tl15 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25324"] = "EMAPA_25324"


class _Tl15_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl15 ventral root"""

    name: Literal["Tl15 ventral root"] = "Tl15 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25325"] = "EMAPA_25325"


class _Tl16_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl16 dorsal root"""

    name: Literal["Tl16 dorsal root"] = "Tl16 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25326"] = "EMAPA_25326"


class _Tl16_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl16 ventral root"""

    name: Literal["Tl16 ventral root"] = "Tl16 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25327"] = "EMAPA_25327"


class _Tl17_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl17 dorsal root"""

    name: Literal["Tl17 dorsal root"] = "Tl17 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25328"] = "EMAPA_25328"


class _Tl17_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl17 ventral root"""

    name: Literal["Tl17 ventral root"] = "Tl17 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25329"] = "EMAPA_25329"


class _Tl18_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl18 dorsal root"""

    name: Literal["Tl18 dorsal root"] = "Tl18 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25330"] = "EMAPA_25330"


class _Tl18_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl18 ventral root"""

    name: Literal["Tl18 ventral root"] = "Tl18 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25331"] = "EMAPA_25331"


class _Tl19_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl19 dorsal root"""

    name: Literal["Tl19 dorsal root"] = "Tl19 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25332"] = "EMAPA_25332"


class _Tl19_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl19 ventral root"""

    name: Literal["Tl19 ventral root"] = "Tl19 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25333"] = "EMAPA_25333"


class _Tl2_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl2 dorsal root"""

    name: Literal["Tl2 dorsal root"] = "Tl2 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25334"] = "EMAPA_25334"


class _Tl2_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl2 ventral root"""

    name: Literal["Tl2 ventral root"] = "Tl2 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25335"] = "EMAPA_25335"


class _Tl3_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl3 dorsal root"""

    name: Literal["Tl3 dorsal root"] = "Tl3 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25336"] = "EMAPA_25336"


class _Tl3_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl3 ventral root"""

    name: Literal["Tl3 ventral root"] = "Tl3 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25337"] = "EMAPA_25337"


class _Tl4_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl4 dorsal root"""

    name: Literal["Tl4 dorsal root"] = "Tl4 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25338"] = "EMAPA_25338"


class _Tl4_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl4 ventral root"""

    name: Literal["Tl4 ventral root"] = "Tl4 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25339"] = "EMAPA_25339"


class _Tl5_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl5 dorsal root"""

    name: Literal["Tl5 dorsal root"] = "Tl5 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25340"] = "EMAPA_25340"


class _Tl5_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl5 ventral root"""

    name: Literal["Tl5 ventral root"] = "Tl5 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25341"] = "EMAPA_25341"


class _Tl6_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl6 dorsal root"""

    name: Literal["Tl6 dorsal root"] = "Tl6 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25342"] = "EMAPA_25342"


class _Tl6_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl6 ventral root"""

    name: Literal["Tl6 ventral root"] = "Tl6 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25343"] = "EMAPA_25343"


class _Tl7_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl7 dorsal root"""

    name: Literal["Tl7 dorsal root"] = "Tl7 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25344"] = "EMAPA_25344"


class _Tl7_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl7 ventral root"""

    name: Literal["Tl7 ventral root"] = "Tl7 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25345"] = "EMAPA_25345"


class _Tl8_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl8 dorsal root"""

    name: Literal["Tl8 dorsal root"] = "Tl8 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25346"] = "EMAPA_25346"


class _Tl8_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl8 ventral root"""

    name: Literal["Tl8 ventral root"] = "Tl8 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25347"] = "EMAPA_25347"


class _Tl9_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model Tl9 dorsal root"""

    name: Literal["Tl9 dorsal root"] = "Tl9 dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25348"] = "EMAPA_25348"


class _Tl9_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model Tl9 ventral root"""

    name: Literal["Tl9 ventral root"] = "Tl9 ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25349"] = "EMAPA_25349"


class _Vagus_Nerve_Left_Recurrent_Laryngeal_Branch(_MouseAnatomicalStructureModel):
    """Model vagus nerve left recurrent laryngeal branch"""

    name: Literal["vagus nerve left recurrent laryngeal branch"] = "vagus nerve left recurrent laryngeal branch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25350"] = "EMAPA_25350"


class _Pinna_Mesenchyme_Condensation(_MouseAnatomicalStructureModel):
    """Model pinna mesenchyme condensation"""

    name: Literal["pinna mesenchyme condensation"] = "pinna mesenchyme condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25351"] = "EMAPA_25351"


class _Pinna_Rest_Of_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model pinna rest of mesenchyme"""

    name: Literal["pinna rest of mesenchyme"] = "pinna rest of mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25352"] = "EMAPA_25352"


class _Pinna_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model pinna cartilage condensation"""

    name: Literal["pinna cartilage condensation"] = "pinna cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25353"] = "EMAPA_25353"


class _Subcutaneous_Vein(_MouseAnatomicalStructureModel):
    """Model subcutaneous vein"""

    name: Literal["subcutaneous vein"] = "subcutaneous vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25354"] = "EMAPA_25354"


class _Trunk_Mesenchyme_Derived_From_Neural_Crest_Non_Migrating_Cells(_MouseAnatomicalStructureModel):
    """Model trunk mesenchyme derived from neural crest non-migrating cells"""

    name: Literal[
        "trunk mesenchyme derived from neural crest non-migrating cells"
    ] = "trunk mesenchyme derived from neural crest non-migrating cells"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25355"] = "EMAPA_25355"


class _Mesenchyme_Derived_From_Somites_01_04(_MouseAnatomicalStructureModel):
    """Model mesenchyme derived from somites 01-04"""

    name: Literal["mesenchyme derived from somites 01-04"] = "mesenchyme derived from somites 01-04"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25356"] = "EMAPA_25356"


class _Thyroid_Primordium_Endoderm(_MouseAnatomicalStructureModel):
    """Model thyroid primordium endoderm"""

    name: Literal["thyroid primordium endoderm"] = "thyroid primordium endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25357"] = "EMAPA_25357"


class _Rhombomere_1_Rest_Of_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 1 rest of neural fold"""

    name: Literal["rhombomere 1 rest of neural fold"] = "rhombomere 1 rest of neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25358"] = "EMAPA_25358"


class _Rhombomere_2_Rest_Of_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 2 rest of neural fold"""

    name: Literal["rhombomere 2 rest of neural fold"] = "rhombomere 2 rest of neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25359"] = "EMAPA_25359"


class _Rhombomere_3_Rest_Of_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 3 rest of neural fold"""

    name: Literal["rhombomere 3 rest of neural fold"] = "rhombomere 3 rest of neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25360"] = "EMAPA_25360"


class _Rhombomere_4_Rest_Of_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 4 rest of neural fold"""

    name: Literal["rhombomere 4 rest of neural fold"] = "rhombomere 4 rest of neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25361"] = "EMAPA_25361"


class _Rhombomere_5_Rest_Of_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere 5 rest of neural fold"""

    name: Literal["rhombomere 5 rest of neural fold"] = "rhombomere 5 rest of neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25362"] = "EMAPA_25362"


class _Otocyst_Lumen(_MouseAnatomicalStructureModel):
    """Model otocyst lumen"""

    name: Literal["otocyst lumen"] = "otocyst lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25363"] = "EMAPA_25363"


class _L2_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model L2 vertebra centrum"""

    name: Literal["L2 vertebra centrum"] = "L2 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25366"] = "EMAPA_25366"


class _L2_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model L2 future vertebral canal"""

    name: Literal["L2 future vertebral canal"] = "L2 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25368"] = "EMAPA_25368"


class _L2_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model L2 vertebra neural arch"""

    name: Literal["L2 vertebra neural arch"] = "L2 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25369"] = "EMAPA_25369"


class _L2_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model L2 neural arch lamina"""

    name: Literal["L2 neural arch lamina"] = "L2 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25370"] = "EMAPA_25370"


class _L2_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model L2 neural arch pedicle"""

    name: Literal["L2 neural arch pedicle"] = "L2 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25371"] = "EMAPA_25371"


class _Cartilage_Primordium_Of_Future_L2_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future L2 spinous process"""

    name: Literal[
        "cartilage primordium of future L2 spinous process"
    ] = "cartilage primordium of future L2 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25372"] = "EMAPA_25372"


class _L2_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model L2 neural arch transverse process"""

    name: Literal["L2 neural arch transverse process"] = "L2 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25373"] = "EMAPA_25373"


class _L3_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model L3 vertebra centrum"""

    name: Literal["L3 vertebra centrum"] = "L3 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25374"] = "EMAPA_25374"


class _L3_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model L3 future vertebral canal"""

    name: Literal["L3 future vertebral canal"] = "L3 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25376"] = "EMAPA_25376"


class _L3_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model L3 vertebra neural arch"""

    name: Literal["L3 vertebra neural arch"] = "L3 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25377"] = "EMAPA_25377"


class _L3_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model L3 neural arch lamina"""

    name: Literal["L3 neural arch lamina"] = "L3 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25378"] = "EMAPA_25378"


class _L3_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model L3 neural arch pedicle"""

    name: Literal["L3 neural arch pedicle"] = "L3 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25379"] = "EMAPA_25379"


class _Cartilage_Primordium_Of_Future_L3_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future L3 spinous process"""

    name: Literal[
        "cartilage primordium of future L3 spinous process"
    ] = "cartilage primordium of future L3 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25380"] = "EMAPA_25380"


class _L3_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model L3 neural arch transverse process"""

    name: Literal["L3 neural arch transverse process"] = "L3 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25381"] = "EMAPA_25381"


class _L4_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model L4 vertebra centrum"""

    name: Literal["L4 vertebra centrum"] = "L4 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25382"] = "EMAPA_25382"


class _L4_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model L4 future vertebral canal"""

    name: Literal["L4 future vertebral canal"] = "L4 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25384"] = "EMAPA_25384"


class _L4_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model L4 vertebra neural arch"""

    name: Literal["L4 vertebra neural arch"] = "L4 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25385"] = "EMAPA_25385"


class _L4_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model L4 neural arch lamina"""

    name: Literal["L4 neural arch lamina"] = "L4 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25386"] = "EMAPA_25386"


class _L4_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model L4 neural arch pedicle"""

    name: Literal["L4 neural arch pedicle"] = "L4 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25387"] = "EMAPA_25387"


class _Cartilage_Primordium_Of_Future_L4_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future L4 spinous process"""

    name: Literal[
        "cartilage primordium of future L4 spinous process"
    ] = "cartilage primordium of future L4 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25388"] = "EMAPA_25388"


class _L4_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model L4 neural arch transverse process"""

    name: Literal["L4 neural arch transverse process"] = "L4 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25389"] = "EMAPA_25389"


class _L5_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model L5 vertebra centrum"""

    name: Literal["L5 vertebra centrum"] = "L5 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25390"] = "EMAPA_25390"


class _L5_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model L5 future vertebral canal"""

    name: Literal["L5 future vertebral canal"] = "L5 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25392"] = "EMAPA_25392"


class _L5_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model L5 vertebra neural arch"""

    name: Literal["L5 vertebra neural arch"] = "L5 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25393"] = "EMAPA_25393"


class _L5_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model L5 neural arch lamina"""

    name: Literal["L5 neural arch lamina"] = "L5 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25394"] = "EMAPA_25394"


class _L5_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model L5 neural arch pedicle"""

    name: Literal["L5 neural arch pedicle"] = "L5 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25395"] = "EMAPA_25395"


class _Cartilage_Primordium_Of_Future_L5_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future L5 spinous process"""

    name: Literal[
        "cartilage primordium of future L5 spinous process"
    ] = "cartilage primordium of future L5 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25396"] = "EMAPA_25396"


class _L5_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model L5 neural arch transverse process"""

    name: Literal["L5 neural arch transverse process"] = "L5 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25397"] = "EMAPA_25397"


class _L6_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model L6 vertebra centrum"""

    name: Literal["L6 vertebra centrum"] = "L6 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25398"] = "EMAPA_25398"


class _L6_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model L6 future vertebral canal"""

    name: Literal["L6 future vertebral canal"] = "L6 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25400"] = "EMAPA_25400"


class _L6_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model L6 vertebra neural arch"""

    name: Literal["L6 vertebra neural arch"] = "L6 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25401"] = "EMAPA_25401"


class _L6_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model L6 neural arch lamina"""

    name: Literal["L6 neural arch lamina"] = "L6 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25402"] = "EMAPA_25402"


class _L6_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model L6 neural arch pedicle"""

    name: Literal["L6 neural arch pedicle"] = "L6 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25403"] = "EMAPA_25403"


class _Cartilage_Primordium_Of_Future_L6_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future L6 spinous process"""

    name: Literal[
        "cartilage primordium of future L6 spinous process"
    ] = "cartilage primordium of future L6 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25404"] = "EMAPA_25404"


class _L6_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model L6 neural arch transverse process"""

    name: Literal["L6 neural arch transverse process"] = "L6 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25405"] = "EMAPA_25405"


class _S1_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model S1 vertebra centrum"""

    name: Literal["S1 vertebra centrum"] = "S1 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25406"] = "EMAPA_25406"


class _S1_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model S1 future vertebral canal"""

    name: Literal["S1 future vertebral canal"] = "S1 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25408"] = "EMAPA_25408"


class _S1_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model S1 vertebra neural arch"""

    name: Literal["S1 vertebra neural arch"] = "S1 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25409"] = "EMAPA_25409"


class _S1_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model S1 neural arch lamina"""

    name: Literal["S1 neural arch lamina"] = "S1 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25410"] = "EMAPA_25410"


class _S1_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model S1 neural arch pedicle"""

    name: Literal["S1 neural arch pedicle"] = "S1 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25411"] = "EMAPA_25411"


class _Cartilage_Primordium_Of_Future_S1_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future S1 spinous process"""

    name: Literal[
        "cartilage primordium of future S1 spinous process"
    ] = "cartilage primordium of future S1 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25412"] = "EMAPA_25412"


class _S1_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model S1 neural arch transverse process"""

    name: Literal["S1 neural arch transverse process"] = "S1 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25413"] = "EMAPA_25413"


class _S2_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model S2 vertebra centrum"""

    name: Literal["S2 vertebra centrum"] = "S2 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25414"] = "EMAPA_25414"


class _S2_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model S2 future vertebral canal"""

    name: Literal["S2 future vertebral canal"] = "S2 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25416"] = "EMAPA_25416"


class _S2_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model S2 vertebra neural arch"""

    name: Literal["S2 vertebra neural arch"] = "S2 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25417"] = "EMAPA_25417"


class _S2_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model S2 neural arch lamina"""

    name: Literal["S2 neural arch lamina"] = "S2 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25418"] = "EMAPA_25418"


class _S2_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model S2 neural arch pedicle"""

    name: Literal["S2 neural arch pedicle"] = "S2 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25419"] = "EMAPA_25419"


class _Cartilage_Primordium_Of_Future_S2_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future S2 spinous process"""

    name: Literal[
        "cartilage primordium of future S2 spinous process"
    ] = "cartilage primordium of future S2 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25420"] = "EMAPA_25420"


class _S2_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model S2 neural arch transverse process"""

    name: Literal["S2 neural arch transverse process"] = "S2 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25421"] = "EMAPA_25421"


class _S3_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model S3 vertebra centrum"""

    name: Literal["S3 vertebra centrum"] = "S3 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25422"] = "EMAPA_25422"


class _S3_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model S3 future vertebral canal"""

    name: Literal["S3 future vertebral canal"] = "S3 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25424"] = "EMAPA_25424"


class _S3_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model S3 vertebra neural arch"""

    name: Literal["S3 vertebra neural arch"] = "S3 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25425"] = "EMAPA_25425"


class _S3_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model S3 neural arch lamina"""

    name: Literal["S3 neural arch lamina"] = "S3 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25426"] = "EMAPA_25426"


class _S3_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model S3 neural arch pedicle"""

    name: Literal["S3 neural arch pedicle"] = "S3 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25427"] = "EMAPA_25427"


class _Cartilage_Primordium_Of_Future_S3_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future S3 spinous process"""

    name: Literal[
        "cartilage primordium of future S3 spinous process"
    ] = "cartilage primordium of future S3 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25428"] = "EMAPA_25428"


class _S3_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model S3 neural arch transverse process"""

    name: Literal["S3 neural arch transverse process"] = "S3 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25429"] = "EMAPA_25429"


class _S4_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model S4 vertebra centrum"""

    name: Literal["S4 vertebra centrum"] = "S4 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25430"] = "EMAPA_25430"


class _S4_Future_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model S4 future vertebral canal"""

    name: Literal["S4 future vertebral canal"] = "S4 future vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25432"] = "EMAPA_25432"


class _S4_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model S4 vertebra neural arch"""

    name: Literal["S4 vertebra neural arch"] = "S4 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25433"] = "EMAPA_25433"


class _S4_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model S4 neural arch lamina"""

    name: Literal["S4 neural arch lamina"] = "S4 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25434"] = "EMAPA_25434"


class _S4_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model S4 neural arch pedicle"""

    name: Literal["S4 neural arch pedicle"] = "S4 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25435"] = "EMAPA_25435"


class _Cartilage_Primordium_Of_Future_S4_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future S4 spinous process"""

    name: Literal[
        "cartilage primordium of future S4 spinous process"
    ] = "cartilage primordium of future S4 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25436"] = "EMAPA_25436"


class _S4_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model S4 neural arch transverse process"""

    name: Literal["S4 neural arch transverse process"] = "S4 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25437"] = "EMAPA_25437"


class _T1_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T1 vertebra centrum"""

    name: Literal["T1 vertebra centrum"] = "T1 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25438"] = "EMAPA_25438"


class _T1_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T1 vertebral canal"""

    name: Literal["T1 vertebral canal"] = "T1 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25440"] = "EMAPA_25440"


class _T1_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T1 vertebra neural arch"""

    name: Literal["T1 vertebra neural arch"] = "T1 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25441"] = "EMAPA_25441"


class _T1_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T1 neural arch lamina"""

    name: Literal["T1 neural arch lamina"] = "T1 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25442"] = "EMAPA_25442"


class _T1_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T1 neural arch pedicle"""

    name: Literal["T1 neural arch pedicle"] = "T1 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25443"] = "EMAPA_25443"


class _Cartilage_Primordium_Of_Future_T1_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T1 spinous process"""

    name: Literal[
        "cartilage primordium of future T1 spinous process"
    ] = "cartilage primordium of future T1 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25444"] = "EMAPA_25444"


class _T1_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T1 neural arch transverse process"""

    name: Literal["T1 neural arch transverse process"] = "T1 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25445"] = "EMAPA_25445"


class _T10_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T10 vertebra centrum"""

    name: Literal["T10 vertebra centrum"] = "T10 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25446"] = "EMAPA_25446"


class _T10_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T10 vertebral canal"""

    name: Literal["T10 vertebral canal"] = "T10 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25448"] = "EMAPA_25448"


class _T10_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T10 vertebra neural arch"""

    name: Literal["T10 vertebra neural arch"] = "T10 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25449"] = "EMAPA_25449"


class _T10_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T10 neural arch lamina"""

    name: Literal["T10 neural arch lamina"] = "T10 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25450"] = "EMAPA_25450"


class _T10_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T10 neural arch pedicle"""

    name: Literal["T10 neural arch pedicle"] = "T10 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25451"] = "EMAPA_25451"


class _Cartilage_Primordium_Of_Future_T10_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T10 spinous process"""

    name: Literal[
        "cartilage primordium of future T10 spinous process"
    ] = "cartilage primordium of future T10 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25452"] = "EMAPA_25452"


class _T10_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T10 neural arch transverse process"""

    name: Literal["T10 neural arch transverse process"] = "T10 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25453"] = "EMAPA_25453"


class _T11_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T11 vertebra centrum"""

    name: Literal["T11 vertebra centrum"] = "T11 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25454"] = "EMAPA_25454"


class _T11_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T11 vertebral canal"""

    name: Literal["T11 vertebral canal"] = "T11 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25456"] = "EMAPA_25456"


class _T11_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T11 vertebra neural arch"""

    name: Literal["T11 vertebra neural arch"] = "T11 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25457"] = "EMAPA_25457"


class _T11_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T11 neural arch lamina"""

    name: Literal["T11 neural arch lamina"] = "T11 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25458"] = "EMAPA_25458"


class _T11_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T11 neural arch pedicle"""

    name: Literal["T11 neural arch pedicle"] = "T11 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25459"] = "EMAPA_25459"


class _Cartilage_Primordium_Of_Future_T11_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T11 spinous process"""

    name: Literal[
        "cartilage primordium of future T11 spinous process"
    ] = "cartilage primordium of future T11 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25460"] = "EMAPA_25460"


class _T11_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T11 neural arch transverse process"""

    name: Literal["T11 neural arch transverse process"] = "T11 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25461"] = "EMAPA_25461"


class _T12_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T12 vertebra centrum"""

    name: Literal["T12 vertebra centrum"] = "T12 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25462"] = "EMAPA_25462"


class _T12_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T12 vertebral canal"""

    name: Literal["T12 vertebral canal"] = "T12 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25464"] = "EMAPA_25464"


class _T12_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T12 vertebra neural arch"""

    name: Literal["T12 vertebra neural arch"] = "T12 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25465"] = "EMAPA_25465"


class _T12_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T12 neural arch lamina"""

    name: Literal["T12 neural arch lamina"] = "T12 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25466"] = "EMAPA_25466"


class _T12_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T12 neural arch pedicle"""

    name: Literal["T12 neural arch pedicle"] = "T12 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25467"] = "EMAPA_25467"


class _Cartilage_Primordium_Of_Future_T12_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T12 spinous process"""

    name: Literal[
        "cartilage primordium of future T12 spinous process"
    ] = "cartilage primordium of future T12 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25468"] = "EMAPA_25468"


class _T12_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T12 neural arch transverse process"""

    name: Literal["T12 neural arch transverse process"] = "T12 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25469"] = "EMAPA_25469"


class _T13_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T13 vertebra centrum"""

    name: Literal["T13 vertebra centrum"] = "T13 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25470"] = "EMAPA_25470"


class _T13_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T13 vertebral canal"""

    name: Literal["T13 vertebral canal"] = "T13 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25472"] = "EMAPA_25472"


class _T13_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T13 vertebra neural arch"""

    name: Literal["T13 vertebra neural arch"] = "T13 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25473"] = "EMAPA_25473"


class _T13_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T13 neural arch lamina"""

    name: Literal["T13 neural arch lamina"] = "T13 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25474"] = "EMAPA_25474"


class _T13_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T13 neural arch pedicle"""

    name: Literal["T13 neural arch pedicle"] = "T13 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25475"] = "EMAPA_25475"


class _Cartilage_Primordium_Of_Future_T13_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T13 spinous process"""

    name: Literal[
        "cartilage primordium of future T13 spinous process"
    ] = "cartilage primordium of future T13 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25476"] = "EMAPA_25476"


class _T13_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T13 neural arch transverse process"""

    name: Literal["T13 neural arch transverse process"] = "T13 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25477"] = "EMAPA_25477"


class _T2_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T2 vertebra centrum"""

    name: Literal["T2 vertebra centrum"] = "T2 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25478"] = "EMAPA_25478"


class _T2_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T2 vertebral canal"""

    name: Literal["T2 vertebral canal"] = "T2 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25480"] = "EMAPA_25480"


class _T2_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T2 vertebra neural arch"""

    name: Literal["T2 vertebra neural arch"] = "T2 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25481"] = "EMAPA_25481"


class _T2_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T2 neural arch lamina"""

    name: Literal["T2 neural arch lamina"] = "T2 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25482"] = "EMAPA_25482"


class _T2_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T2 neural arch pedicle"""

    name: Literal["T2 neural arch pedicle"] = "T2 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25483"] = "EMAPA_25483"


class _Cartilage_Primordium_Of_Future_T2_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T2 spinous process"""

    name: Literal[
        "cartilage primordium of future T2 spinous process"
    ] = "cartilage primordium of future T2 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25484"] = "EMAPA_25484"


class _T2_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T2 neural arch transverse process"""

    name: Literal["T2 neural arch transverse process"] = "T2 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25485"] = "EMAPA_25485"


class _T3_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T3 vertebra centrum"""

    name: Literal["T3 vertebra centrum"] = "T3 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25486"] = "EMAPA_25486"


class _T3_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T3 vertebral canal"""

    name: Literal["T3 vertebral canal"] = "T3 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25488"] = "EMAPA_25488"


class _T3_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T3 vertebra neural arch"""

    name: Literal["T3 vertebra neural arch"] = "T3 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25489"] = "EMAPA_25489"


class _T3_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T3 neural arch lamina"""

    name: Literal["T3 neural arch lamina"] = "T3 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25490"] = "EMAPA_25490"


class _T3_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T3 neural arch pedicle"""

    name: Literal["T3 neural arch pedicle"] = "T3 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25491"] = "EMAPA_25491"


class _Cartilage_Primordium_Of_Future_T3_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T3 spinous process"""

    name: Literal[
        "cartilage primordium of future T3 spinous process"
    ] = "cartilage primordium of future T3 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25492"] = "EMAPA_25492"


class _T3_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T3 neural arch transverse process"""

    name: Literal["T3 neural arch transverse process"] = "T3 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25493"] = "EMAPA_25493"


class _T4_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T4 vertebra centrum"""

    name: Literal["T4 vertebra centrum"] = "T4 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25494"] = "EMAPA_25494"


class _T4_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T4 vertebral canal"""

    name: Literal["T4 vertebral canal"] = "T4 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25496"] = "EMAPA_25496"


class _T4_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T4 vertebra neural arch"""

    name: Literal["T4 vertebra neural arch"] = "T4 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25497"] = "EMAPA_25497"


class _T4_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T4 neural arch lamina"""

    name: Literal["T4 neural arch lamina"] = "T4 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25498"] = "EMAPA_25498"


class _T4_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T4 neural arch pedicle"""

    name: Literal["T4 neural arch pedicle"] = "T4 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25499"] = "EMAPA_25499"


class _Cartilage_Primordium_Of_Future_T4_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T4 spinous process"""

    name: Literal[
        "cartilage primordium of future T4 spinous process"
    ] = "cartilage primordium of future T4 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25500"] = "EMAPA_25500"


class _T4_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T4 neural arch transverse process"""

    name: Literal["T4 neural arch transverse process"] = "T4 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25501"] = "EMAPA_25501"


class _T5_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T5 vertebra centrum"""

    name: Literal["T5 vertebra centrum"] = "T5 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25502"] = "EMAPA_25502"


class _T5_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T5 vertebral canal"""

    name: Literal["T5 vertebral canal"] = "T5 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25504"] = "EMAPA_25504"


class _T5_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T5 vertebra neural arch"""

    name: Literal["T5 vertebra neural arch"] = "T5 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25505"] = "EMAPA_25505"


class _T5_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T5 neural arch lamina"""

    name: Literal["T5 neural arch lamina"] = "T5 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25506"] = "EMAPA_25506"


class _T5_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T5 neural arch pedicle"""

    name: Literal["T5 neural arch pedicle"] = "T5 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25507"] = "EMAPA_25507"


class _Cartilage_Primordium_Of_Future_T5_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T5 spinous process"""

    name: Literal[
        "cartilage primordium of future T5 spinous process"
    ] = "cartilage primordium of future T5 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25508"] = "EMAPA_25508"


class _T5_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T5 neural arch transverse process"""

    name: Literal["T5 neural arch transverse process"] = "T5 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25509"] = "EMAPA_25509"


class _T6_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T6 vertebra centrum"""

    name: Literal["T6 vertebra centrum"] = "T6 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25510"] = "EMAPA_25510"


class _T6_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T6 vertebral canal"""

    name: Literal["T6 vertebral canal"] = "T6 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25512"] = "EMAPA_25512"


class _T6_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T6 vertebra neural arch"""

    name: Literal["T6 vertebra neural arch"] = "T6 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25513"] = "EMAPA_25513"


class _T6_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T6 neural arch lamina"""

    name: Literal["T6 neural arch lamina"] = "T6 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25514"] = "EMAPA_25514"


class _T6_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T6 neural arch pedicle"""

    name: Literal["T6 neural arch pedicle"] = "T6 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25515"] = "EMAPA_25515"


class _Cartilage_Primordium_Of_Future_T6_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T6 spinous process"""

    name: Literal[
        "cartilage primordium of future T6 spinous process"
    ] = "cartilage primordium of future T6 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25516"] = "EMAPA_25516"


class _T6_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T6 neural arch transverse process"""

    name: Literal["T6 neural arch transverse process"] = "T6 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25517"] = "EMAPA_25517"


class _T7_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T7 vertebra centrum"""

    name: Literal["T7 vertebra centrum"] = "T7 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25518"] = "EMAPA_25518"


class _T7_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T7 vertebral canal"""

    name: Literal["T7 vertebral canal"] = "T7 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25520"] = "EMAPA_25520"


class _T7_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T7 vertebra neural arch"""

    name: Literal["T7 vertebra neural arch"] = "T7 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25521"] = "EMAPA_25521"


class _T7_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T7 neural arch lamina"""

    name: Literal["T7 neural arch lamina"] = "T7 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25522"] = "EMAPA_25522"


class _T7_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T7 neural arch pedicle"""

    name: Literal["T7 neural arch pedicle"] = "T7 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25523"] = "EMAPA_25523"


class _Cartilage_Primordium_Of_Future_T7_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T7 spinous process"""

    name: Literal[
        "cartilage primordium of future T7 spinous process"
    ] = "cartilage primordium of future T7 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25524"] = "EMAPA_25524"


class _T7_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T7 neural arch transverse process"""

    name: Literal["T7 neural arch transverse process"] = "T7 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25525"] = "EMAPA_25525"


class _T8_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T8 vertebra centrum"""

    name: Literal["T8 vertebra centrum"] = "T8 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25526"] = "EMAPA_25526"


class _T8_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T8 vertebral canal"""

    name: Literal["T8 vertebral canal"] = "T8 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25528"] = "EMAPA_25528"


class _T8_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T8 vertebra neural arch"""

    name: Literal["T8 vertebra neural arch"] = "T8 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25529"] = "EMAPA_25529"


class _T8_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T8 neural arch lamina"""

    name: Literal["T8 neural arch lamina"] = "T8 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25530"] = "EMAPA_25530"


class _T8_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T8 neural arch pedicle"""

    name: Literal["T8 neural arch pedicle"] = "T8 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25531"] = "EMAPA_25531"


class _Cartilage_Primordium_Of_Future_T8_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T8 spinous process"""

    name: Literal[
        "cartilage primordium of future T8 spinous process"
    ] = "cartilage primordium of future T8 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25532"] = "EMAPA_25532"


class _T8_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T8 neural arch transverse process"""

    name: Literal["T8 neural arch transverse process"] = "T8 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25533"] = "EMAPA_25533"


class _T9_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model T9 vertebra centrum"""

    name: Literal["T9 vertebra centrum"] = "T9 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25534"] = "EMAPA_25534"


class _T9_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model T9 vertebral canal"""

    name: Literal["T9 vertebral canal"] = "T9 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25536"] = "EMAPA_25536"


class _T9_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model T9 vertebra neural arch"""

    name: Literal["T9 vertebra neural arch"] = "T9 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25537"] = "EMAPA_25537"


class _T9_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model T9 neural arch lamina"""

    name: Literal["T9 neural arch lamina"] = "T9 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25538"] = "EMAPA_25538"


class _T9_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model T9 neural arch pedicle"""

    name: Literal["T9 neural arch pedicle"] = "T9 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25539"] = "EMAPA_25539"


class _Cartilage_Primordium_Of_Future_T9_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future T9 spinous process"""

    name: Literal[
        "cartilage primordium of future T9 spinous process"
    ] = "cartilage primordium of future T9 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25540"] = "EMAPA_25540"


class _T9_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model T9 neural arch transverse process"""

    name: Literal["T9 neural arch transverse process"] = "T9 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25541"] = "EMAPA_25541"


class _Tl1_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl1 vertebra centrum"""

    name: Literal["Tl1 vertebra centrum"] = "Tl1 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25542"] = "EMAPA_25542"


class _Tl1_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl1 vertebral canal"""

    name: Literal["Tl1 vertebral canal"] = "Tl1 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25544"] = "EMAPA_25544"


class _Tl1_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl1 vertebra neural arch"""

    name: Literal["Tl1 vertebra neural arch"] = "Tl1 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25545"] = "EMAPA_25545"


class _Tl1_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl1 neural arch lamina"""

    name: Literal["Tl1 neural arch lamina"] = "Tl1 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25546"] = "EMAPA_25546"


class _Tl1_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl1 neural arch pedicle"""

    name: Literal["Tl1 neural arch pedicle"] = "Tl1 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25547"] = "EMAPA_25547"


class _Cartilage_Primordium_Of_Future_Tl1_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl1 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl1 spinous process"
    ] = "cartilage primordium of future Tl1 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25548"] = "EMAPA_25548"


class _Tl1_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl1 neural arch transverse process"""

    name: Literal["Tl1 neural arch transverse process"] = "Tl1 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25549"] = "EMAPA_25549"


class _Tl10_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl10 vertebra centrum"""

    name: Literal["Tl10 vertebra centrum"] = "Tl10 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25550"] = "EMAPA_25550"


class _Tl10_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl10 vertebral canal"""

    name: Literal["Tl10 vertebral canal"] = "Tl10 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25552"] = "EMAPA_25552"


class _Tl10_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl10 vertebra neural arch"""

    name: Literal["Tl10 vertebra neural arch"] = "Tl10 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25553"] = "EMAPA_25553"


class _Tl10_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl10 neural arch lamina"""

    name: Literal["Tl10 neural arch lamina"] = "Tl10 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25554"] = "EMAPA_25554"


class _Tl10_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl10 neural arch pedicle"""

    name: Literal["Tl10 neural arch pedicle"] = "Tl10 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25555"] = "EMAPA_25555"


class _Cartilage_Primordium_Of_Future_Tl10_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl10 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl10 spinous process"
    ] = "cartilage primordium of future Tl10 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25556"] = "EMAPA_25556"


class _Tl10_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl10 neural arch transverse process"""

    name: Literal["Tl10 neural arch transverse process"] = "Tl10 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25557"] = "EMAPA_25557"


class _Tl11_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl11 vertebra centrum"""

    name: Literal["Tl11 vertebra centrum"] = "Tl11 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25558"] = "EMAPA_25558"


class _Tl11_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl11 vertebral canal"""

    name: Literal["Tl11 vertebral canal"] = "Tl11 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25560"] = "EMAPA_25560"


class _Tl11_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl11 vertebra neural arch"""

    name: Literal["Tl11 vertebra neural arch"] = "Tl11 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25561"] = "EMAPA_25561"


class _Tl11_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl11 neural arch lamina"""

    name: Literal["Tl11 neural arch lamina"] = "Tl11 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25562"] = "EMAPA_25562"


class _Tl11_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl11 neural arch pedicle"""

    name: Literal["Tl11 neural arch pedicle"] = "Tl11 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25563"] = "EMAPA_25563"


class _Cartilage_Primordium_Of_Future_Tl11_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl11 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl11 spinous process"
    ] = "cartilage primordium of future Tl11 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25564"] = "EMAPA_25564"


class _Tl11_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl11 neural arch transverse process"""

    name: Literal["Tl11 neural arch transverse process"] = "Tl11 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25565"] = "EMAPA_25565"


class _Tl12_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl12 vertebra centrum"""

    name: Literal["Tl12 vertebra centrum"] = "Tl12 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25566"] = "EMAPA_25566"


class _Tl12_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl12 vertebral canal"""

    name: Literal["Tl12 vertebral canal"] = "Tl12 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25568"] = "EMAPA_25568"


class _Tl12_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl12 vertebra neural arch"""

    name: Literal["Tl12 vertebra neural arch"] = "Tl12 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25569"] = "EMAPA_25569"


class _Tl12_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl12 neural arch lamina"""

    name: Literal["Tl12 neural arch lamina"] = "Tl12 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25570"] = "EMAPA_25570"


class _Tl12_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl12 neural arch pedicle"""

    name: Literal["Tl12 neural arch pedicle"] = "Tl12 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25571"] = "EMAPA_25571"


class _Cartilage_Primordium_Of_Future_Tl12_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl12 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl12 spinous process"
    ] = "cartilage primordium of future Tl12 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25572"] = "EMAPA_25572"


class _Tl12_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl12 neural arch transverse process"""

    name: Literal["Tl12 neural arch transverse process"] = "Tl12 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25573"] = "EMAPA_25573"


class _Tl13_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl13 vertebra centrum"""

    name: Literal["Tl13 vertebra centrum"] = "Tl13 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25574"] = "EMAPA_25574"


class _Tl13_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl13 vertebral canal"""

    name: Literal["Tl13 vertebral canal"] = "Tl13 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25576"] = "EMAPA_25576"


class _Tl13_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl13 vertebra neural arch"""

    name: Literal["Tl13 vertebra neural arch"] = "Tl13 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25577"] = "EMAPA_25577"


class _Tl13_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl13 neural arch lamina"""

    name: Literal["Tl13 neural arch lamina"] = "Tl13 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25578"] = "EMAPA_25578"


class _Tl13_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl13 neural arch pedicle"""

    name: Literal["Tl13 neural arch pedicle"] = "Tl13 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25579"] = "EMAPA_25579"


class _Cartilage_Primordium_Of_Future_Tl13_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl13 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl13 spinous process"
    ] = "cartilage primordium of future Tl13 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25580"] = "EMAPA_25580"


class _Tl13_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl13 neural arch transverse process"""

    name: Literal["Tl13 neural arch transverse process"] = "Tl13 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25581"] = "EMAPA_25581"


class _Tl14_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl14 vertebra centrum"""

    name: Literal["Tl14 vertebra centrum"] = "Tl14 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25582"] = "EMAPA_25582"


class _Tl14_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl14 vertebral canal"""

    name: Literal["Tl14 vertebral canal"] = "Tl14 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25584"] = "EMAPA_25584"


class _Tl14_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl14 vertebra neural arch"""

    name: Literal["Tl14 vertebra neural arch"] = "Tl14 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25585"] = "EMAPA_25585"


class _Tl14_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl14 neural arch lamina"""

    name: Literal["Tl14 neural arch lamina"] = "Tl14 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25586"] = "EMAPA_25586"


class _Tl14_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl14 neural arch pedicle"""

    name: Literal["Tl14 neural arch pedicle"] = "Tl14 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25587"] = "EMAPA_25587"


class _Cartilage_Primordium_Of_Future_Tl14_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl14 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl14 spinous process"
    ] = "cartilage primordium of future Tl14 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25588"] = "EMAPA_25588"


class _Tl14_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl14 neural arch transverse process"""

    name: Literal["Tl14 neural arch transverse process"] = "Tl14 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25589"] = "EMAPA_25589"


class _Tl15_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl15 vertebra centrum"""

    name: Literal["Tl15 vertebra centrum"] = "Tl15 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25590"] = "EMAPA_25590"


class _Tl15_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl15 vertebral canal"""

    name: Literal["Tl15 vertebral canal"] = "Tl15 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25592"] = "EMAPA_25592"


class _Tl15_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl15 vertebra neural arch"""

    name: Literal["Tl15 vertebra neural arch"] = "Tl15 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25593"] = "EMAPA_25593"


class _Tl15_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl15 neural arch lamina"""

    name: Literal["Tl15 neural arch lamina"] = "Tl15 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25594"] = "EMAPA_25594"


class _Tl15_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl15 neural arch pedicle"""

    name: Literal["Tl15 neural arch pedicle"] = "Tl15 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25595"] = "EMAPA_25595"


class _Cartilage_Primordium_Of_Future_Tl15_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl15 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl15 spinous process"
    ] = "cartilage primordium of future Tl15 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25596"] = "EMAPA_25596"


class _Tl15_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl15 neural arch transverse process"""

    name: Literal["Tl15 neural arch transverse process"] = "Tl15 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25597"] = "EMAPA_25597"


class _Tl16_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl16 vertebra centrum"""

    name: Literal["Tl16 vertebra centrum"] = "Tl16 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25598"] = "EMAPA_25598"


class _Tl16_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl16 vertebral canal"""

    name: Literal["Tl16 vertebral canal"] = "Tl16 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25600"] = "EMAPA_25600"


class _Tl16_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl16 vertebra neural arch"""

    name: Literal["Tl16 vertebra neural arch"] = "Tl16 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25601"] = "EMAPA_25601"


class _Tl16_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl16 neural arch lamina"""

    name: Literal["Tl16 neural arch lamina"] = "Tl16 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25602"] = "EMAPA_25602"


class _Tl16_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl16 neural arch pedicle"""

    name: Literal["Tl16 neural arch pedicle"] = "Tl16 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25603"] = "EMAPA_25603"


class _Cartilage_Primordium_Of_Future_Tl16_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl16 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl16 spinous process"
    ] = "cartilage primordium of future Tl16 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25604"] = "EMAPA_25604"


class _Tl16_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl16 neural arch transverse process"""

    name: Literal["Tl16 neural arch transverse process"] = "Tl16 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25605"] = "EMAPA_25605"


class _Tl17_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl17 vertebra centrum"""

    name: Literal["Tl17 vertebra centrum"] = "Tl17 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25606"] = "EMAPA_25606"


class _Tl17_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl17 vertebral canal"""

    name: Literal["Tl17 vertebral canal"] = "Tl17 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25608"] = "EMAPA_25608"


class _Tl17_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl17 vertebra neural arch"""

    name: Literal["Tl17 vertebra neural arch"] = "Tl17 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25609"] = "EMAPA_25609"


class _Tl17_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl17 neural arch lamina"""

    name: Literal["Tl17 neural arch lamina"] = "Tl17 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25610"] = "EMAPA_25610"


class _Tl17_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl17 neural arch pedicle"""

    name: Literal["Tl17 neural arch pedicle"] = "Tl17 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25611"] = "EMAPA_25611"


class _Cartilage_Primordium_Of_Future_Tl17_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl17 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl17 spinous process"
    ] = "cartilage primordium of future Tl17 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25612"] = "EMAPA_25612"


class _Tl17_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl17 neural arch transverse process"""

    name: Literal["Tl17 neural arch transverse process"] = "Tl17 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25613"] = "EMAPA_25613"


class _Tl18_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl18 vertebra centrum"""

    name: Literal["Tl18 vertebra centrum"] = "Tl18 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25614"] = "EMAPA_25614"


class _Tl18_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl18 vertebral canal"""

    name: Literal["Tl18 vertebral canal"] = "Tl18 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25616"] = "EMAPA_25616"


class _Tl18_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl18 vertebra neural arch"""

    name: Literal["Tl18 vertebra neural arch"] = "Tl18 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25617"] = "EMAPA_25617"


class _Tl18_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl18 neural arch lamina"""

    name: Literal["Tl18 neural arch lamina"] = "Tl18 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25618"] = "EMAPA_25618"


class _Tl18_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl18 neural arch pedicle"""

    name: Literal["Tl18 neural arch pedicle"] = "Tl18 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25619"] = "EMAPA_25619"


class _Cartilage_Primordium_Of_Future_Tl18_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl18 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl18 spinous process"
    ] = "cartilage primordium of future Tl18 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25620"] = "EMAPA_25620"


class _Tl18_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl18 neural arch transverse process"""

    name: Literal["Tl18 neural arch transverse process"] = "Tl18 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25621"] = "EMAPA_25621"


class _Tl19_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl19 vertebra centrum"""

    name: Literal["Tl19 vertebra centrum"] = "Tl19 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25622"] = "EMAPA_25622"


class _Tl19_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl19 vertebral canal"""

    name: Literal["Tl19 vertebral canal"] = "Tl19 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25624"] = "EMAPA_25624"


class _Tl19_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl19 vertebra neural arch"""

    name: Literal["Tl19 vertebra neural arch"] = "Tl19 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25625"] = "EMAPA_25625"


class _Tl19_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl19 neural arch lamina"""

    name: Literal["Tl19 neural arch lamina"] = "Tl19 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25626"] = "EMAPA_25626"


class _Tl19_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl19 neural arch pedicle"""

    name: Literal["Tl19 neural arch pedicle"] = "Tl19 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25627"] = "EMAPA_25627"


class _Cartilage_Primordium_Of_Future_Tl19_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl19 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl19 spinous process"
    ] = "cartilage primordium of future Tl19 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25628"] = "EMAPA_25628"


class _Tl19_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl19 neural arch transverse process"""

    name: Literal["Tl19 neural arch transverse process"] = "Tl19 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25629"] = "EMAPA_25629"


class _Tl2_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl2 vertebra centrum"""

    name: Literal["Tl2 vertebra centrum"] = "Tl2 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25630"] = "EMAPA_25630"


class _Tl2_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl2 vertebral canal"""

    name: Literal["Tl2 vertebral canal"] = "Tl2 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25632"] = "EMAPA_25632"


class _Tl2_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl2 vertebra neural arch"""

    name: Literal["Tl2 vertebra neural arch"] = "Tl2 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25633"] = "EMAPA_25633"


class _Tl2_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl2 neural arch lamina"""

    name: Literal["Tl2 neural arch lamina"] = "Tl2 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25634"] = "EMAPA_25634"


class _Tl2_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl2 neural arch pedicle"""

    name: Literal["Tl2 neural arch pedicle"] = "Tl2 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25635"] = "EMAPA_25635"


class _Cartilage_Primordium_Of_Future_Tl2_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl2 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl2 spinous process"
    ] = "cartilage primordium of future Tl2 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25636"] = "EMAPA_25636"


class _Tl2_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl2 neural arch transverse process"""

    name: Literal["Tl2 neural arch transverse process"] = "Tl2 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25637"] = "EMAPA_25637"


class _Tl3_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl3 vertebra centrum"""

    name: Literal["Tl3 vertebra centrum"] = "Tl3 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25638"] = "EMAPA_25638"


class _Tl3_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl3 vertebral canal"""

    name: Literal["Tl3 vertebral canal"] = "Tl3 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25640"] = "EMAPA_25640"


class _Tl3_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl3 vertebra neural arch"""

    name: Literal["Tl3 vertebra neural arch"] = "Tl3 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25641"] = "EMAPA_25641"


class _Tl3_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl3 neural arch lamina"""

    name: Literal["Tl3 neural arch lamina"] = "Tl3 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25642"] = "EMAPA_25642"


class _Tl3_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl3 neural arch pedicle"""

    name: Literal["Tl3 neural arch pedicle"] = "Tl3 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25643"] = "EMAPA_25643"


class _Cartilage_Primordium_Of_Future_Tl3_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl3 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl3 spinous process"
    ] = "cartilage primordium of future Tl3 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25644"] = "EMAPA_25644"


class _Tl3_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl3 neural arch transverse process"""

    name: Literal["Tl3 neural arch transverse process"] = "Tl3 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25645"] = "EMAPA_25645"


class _Tl4_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl4 vertebra centrum"""

    name: Literal["Tl4 vertebra centrum"] = "Tl4 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25646"] = "EMAPA_25646"


class _Tl4_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl4 vertebral canal"""

    name: Literal["Tl4 vertebral canal"] = "Tl4 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25648"] = "EMAPA_25648"


class _Tl4_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl4 vertebra neural arch"""

    name: Literal["Tl4 vertebra neural arch"] = "Tl4 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25649"] = "EMAPA_25649"


class _Tl4_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl4 neural arch lamina"""

    name: Literal["Tl4 neural arch lamina"] = "Tl4 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25650"] = "EMAPA_25650"


class _Tl4_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl4 neural arch pedicle"""

    name: Literal["Tl4 neural arch pedicle"] = "Tl4 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25651"] = "EMAPA_25651"


class _Cartilage_Primordium_Of_Future_Tl4_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl4 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl4 spinous process"
    ] = "cartilage primordium of future Tl4 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25652"] = "EMAPA_25652"


class _Tl4_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl4 neural arch transverse process"""

    name: Literal["Tl4 neural arch transverse process"] = "Tl4 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25653"] = "EMAPA_25653"


class _Tl5_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl5 vertebra centrum"""

    name: Literal["Tl5 vertebra centrum"] = "Tl5 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25654"] = "EMAPA_25654"


class _Tl5_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl5 vertebral canal"""

    name: Literal["Tl5 vertebral canal"] = "Tl5 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25656"] = "EMAPA_25656"


class _Tl5_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl5 vertebra neural arch"""

    name: Literal["Tl5 vertebra neural arch"] = "Tl5 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25657"] = "EMAPA_25657"


class _Tl5_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl5 neural arch lamina"""

    name: Literal["Tl5 neural arch lamina"] = "Tl5 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25658"] = "EMAPA_25658"


class _Tl5_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl5 neural arch pedicle"""

    name: Literal["Tl5 neural arch pedicle"] = "Tl5 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25659"] = "EMAPA_25659"


class _Cartilage_Primordium_Of_Future_Tl5_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl5 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl5 spinous process"
    ] = "cartilage primordium of future Tl5 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25660"] = "EMAPA_25660"


class _Tl5_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl5 neural arch transverse process"""

    name: Literal["Tl5 neural arch transverse process"] = "Tl5 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25661"] = "EMAPA_25661"


class _Tl6_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl6 vertebra centrum"""

    name: Literal["Tl6 vertebra centrum"] = "Tl6 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25662"] = "EMAPA_25662"


class _Tl6_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl6 vertebral canal"""

    name: Literal["Tl6 vertebral canal"] = "Tl6 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25664"] = "EMAPA_25664"


class _Tl6_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl6 vertebra neural arch"""

    name: Literal["Tl6 vertebra neural arch"] = "Tl6 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25665"] = "EMAPA_25665"


class _Tl6_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl6 neural arch lamina"""

    name: Literal["Tl6 neural arch lamina"] = "Tl6 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25666"] = "EMAPA_25666"


class _Tl6_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl6 neural arch pedicle"""

    name: Literal["Tl6 neural arch pedicle"] = "Tl6 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25667"] = "EMAPA_25667"


class _Cartilage_Primordium_Of_Future_Tl6_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl6 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl6 spinous process"
    ] = "cartilage primordium of future Tl6 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25668"] = "EMAPA_25668"


class _Tl6_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl6 neural arch transverse process"""

    name: Literal["Tl6 neural arch transverse process"] = "Tl6 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25669"] = "EMAPA_25669"


class _Tl7_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl7 vertebra centrum"""

    name: Literal["Tl7 vertebra centrum"] = "Tl7 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25670"] = "EMAPA_25670"


class _Tl7_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl7 vertebral canal"""

    name: Literal["Tl7 vertebral canal"] = "Tl7 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25672"] = "EMAPA_25672"


class _Tl7_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl7 vertebra neural arch"""

    name: Literal["Tl7 vertebra neural arch"] = "Tl7 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25673"] = "EMAPA_25673"


class _Tl7_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl7 neural arch lamina"""

    name: Literal["Tl7 neural arch lamina"] = "Tl7 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25674"] = "EMAPA_25674"


class _Tl7_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl7 neural arch pedicle"""

    name: Literal["Tl7 neural arch pedicle"] = "Tl7 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25675"] = "EMAPA_25675"


class _Cartilage_Primordium_Of_Future_Tl7_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl7 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl7 spinous process"
    ] = "cartilage primordium of future Tl7 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25676"] = "EMAPA_25676"


class _Tl7_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl7 neural arch transverse process"""

    name: Literal["Tl7 neural arch transverse process"] = "Tl7 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25677"] = "EMAPA_25677"


class _Tl8_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl8 vertebra centrum"""

    name: Literal["Tl8 vertebra centrum"] = "Tl8 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25678"] = "EMAPA_25678"


class _Tl8_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl8 vertebral canal"""

    name: Literal["Tl8 vertebral canal"] = "Tl8 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25680"] = "EMAPA_25680"


class _Tl8_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl8 vertebra neural arch"""

    name: Literal["Tl8 vertebra neural arch"] = "Tl8 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25681"] = "EMAPA_25681"


class _Tl8_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl8 neural arch lamina"""

    name: Literal["Tl8 neural arch lamina"] = "Tl8 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25682"] = "EMAPA_25682"


class _Tl8_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl8 neural arch pedicle"""

    name: Literal["Tl8 neural arch pedicle"] = "Tl8 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25683"] = "EMAPA_25683"


class _Cartilage_Primordium_Of_Future_Tl8_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl8 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl8 spinous process"
    ] = "cartilage primordium of future Tl8 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25684"] = "EMAPA_25684"


class _Tl8_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl8 neural arch transverse process"""

    name: Literal["Tl8 neural arch transverse process"] = "Tl8 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25685"] = "EMAPA_25685"


class _Tl9_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model Tl9 vertebra centrum"""

    name: Literal["Tl9 vertebra centrum"] = "Tl9 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25686"] = "EMAPA_25686"


class _Tl9_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model Tl9 vertebral canal"""

    name: Literal["Tl9 vertebral canal"] = "Tl9 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25688"] = "EMAPA_25688"


class _Tl9_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model Tl9 vertebra neural arch"""

    name: Literal["Tl9 vertebra neural arch"] = "Tl9 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25689"] = "EMAPA_25689"


class _Tl9_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model Tl9 neural arch lamina"""

    name: Literal["Tl9 neural arch lamina"] = "Tl9 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25690"] = "EMAPA_25690"


class _Tl9_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model Tl9 neural arch pedicle"""

    name: Literal["Tl9 neural arch pedicle"] = "Tl9 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25691"] = "EMAPA_25691"


class _Cartilage_Primordium_Of_Future_Tl9_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future Tl9 spinous process"""

    name: Literal[
        "cartilage primordium of future Tl9 spinous process"
    ] = "cartilage primordium of future Tl9 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25692"] = "EMAPA_25692"


class _Tl9_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model Tl9 neural arch transverse process"""

    name: Literal["Tl9 neural arch transverse process"] = "Tl9 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25693"] = "EMAPA_25693"


class _T10_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T10 rib costal cartilage"""

    name: Literal["T10 rib costal cartilage"] = "T10 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25694"] = "EMAPA_25694"


class _T10_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T10 rib head cartilage"""

    name: Literal["T10 rib head cartilage"] = "T10 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25695"] = "EMAPA_25695"


class _T10_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T10 rib neck cartilage"""

    name: Literal["T10 rib neck cartilage"] = "T10 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25696"] = "EMAPA_25696"


class _T11_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T11 rib costal cartilage"""

    name: Literal["T11 rib costal cartilage"] = "T11 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25697"] = "EMAPA_25697"


class _T11_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T11 rib head cartilage"""

    name: Literal["T11 rib head cartilage"] = "T11 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25698"] = "EMAPA_25698"


class _T11_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T11 rib neck cartilage"""

    name: Literal["T11 rib neck cartilage"] = "T11 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25699"] = "EMAPA_25699"


class _T12_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T12 rib costal cartilage"""

    name: Literal["T12 rib costal cartilage"] = "T12 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25700"] = "EMAPA_25700"


class _T12_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T12 rib head cartilage"""

    name: Literal["T12 rib head cartilage"] = "T12 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25701"] = "EMAPA_25701"


class _T12_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T12 rib neck cartilage"""

    name: Literal["T12 rib neck cartilage"] = "T12 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25702"] = "EMAPA_25702"


class _T13_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T13 rib costal cartilage"""

    name: Literal["T13 rib costal cartilage"] = "T13 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25703"] = "EMAPA_25703"


class _T13_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T13 rib head cartilage"""

    name: Literal["T13 rib head cartilage"] = "T13 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25704"] = "EMAPA_25704"


class _T13_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T13 rib neck cartilage"""

    name: Literal["T13 rib neck cartilage"] = "T13 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25705"] = "EMAPA_25705"


class _T2_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T2 rib costal cartilage"""

    name: Literal["T2 rib costal cartilage"] = "T2 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25706"] = "EMAPA_25706"


class _T2_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T2 rib head cartilage"""

    name: Literal["T2 rib head cartilage"] = "T2 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25707"] = "EMAPA_25707"


class _T2_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T2 rib neck cartilage"""

    name: Literal["T2 rib neck cartilage"] = "T2 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25708"] = "EMAPA_25708"


class _T3_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T3 rib costal cartilage"""

    name: Literal["T3 rib costal cartilage"] = "T3 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25709"] = "EMAPA_25709"


class _T3_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T3 rib head cartilage"""

    name: Literal["T3 rib head cartilage"] = "T3 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25710"] = "EMAPA_25710"


class _T3_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T3 rib neck cartilage"""

    name: Literal["T3 rib neck cartilage"] = "T3 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25711"] = "EMAPA_25711"


class _T4_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T4 rib costal cartilage"""

    name: Literal["T4 rib costal cartilage"] = "T4 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25712"] = "EMAPA_25712"


class _T4_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T4 rib head cartilage"""

    name: Literal["T4 rib head cartilage"] = "T4 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25713"] = "EMAPA_25713"


class _T4_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T4 rib neck cartilage"""

    name: Literal["T4 rib neck cartilage"] = "T4 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25714"] = "EMAPA_25714"


class _T5_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T5 rib costal cartilage"""

    name: Literal["T5 rib costal cartilage"] = "T5 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25715"] = "EMAPA_25715"


class _T5_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T5 rib head cartilage"""

    name: Literal["T5 rib head cartilage"] = "T5 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25716"] = "EMAPA_25716"


class _T5_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T5 rib neck cartilage"""

    name: Literal["T5 rib neck cartilage"] = "T5 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25717"] = "EMAPA_25717"


class _T6_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T6 rib costal cartilage"""

    name: Literal["T6 rib costal cartilage"] = "T6 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25718"] = "EMAPA_25718"


class _T6_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T6 rib head cartilage"""

    name: Literal["T6 rib head cartilage"] = "T6 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25719"] = "EMAPA_25719"


class _T6_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T6 rib neck cartilage"""

    name: Literal["T6 rib neck cartilage"] = "T6 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25720"] = "EMAPA_25720"


class _T7_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T7 rib costal cartilage"""

    name: Literal["T7 rib costal cartilage"] = "T7 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25721"] = "EMAPA_25721"


class _T7_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T7 rib head cartilage"""

    name: Literal["T7 rib head cartilage"] = "T7 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25722"] = "EMAPA_25722"


class _T7_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T7 rib neck cartilage"""

    name: Literal["T7 rib neck cartilage"] = "T7 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25723"] = "EMAPA_25723"


class _T8_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T8 rib costal cartilage"""

    name: Literal["T8 rib costal cartilage"] = "T8 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25724"] = "EMAPA_25724"


class _T8_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T8 rib head cartilage"""

    name: Literal["T8 rib head cartilage"] = "T8 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25725"] = "EMAPA_25725"


class _T8_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T8 rib neck cartilage"""

    name: Literal["T8 rib neck cartilage"] = "T8 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25726"] = "EMAPA_25726"


class _T9_Rib_Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model T9 rib costal cartilage"""

    name: Literal["T9 rib costal cartilage"] = "T9 rib costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25727"] = "EMAPA_25727"


class _T9_Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model T9 rib head cartilage"""

    name: Literal["T9 rib head cartilage"] = "T9 rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25728"] = "EMAPA_25728"


class _T9_Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model T9 rib neck cartilage"""

    name: Literal["T9 rib neck cartilage"] = "T9 rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25729"] = "EMAPA_25729"


class _C3_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model C3 vertebra centrum"""

    name: Literal["C3 vertebra centrum"] = "C3 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25730"] = "EMAPA_25730"


class _C3_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model C3 vertebral canal"""

    name: Literal["C3 vertebral canal"] = "C3 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25731"] = "EMAPA_25731"


class _C3_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model C3 vertebra neural arch"""

    name: Literal["C3 vertebra neural arch"] = "C3 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25732"] = "EMAPA_25732"


class _C3_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model C3 neural arch lamina"""

    name: Literal["C3 neural arch lamina"] = "C3 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25733"] = "EMAPA_25733"


class _C3_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model C3 neural arch pedicle"""

    name: Literal["C3 neural arch pedicle"] = "C3 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25734"] = "EMAPA_25734"


class _Cartilage_Primordium_Of_Future_C3_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future C3 spinous process"""

    name: Literal[
        "cartilage primordium of future C3 spinous process"
    ] = "cartilage primordium of future C3 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25735"] = "EMAPA_25735"


class _C3_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model C3 neural arch transverse process"""

    name: Literal["C3 neural arch transverse process"] = "C3 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25736"] = "EMAPA_25736"


class _C4_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model C4 vertebra centrum"""

    name: Literal["C4 vertebra centrum"] = "C4 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25737"] = "EMAPA_25737"


class _C4_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model C4 vertebral canal"""

    name: Literal["C4 vertebral canal"] = "C4 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25738"] = "EMAPA_25738"


class _C4_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model C4 vertebra neural arch"""

    name: Literal["C4 vertebra neural arch"] = "C4 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25739"] = "EMAPA_25739"


class _C4_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model C4 neural arch lamina"""

    name: Literal["C4 neural arch lamina"] = "C4 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25740"] = "EMAPA_25740"


class _C4_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model C4 neural arch pedicle"""

    name: Literal["C4 neural arch pedicle"] = "C4 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25741"] = "EMAPA_25741"


class _Cartilage_Primordium_Of_Future_C4_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future C4 spinous process"""

    name: Literal[
        "cartilage primordium of future C4 spinous process"
    ] = "cartilage primordium of future C4 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25742"] = "EMAPA_25742"


class _C4_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model C4 neural arch transverse process"""

    name: Literal["C4 neural arch transverse process"] = "C4 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25743"] = "EMAPA_25743"


class _C5_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model C5 vertebra centrum"""

    name: Literal["C5 vertebra centrum"] = "C5 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25744"] = "EMAPA_25744"


class _C5_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model C5 vertebral canal"""

    name: Literal["C5 vertebral canal"] = "C5 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25745"] = "EMAPA_25745"


class _C5_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model C5 vertebra neural arch"""

    name: Literal["C5 vertebra neural arch"] = "C5 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25746"] = "EMAPA_25746"


class _C5_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model C5 neural arch lamina"""

    name: Literal["C5 neural arch lamina"] = "C5 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25747"] = "EMAPA_25747"


class _C5_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model C5 neural arch pedicle"""

    name: Literal["C5 neural arch pedicle"] = "C5 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25748"] = "EMAPA_25748"


class _Cartilage_Primordium_Of_Future_C5_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future C5 spinous process"""

    name: Literal[
        "cartilage primordium of future C5 spinous process"
    ] = "cartilage primordium of future C5 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25749"] = "EMAPA_25749"


class _C5_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model C5 neural arch transverse process"""

    name: Literal["C5 neural arch transverse process"] = "C5 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25750"] = "EMAPA_25750"


class _C6_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model C6 vertebra centrum"""

    name: Literal["C6 vertebra centrum"] = "C6 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25751"] = "EMAPA_25751"


class _C6_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model C6 vertebral canal"""

    name: Literal["C6 vertebral canal"] = "C6 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25752"] = "EMAPA_25752"


class _C6_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model C6 vertebra neural arch"""

    name: Literal["C6 vertebra neural arch"] = "C6 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25753"] = "EMAPA_25753"


class _C6_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model C6 neural arch lamina"""

    name: Literal["C6 neural arch lamina"] = "C6 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25754"] = "EMAPA_25754"


class _C6_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model C6 neural arch pedicle"""

    name: Literal["C6 neural arch pedicle"] = "C6 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25755"] = "EMAPA_25755"


class _Cartilage_Primordium_Of_Future_C6_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future C6 spinous process"""

    name: Literal[
        "cartilage primordium of future C6 spinous process"
    ] = "cartilage primordium of future C6 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25756"] = "EMAPA_25756"


class _C6_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model C6 neural arch transverse process"""

    name: Literal["C6 neural arch transverse process"] = "C6 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25757"] = "EMAPA_25757"


class _C7_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model C7 vertebra centrum"""

    name: Literal["C7 vertebra centrum"] = "C7 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25758"] = "EMAPA_25758"


class _C7_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model C7 vertebral canal"""

    name: Literal["C7 vertebral canal"] = "C7 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25759"] = "EMAPA_25759"


class _C7_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model C7 vertebra neural arch"""

    name: Literal["C7 vertebra neural arch"] = "C7 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25760"] = "EMAPA_25760"


class _C7_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model C7 neural arch lamina"""

    name: Literal["C7 neural arch lamina"] = "C7 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25761"] = "EMAPA_25761"


class _C7_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model C7 neural arch pedicle"""

    name: Literal["C7 neural arch pedicle"] = "C7 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25762"] = "EMAPA_25762"


class _Cartilage_Primordium_Of_Future_C7_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future C7 spinous process"""

    name: Literal[
        "cartilage primordium of future C7 spinous process"
    ] = "cartilage primordium of future C7 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25763"] = "EMAPA_25763"


class _C7_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model C7 neural arch transverse process"""

    name: Literal["C7 neural arch transverse process"] = "C7 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25764"] = "EMAPA_25764"


class _Mouse(_MouseAnatomicalStructureModel):
    """Model mouse"""

    name: Literal["mouse"] = "mouse"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_25765"] = "EMAPA_25765"


class _Left_Atrium_Lumen(_MouseAnatomicalStructureModel):
    """Model left atrium lumen"""

    name: Literal["left atrium lumen"] = "left atrium lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26011"] = "EMAPA_26011"


class _Right_Atrium_Lumen(_MouseAnatomicalStructureModel):
    """Model right atrium lumen"""

    name: Literal["right atrium lumen"] = "right atrium lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26020"] = "EMAPA_26020"


class _Interventricular_Canal(_MouseAnatomicalStructureModel):
    """Model interventricular canal"""

    name: Literal["interventricular canal"] = "interventricular canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26029"] = "EMAPA_26029"


class _Left_Ventricle_Lumen(_MouseAnatomicalStructureModel):
    """Model left ventricle lumen"""

    name: Literal["left ventricle lumen"] = "left ventricle lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26038"] = "EMAPA_26038"


class _Right_Ventricle_Lumen(_MouseAnatomicalStructureModel):
    """Model right ventricle lumen"""

    name: Literal["right ventricle lumen"] = "right ventricle lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26047"] = "EMAPA_26047"


class _Intersegmental_Vein(_MouseAnatomicalStructureModel):
    """Model intersegmental vein"""

    name: Literal["intersegmental vein"] = "intersegmental vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26056"] = "EMAPA_26056"


class _Median_Sacral_Vein(_MouseAnatomicalStructureModel):
    """Model median sacral vein"""

    name: Literal["median sacral vein"] = "median sacral vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26064"] = "EMAPA_26064"


class _Inferior_Vena_Cava_Intrahepatic_Part(_MouseAnatomicalStructureModel):
    """Model inferior vena cava intrahepatic part"""

    name: Literal["inferior vena cava intrahepatic part"] = "inferior vena cava intrahepatic part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26072"] = "EMAPA_26072"


class _Communication_Ductus_Venosus_To_Portal_Vein(_MouseAnatomicalStructureModel):
    """Model communication ductus venosus to portal vein"""

    name: Literal["communication ductus venosus to portal vein"] = "communication ductus venosus to portal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26081"] = "EMAPA_26081"


class _Physiological_Umbilical_Hernia_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model physiological umbilical hernia mesenchyme"""

    name: Literal["physiological umbilical hernia mesenchyme"] = "physiological umbilical hernia mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26089"] = "EMAPA_26089"


class _Physiological_Umbilical_Hernia_Mesothelium(_MouseAnatomicalStructureModel):
    """Model physiological umbilical hernia mesothelium"""

    name: Literal["physiological umbilical hernia mesothelium"] = "physiological umbilical hernia mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26097"] = "EMAPA_26097"


class _Umbilical_Cord(_MouseAnatomicalStructureModel):
    """Model umbilical cord"""

    name: Literal["umbilical cord"] = "umbilical cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26115"] = "EMAPA_26115"


class _Umbilical_Cord_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model umbilical cord mesenchyme"""

    name: Literal["umbilical cord mesenchyme"] = "umbilical cord mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26127"] = "EMAPA_26127"


class _Vitelline_Duct(_MouseAnatomicalStructureModel):
    """Model vitelline duct"""

    name: Literal["vitelline duct"] = "vitelline duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26139"] = "EMAPA_26139"


class _Vitelline_Vein_Vitelline_Duct_Part(_MouseAnatomicalStructureModel):
    """Model vitelline vein vitelline duct part"""

    name: Literal["vitelline vein vitelline duct part"] = "vitelline vein vitelline duct part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26151"] = "EMAPA_26151"


class _Cavity_Of_Physiological_Umbilical_Hernia(_MouseAnatomicalStructureModel):
    """Model cavity of physiological umbilical hernia"""

    name: Literal["cavity of physiological umbilical hernia"] = "cavity of physiological umbilical hernia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26164"] = "EMAPA_26164"


class _Cavity_Of_Physiological_Umbilical_Hernia_Mesothelium(_MouseAnatomicalStructureModel):
    """Model cavity of physiological umbilical hernia mesothelium"""

    name: Literal[
        "cavity of physiological umbilical hernia mesothelium"
    ] = "cavity of physiological umbilical hernia mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26172"] = "EMAPA_26172"


class _Pancreas_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model pancreas mesenchyme"""

    name: Literal["pancreas mesenchyme"] = "pancreas mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26220"] = "EMAPA_26220"


class _Hindlimb_Digit_1_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 interphalangeal joint"""

    name: Literal["hindlimb digit 1 interphalangeal joint"] = "hindlimb digit 1 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26430"] = "EMAPA_26430"


class _Hindlimb_Digit_1_Metatarsal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 1 metatarsal-phalangeal joint"""

    name: Literal["hindlimb digit 1 metatarsal-phalangeal joint"] = "hindlimb digit 1 metatarsal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26436"] = "EMAPA_26436"


class _Hindlimb_Digit_2_Metatarsal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 metatarsal-phalangeal joint"""

    name: Literal["hindlimb digit 2 metatarsal-phalangeal joint"] = "hindlimb digit 2 metatarsal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26442"] = "EMAPA_26442"


class _Hindlimb_Digit_2_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 2 interphalangeal joint"""

    name: Literal["hindlimb digit 2 interphalangeal joint"] = "hindlimb digit 2 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26448"] = "EMAPA_26448"


class _Hindlimb_Digit_3_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 interphalangeal joint"""

    name: Literal["hindlimb digit 3 interphalangeal joint"] = "hindlimb digit 3 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26454"] = "EMAPA_26454"


class _Hindlimb_Digit_3_Metatarsal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 3 metatarsal-phalangeal joint"""

    name: Literal["hindlimb digit 3 metatarsal-phalangeal joint"] = "hindlimb digit 3 metatarsal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26460"] = "EMAPA_26460"


class _Hindlimb_Digit_4_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 interphalangeal joint"""

    name: Literal["hindlimb digit 4 interphalangeal joint"] = "hindlimb digit 4 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26466"] = "EMAPA_26466"


class _Hindlimb_Digit_4_Metatarsal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 4 metatarsal-phalangeal joint"""

    name: Literal["hindlimb digit 4 metatarsal-phalangeal joint"] = "hindlimb digit 4 metatarsal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26472"] = "EMAPA_26472"


class _Hindlimb_Digit_5_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 interphalangeal joint"""

    name: Literal["hindlimb digit 5 interphalangeal joint"] = "hindlimb digit 5 interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26478"] = "EMAPA_26478"


class _Hindlimb_Digit_5_Metatarsal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb digit 5 metatarsal-phalangeal joint"""

    name: Literal["hindlimb digit 5 metatarsal-phalangeal joint"] = "hindlimb digit 5 metatarsal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26484"] = "EMAPA_26484"


class _C1_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model C1 vertebral canal"""

    name: Literal["C1 vertebral canal"] = "C1 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26521"] = "EMAPA_26521"


class _C1_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model C1 vertebra neural arch"""

    name: Literal["C1 vertebra neural arch"] = "C1 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26523"] = "EMAPA_26523"


class _Cartilage_Primordium_Of_Future_C1_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future C1 spinous process"""

    name: Literal[
        "cartilage primordium of future C1 spinous process"
    ] = "cartilage primordium of future C1 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26525"] = "EMAPA_26525"


class _C1_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model C1 neural arch lamina"""

    name: Literal["C1 neural arch lamina"] = "C1 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26527"] = "EMAPA_26527"


class _C1_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model C1 neural arch pedicle"""

    name: Literal["C1 neural arch pedicle"] = "C1 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26529"] = "EMAPA_26529"


class _C2_Vertebra_Centrum(_MouseAnatomicalStructureModel):
    """Model C2 vertebra centrum"""

    name: Literal["C2 vertebra centrum"] = "C2 vertebra centrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26533"] = "EMAPA_26533"


class _Odontoid_Process(_MouseAnatomicalStructureModel):
    """Model odontoid process"""

    name: Literal["odontoid process"] = "odontoid process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26535"] = "EMAPA_26535"


class _C2_Vertebral_Canal(_MouseAnatomicalStructureModel):
    """Model C2 vertebral canal"""

    name: Literal["C2 vertebral canal"] = "C2 vertebral canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26537"] = "EMAPA_26537"


class _C2_Vertebra_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model C2 vertebra neural arch"""

    name: Literal["C2 vertebra neural arch"] = "C2 vertebra neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26539"] = "EMAPA_26539"


class _Cartilage_Primordium_Of_Future_C2_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future C2 spinous process"""

    name: Literal[
        "cartilage primordium of future C2 spinous process"
    ] = "cartilage primordium of future C2 spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26541"] = "EMAPA_26541"


class _C2_Neural_Arch_Lamina(_MouseAnatomicalStructureModel):
    """Model C2 neural arch lamina"""

    name: Literal["C2 neural arch lamina"] = "C2 neural arch lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26543"] = "EMAPA_26543"


class _C2_Neural_Arch_Pedicle(_MouseAnatomicalStructureModel):
    """Model C2 neural arch pedicle"""

    name: Literal["C2 neural arch pedicle"] = "C2 neural arch pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26545"] = "EMAPA_26545"


class _C3_Foramen_Transversarium(_MouseAnatomicalStructureModel):
    """Model C3 foramen transversarium"""

    name: Literal["C3 foramen transversarium"] = "C3 foramen transversarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26549"] = "EMAPA_26549"


class _C4_Foramen_Transversarium(_MouseAnatomicalStructureModel):
    """Model C4 foramen transversarium"""

    name: Literal["C4 foramen transversarium"] = "C4 foramen transversarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26551"] = "EMAPA_26551"


class _C5_Foramen_Transversarium(_MouseAnatomicalStructureModel):
    """Model C5 foramen transversarium"""

    name: Literal["C5 foramen transversarium"] = "C5 foramen transversarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26553"] = "EMAPA_26553"


class _C6_Foramen_Transversarium(_MouseAnatomicalStructureModel):
    """Model C6 foramen transversarium"""

    name: Literal["C6 foramen transversarium"] = "C6 foramen transversarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26555"] = "EMAPA_26555"


class _C7_Foramen_Transversarium(_MouseAnatomicalStructureModel):
    """Model C7 foramen transversarium"""

    name: Literal["C7 foramen transversarium"] = "C7 foramen transversarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26557"] = "EMAPA_26557"


class _C1_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C1 mixed spinal nerve"""

    name: Literal["C1 mixed spinal nerve"] = "C1 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26559"] = "EMAPA_26559"


class _C2_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C2 mixed spinal nerve"""

    name: Literal["C2 mixed spinal nerve"] = "C2 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26561"] = "EMAPA_26561"


class _C3_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C3 mixed spinal nerve"""

    name: Literal["C3 mixed spinal nerve"] = "C3 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26563"] = "EMAPA_26563"


class _C4_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C4 mixed spinal nerve"""

    name: Literal["C4 mixed spinal nerve"] = "C4 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26565"] = "EMAPA_26565"


class _C5_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C5 mixed spinal nerve"""

    name: Literal["C5 mixed spinal nerve"] = "C5 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26567"] = "EMAPA_26567"


class _C6_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C6 mixed spinal nerve"""

    name: Literal["C6 mixed spinal nerve"] = "C6 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26569"] = "EMAPA_26569"


class _C7_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model C7 mixed spinal nerve"""

    name: Literal["C7 mixed spinal nerve"] = "C7 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26571"] = "EMAPA_26571"


class _L1_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L1 mixed spinal nerve"""

    name: Literal["L1 mixed spinal nerve"] = "L1 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26573"] = "EMAPA_26573"


class _L2_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L2 mixed spinal nerve"""

    name: Literal["L2 mixed spinal nerve"] = "L2 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26575"] = "EMAPA_26575"


class _L3_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L3 mixed spinal nerve"""

    name: Literal["L3 mixed spinal nerve"] = "L3 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26577"] = "EMAPA_26577"


class _L4_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L4 mixed spinal nerve"""

    name: Literal["L4 mixed spinal nerve"] = "L4 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26579"] = "EMAPA_26579"


class _L5_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L5 mixed spinal nerve"""

    name: Literal["L5 mixed spinal nerve"] = "L5 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26581"] = "EMAPA_26581"


class _L6_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model L6 mixed spinal nerve"""

    name: Literal["L6 mixed spinal nerve"] = "L6 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26583"] = "EMAPA_26583"


class _S1_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model S1 mixed spinal nerve"""

    name: Literal["S1 mixed spinal nerve"] = "S1 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26585"] = "EMAPA_26585"


class _S2_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model S2 mixed spinal nerve"""

    name: Literal["S2 mixed spinal nerve"] = "S2 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26587"] = "EMAPA_26587"


class _S3_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model S3 mixed spinal nerve"""

    name: Literal["S3 mixed spinal nerve"] = "S3 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26589"] = "EMAPA_26589"


class _S4_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model S4 mixed spinal nerve"""

    name: Literal["S4 mixed spinal nerve"] = "S4 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26591"] = "EMAPA_26591"


class _T1_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T1 mixed spinal nerve"""

    name: Literal["T1 mixed spinal nerve"] = "T1 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26593"] = "EMAPA_26593"


class _T2_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T2 mixed spinal nerve"""

    name: Literal["T2 mixed spinal nerve"] = "T2 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26595"] = "EMAPA_26595"


class _T3_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T3 mixed spinal nerve"""

    name: Literal["T3 mixed spinal nerve"] = "T3 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26597"] = "EMAPA_26597"


class _T4_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T4 mixed spinal nerve"""

    name: Literal["T4 mixed spinal nerve"] = "T4 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26599"] = "EMAPA_26599"


class _T5_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T5 mixed spinal nerve"""

    name: Literal["T5 mixed spinal nerve"] = "T5 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26601"] = "EMAPA_26601"


class _T6_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T6 mixed spinal nerve"""

    name: Literal["T6 mixed spinal nerve"] = "T6 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26603"] = "EMAPA_26603"


class _T7_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T7 mixed spinal nerve"""

    name: Literal["T7 mixed spinal nerve"] = "T7 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26605"] = "EMAPA_26605"


class _T8_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T8 mixed spinal nerve"""

    name: Literal["T8 mixed spinal nerve"] = "T8 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26607"] = "EMAPA_26607"


class _T9_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T9 mixed spinal nerve"""

    name: Literal["T9 mixed spinal nerve"] = "T9 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26609"] = "EMAPA_26609"


class _T10_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T10 mixed spinal nerve"""

    name: Literal["T10 mixed spinal nerve"] = "T10 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26611"] = "EMAPA_26611"


class _T11_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T11 mixed spinal nerve"""

    name: Literal["T11 mixed spinal nerve"] = "T11 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26613"] = "EMAPA_26613"


class _T12_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T12 mixed spinal nerve"""

    name: Literal["T12 mixed spinal nerve"] = "T12 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26615"] = "EMAPA_26615"


class _T13_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model T13 mixed spinal nerve"""

    name: Literal["T13 mixed spinal nerve"] = "T13 mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26617"] = "EMAPA_26617"


class _T1_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T1 rib shaft ossified region"""

    name: Literal["T1 rib shaft ossified region"] = "T1 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26619"] = "EMAPA_26619"


class _T1_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T1 rib shaft non-ossified region"""

    name: Literal["T1 rib shaft non-ossified region"] = "T1 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26621"] = "EMAPA_26621"


class _T2_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T2 rib shaft ossified region"""

    name: Literal["T2 rib shaft ossified region"] = "T2 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26623"] = "EMAPA_26623"


class _T2_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T2 rib shaft non-ossified region"""

    name: Literal["T2 rib shaft non-ossified region"] = "T2 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26625"] = "EMAPA_26625"


class _T3_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T3 rib shaft ossified region"""

    name: Literal["T3 rib shaft ossified region"] = "T3 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26627"] = "EMAPA_26627"


class _T3_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T3 rib shaft non-ossified region"""

    name: Literal["T3 rib shaft non-ossified region"] = "T3 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26629"] = "EMAPA_26629"


class _T4_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T4 rib shaft ossified region"""

    name: Literal["T4 rib shaft ossified region"] = "T4 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26631"] = "EMAPA_26631"


class _T4_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T4 rib shaft non-ossified region"""

    name: Literal["T4 rib shaft non-ossified region"] = "T4 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26633"] = "EMAPA_26633"


class _T5_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T5 rib shaft ossified region"""

    name: Literal["T5 rib shaft ossified region"] = "T5 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26635"] = "EMAPA_26635"


class _T5_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T5 rib shaft non-ossified region"""

    name: Literal["T5 rib shaft non-ossified region"] = "T5 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26637"] = "EMAPA_26637"


class _T6_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T6 rib shaft ossified region"""

    name: Literal["T6 rib shaft ossified region"] = "T6 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26639"] = "EMAPA_26639"


class _T6_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T6 rib shaft non-ossified region"""

    name: Literal["T6 rib shaft non-ossified region"] = "T6 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26641"] = "EMAPA_26641"


class _T7_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T7 rib shaft ossified region"""

    name: Literal["T7 rib shaft ossified region"] = "T7 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26643"] = "EMAPA_26643"


class _T7_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T7 rib shaft non-ossified region"""

    name: Literal["T7 rib shaft non-ossified region"] = "T7 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26645"] = "EMAPA_26645"


class _T8_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T8 rib shaft ossified region"""

    name: Literal["T8 rib shaft ossified region"] = "T8 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26647"] = "EMAPA_26647"


class _T8_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T8 rib shaft non-ossified region"""

    name: Literal["T8 rib shaft non-ossified region"] = "T8 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26649"] = "EMAPA_26649"


class _T9_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T9 rib shaft ossified region"""

    name: Literal["T9 rib shaft ossified region"] = "T9 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26651"] = "EMAPA_26651"


class _T9_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T9 rib shaft non-ossified region"""

    name: Literal["T9 rib shaft non-ossified region"] = "T9 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26653"] = "EMAPA_26653"


class _T10_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T10 rib shaft ossified region"""

    name: Literal["T10 rib shaft ossified region"] = "T10 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26655"] = "EMAPA_26655"


class _T10_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T10 rib shaft non-ossified region"""

    name: Literal["T10 rib shaft non-ossified region"] = "T10 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26657"] = "EMAPA_26657"


class _T11_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T11 rib shaft ossified region"""

    name: Literal["T11 rib shaft ossified region"] = "T11 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26659"] = "EMAPA_26659"


class _T11_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T11 rib shaft non-ossified region"""

    name: Literal["T11 rib shaft non-ossified region"] = "T11 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26661"] = "EMAPA_26661"


class _T12_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T12 rib shaft non-ossified region"""

    name: Literal["T12 rib shaft non-ossified region"] = "T12 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26663"] = "EMAPA_26663"


class _T12_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T12 rib shaft ossified region"""

    name: Literal["T12 rib shaft ossified region"] = "T12 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26665"] = "EMAPA_26665"


class _T13_Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T13 rib shaft ossified region"""

    name: Literal["T13 rib shaft ossified region"] = "T13 rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26667"] = "EMAPA_26667"


class _T13_Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model T13 rib shaft non-ossified region"""

    name: Literal["T13 rib shaft non-ossified region"] = "T13 rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26669"] = "EMAPA_26669"


class _C1_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model C1 neural arch transverse process"""

    name: Literal["C1 neural arch transverse process"] = "C1 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26671"] = "EMAPA_26671"


class _C1_Foramen_Transversarium(_MouseAnatomicalStructureModel):
    """Model C1 foramen transversarium"""

    name: Literal["C1 foramen transversarium"] = "C1 foramen transversarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26673"] = "EMAPA_26673"


class _C2_Neural_Arch_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model C2 neural arch transverse process"""

    name: Literal["C2 neural arch transverse process"] = "C2 neural arch transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26675"] = "EMAPA_26675"


class _C2_Foramen_Transversarium(_MouseAnatomicalStructureModel):
    """Model C2 foramen transversarium"""

    name: Literal["C2 foramen transversarium"] = "C2 foramen transversarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26677"] = "EMAPA_26677"


class _Vibrissa_Bulb(_MouseAnatomicalStructureModel):
    """Model vibrissa bulb"""

    name: Literal["vibrissa bulb"] = "vibrissa bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26716"] = "EMAPA_26716"


class _Vibrissa_Follicle(_MouseAnatomicalStructureModel):
    """Model vibrissa follicle"""

    name: Literal["vibrissa follicle"] = "vibrissa follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26720"] = "EMAPA_26720"


class _Vibrissa_Root_Sheath(_MouseAnatomicalStructureModel):
    """Model vibrissa root sheath"""

    name: Literal["vibrissa root sheath"] = "vibrissa root sheath"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26724"] = "EMAPA_26724"


class _Vibrissa_Hair(_MouseAnatomicalStructureModel):
    """Model vibrissa hair"""

    name: Literal["vibrissa hair"] = "vibrissa hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26747"] = "EMAPA_26747"


class _Vibrissa_Arrector_Pili_Muscle(_MouseAnatomicalStructureModel):
    """Model vibrissa arrector pili muscle"""

    name: Literal["vibrissa arrector pili muscle"] = "vibrissa arrector pili muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26771"] = "EMAPA_26771"


class _Hair_Arrector_Pili_Muscle(_MouseAnatomicalStructureModel):
    """Model hair arrector pili muscle"""

    name: Literal["hair arrector pili muscle"] = "hair arrector pili muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26775"] = "EMAPA_26775"


class _Male_Inguinal_Canal(_MouseAnatomicalStructureModel):
    """Model male inguinal canal"""

    name: Literal["male inguinal canal"] = "male inguinal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26913"] = "EMAPA_26913"


class _Enteric_Nervous_System(_MouseAnatomicalStructureModel):
    """Model enteric nervous system"""

    name: Literal["enteric nervous system"] = "enteric nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26922"] = "EMAPA_26922"


class _Pubis_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model pubis cartilage condensation"""

    name: Literal["pubis cartilage condensation"] = "pubis cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26928"] = "EMAPA_26928"


class _Ischium_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model ischium cartilage condensation"""

    name: Literal["ischium cartilage condensation"] = "ischium cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26930"] = "EMAPA_26930"


class _Oral_Mucosa(_MouseAnatomicalStructureModel):
    """Model oral mucosa"""

    name: Literal["oral mucosa"] = "oral mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26937"] = "EMAPA_26937"


class _Oral_Epithelium(_MouseAnatomicalStructureModel):
    """Model oral epithelium"""

    name: Literal["oral epithelium"] = "oral epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26942"] = "EMAPA_26942"


class _Oral_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model oral lamina propria"""

    name: Literal["oral lamina propria"] = "oral lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26947"] = "EMAPA_26947"


class _Oral_Region_Muscularis(_MouseAnatomicalStructureModel):
    """Model oral region muscularis"""

    name: Literal["oral region muscularis"] = "oral region muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26952"] = "EMAPA_26952"


class _Pharynx_Mucosa(_MouseAnatomicalStructureModel):
    """Model pharynx mucosa"""

    name: Literal["pharynx mucosa"] = "pharynx mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26957"] = "EMAPA_26957"


class _Pharynx_Muscularis(_MouseAnatomicalStructureModel):
    """Model pharynx muscularis"""

    name: Literal["pharynx muscularis"] = "pharynx muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26959"] = "EMAPA_26959"


class _Pharynx_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model pharynx lamina propria"""

    name: Literal["pharynx lamina propria"] = "pharynx lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26963"] = "EMAPA_26963"


class _Esophagus_Mucosa(_MouseAnatomicalStructureModel):
    """Model esophagus mucosa"""

    name: Literal["esophagus mucosa"] = "esophagus mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26981"] = "EMAPA_26981"


class _Esophagus_Muscularis(_MouseAnatomicalStructureModel):
    """Model esophagus muscularis"""

    name: Literal["esophagus muscularis"] = "esophagus muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26983"] = "EMAPA_26983"


class _Esophagus_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model esophagus lamina propria"""

    name: Literal["esophagus lamina propria"] = "esophagus lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26987"] = "EMAPA_26987"


class _Esophagus_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model esophagus muscularis mucosa"""

    name: Literal["esophagus muscularis mucosa"] = "esophagus muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_26989"] = "EMAPA_26989"


class _Foregut_Midgut_Junction_Mucosa(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction mucosa"""

    name: Literal["foregut-midgut junction mucosa"] = "foregut-midgut junction mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27011"] = "EMAPA_27011"


class _Foregut_Midgut_Junction_Submucosa(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction submucosa"""

    name: Literal["foregut-midgut junction submucosa"] = "foregut-midgut junction submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27013"] = "EMAPA_27013"


class _Foregut_Midgut_Junction_Muscularis(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction muscularis"""

    name: Literal["foregut-midgut junction muscularis"] = "foregut-midgut junction muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27015"] = "EMAPA_27015"


class _Foregut_Midgut_Junction_Serosa(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction serosa"""

    name: Literal["foregut-midgut junction serosa"] = "foregut-midgut junction serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27017"] = "EMAPA_27017"


class _Foregut_Midgut_Junction_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction lamina propria"""

    name: Literal["foregut-midgut junction lamina propria"] = "foregut-midgut junction lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27021"] = "EMAPA_27021"


class _Foregut_Midgut_Junction_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model foregut-midgut junction muscularis mucosa"""

    name: Literal["foregut-midgut junction muscularis mucosa"] = "foregut-midgut junction muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27023"] = "EMAPA_27023"


class _Duodenum_Rostral_Part_Mucosa(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part mucosa"""

    name: Literal["duodenum rostral part mucosa"] = "duodenum rostral part mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27025"] = "EMAPA_27025"


class _Duodenum_Rostral_Part_Submucosa(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part submucosa"""

    name: Literal["duodenum rostral part submucosa"] = "duodenum rostral part submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27027"] = "EMAPA_27027"


class _Duodenum_Rostral_Part_Muscularis(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part muscularis"""

    name: Literal["duodenum rostral part muscularis"] = "duodenum rostral part muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27029"] = "EMAPA_27029"


class _Duodenum_Rostral_Part_Serosa(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part serosa"""

    name: Literal["duodenum rostral part serosa"] = "duodenum rostral part serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27031"] = "EMAPA_27031"


class _Duodenum_Rostral_Part_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part lamina propria"""

    name: Literal["duodenum rostral part lamina propria"] = "duodenum rostral part lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27035"] = "EMAPA_27035"


class _Duodenum_Rostral_Part_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model duodenum rostral part muscularis mucosa"""

    name: Literal["duodenum rostral part muscularis mucosa"] = "duodenum rostral part muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27037"] = "EMAPA_27037"


class _Gastro_Esophageal_Junction_Mucosa(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction mucosa"""

    name: Literal["gastro-esophageal junction mucosa"] = "gastro-esophageal junction mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27039"] = "EMAPA_27039"


class _Gastro_Esophageal_Junction_Submucosa(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction submucosa"""

    name: Literal["gastro-esophageal junction submucosa"] = "gastro-esophageal junction submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27041"] = "EMAPA_27041"


class _Gastro_Esophageal_Junction_Muscularis(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction muscularis"""

    name: Literal["gastro-esophageal junction muscularis"] = "gastro-esophageal junction muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27043"] = "EMAPA_27043"


class _Gastro_Esophageal_Junction_Serosa(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction serosa"""

    name: Literal["gastro-esophageal junction serosa"] = "gastro-esophageal junction serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27045"] = "EMAPA_27045"


class _Gastro_Esophageal_Junction_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction lamina propria"""

    name: Literal["gastro-esophageal junction lamina propria"] = "gastro-esophageal junction lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27049"] = "EMAPA_27049"


class _Gastro_Esophageal_Junction_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model gastro-esophageal junction muscularis mucosa"""

    name: Literal["gastro-esophageal junction muscularis mucosa"] = "gastro-esophageal junction muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27051"] = "EMAPA_27051"


class _Perineal_Body_Mucosa(_MouseAnatomicalStructureModel):
    """Model perineal body mucosa"""

    name: Literal["perineal body mucosa"] = "perineal body mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27053"] = "EMAPA_27053"


class _Perineal_Body_Submucosa(_MouseAnatomicalStructureModel):
    """Model perineal body submucosa"""

    name: Literal["perineal body submucosa"] = "perineal body submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27055"] = "EMAPA_27055"


class _Perineal_Body_Muscularis(_MouseAnatomicalStructureModel):
    """Model perineal body muscularis"""

    name: Literal["perineal body muscularis"] = "perineal body muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27057"] = "EMAPA_27057"


class _Perineal_Body_Serosa(_MouseAnatomicalStructureModel):
    """Model perineal body serosa"""

    name: Literal["perineal body serosa"] = "perineal body serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27059"] = "EMAPA_27059"


class _Perineal_Body_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model perineal body lamina propria"""

    name: Literal["perineal body lamina propria"] = "perineal body lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27063"] = "EMAPA_27063"


class _Perineal_Body_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model perineal body muscularis mucosa"""

    name: Literal["perineal body muscularis mucosa"] = "perineal body muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27065"] = "EMAPA_27065"


class _Hindgut_Mucosa(_MouseAnatomicalStructureModel):
    """Model hindgut mucosa"""

    name: Literal["hindgut mucosa"] = "hindgut mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27067"] = "EMAPA_27067"


class _Hindgut_Submucosa(_MouseAnatomicalStructureModel):
    """Model hindgut submucosa"""

    name: Literal["hindgut submucosa"] = "hindgut submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27069"] = "EMAPA_27069"


class _Hindgut_Muscularis(_MouseAnatomicalStructureModel):
    """Model hindgut muscularis"""

    name: Literal["hindgut muscularis"] = "hindgut muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27071"] = "EMAPA_27071"


class _Hindgut_Serosa(_MouseAnatomicalStructureModel):
    """Model hindgut serosa"""

    name: Literal["hindgut serosa"] = "hindgut serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27073"] = "EMAPA_27073"


class _Hindgut_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model hindgut lamina propria"""

    name: Literal["hindgut lamina propria"] = "hindgut lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27077"] = "EMAPA_27077"


class _Hindgut_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model hindgut muscularis mucosa"""

    name: Literal["hindgut muscularis mucosa"] = "hindgut muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27079"] = "EMAPA_27079"


class _Rectum_Mucosa(_MouseAnatomicalStructureModel):
    """Model rectum mucosa"""

    name: Literal["rectum mucosa"] = "rectum mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27081"] = "EMAPA_27081"


class _Rectum_Submucosa(_MouseAnatomicalStructureModel):
    """Model rectum submucosa"""

    name: Literal["rectum submucosa"] = "rectum submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27083"] = "EMAPA_27083"


class _Rectum_Muscularis(_MouseAnatomicalStructureModel):
    """Model rectum muscularis"""

    name: Literal["rectum muscularis"] = "rectum muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27085"] = "EMAPA_27085"


class _Rectum_Serosa(_MouseAnatomicalStructureModel):
    """Model rectum serosa"""

    name: Literal["rectum serosa"] = "rectum serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27087"] = "EMAPA_27087"


class _Rectum_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model rectum lamina propria"""

    name: Literal["rectum lamina propria"] = "rectum lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27091"] = "EMAPA_27091"


class _Rectum_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model rectum muscularis mucosa"""

    name: Literal["rectum muscularis mucosa"] = "rectum muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27093"] = "EMAPA_27093"


class _Duodenum_Caudal_Part_Mucosa(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part mucosa"""

    name: Literal["duodenum caudal part mucosa"] = "duodenum caudal part mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27095"] = "EMAPA_27095"


class _Duodenum_Caudal_Part_Submucosa(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part submucosa"""

    name: Literal["duodenum caudal part submucosa"] = "duodenum caudal part submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27097"] = "EMAPA_27097"


class _Duodenum_Caudal_Part_Muscularis(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part muscularis"""

    name: Literal["duodenum caudal part muscularis"] = "duodenum caudal part muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27099"] = "EMAPA_27099"


class _Duodenum_Caudal_Part_Serosa(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part serosa"""

    name: Literal["duodenum caudal part serosa"] = "duodenum caudal part serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27101"] = "EMAPA_27101"


class _Duodenum_Caudal_Part_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part lamina propria"""

    name: Literal["duodenum caudal part lamina propria"] = "duodenum caudal part lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27105"] = "EMAPA_27105"


class _Duodenum_Caudal_Part_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model duodenum caudal part muscularis mucosa"""

    name: Literal["duodenum caudal part muscularis mucosa"] = "duodenum caudal part muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27107"] = "EMAPA_27107"


class _Jejunum_Mucosa(_MouseAnatomicalStructureModel):
    """Model jejunum mucosa"""

    name: Literal["jejunum mucosa"] = "jejunum mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27109"] = "EMAPA_27109"


class _Jejunum_Submucosa(_MouseAnatomicalStructureModel):
    """Model jejunum submucosa"""

    name: Literal["jejunum submucosa"] = "jejunum submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27111"] = "EMAPA_27111"


class _Jejunum_Muscularis(_MouseAnatomicalStructureModel):
    """Model jejunum muscularis"""

    name: Literal["jejunum muscularis"] = "jejunum muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27113"] = "EMAPA_27113"


class _Jejunum_Serosa(_MouseAnatomicalStructureModel):
    """Model jejunum serosa"""

    name: Literal["jejunum serosa"] = "jejunum serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27115"] = "EMAPA_27115"


class _Jejunum_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model jejunum lamina propria"""

    name: Literal["jejunum lamina propria"] = "jejunum lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27119"] = "EMAPA_27119"


class _Jejunum_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model jejunum muscularis mucosa"""

    name: Literal["jejunum muscularis mucosa"] = "jejunum muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27121"] = "EMAPA_27121"


class _Midgut_Loop_Mucosa(_MouseAnatomicalStructureModel):
    """Model midgut loop mucosa"""

    name: Literal["midgut loop mucosa"] = "midgut loop mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27123"] = "EMAPA_27123"


class _Midgut_Loop_Submucosa(_MouseAnatomicalStructureModel):
    """Model midgut loop submucosa"""

    name: Literal["midgut loop submucosa"] = "midgut loop submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27125"] = "EMAPA_27125"


class _Midgut_Loop_Muscularis(_MouseAnatomicalStructureModel):
    """Model midgut loop muscularis"""

    name: Literal["midgut loop muscularis"] = "midgut loop muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27127"] = "EMAPA_27127"


class _Midgut_Loop_Serosa(_MouseAnatomicalStructureModel):
    """Model midgut loop serosa"""

    name: Literal["midgut loop serosa"] = "midgut loop serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27129"] = "EMAPA_27129"


class _Midgut_Loop_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model midgut loop lamina propria"""

    name: Literal["midgut loop lamina propria"] = "midgut loop lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27133"] = "EMAPA_27133"


class _Midgut_Loop_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model midgut loop muscularis mucosa"""

    name: Literal["midgut loop muscularis mucosa"] = "midgut loop muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27135"] = "EMAPA_27135"


class _Midgut_Mucosa(_MouseAnatomicalStructureModel):
    """Model midgut mucosa"""

    name: Literal["midgut mucosa"] = "midgut mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27137"] = "EMAPA_27137"


class _Midgut_Submucosa(_MouseAnatomicalStructureModel):
    """Model midgut submucosa"""

    name: Literal["midgut submucosa"] = "midgut submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27139"] = "EMAPA_27139"


class _Midgut_Muscularis(_MouseAnatomicalStructureModel):
    """Model midgut muscularis"""

    name: Literal["midgut muscularis"] = "midgut muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27141"] = "EMAPA_27141"


class _Midgut_Serosa(_MouseAnatomicalStructureModel):
    """Model midgut serosa"""

    name: Literal["midgut serosa"] = "midgut serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27143"] = "EMAPA_27143"


class _Midgut_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model midgut lamina propria"""

    name: Literal["midgut lamina propria"] = "midgut lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27147"] = "EMAPA_27147"


class _Midgut_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model midgut muscularis mucosa"""

    name: Literal["midgut muscularis mucosa"] = "midgut muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27149"] = "EMAPA_27149"


class _Stomach_Fundus_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach fundus mucosa"""

    name: Literal["stomach fundus mucosa"] = "stomach fundus mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27151"] = "EMAPA_27151"


class _Stomach_Fundus_Submucosa(_MouseAnatomicalStructureModel):
    """Model stomach fundus submucosa"""

    name: Literal["stomach fundus submucosa"] = "stomach fundus submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27153"] = "EMAPA_27153"


class _Stomach_Fundus_Muscularis(_MouseAnatomicalStructureModel):
    """Model stomach fundus muscularis"""

    name: Literal["stomach fundus muscularis"] = "stomach fundus muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27155"] = "EMAPA_27155"


class _Stomach_Fundus_Serosa(_MouseAnatomicalStructureModel):
    """Model stomach fundus serosa"""

    name: Literal["stomach fundus serosa"] = "stomach fundus serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27157"] = "EMAPA_27157"


class _Stomach_Fundus_Gastric_Gland(_MouseAnatomicalStructureModel):
    """Model stomach fundus gastric gland"""

    name: Literal["stomach fundus gastric gland"] = "stomach fundus gastric gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27161"] = "EMAPA_27161"


class _Stomach_Fundus_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model stomach fundus lamina propria"""

    name: Literal["stomach fundus lamina propria"] = "stomach fundus lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27163"] = "EMAPA_27163"


class _Stomach_Fundus_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach fundus muscularis mucosa"""

    name: Literal["stomach fundus muscularis mucosa"] = "stomach fundus muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27165"] = "EMAPA_27165"


class _Stomach_Glandular_Region_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach glandular region mucosa"""

    name: Literal["stomach glandular region mucosa"] = "stomach glandular region mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27167"] = "EMAPA_27167"


class _Stomach_Glandular_Region_Submucosa(_MouseAnatomicalStructureModel):
    """Model stomach glandular region submucosa"""

    name: Literal["stomach glandular region submucosa"] = "stomach glandular region submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27169"] = "EMAPA_27169"


class _Stomach_Glandular_Region_Muscularis(_MouseAnatomicalStructureModel):
    """Model stomach glandular region muscularis"""

    name: Literal["stomach glandular region muscularis"] = "stomach glandular region muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27171"] = "EMAPA_27171"


class _Stomach_Glandular_Region_Serosa(_MouseAnatomicalStructureModel):
    """Model stomach glandular region serosa"""

    name: Literal["stomach glandular region serosa"] = "stomach glandular region serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27173"] = "EMAPA_27173"


class _Stomach_Glandular_Region_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model stomach glandular region lamina propria"""

    name: Literal["stomach glandular region lamina propria"] = "stomach glandular region lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27177"] = "EMAPA_27177"


class _Stomach_Glandular_Region_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach glandular region muscularis mucosa"""

    name: Literal["stomach glandular region muscularis mucosa"] = "stomach glandular region muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27179"] = "EMAPA_27179"


class _Stomach_Glandular_Region_Gastric_Gland(_MouseAnatomicalStructureModel):
    """Model stomach glandular region gastric gland"""

    name: Literal["stomach glandular region gastric gland"] = "stomach glandular region gastric gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27181"] = "EMAPA_27181"


class _Stomach_Proventricular_Region_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region mucosa"""

    name: Literal["stomach proventricular region mucosa"] = "stomach proventricular region mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27183"] = "EMAPA_27183"


class _Stomach_Proventricular_Region_Submucosa(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region submucosa"""

    name: Literal["stomach proventricular region submucosa"] = "stomach proventricular region submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27185"] = "EMAPA_27185"


class _Stomach_Proventricular_Region_Muscularis(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region muscularis"""

    name: Literal["stomach proventricular region muscularis"] = "stomach proventricular region muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27187"] = "EMAPA_27187"


class _Stomach_Proventricular_Region_Serosa(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region serosa"""

    name: Literal["stomach proventricular region serosa"] = "stomach proventricular region serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27189"] = "EMAPA_27189"


class _Stomach_Proventricular_Region_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region lamina propria"""

    name: Literal["stomach proventricular region lamina propria"] = "stomach proventricular region lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27193"] = "EMAPA_27193"


class _Stomach_Proventricular_Region_Gastric_Gland(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region gastric gland"""

    name: Literal["stomach proventricular region gastric gland"] = "stomach proventricular region gastric gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27195"] = "EMAPA_27195"


class _Stomach_Proventricular_Region_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach proventricular region muscularis mucosa"""

    name: Literal["stomach proventricular region muscularis mucosa"] = "stomach proventricular region muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27197"] = "EMAPA_27197"


class _Stomach_Pyloric_Region_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region mucosa"""

    name: Literal["stomach pyloric region mucosa"] = "stomach pyloric region mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27199"] = "EMAPA_27199"


class _Stomach_Pyloric_Region_Submucosa(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region submucosa"""

    name: Literal["stomach pyloric region submucosa"] = "stomach pyloric region submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27201"] = "EMAPA_27201"


class _Stomach_Pyloric_Region_Serosa(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region serosa"""

    name: Literal["stomach pyloric region serosa"] = "stomach pyloric region serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27205"] = "EMAPA_27205"


class _Stomach_Pyloric_Region_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region lamina propria"""

    name: Literal["stomach pyloric region lamina propria"] = "stomach pyloric region lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27209"] = "EMAPA_27209"


class _Stomach_Pyloric_Region_Gastric_Gland(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region gastric gland"""

    name: Literal["stomach pyloric region gastric gland"] = "stomach pyloric region gastric gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27211"] = "EMAPA_27211"


class _Stomach_Pyloric_Region_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach pyloric region muscularis mucosa"""

    name: Literal["stomach pyloric region muscularis mucosa"] = "stomach pyloric region muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27213"] = "EMAPA_27213"


class _Anal_Canal_Caudal_Part_Mucosa(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part mucosa"""

    name: Literal["anal canal caudal part mucosa"] = "anal canal caudal part mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27215"] = "EMAPA_27215"


class _Anal_Canal_Caudal_Part_Submucosa(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part submucosa"""

    name: Literal["anal canal caudal part submucosa"] = "anal canal caudal part submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27217"] = "EMAPA_27217"


class _Anal_Canal_Caudal_Part_Gland(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part gland"""

    name: Literal["anal canal caudal part gland"] = "anal canal caudal part gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27221"] = "EMAPA_27221"


class _Anal_Canal_Caudal_Part_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model anal canal caudal part lamina propria"""

    name: Literal["anal canal caudal part lamina propria"] = "anal canal caudal part lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27223"] = "EMAPA_27223"


class _Anal_Canal_Rostral_Part_Mucosa(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part mucosa"""

    name: Literal["anal canal rostral part mucosa"] = "anal canal rostral part mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27225"] = "EMAPA_27225"


class _Anal_Canal_Rostral_Part_Submucosa(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part submucosa"""

    name: Literal["anal canal rostral part submucosa"] = "anal canal rostral part submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27227"] = "EMAPA_27227"


class _Anal_Canal_Rostral_Part_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part lamina propria"""

    name: Literal["anal canal rostral part lamina propria"] = "anal canal rostral part lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27231"] = "EMAPA_27231"


class _Anal_Canal_Rostral_Part_Gland(_MouseAnatomicalStructureModel):
    """Model anal canal rostral part gland"""

    name: Literal["anal canal rostral part gland"] = "anal canal rostral part gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27233"] = "EMAPA_27233"


class _Duodenum_Mucosa(_MouseAnatomicalStructureModel):
    """Model duodenum mucosa"""

    name: Literal["duodenum mucosa"] = "duodenum mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27235"] = "EMAPA_27235"


class _Duodenum_Submucosa(_MouseAnatomicalStructureModel):
    """Model duodenum submucosa"""

    name: Literal["duodenum submucosa"] = "duodenum submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27239"] = "EMAPA_27239"


class _Duodenum_Muscularis(_MouseAnatomicalStructureModel):
    """Model duodenum muscularis"""

    name: Literal["duodenum muscularis"] = "duodenum muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27243"] = "EMAPA_27243"


class _Duodenum_Serosa(_MouseAnatomicalStructureModel):
    """Model duodenum serosa"""

    name: Literal["duodenum serosa"] = "duodenum serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27247"] = "EMAPA_27247"


class _Duodenum_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model duodenum lamina propria"""

    name: Literal["duodenum lamina propria"] = "duodenum lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27255"] = "EMAPA_27255"


class _Duodenum_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model duodenum muscularis mucosa"""

    name: Literal["duodenum muscularis mucosa"] = "duodenum muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27259"] = "EMAPA_27259"


class _Colon_Mucosa(_MouseAnatomicalStructureModel):
    """Model colon mucosa"""

    name: Literal["colon mucosa"] = "colon mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27375"] = "EMAPA_27375"


class _Colon_Submucosa(_MouseAnatomicalStructureModel):
    """Model colon submucosa"""

    name: Literal["colon submucosa"] = "colon submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27379"] = "EMAPA_27379"


class _Colon_Muscularis(_MouseAnatomicalStructureModel):
    """Model colon muscularis"""

    name: Literal["colon muscularis"] = "colon muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27383"] = "EMAPA_27383"


class _Colon_Serosa(_MouseAnatomicalStructureModel):
    """Model colon serosa"""

    name: Literal["colon serosa"] = "colon serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27387"] = "EMAPA_27387"


class _Colon_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model colon lamina propria"""

    name: Literal["colon lamina propria"] = "colon lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27395"] = "EMAPA_27395"


class _Colon_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model colon muscularis mucosa"""

    name: Literal["colon muscularis mucosa"] = "colon muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27399"] = "EMAPA_27399"


class _Anal_Canal_Mucosa(_MouseAnatomicalStructureModel):
    """Model anal canal mucosa"""

    name: Literal["anal canal mucosa"] = "anal canal mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27531"] = "EMAPA_27531"


class _Anal_Canal_Submucosa(_MouseAnatomicalStructureModel):
    """Model anal canal submucosa"""

    name: Literal["anal canal submucosa"] = "anal canal submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27535"] = "EMAPA_27535"


class _Anal_Canal_Gland(_MouseAnatomicalStructureModel):
    """Model anal canal gland"""

    name: Literal["anal canal gland"] = "anal canal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27543"] = "EMAPA_27543"


class _Anal_Canal_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model anal canal lamina propria"""

    name: Literal["anal canal lamina propria"] = "anal canal lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27547"] = "EMAPA_27547"


class _Coelomic_Epithelium_Of_Gonad_Primordium(_MouseAnatomicalStructureModel):
    """Model coelomic epithelium of gonad primordium"""

    name: Literal["coelomic epithelium of gonad primordium"] = "coelomic epithelium of gonad primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27564"] = "EMAPA_27564"


class _Anterior_Gonad_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model anterior gonad primordium mesenchyme"""

    name: Literal["anterior gonad primordium mesenchyme"] = "anterior gonad primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27566"] = "EMAPA_27566"


class _Central_Gonad_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model central gonad primordium mesenchyme"""

    name: Literal["central gonad primordium mesenchyme"] = "central gonad primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27568"] = "EMAPA_27568"


class _Posterior_Gonad_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model posterior gonad primordium mesenchyme"""

    name: Literal["posterior gonad primordium mesenchyme"] = "posterior gonad primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27570"] = "EMAPA_27570"


class _Cloaca(_MouseAnatomicalStructureModel):
    """Model cloaca"""

    name: Literal["cloaca"] = "cloaca"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27573"] = "EMAPA_27573"


class _Cloacal_Epithelium(_MouseAnatomicalStructureModel):
    """Model cloacal epithelium"""

    name: Literal["cloacal epithelium"] = "cloacal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27577"] = "EMAPA_27577"


class _Cloaca_Associated_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model cloaca associated mesenchyme"""

    name: Literal["cloaca associated mesenchyme"] = "cloaca associated mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27581"] = "EMAPA_27581"


class _Nephric_Duct_Mesonephric_Portion(_MouseAnatomicalStructureModel):
    """Model nephric duct, mesonephric portion"""

    name: Literal["nephric duct, mesonephric portion"] = "nephric duct, mesonephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27591"] = "EMAPA_27591"


class _Nephric_Duct_Metanephric_Portion(_MouseAnatomicalStructureModel):
    """Model nephric duct, metanephric portion"""

    name: Literal["nephric duct, metanephric portion"] = "nephric duct, metanephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27599"] = "EMAPA_27599"


class _Nephric_Duct_Pronephric_Portion(_MouseAnatomicalStructureModel):
    """Model nephric duct, pronephric portion"""

    name: Literal["nephric duct, pronephric portion"] = "nephric duct, pronephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27602"] = "EMAPA_27602"


class _Ureteric_Tip(_MouseAnatomicalStructureModel):
    """Model ureteric tip"""

    name: Literal["ureteric tip"] = "ureteric tip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27605"] = "EMAPA_27605"


class _Ureteric_Stalk(_MouseAnatomicalStructureModel):
    """Model ureteric stalk"""

    name: Literal["ureteric stalk"] = "ureteric stalk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27608"] = "EMAPA_27608"


class _Parametanephric_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model parametanephric mesenchyme"""

    name: Literal["parametanephric mesenchyme"] = "parametanephric mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27615"] = "EMAPA_27615"


class _Rostral_Parametanephric_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model rostral parametanephric mesenchyme"""

    name: Literal["rostral parametanephric mesenchyme"] = "rostral parametanephric mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27617"] = "EMAPA_27617"


class _Caudal_Paramesonephric_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model caudal paramesonephric mesenchyme"""

    name: Literal["caudal paramesonephric mesenchyme"] = "caudal paramesonephric mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27619"] = "EMAPA_27619"


class _Cap_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model cap mesenchyme"""

    name: Literal["cap mesenchyme"] = "cap mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27621"] = "EMAPA_27621"


class _Peripheral_Blastema(_MouseAnatomicalStructureModel):
    """Model peripheral blastema"""

    name: Literal["peripheral blastema"] = "peripheral blastema"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27623"] = "EMAPA_27623"


class _Anterior_Gonadal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model anterior gonadal mesenchyme"""

    name: Literal["anterior gonadal mesenchyme"] = "anterior gonadal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27653"] = "EMAPA_27653"


class _Central_Gonadal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model central gonadal mesenchyme"""

    name: Literal["central gonadal mesenchyme"] = "central gonadal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27655"] = "EMAPA_27655"


class _Posterior_Gonadal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model posterior gonadal mesenchyme"""

    name: Literal["posterior gonadal mesenchyme"] = "posterior gonadal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27657"] = "EMAPA_27657"


class _Paramesonephric_Duct(_MouseAnatomicalStructureModel):
    """Model paramesonephric duct"""

    name: Literal["paramesonephric duct"] = "paramesonephric duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27665"] = "EMAPA_27665"


class _Pretubular_Aggregate(_MouseAnatomicalStructureModel):
    """Model pretubular aggregate"""

    name: Literal["pretubular aggregate"] = "pretubular aggregate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27673"] = "EMAPA_27673"


class _Renal_Vesicle(_MouseAnatomicalStructureModel):
    """Model renal vesicle"""

    name: Literal["renal vesicle"] = "renal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27678"] = "EMAPA_27678"


class _Comma_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model comma-shaped body"""

    name: Literal["comma-shaped body"] = "comma-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27681"] = "EMAPA_27681"


class _Upper_Limb_Of_Comma_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model upper limb of comma-shaped body"""

    name: Literal["upper limb of comma-shaped body"] = "upper limb of comma-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27684"] = "EMAPA_27684"


class _Ureteric_Trunk(_MouseAnatomicalStructureModel):
    """Model ureteric trunk"""

    name: Literal["ureteric trunk"] = "ureteric trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27697"] = "EMAPA_27697"


class _Epithelial_Layer_Of_Ureter(_MouseAnatomicalStructureModel):
    """Model epithelial layer of ureter"""

    name: Literal["epithelial layer of ureter"] = "epithelial layer of ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27708"] = "EMAPA_27708"


class _Ureteral_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model ureteral mesenchyme"""

    name: Literal["ureteral mesenchyme"] = "ureteral mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27711"] = "EMAPA_27711"


class _Nephrogenic_Zone(_MouseAnatomicalStructureModel):
    """Model nephrogenic zone"""

    name: Literal["nephrogenic zone"] = "nephrogenic zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27721"] = "EMAPA_27721"


class _S_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model s-shaped body"""

    name: Literal["s-shaped body"] = "s-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27756"] = "EMAPA_27756"


class _Renal_Connecting_Tubule_Of_S_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model renal connecting tubule of s-shaped body"""

    name: Literal["renal connecting tubule of s-shaped body"] = "renal connecting tubule of s-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27758"] = "EMAPA_27758"


class _Distal_Segment_Of_S_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model distal segment of s-shaped body"""

    name: Literal["distal segment of s-shaped body"] = "distal segment of s-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27760"] = "EMAPA_27760"


class _Medial_Segment_Of_S_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model medial segment of s-shaped body"""

    name: Literal["medial segment of s-shaped body"] = "medial segment of s-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27762"] = "EMAPA_27762"


class _Proximal_Segment_Of_S_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model proximal segment of s-shaped body"""

    name: Literal["proximal segment of s-shaped body"] = "proximal segment of s-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27764"] = "EMAPA_27764"


class _Visceral_Epithelium_Of_S_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model visceral epithelium of s-shaped body"""

    name: Literal["visceral epithelium of s-shaped body"] = "visceral epithelium of s-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27766"] = "EMAPA_27766"


class _Parietal_Epithelium_Of_S_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model parietal epithelium of s-shaped body"""

    name: Literal["parietal epithelium of s-shaped body"] = "parietal epithelium of s-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27768"] = "EMAPA_27768"


class _Capillary_Loop_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model capillary loop renal corpuscle"""

    name: Literal["capillary loop renal corpuscle"] = "capillary loop renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27770"] = "EMAPA_27770"


class _Visceral_Epithelium_Of_Capillary_Loop_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model visceral epithelium of capillary loop renal corpuscle"""

    name: Literal[
        "visceral epithelium of capillary loop renal corpuscle"
    ] = "visceral epithelium of capillary loop renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27772"] = "EMAPA_27772"


class _Parietal_Epithelium_Of_Capillary_Loop_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model parietal epithelium of capillary loop renal corpuscle"""

    name: Literal[
        "parietal epithelium of capillary loop renal corpuscle"
    ] = "parietal epithelium of capillary loop renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27774"] = "EMAPA_27774"


class _Associated_Interstitium_Of_Capillary_Loop_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model associated interstitium of capillary loop renal corpuscle"""

    name: Literal[
        "associated interstitium of capillary loop renal corpuscle"
    ] = "associated interstitium of capillary loop renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27776"] = "EMAPA_27776"


class _Presumptive_Mesangium_Of_Capillary_Loop_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model presumptive mesangium of capillary loop renal corpuscle"""

    name: Literal[
        "presumptive mesangium of capillary loop renal corpuscle"
    ] = "presumptive mesangium of capillary loop renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27778"] = "EMAPA_27778"


class _Presumptive_Endothelium_Of_Capillary_Loop_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model presumptive endothelium of capillary loop renal corpuscle"""

    name: Literal[
        "presumptive endothelium of capillary loop renal corpuscle"
    ] = "presumptive endothelium of capillary loop renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27780"] = "EMAPA_27780"


class _Renal_Tubule(_MouseAnatomicalStructureModel):
    """Model renal tubule"""

    name: Literal["renal tubule"] = "renal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27782"] = "EMAPA_27782"


class _Early_Proximal_Tubule(_MouseAnatomicalStructureModel):
    """Model early proximal tubule"""

    name: Literal["early proximal tubule"] = "early proximal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27784"] = "EMAPA_27784"


class _Anlage_Of_Loop_Of_Henle(_MouseAnatomicalStructureModel):
    """Model anlage of loop of Henle"""

    name: Literal["anlage of loop of Henle"] = "anlage of loop of Henle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27786"] = "EMAPA_27786"


class _Early_Distal_Tubule(_MouseAnatomicalStructureModel):
    """Model early distal tubule"""

    name: Literal["early distal tubule"] = "early distal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27788"] = "EMAPA_27788"


class _Renal_Connecting_Tubule_Of_Capillary_Loop_Nephron(_MouseAnatomicalStructureModel):
    """Model renal connecting tubule of capillary loop nephron"""

    name: Literal[
        "renal connecting tubule of capillary loop nephron"
    ] = "renal connecting tubule of capillary loop nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27790"] = "EMAPA_27790"


class _Developing_Vasculature_Of_Metanephros(_MouseAnatomicalStructureModel):
    """Model developing vasculature of metanephros"""

    name: Literal["developing vasculature of metanephros"] = "developing vasculature of metanephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27794"] = "EMAPA_27794"


class _Lower_Limb_Of_Comma_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model lower limb of comma-shaped body"""

    name: Literal["lower limb of comma-shaped body"] = "lower limb of comma-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27847"] = "EMAPA_27847"


class _Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model maturing renal corpuscle"""

    name: Literal["maturing renal corpuscle"] = "maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27943"] = "EMAPA_27943"


class _Maturing_Glomerular_Tuft(_MouseAnatomicalStructureModel):
    """Model maturing glomerular tuft"""

    name: Literal["maturing glomerular tuft"] = "maturing glomerular tuft"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27949"] = "EMAPA_27949"


class _Glomerular_Capillary_System_Of_Maturing_Glomerular_Tuft(_MouseAnatomicalStructureModel):
    """Model glomerular capillary system of maturing glomerular tuft"""

    name: Literal[
        "glomerular capillary system of maturing glomerular tuft"
    ] = "glomerular capillary system of maturing glomerular tuft"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27955"] = "EMAPA_27955"


class _Glomerular_Mesangium_Of_Maturing_Glomerular_Tuft(_MouseAnatomicalStructureModel):
    """Model glomerular mesangium of maturing glomerular tuft"""

    name: Literal[
        "glomerular mesangium of maturing glomerular tuft"
    ] = "glomerular mesangium of maturing glomerular tuft"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27961"] = "EMAPA_27961"


class _Visceral_Epithelium_Of_Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model visceral epithelium of maturing renal corpuscle"""

    name: Literal["visceral epithelium of maturing renal corpuscle"] = "visceral epithelium of maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27967"] = "EMAPA_27967"


class _Bowman_S_Capsule_Of_Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model Bowman's capsule of maturing renal corpuscle"""

    name: Literal["Bowman's capsule of maturing renal corpuscle"] = "Bowman's capsule of maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27973"] = "EMAPA_27973"


class _Parietal_Epithelium_Of_Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model parietal epithelium of maturing renal corpuscle"""

    name: Literal["parietal epithelium of maturing renal corpuscle"] = "parietal epithelium of maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27979"] = "EMAPA_27979"


class _Urinary_Space_Of_Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model urinary space of maturing renal corpuscle"""

    name: Literal["urinary space of maturing renal corpuscle"] = "urinary space of maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27985"] = "EMAPA_27985"


class _Juxtaglomerular_Arteriole(_MouseAnatomicalStructureModel):
    """Model juxtaglomerular arteriole"""

    name: Literal["juxtaglomerular arteriole"] = "juxtaglomerular arteriole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_27991"] = "EMAPA_27991"


class _Cortical_Early_Proximal_Tubule(_MouseAnatomicalStructureModel):
    """Model cortical early proximal tubule"""

    name: Literal["cortical early proximal tubule"] = "cortical early proximal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28003"] = "EMAPA_28003"


class _Cortical_Early_Distal_Tubule(_MouseAnatomicalStructureModel):
    """Model cortical early distal tubule"""

    name: Literal["cortical early distal tubule"] = "cortical early distal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28007"] = "EMAPA_28007"


class _Renal_Connecting_Tubule(_MouseAnatomicalStructureModel):
    """Model renal connecting tubule"""

    name: Literal["renal connecting tubule"] = "renal connecting tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28011"] = "EMAPA_28011"


class _Developing_Vasculature_Of_Renal_Cortex(_MouseAnatomicalStructureModel):
    """Model developing vasculature of renal cortex"""

    name: Literal["developing vasculature of renal cortex"] = "developing vasculature of renal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28029"] = "EMAPA_28029"


class _Developing_Arterial_Vasculature_Of_Renal_Cortex(_MouseAnatomicalStructureModel):
    """Model developing arterial vasculature of renal cortex"""

    name: Literal["developing arterial vasculature of renal cortex"] = "developing arterial vasculature of renal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28035"] = "EMAPA_28035"


class _Developing_Venous_Vasculature_Of_Renal_Cortex(_MouseAnatomicalStructureModel):
    """Model developing venous vasculature of renal cortex"""

    name: Literal["developing venous vasculature of renal cortex"] = "developing venous vasculature of renal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28037"] = "EMAPA_28037"


class _Developing_Capillary_Of_Renal_Cortex(_MouseAnatomicalStructureModel):
    """Model developing capillary of renal cortex"""

    name: Literal["developing capillary of renal cortex"] = "developing capillary of renal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28039"] = "EMAPA_28039"


class _Immature_Loop_Of_Henle(_MouseAnatomicalStructureModel):
    """Model immature loop of Henle"""

    name: Literal["immature loop of Henle"] = "immature loop of Henle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28049"] = "EMAPA_28049"


class _Medullary_Collecting_Duct(_MouseAnatomicalStructureModel):
    """Model medullary collecting duct"""

    name: Literal["medullary collecting duct"] = "medullary collecting duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28061"] = "EMAPA_28061"


class _Developing_Vasculature_Of_Renal_Medulla(_MouseAnatomicalStructureModel):
    """Model developing vasculature of renal medulla"""

    name: Literal["developing vasculature of renal medulla"] = "developing vasculature of renal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28069"] = "EMAPA_28069"


class _Developing_Arterial_Vasculature_Of_Renal_Medulla(_MouseAnatomicalStructureModel):
    """Model developing arterial vasculature of renal medulla"""

    name: Literal[
        "developing arterial vasculature of renal medulla"
    ] = "developing arterial vasculature of renal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28071"] = "EMAPA_28071"


class _Developing_Venous_Vasculature_Of_Renal_Medulla(_MouseAnatomicalStructureModel):
    """Model developing venous vasculature of renal medulla"""

    name: Literal["developing venous vasculature of renal medulla"] = "developing venous vasculature of renal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28073"] = "EMAPA_28073"


class _Developing_Capillary_Of_Renal_Medulla(_MouseAnatomicalStructureModel):
    """Model developing capillary of renal medulla"""

    name: Literal["developing capillary of renal medulla"] = "developing capillary of renal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28075"] = "EMAPA_28075"


class _Pelvic_Urothelial_Lining(_MouseAnatomicalStructureModel):
    """Model pelvic urothelial lining"""

    name: Literal["pelvic urothelial lining"] = "pelvic urothelial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28077"] = "EMAPA_28077"


class _Perihilar_Interstitium(_MouseAnatomicalStructureModel):
    """Model perihilar interstitium"""

    name: Literal["perihilar interstitium"] = "perihilar interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28083"] = "EMAPA_28083"


class _Urothelium_Of_Ureter(_MouseAnatomicalStructureModel):
    """Model urothelium of ureter"""

    name: Literal["urothelium of ureter"] = "urothelium of ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28089"] = "EMAPA_28089"


class _Adventitia_Of_Ureter(_MouseAnatomicalStructureModel):
    """Model adventitia of ureter"""

    name: Literal["adventitia of ureter"] = "adventitia of ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28114"] = "EMAPA_28114"


class _Pelvic_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model pelvic smooth muscle"""

    name: Literal["pelvic smooth muscle"] = "pelvic smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28120"] = "EMAPA_28120"


class _Cortical_Collecting_Duct(_MouseAnatomicalStructureModel):
    """Model cortical collecting duct"""

    name: Literal["cortical collecting duct"] = "cortical collecting duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28130"] = "EMAPA_28130"


class _Renal_Cortical_Interstitium(_MouseAnatomicalStructureModel):
    """Model renal cortical interstitium"""

    name: Literal["renal cortical interstitium"] = "renal cortical interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28136"] = "EMAPA_28136"


class _Renal_Cortical_Vasculature(_MouseAnatomicalStructureModel):
    """Model renal cortical vasculature"""

    name: Literal["renal cortical vasculature"] = "renal cortical vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28142"] = "EMAPA_28142"


class _Renal_Cortical_Arterial_System(_MouseAnatomicalStructureModel):
    """Model renal cortical arterial system"""

    name: Literal["renal cortical arterial system"] = "renal cortical arterial system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28147"] = "EMAPA_28147"


class _Renal_Cortical_Venous_System(_MouseAnatomicalStructureModel):
    """Model renal cortical venous system"""

    name: Literal["renal cortical venous system"] = "renal cortical venous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28152"] = "EMAPA_28152"


class _Renal_Medullary_Vasculature(_MouseAnatomicalStructureModel):
    """Model renal medullary vasculature"""

    name: Literal["renal medullary vasculature"] = "renal medullary vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28157"] = "EMAPA_28157"


class _Renal_Medullary_Arterial_System(_MouseAnatomicalStructureModel):
    """Model renal medullary arterial system"""

    name: Literal["renal medullary arterial system"] = "renal medullary arterial system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28162"] = "EMAPA_28162"


class _Renal_Medullary_Venous_System(_MouseAnatomicalStructureModel):
    """Model renal medullary venous system"""

    name: Literal["renal medullary venous system"] = "renal medullary venous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28167"] = "EMAPA_28167"


class _Interlobular_Artery(_MouseAnatomicalStructureModel):
    """Model interlobular artery"""

    name: Literal["interlobular artery"] = "interlobular artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28212"] = "EMAPA_28212"


class _Arcuate_Artery(_MouseAnatomicalStructureModel):
    """Model arcuate artery"""

    name: Literal["arcuate artery"] = "arcuate artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28215"] = "EMAPA_28215"


class _Interlobular_Vein(_MouseAnatomicalStructureModel):
    """Model interlobular vein"""

    name: Literal["interlobular vein"] = "interlobular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28218"] = "EMAPA_28218"


class _Arcuate_Vein(_MouseAnatomicalStructureModel):
    """Model arcuate vein"""

    name: Literal["arcuate vein"] = "arcuate vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28221"] = "EMAPA_28221"


class _Afferent_Arteriole_Of_Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model afferent arteriole of maturing renal corpuscle"""

    name: Literal["afferent arteriole of maturing renal corpuscle"] = "afferent arteriole of maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28230"] = "EMAPA_28230"


class _Efferent_Arteriole_Of_Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model efferent arteriole of maturing renal corpuscle"""

    name: Literal["efferent arteriole of maturing renal corpuscle"] = "efferent arteriole of maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28233"] = "EMAPA_28233"


class _Mature_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model mature renal corpuscle"""

    name: Literal["mature renal corpuscle"] = "mature renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28236"] = "EMAPA_28236"


class _Glomerular_Tuft(_MouseAnatomicalStructureModel):
    """Model glomerular tuft"""

    name: Literal["glomerular tuft"] = "glomerular tuft"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28239"] = "EMAPA_28239"


class _Glomerular_Capillary_System(_MouseAnatomicalStructureModel):
    """Model glomerular capillary system"""

    name: Literal["glomerular capillary system"] = "glomerular capillary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28245"] = "EMAPA_28245"


class _Glomerular_Mesangium_Of_Glomerular_Tuft(_MouseAnatomicalStructureModel):
    """Model glomerular mesangium of glomerular tuft"""

    name: Literal["glomerular mesangium of glomerular tuft"] = "glomerular mesangium of glomerular tuft"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28248"] = "EMAPA_28248"


class _Glomerular_Basement_Membrane_Of_Mature_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model glomerular basement membrane of mature renal corpuscle"""

    name: Literal[
        "glomerular basement membrane of mature renal corpuscle"
    ] = "glomerular basement membrane of mature renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28251"] = "EMAPA_28251"


class _Visceral_Epithelium_Of_Mature_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model visceral epithelium of mature renal corpuscle"""

    name: Literal["visceral epithelium of mature renal corpuscle"] = "visceral epithelium of mature renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28254"] = "EMAPA_28254"


class _Bowman_S_Capsule_Of_Mature_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model Bowman's capsule of mature renal corpuscle"""

    name: Literal["Bowman's capsule of mature renal corpuscle"] = "Bowman's capsule of mature renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28257"] = "EMAPA_28257"


class _Parietal_Epithelium_Of_Mature_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model parietal epithelium of mature renal corpuscle"""

    name: Literal["parietal epithelium of mature renal corpuscle"] = "parietal epithelium of mature renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28260"] = "EMAPA_28260"


class _Urinary_Space_Of_Mature_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model urinary space of mature renal corpuscle"""

    name: Literal["urinary space of mature renal corpuscle"] = "urinary space of mature renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28263"] = "EMAPA_28263"


class _Afferent_Arteriole_Of_Mature_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model afferent arteriole of mature renal corpuscle"""

    name: Literal["afferent arteriole of mature renal corpuscle"] = "afferent arteriole of mature renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28266"] = "EMAPA_28266"


class _Part_Of_Afferent_Arteriole_Forming_The_Juxtaglomerular_Complex(_MouseAnatomicalStructureModel):
    """Model part of afferent arteriole forming the juxtaglomerular complex"""

    name: Literal[
        "part of afferent arteriole forming the juxtaglomerular complex"
    ] = "part of afferent arteriole forming the juxtaglomerular complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28269"] = "EMAPA_28269"


class _Rest_Of_Afferent_Arteriole(_MouseAnatomicalStructureModel):
    """Model rest of afferent arteriole"""

    name: Literal["rest of afferent arteriole"] = "rest of afferent arteriole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28272"] = "EMAPA_28272"


class _Efferent_Arteriole_Of_Mature_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model efferent arteriole of mature renal corpuscle"""

    name: Literal["efferent arteriole of mature renal corpuscle"] = "efferent arteriole of mature renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28275"] = "EMAPA_28275"


class _Extraglomerular_Mesangium(_MouseAnatomicalStructureModel):
    """Model extraglomerular mesangium"""

    name: Literal["extraglomerular mesangium"] = "extraglomerular mesangium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28278"] = "EMAPA_28278"


class _Renal_Proximal_Tubule(_MouseAnatomicalStructureModel):
    """Model renal proximal tubule"""

    name: Literal["renal proximal tubule"] = "renal proximal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28281"] = "EMAPA_28281"


class _Renal_Proximal_Convoluted_Tubule(_MouseAnatomicalStructureModel):
    """Model renal proximal convoluted tubule"""

    name: Literal["renal proximal convoluted tubule"] = "renal proximal convoluted tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28287"] = "EMAPA_28287"


class _Outer_Renal_Medulla(_MouseAnatomicalStructureModel):
    """Model outer renal medulla"""

    name: Literal["outer renal medulla"] = "outer renal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28310"] = "EMAPA_28310"


class _Loop_Of_Henle_Outer_Medullary_Portion(_MouseAnatomicalStructureModel):
    """Model loop of Henle, outer medullary portion"""

    name: Literal["loop of Henle, outer medullary portion"] = "loop of Henle, outer medullary portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28322"] = "EMAPA_28322"


class _Thin_Descending_Limb_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model thin descending limb of outer medulla"""

    name: Literal["thin descending limb of outer medulla"] = "thin descending limb of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28325"] = "EMAPA_28325"


class _Thin_Ascending_Limb_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model thin ascending limb of outer medulla"""

    name: Literal["thin ascending limb of outer medulla"] = "thin ascending limb of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28328"] = "EMAPA_28328"


class _Premacula_Segment_Of_Distal_Straight_Tubule_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model premacula segment of distal straight tubule of outer medulla"""

    name: Literal[
        "premacula segment of distal straight tubule of outer medulla"
    ] = "premacula segment of distal straight tubule of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28331"] = "EMAPA_28331"


class _Outer_Medullary_Interstitium(_MouseAnatomicalStructureModel):
    """Model outer medullary interstitium"""

    name: Literal["outer medullary interstitium"] = "outer medullary interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28337"] = "EMAPA_28337"


class _Outer_Medullary_Collecting_Duct(_MouseAnatomicalStructureModel):
    """Model outer medullary collecting duct"""

    name: Literal["outer medullary collecting duct"] = "outer medullary collecting duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28346"] = "EMAPA_28346"


class _Inner_Renal_Medulla(_MouseAnatomicalStructureModel):
    """Model inner renal medulla"""

    name: Literal["inner renal medulla"] = "inner renal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28349"] = "EMAPA_28349"


class _Loop_Of_Henle_Inner_Medullary_Portion(_MouseAnatomicalStructureModel):
    """Model loop of Henle, inner medullary portion"""

    name: Literal["loop of Henle, inner medullary portion"] = "loop of Henle, inner medullary portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28352"] = "EMAPA_28352"


class _Thin_Descending_Limb_Of_Inner_Medulla(_MouseAnatomicalStructureModel):
    """Model thin descending limb of inner medulla"""

    name: Literal["thin descending limb of inner medulla"] = "thin descending limb of inner medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28355"] = "EMAPA_28355"


class _Bend_Of_Loop_Of_Henle_Inner_Medullary_Portion(_MouseAnatomicalStructureModel):
    """Model bend of loop of Henle inner medullary portion"""

    name: Literal["bend of loop of Henle inner medullary portion"] = "bend of loop of Henle inner medullary portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28358"] = "EMAPA_28358"


class _Thin_Ascending_Limb_Of_Inner_Medulla(_MouseAnatomicalStructureModel):
    """Model thin ascending limb of inner medulla"""

    name: Literal["thin ascending limb of inner medulla"] = "thin ascending limb of inner medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28361"] = "EMAPA_28361"


class _Inner_Medullary_Interstitium(_MouseAnatomicalStructureModel):
    """Model inner medullary interstitium"""

    name: Literal["inner medullary interstitium"] = "inner medullary interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28364"] = "EMAPA_28364"


class _Inner_Medullary_Collecting_Duct(_MouseAnatomicalStructureModel):
    """Model inner medullary collecting duct"""

    name: Literal["inner medullary collecting duct"] = "inner medullary collecting duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28370"] = "EMAPA_28370"


class _Renal_Artery(_MouseAnatomicalStructureModel):
    """Model renal artery"""

    name: Literal["renal artery"] = "renal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28373"] = "EMAPA_28373"


class _Renal_Vein(_MouseAnatomicalStructureModel):
    """Model renal vein"""

    name: Literal["renal vein"] = "renal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28376"] = "EMAPA_28376"


class _Renal_Distal_Tubule(_MouseAnatomicalStructureModel):
    """Model renal distal tubule"""

    name: Literal["renal distal tubule"] = "renal distal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28387"] = "EMAPA_28387"


class _Distal_Convoluted_Tubule(_MouseAnatomicalStructureModel):
    """Model distal convoluted tubule"""

    name: Literal["distal convoluted tubule"] = "distal convoluted tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28393"] = "EMAPA_28393"


class _Distal_Straight_Tubule_Of_Renal_Cortex(_MouseAnatomicalStructureModel):
    """Model distal straight tubule of renal cortex"""

    name: Literal["distal straight tubule of renal cortex"] = "distal straight tubule of renal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28396"] = "EMAPA_28396"


class _Macula_Densa(_MouseAnatomicalStructureModel):
    """Model macula densa"""

    name: Literal["macula densa"] = "macula densa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28399"] = "EMAPA_28399"


class _Postmacula_Segment_Of_Distal_Straight_Tubule(_MouseAnatomicalStructureModel):
    """Model postmacula segment of distal straight tubule"""

    name: Literal["postmacula segment of distal straight tubule"] = "postmacula segment of distal straight tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28402"] = "EMAPA_28402"


class _Collecting_Duct(_MouseAnatomicalStructureModel):
    """Model collecting duct"""

    name: Literal["collecting duct"] = "collecting duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28407"] = "EMAPA_28407"


class _Stage_Iv_Immature_Nephron(_MouseAnatomicalStructureModel):
    """Model stage IV immature nephron"""

    name: Literal["stage IV immature nephron"] = "stage IV immature nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28445"] = "EMAPA_28445"


class _Renal_Vasculature(_MouseAnatomicalStructureModel):
    """Model renal vasculature"""

    name: Literal["renal vasculature"] = "renal vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28457"] = "EMAPA_28457"


class _Maturing_Nephron(_MouseAnatomicalStructureModel):
    """Model maturing nephron"""

    name: Literal["maturing nephron"] = "maturing nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28485"] = "EMAPA_28485"


class _Mature_Nephron(_MouseAnatomicalStructureModel):
    """Model mature nephron"""

    name: Literal["mature nephron"] = "mature nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28491"] = "EMAPA_28491"


class _Early_Tubule(_MouseAnatomicalStructureModel):
    """Model early tubule"""

    name: Literal["early tubule"] = "early tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28500"] = "EMAPA_28500"


class _Developing_Capillary_Loop_Stage_Nephron_Group(_MouseAnatomicalStructureModel):
    """Model developing capillary loop stage nephron group"""

    name: Literal["developing capillary loop stage nephron group"] = "developing capillary loop stage nephron group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28506"] = "EMAPA_28506"


class _Renal_Interstitium(_MouseAnatomicalStructureModel):
    """Model renal interstitium"""

    name: Literal["renal interstitium"] = "renal interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28518"] = "EMAPA_28518"


class _Late_Tubule(_MouseAnatomicalStructureModel):
    """Model late tubule"""

    name: Literal["late tubule"] = "late tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28527"] = "EMAPA_28527"


class _Male_Associated_Reproductive_Structure(_MouseAnatomicalStructureModel):
    """Model male associated reproductive structure"""

    name: Literal["male associated reproductive structure"] = "male associated reproductive structure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28533"] = "EMAPA_28533"


class _Female_Associated_Reproductive_Structure(_MouseAnatomicalStructureModel):
    """Model female associated reproductive structure"""

    name: Literal["female associated reproductive structure"] = "female associated reproductive structure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28540"] = "EMAPA_28540"


class _Allantois_Of_Embryonic_Urinary_System(_MouseAnatomicalStructureModel):
    """Model allantois of embryonic urinary system"""

    name: Literal["allantois of embryonic urinary system"] = "allantois of embryonic urinary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28547"] = "EMAPA_28547"


class _Urethral_Plate(_MouseAnatomicalStructureModel):
    """Model urethral plate"""

    name: Literal["urethral plate"] = "urethral plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28555"] = "EMAPA_28555"


class _Ureteral_Mesenchyme_Subepithelial_Layer(_MouseAnatomicalStructureModel):
    """Model ureteral mesenchyme subepithelial layer"""

    name: Literal["ureteral mesenchyme subepithelial layer"] = "ureteral mesenchyme subepithelial layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28561"] = "EMAPA_28561"


class _Ureteral_Mesenchyme_Middle_Layer(_MouseAnatomicalStructureModel):
    """Model ureteral mesenchyme middle layer"""

    name: Literal["ureteral mesenchyme middle layer"] = "ureteral mesenchyme middle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28567"] = "EMAPA_28567"


class _Ureteral_Mesenchyme_Outer_Layer(_MouseAnatomicalStructureModel):
    """Model ureteral mesenchyme outer layer"""

    name: Literal["ureteral mesenchyme outer layer"] = "ureteral mesenchyme outer layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28570"] = "EMAPA_28570"


class _Superficial_Cell_Layer_Of_Ureter(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of ureter"""

    name: Literal["superficial cell layer of ureter"] = "superficial cell layer of ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28588"] = "EMAPA_28588"


class _Urothelium_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model urothelium of bladder"""

    name: Literal["urothelium of bladder"] = "urothelium of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28601"] = "EMAPA_28601"


class _Urothelium_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model urothelium of bladder fundus"""

    name: Literal["urothelium of bladder fundus"] = "urothelium of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28607"] = "EMAPA_28607"


class _Urothelium_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model urothelium of bladder trigone"""

    name: Literal["urothelium of bladder trigone"] = "urothelium of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28613"] = "EMAPA_28613"


class _Muscularis_Mucosa_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of bladder"""

    name: Literal["muscularis mucosa of bladder"] = "muscularis mucosa of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28619"] = "EMAPA_28619"


class _Muscularis_Mucosa_Of_Fundus(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of fundus"""

    name: Literal["muscularis mucosa of fundus"] = "muscularis mucosa of fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28625"] = "EMAPA_28625"


class _Muscularis_Mucosa_Of_Trigone(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of trigone"""

    name: Literal["muscularis mucosa of trigone"] = "muscularis mucosa of trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28631"] = "EMAPA_28631"


class _Detrusor_Muscle_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model detrusor muscle of bladder"""

    name: Literal["detrusor muscle of bladder"] = "detrusor muscle of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28637"] = "EMAPA_28637"


class _Detrusor_Muscle_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model detrusor muscle of bladder fundus"""

    name: Literal["detrusor muscle of bladder fundus"] = "detrusor muscle of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28643"] = "EMAPA_28643"


class _Detrusor_Muscle_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model detrusor muscle of bladder trigone"""

    name: Literal["detrusor muscle of bladder trigone"] = "detrusor muscle of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28649"] = "EMAPA_28649"


class _Serosa_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model serosa of bladder"""

    name: Literal["serosa of bladder"] = "serosa of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28661"] = "EMAPA_28661"


class _Serosa_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model serosa of bladder fundus"""

    name: Literal["serosa of bladder fundus"] = "serosa of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28667"] = "EMAPA_28667"


class _Serosa_Of_Trigone(_MouseAnatomicalStructureModel):
    """Model serosa of trigone"""

    name: Literal["serosa of trigone"] = "serosa of trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28673"] = "EMAPA_28673"


class _Vasculature_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model vasculature of bladder"""

    name: Literal["vasculature of bladder"] = "vasculature of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28679"] = "EMAPA_28679"


class _Epithelium_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of pelvic urethra of male"""

    name: Literal["epithelium of pelvic urethra of male"] = "epithelium of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28697"] = "EMAPA_28697"


class _Mesenchymal_Layer_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of pelvic urethra of male"""

    name: Literal["mesenchymal layer of pelvic urethra of male"] = "mesenchymal layer of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28703"] = "EMAPA_28703"


class _Muscle_Layer_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model muscle layer of pelvic urethra of male"""

    name: Literal["muscle layer of pelvic urethra of male"] = "muscle layer of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28709"] = "EMAPA_28709"


class _Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model urethra of female"""

    name: Literal["urethra of female"] = "urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28747"] = "EMAPA_28747"


class _Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model pelvic urethra of female"""

    name: Literal["pelvic urethra of female"] = "pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28753"] = "EMAPA_28753"


class _Epithelium_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model epithelium of pelvic urethra of female"""

    name: Literal["epithelium of pelvic urethra of female"] = "epithelium of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28759"] = "EMAPA_28759"


class _Mesenchymal_Layer_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of pelvic urethra of female"""

    name: Literal["mesenchymal layer of pelvic urethra of female"] = "mesenchymal layer of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28765"] = "EMAPA_28765"


class _Muscle_Layer_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model muscle layer of pelvic urethra of female"""

    name: Literal["muscle layer of pelvic urethra of female"] = "muscle layer of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28771"] = "EMAPA_28771"


class _Intermediate_Cell_Layer_Of_Ureter(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of ureter"""

    name: Literal["intermediate cell layer of ureter"] = "intermediate cell layer of ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28801"] = "EMAPA_28801"


class _Basal_Cell_Layer_Of_Ureter(_MouseAnatomicalStructureModel):
    """Model basal cell layer of ureter"""

    name: Literal["basal cell layer of ureter"] = "basal cell layer of ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28806"] = "EMAPA_28806"


class _Ureteral_Smooth_Muscle_Layer(_MouseAnatomicalStructureModel):
    """Model ureteral smooth muscle layer"""

    name: Literal["ureteral smooth muscle layer"] = "ureteral smooth muscle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28811"] = "EMAPA_28811"


class _Ureteral_Smooth_Muscle_Layer_Smooth_Muscle_Component(_MouseAnatomicalStructureModel):
    """Model ureteral smooth muscle layer smooth muscle component"""

    name: Literal[
        "ureteral smooth muscle layer smooth muscle component"
    ] = "ureteral smooth muscle layer smooth muscle component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28814"] = "EMAPA_28814"


class _Adventitia_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model adventitia of bladder"""

    name: Literal["adventitia of bladder"] = "adventitia of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28826"] = "EMAPA_28826"


class _Adventitia_Of_Fundus(_MouseAnatomicalStructureModel):
    """Model adventitia of fundus"""

    name: Literal["adventitia of fundus"] = "adventitia of fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28831"] = "EMAPA_28831"


class _Adventitia_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model adventitia of bladder trigone"""

    name: Literal["adventitia of bladder trigone"] = "adventitia of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28836"] = "EMAPA_28836"


class _Lamina_Propria_Of_Ureter(_MouseAnatomicalStructureModel):
    """Model lamina propria of ureter"""

    name: Literal["lamina propria of ureter"] = "lamina propria of ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28841"] = "EMAPA_28841"


class _Mesenchymal_Layer_Of_Phallic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of phallic urethra of male"""

    name: Literal["mesenchymal layer of phallic urethra of male"] = "mesenchymal layer of phallic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28856"] = "EMAPA_28856"


class _Muscle_Layer_Of_Phallic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model muscle layer of phallic urethra of male"""

    name: Literal["muscle layer of phallic urethra of male"] = "muscle layer of phallic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28859"] = "EMAPA_28859"


class _Proximal_Straight_Tubule_Outer_Medullary_Portion(_MouseAnatomicalStructureModel):
    """Model proximal straight tubule, outer medullary portion"""

    name: Literal[
        "proximal straight tubule, outer medullary portion"
    ] = "proximal straight tubule, outer medullary portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28862"] = "EMAPA_28862"


class _Mesenchymal_Stroma_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model mesenchymal stroma of ovary"""

    name: Literal["mesenchymal stroma of ovary"] = "mesenchymal stroma of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28880"] = "EMAPA_28880"


class _Developing_Vasculature_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model developing vasculature of ovary"""

    name: Literal["developing vasculature of ovary"] = "developing vasculature of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28888"] = "EMAPA_28888"


class _Mesonephros_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesonephros of female"""

    name: Literal["mesonephros of female"] = "mesonephros of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28909"] = "EMAPA_28909"


class _Mesonephric_Mesenchyme_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesonephric mesenchyme of female"""

    name: Literal["mesonephric mesenchyme of female"] = "mesonephric mesenchyme of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28914"] = "EMAPA_28914"


class _Mesonephric_Tubule_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesonephric tubule of female"""

    name: Literal["mesonephric tubule of female"] = "mesonephric tubule of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28919"] = "EMAPA_28919"


class _Nephric_Duct_Of_Female_Mesonephric_Portion(_MouseAnatomicalStructureModel):
    """Model nephric duct of female, mesonephric portion"""

    name: Literal["nephric duct of female, mesonephric portion"] = "nephric duct of female, mesonephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28924"] = "EMAPA_28924"


class _Rete_Ovarii_Of_Mesonephros(_MouseAnatomicalStructureModel):
    """Model rete ovarii of mesonephros"""

    name: Literal["rete ovarii of mesonephros"] = "rete ovarii of mesonephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28929"] = "EMAPA_28929"


class _Coelomic_Epithelium_Of_Female_Mesonephros(_MouseAnatomicalStructureModel):
    """Model coelomic epithelium of female mesonephros"""

    name: Literal["coelomic epithelium of female mesonephros"] = "coelomic epithelium of female mesonephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28934"] = "EMAPA_28934"


class _Paramesonephric_Duct_Of_Female_Mesonephric_Portion(_MouseAnatomicalStructureModel):
    """Model paramesonephric duct of female, mesonephric portion"""

    name: Literal[
        "paramesonephric duct of female, mesonephric portion"
    ] = "paramesonephric duct of female, mesonephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28937"] = "EMAPA_28937"


class _Paramesonephric_Duct_Of_Female_Rest_Of(_MouseAnatomicalStructureModel):
    """Model paramesonephric duct of female, rest of"""

    name: Literal["paramesonephric duct of female, rest of"] = "paramesonephric duct of female, rest of"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28940"] = "EMAPA_28940"


class _Nephric_Duct_Of_Female_Rest_Of(_MouseAnatomicalStructureModel):
    """Model nephric duct of female, rest of"""

    name: Literal["nephric duct of female, rest of"] = "nephric duct of female, rest of"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28945"] = "EMAPA_28945"


class _Epithelium_Of_Nephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model epithelium of nephric duct of female"""

    name: Literal["epithelium of nephric duct of female"] = "epithelium of nephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28949"] = "EMAPA_28949"


class _Mesenchyme_Of_Nephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchyme of nephric duct of female"""

    name: Literal["mesenchyme of nephric duct of female"] = "mesenchyme of nephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28953"] = "EMAPA_28953"


class _Epithelium_Of_Rest_Of_Paramesonephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model epithelium of rest of paramesonephric duct of female"""

    name: Literal[
        "epithelium of rest of paramesonephric duct of female"
    ] = "epithelium of rest of paramesonephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28957"] = "EMAPA_28957"


class _Mesenchyme_Of_Rest_Of_Paramesonephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchyme of rest of paramesonephric duct of female"""

    name: Literal[
        "mesenchyme of rest of paramesonephric duct of female"
    ] = "mesenchyme of rest of paramesonephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28961"] = "EMAPA_28961"


class _Meiotic_Germ_Cell_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model meiotic germ cell of ovary"""

    name: Literal["meiotic germ cell of ovary"] = "meiotic germ cell of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28965"] = "EMAPA_28965"


class _Premeiotic_Germ_Cell_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model premeiotic germ cell of ovary"""

    name: Literal["premeiotic germ cell of ovary"] = "premeiotic germ cell of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28971"] = "EMAPA_28971"


class _Degenerating_Mesonephric_Tubule_Of_Female(_MouseAnatomicalStructureModel):
    """Model degenerating mesonephric tubule of female"""

    name: Literal["degenerating mesonephric tubule of female"] = "degenerating mesonephric tubule of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28978"] = "EMAPA_28978"


class _Degenerating_Mesonephric_Portion_Of_Nephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model degenerating mesonephric portion of nephric duct of female"""

    name: Literal[
        "degenerating mesonephric portion of nephric duct of female"
    ] = "degenerating mesonephric portion of nephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_28981"] = "EMAPA_28981"


class _Cortical_Component_Of_Mesenchymal_Stroma(_MouseAnatomicalStructureModel):
    """Model cortical component of mesenchymal stroma"""

    name: Literal["cortical component of mesenchymal stroma"] = "cortical component of mesenchymal stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29009"] = "EMAPA_29009"


class _Medullary_Component_Of_Mesenchymal_Stroma(_MouseAnatomicalStructureModel):
    """Model medullary component of mesenchymal stroma"""

    name: Literal["medullary component of mesenchymal stroma"] = "medullary component of mesenchymal stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29014"] = "EMAPA_29014"


class _Uterine_Horn_Epithelium(_MouseAnatomicalStructureModel):
    """Model uterine horn epithelium"""

    name: Literal["uterine horn epithelium"] = "uterine horn epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29030"] = "EMAPA_29030"


class _Uterine_Horn_Muscular_Layer(_MouseAnatomicalStructureModel):
    """Model uterine horn muscular layer"""

    name: Literal["uterine horn muscular layer"] = "uterine horn muscular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29034"] = "EMAPA_29034"


class _Epithelial_Layer_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model epithelial layer of oviduct"""

    name: Literal["epithelial layer of oviduct"] = "epithelial layer of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29043"] = "EMAPA_29043"


class _Muscle_Layer_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model muscle layer of oviduct"""

    name: Literal["muscle layer of oviduct"] = "muscle layer of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29046"] = "EMAPA_29046"


class _Outer_Layer_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model outer layer of oviduct"""

    name: Literal["outer layer of oviduct"] = "outer layer of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29049"] = "EMAPA_29049"


class _Epithelium_Of_Upper_Vagina(_MouseAnatomicalStructureModel):
    """Model epithelium of upper vagina"""

    name: Literal["epithelium of upper vagina"] = "epithelium of upper vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29052"] = "EMAPA_29052"


class _Muscle_Of_Upper_Vagina(_MouseAnatomicalStructureModel):
    """Model muscle of upper vagina"""

    name: Literal["muscle of upper vagina"] = "muscle of upper vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29055"] = "EMAPA_29055"


class _Epithelium_Of_Sinovaginal_Bulb(_MouseAnatomicalStructureModel):
    """Model epithelium of sinovaginal bulb"""

    name: Literal["epithelium of sinovaginal bulb"] = "epithelium of sinovaginal bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29058"] = "EMAPA_29058"


class _Muscle_Of_Sinovaginal_Bulb(_MouseAnatomicalStructureModel):
    """Model muscle of sinovaginal bulb"""

    name: Literal["muscle of sinovaginal bulb"] = "muscle of sinovaginal bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29061"] = "EMAPA_29061"


class _Oocyte_Of_Primary_Follicle(_MouseAnatomicalStructureModel):
    """Model oocyte of primary follicle"""

    name: Literal["oocyte of primary follicle"] = "oocyte of primary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29065"] = "EMAPA_29065"


class _Follicle_Cell_Of_Primary_Follicle(_MouseAnatomicalStructureModel):
    """Model follicle cell of primary follicle"""

    name: Literal["follicle cell of primary follicle"] = "follicle cell of primary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29067"] = "EMAPA_29067"


class _Primary_Sex_Cord(_MouseAnatomicalStructureModel):
    """Model primary sex cord"""

    name: Literal["primary sex cord"] = "primary sex cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29098"] = "EMAPA_29098"


class _Sertoli_Cell(_MouseAnatomicalStructureModel):
    """Model Sertoli cell"""

    name: Literal["Sertoli cell"] = "Sertoli cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29106"] = "EMAPA_29106"


class _Peritubular_Myoid_Cell(_MouseAnatomicalStructureModel):
    """Model peritubular myoid cell"""

    name: Literal["peritubular myoid cell"] = "peritubular myoid cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29110"] = "EMAPA_29110"


class _Developing_Vasculature_Of_Testis(_MouseAnatomicalStructureModel):
    """Model developing vasculature of testis"""

    name: Literal["developing vasculature of testis"] = "developing vasculature of testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29114"] = "EMAPA_29114"


class _Coelomic_Vessel(_MouseAnatomicalStructureModel):
    """Model coelomic vessel"""

    name: Literal["coelomic vessel"] = "coelomic vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29122"] = "EMAPA_29122"


class _Interstitial_Vessel(_MouseAnatomicalStructureModel):
    """Model interstitial vessel"""

    name: Literal["interstitial vessel"] = "interstitial vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29130"] = "EMAPA_29130"


class _Mesonephros_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesonephros of male"""

    name: Literal["mesonephros of male"] = "mesonephros of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29138"] = "EMAPA_29138"


class _Mesonephric_Mesenchyme_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesonephric mesenchyme of male"""

    name: Literal["mesonephric mesenchyme of male"] = "mesonephric mesenchyme of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29143"] = "EMAPA_29143"


class _Mesonephric_Tubule_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesonephric tubule of male"""

    name: Literal["mesonephric tubule of male"] = "mesonephric tubule of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29148"] = "EMAPA_29148"


class _Paramesonephric_Duct_Of_Male_Mesonephric_Portion(_MouseAnatomicalStructureModel):
    """Model paramesonephric duct of male, mesonephric portion"""

    name: Literal[
        "paramesonephric duct of male, mesonephric portion"
    ] = "paramesonephric duct of male, mesonephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29158"] = "EMAPA_29158"


class _Degenerating_Mesonephric_Portion_Of_Male_Paramesonephric_Duct(_MouseAnatomicalStructureModel):
    """Model degenerating mesonephric portion of male paramesonephric duct"""

    name: Literal[
        "degenerating mesonephric portion of male paramesonephric duct"
    ] = "degenerating mesonephric portion of male paramesonephric duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29161"] = "EMAPA_29161"


class _Genital_Tubercle_Mesenchyme_Of_Male(_MouseAnatomicalStructureModel):
    """Model genital tubercle mesenchyme of male"""

    name: Literal["genital tubercle mesenchyme of male"] = "genital tubercle mesenchyme of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29167"] = "EMAPA_29167"


class _Genital_Tubercle_Skin_Of_Male(_MouseAnatomicalStructureModel):
    """Model genital tubercle skin of male"""

    name: Literal["genital tubercle skin of male"] = "genital tubercle skin of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29170"] = "EMAPA_29170"


class _Nephric_Duct_Of_Male_Rest_Of(_MouseAnatomicalStructureModel):
    """Model nephric duct of male, rest of"""

    name: Literal["nephric duct of male, rest of"] = "nephric duct of male, rest of"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29173"] = "EMAPA_29173"


class _Mesenchyme_Of_Nephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchyme of nephric duct of male"""

    name: Literal["mesenchyme of nephric duct of male"] = "mesenchyme of nephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29177"] = "EMAPA_29177"


class _Epithelium_Of_Nephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of nephric duct of male"""

    name: Literal["epithelium of nephric duct of male"] = "epithelium of nephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29181"] = "EMAPA_29181"


class _Paramesonephric_Duct_Of_Male_Rest_Of(_MouseAnatomicalStructureModel):
    """Model paramesonephric duct of male, rest of"""

    name: Literal["paramesonephric duct of male, rest of"] = "paramesonephric duct of male, rest of"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29185"] = "EMAPA_29185"


class _Epithelium_Of_Rest_Of_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of rest of paramesonephric duct of male"""

    name: Literal[
        "epithelium of rest of paramesonephric duct of male"
    ] = "epithelium of rest of paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29187"] = "EMAPA_29187"


class _Mesenchyme_Of_Rest_Of_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchyme of rest of paramesonephric duct of male"""

    name: Literal[
        "mesenchyme of rest of paramesonephric duct of male"
    ] = "mesenchyme of rest of paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29189"] = "EMAPA_29189"


class _Degenerating_Rest_Of_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model degenerating rest of paramesonephric duct of male"""

    name: Literal[
        "degenerating rest of paramesonephric duct of male"
    ] = "degenerating rest of paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29196"] = "EMAPA_29196"


class _Epithelium_Of_Degenerating_Rest_Of_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of degenerating rest of paramesonephric duct of male"""

    name: Literal[
        "epithelium of degenerating rest of paramesonephric duct of male"
    ] = "epithelium of degenerating rest of paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29199"] = "EMAPA_29199"


class _Mesenchyme_Of_Degenerating_Rest_Of_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchyme of degenerating rest of paramesonephric duct of male"""

    name: Literal[
        "mesenchyme of degenerating rest of paramesonephric duct of male"
    ] = "mesenchyme of degenerating rest of paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29202"] = "EMAPA_29202"


class _Distal_Genital_Tubercle_Of_Male(_MouseAnatomicalStructureModel):
    """Model distal genital tubercle of male"""

    name: Literal["distal genital tubercle of male"] = "distal genital tubercle of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29205"] = "EMAPA_29205"


class _Mesenchyme_Of_Distal_Genital_Tubercle_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchyme of distal genital tubercle of male"""

    name: Literal["mesenchyme of distal genital tubercle of male"] = "mesenchyme of distal genital tubercle of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29207"] = "EMAPA_29207"


class _Skin_Of_Distal_Genital_Tubercle_Of_Male(_MouseAnatomicalStructureModel):
    """Model skin of distal genital tubercle of male"""

    name: Literal["skin of distal genital tubercle of male"] = "skin of distal genital tubercle of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29209"] = "EMAPA_29209"


class _Preputial_Swelling_Of_Male(_MouseAnatomicalStructureModel):
    """Model preputial swelling of male"""

    name: Literal["preputial swelling of male"] = "preputial swelling of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29220"] = "EMAPA_29220"


class _Skin_Of_Male_Preputial_Swelling(_MouseAnatomicalStructureModel):
    """Model skin of male preputial swelling"""

    name: Literal["skin of male preputial swelling"] = "skin of male preputial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29223"] = "EMAPA_29223"


class _Mesenchyme_Of_Male_Preputial_Swelling(_MouseAnatomicalStructureModel):
    """Model mesenchyme of male preputial swelling"""

    name: Literal["mesenchyme of male preputial swelling"] = "mesenchyme of male preputial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29226"] = "EMAPA_29226"


class _Glans_Of_Male_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model glans of male genital tubercle"""

    name: Literal["glans of male genital tubercle"] = "glans of male genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29252"] = "EMAPA_29252"


class _Mesenchyme_Of_Glans_Of_Male_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model mesenchyme of glans of male genital tubercle"""

    name: Literal["mesenchyme of glans of male genital tubercle"] = "mesenchyme of glans of male genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29254"] = "EMAPA_29254"


class _Skin_Of_Glans_Of_Male_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model skin of glans of male genital tubercle"""

    name: Literal["skin of glans of male genital tubercle"] = "skin of glans of male genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29256"] = "EMAPA_29256"


class _Muscle_Of_Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model muscle of ductus deferens"""

    name: Literal["muscle of ductus deferens"] = "muscle of ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29270"] = "EMAPA_29270"


class _Epithelium_Of_Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model epithelium of ductus deferens"""

    name: Literal["epithelium of ductus deferens"] = "epithelium of ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29274"] = "EMAPA_29274"


class _Male_Cystic_Vesicular_Appendage(_MouseAnatomicalStructureModel):
    """Model male cystic vesicular appendage"""

    name: Literal["male cystic vesicular appendage"] = "male cystic vesicular appendage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29304"] = "EMAPA_29304"


class _Male_Inguinal_Ring(_MouseAnatomicalStructureModel):
    """Model male inguinal ring"""

    name: Literal["male inguinal ring"] = "male inguinal ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29307"] = "EMAPA_29307"


class _Male_External_Inguinal_Ring(_MouseAnatomicalStructureModel):
    """Model male external inguinal ring"""

    name: Literal["male external inguinal ring"] = "male external inguinal ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29310"] = "EMAPA_29310"


class _Male_Internal_Inguinal_Ring(_MouseAnatomicalStructureModel):
    """Model male internal inguinal ring"""

    name: Literal["male internal inguinal ring"] = "male internal inguinal ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29313"] = "EMAPA_29313"


class _Scrotal_Fold(_MouseAnatomicalStructureModel):
    """Model scrotal fold"""

    name: Literal["scrotal fold"] = "scrotal fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29316"] = "EMAPA_29316"


class _Vasculature_Of_Testis(_MouseAnatomicalStructureModel):
    """Model vasculature of testis"""

    name: Literal["vasculature of testis"] = "vasculature of testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29603"] = "EMAPA_29603"


class _Rest_Of_Mesentery(_MouseAnatomicalStructureModel):
    """Model rest of mesentery"""

    name: Literal["rest of mesentery"] = "rest of mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29609"] = "EMAPA_29609"


class _Genital_Tubercle_Mesenchyme_Of_Female(_MouseAnatomicalStructureModel):
    """Model genital tubercle mesenchyme of female"""

    name: Literal["genital tubercle mesenchyme of female"] = "genital tubercle mesenchyme of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29621"] = "EMAPA_29621"


class _Genital_Tubercle_Skin_Of_Female(_MouseAnatomicalStructureModel):
    """Model genital tubercle skin of female"""

    name: Literal["genital tubercle skin of female"] = "genital tubercle skin of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29626"] = "EMAPA_29626"


class _Vasculature_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model vasculature of ovary"""

    name: Literal["vasculature of ovary"] = "vasculature of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29631"] = "EMAPA_29631"


class _Ureteral_Smooth_Muscle_Layer_Inner_Longitudinal_Muscle(_MouseAnatomicalStructureModel):
    """Model ureteral smooth muscle layer inner longitudinal muscle"""

    name: Literal[
        "ureteral smooth muscle layer inner longitudinal muscle"
    ] = "ureteral smooth muscle layer inner longitudinal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29633"] = "EMAPA_29633"


class _Ureteral_Smooth_Muscle_Layer_Outer_Circular_Muscle(_MouseAnatomicalStructureModel):
    """Model ureteral smooth muscle layer outer circular muscle"""

    name: Literal[
        "ureteral smooth muscle layer outer circular muscle"
    ] = "ureteral smooth muscle layer outer circular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29635"] = "EMAPA_29635"


class _Median_Umbilical_Ligament(_MouseAnatomicalStructureModel):
    """Model median umbilical ligament"""

    name: Literal["median umbilical ligament"] = "median umbilical ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29637"] = "EMAPA_29637"


class _Bulbar_Part_Of_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model bulbar part of urethra of male"""

    name: Literal["bulbar part of urethra of male"] = "bulbar part of urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29639"] = "EMAPA_29639"


class _Male_Urethral_Gland(_MouseAnatomicalStructureModel):
    """Model male urethral gland"""

    name: Literal["male urethral gland"] = "male urethral gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29645"] = "EMAPA_29645"


class _Female_Urethral_Gland(_MouseAnatomicalStructureModel):
    """Model female urethral gland"""

    name: Literal["female urethral gland"] = "female urethral gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29653"] = "EMAPA_29653"


class _Leydig_Cell(_MouseAnatomicalStructureModel):
    """Model Leydig cell"""

    name: Literal["Leydig cell"] = "Leydig cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29655"] = "EMAPA_29655"


class _Segment_1_Of_Proximal_Tubule(_MouseAnatomicalStructureModel):
    """Model segment 1 of proximal tubule"""

    name: Literal["segment 1 of proximal tubule"] = "segment 1 of proximal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29657"] = "EMAPA_29657"


class _Segment_2_Of_Proximal_Tubule(_MouseAnatomicalStructureModel):
    """Model segment 2 of proximal tubule"""

    name: Literal["segment 2 of proximal tubule"] = "segment 2 of proximal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29659"] = "EMAPA_29659"


class _Proximal_Straight_Tubule_Cortical_Portion(_MouseAnatomicalStructureModel):
    """Model proximal straight tubule, cortical portion"""

    name: Literal["proximal straight tubule, cortical portion"] = "proximal straight tubule, cortical portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29661"] = "EMAPA_29661"


class _Outer_Stripe_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model outer stripe of outer medulla"""

    name: Literal["outer stripe of outer medulla"] = "outer stripe of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29663"] = "EMAPA_29663"


class _Loop_Of_Henle_Of_Outer_Stripe_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model loop of Henle of outer stripe of outer medulla"""

    name: Literal["loop of Henle of outer stripe of outer medulla"] = "loop of Henle of outer stripe of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29665"] = "EMAPA_29665"


class _Proximal_Straight_Tubule_Of_Outer_Stripe_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model proximal straight tubule of outer stripe of outer medulla"""

    name: Literal[
        "proximal straight tubule of outer stripe of outer medulla"
    ] = "proximal straight tubule of outer stripe of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29669"] = "EMAPA_29669"


class _Distal_Straight_Tubule_Of_Outer_Stripe_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model distal straight tubule of outer stripe of outer medulla"""

    name: Literal[
        "distal straight tubule of outer stripe of outer medulla"
    ] = "distal straight tubule of outer stripe of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29671"] = "EMAPA_29671"


class _Inner_Stripe_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model inner stripe of outer medulla"""

    name: Literal["inner stripe of outer medulla"] = "inner stripe of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29675"] = "EMAPA_29675"


class _Loop_Of_Henle_Of_Inner_Stripe_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model loop of Henle of inner stripe of outer medulla"""

    name: Literal["loop of Henle of inner stripe of outer medulla"] = "loop of Henle of inner stripe of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29679"] = "EMAPA_29679"


class _Thin_Descending_Limb_Of_Inner_Stripe_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model thin descending limb of inner stripe of outer medulla"""

    name: Literal[
        "thin descending limb of inner stripe of outer medulla"
    ] = "thin descending limb of inner stripe of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29681"] = "EMAPA_29681"


class _Premacula_Segment_Of_Distal_Straight_Tubule_Of_Inner_Stripe_Of_Inner_Medulla(_MouseAnatomicalStructureModel):
    """Model premacula segment of distal straight tubule of inner stripe of inner medulla"""

    name: Literal[
        "premacula segment of distal straight tubule of inner stripe of inner medulla"
    ] = "premacula segment of distal straight tubule of inner stripe of inner medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29683"] = "EMAPA_29683"


class _Renal_Nerve(_MouseAnatomicalStructureModel):
    """Model renal nerve"""

    name: Literal["renal nerve"] = "renal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29691"] = "EMAPA_29691"


class _Epithelium_Of_Cauda_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model epithelium of cauda of epididymis"""

    name: Literal["epithelium of cauda of epididymis"] = "epithelium of cauda of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29693"] = "EMAPA_29693"


class _Trunk_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model trunk dermomyotome"""

    name: Literal["trunk dermomyotome"] = "trunk dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29695"] = "EMAPA_29695"


class _Tail_Dermomyotome(_MouseAnatomicalStructureModel):
    """Model tail dermomyotome"""

    name: Literal["tail dermomyotome"] = "tail dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29703"] = "EMAPA_29703"


class _Testicular_Branch_Of_Genital_Nerve(_MouseAnatomicalStructureModel):
    """Model testicular branch of genital nerve"""

    name: Literal["testicular branch of genital nerve"] = "testicular branch of genital nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29731"] = "EMAPA_29731"


class _Epidermal_Layer_Of_Scrotum(_MouseAnatomicalStructureModel):
    """Model epidermal layer of scrotum"""

    name: Literal["epidermal layer of scrotum"] = "epidermal layer of scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29733"] = "EMAPA_29733"


class _Basal_Epidermal_Layer_Of_Scrotum(_MouseAnatomicalStructureModel):
    """Model basal epidermal layer of scrotum"""

    name: Literal["basal epidermal layer of scrotum"] = "basal epidermal layer of scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29735"] = "EMAPA_29735"


class _Stratified_Epidermal_Layer_Of_Scrotum(_MouseAnatomicalStructureModel):
    """Model stratified epidermal layer of scrotum"""

    name: Literal["stratified epidermal layer of scrotum"] = "stratified epidermal layer of scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29737"] = "EMAPA_29737"


class _Dermal_Layer_Of_Scrotum(_MouseAnatomicalStructureModel):
    """Model dermal layer of scrotum"""

    name: Literal["dermal layer of scrotum"] = "dermal layer of scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29739"] = "EMAPA_29739"


class _Hair_Follicle_Of_Scrotum_Dermal_Layer(_MouseAnatomicalStructureModel):
    """Model hair follicle of scrotum dermal layer"""

    name: Literal["hair follicle of scrotum dermal layer"] = "hair follicle of scrotum dermal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29741"] = "EMAPA_29741"


class _Sweat_Gland_Of_Scrotum_Dermal_Layer(_MouseAnatomicalStructureModel):
    """Model sweat gland of scrotum dermal layer"""

    name: Literal["sweat gland of scrotum dermal layer"] = "sweat gland of scrotum dermal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29743"] = "EMAPA_29743"


class _Septum_Of_Scrotum(_MouseAnatomicalStructureModel):
    """Model septum of scrotum"""

    name: Literal["septum of scrotum"] = "septum of scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29745"] = "EMAPA_29745"


class _Epithelial_Layer_Of_Efferent_Duct(_MouseAnatomicalStructureModel):
    """Model epithelial layer of efferent duct"""

    name: Literal["epithelial layer of efferent duct"] = "epithelial layer of efferent duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29747"] = "EMAPA_29747"


class _Rest_Of_Efferent_Duct(_MouseAnatomicalStructureModel):
    """Model rest of efferent duct"""

    name: Literal["rest of efferent duct"] = "rest of efferent duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29749"] = "EMAPA_29749"


class _Muscle_Layer_Of_Cauda_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model muscle layer of cauda of epididymis"""

    name: Literal["muscle layer of cauda of epididymis"] = "muscle layer of cauda of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29751"] = "EMAPA_29751"


class _Adventitia_Of_Cauda_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model adventitia of cauda of epididymis"""

    name: Literal["adventitia of cauda of epididymis"] = "adventitia of cauda of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29753"] = "EMAPA_29753"


class _Epithelium_Of_Corpus_Epididymis(_MouseAnatomicalStructureModel):
    """Model epithelium of corpus epididymis"""

    name: Literal["epithelium of corpus epididymis"] = "epithelium of corpus epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29755"] = "EMAPA_29755"


class _Muscle_Layer_Of_Corpus_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model muscle layer of corpus of epididymis"""

    name: Literal["muscle layer of corpus of epididymis"] = "muscle layer of corpus of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29757"] = "EMAPA_29757"


class _Adventitia_Of_Corpus_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model adventitia of corpus of epididymis"""

    name: Literal["adventitia of corpus of epididymis"] = "adventitia of corpus of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29759"] = "EMAPA_29759"


class _Epithelium_Of_Caput_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model epithelium of caput of epididymis"""

    name: Literal["epithelium of caput of epididymis"] = "epithelium of caput of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29761"] = "EMAPA_29761"


class _Muscle_Layer_Of_Caput_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model muscle layer of caput of epididymis"""

    name: Literal["muscle layer of caput of epididymis"] = "muscle layer of caput of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29763"] = "EMAPA_29763"


class _Adventitia_Of_Caput_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model adventitia of caput of epididymis"""

    name: Literal["adventitia of caput of epididymis"] = "adventitia of caput of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29765"] = "EMAPA_29765"


class _Serosa_Of_Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model serosa of ductus deferens"""

    name: Literal["serosa of ductus deferens"] = "serosa of ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29767"] = "EMAPA_29767"


class _Os_Penis(_MouseAnatomicalStructureModel):
    """Model os penis"""

    name: Literal["os penis"] = "os penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29769"] = "EMAPA_29769"


class _Epithelium_Of_Seminal_Vesicle(_MouseAnatomicalStructureModel):
    """Model epithelium of seminal vesicle"""

    name: Literal["epithelium of seminal vesicle"] = "epithelium of seminal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29771"] = "EMAPA_29771"


class _Muscle_Of_Seminal_Vesicle(_MouseAnatomicalStructureModel):
    """Model muscle of seminal vesicle"""

    name: Literal["muscle of seminal vesicle"] = "muscle of seminal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29773"] = "EMAPA_29773"


class _Serosa_Of_Seminal_Vesicle(_MouseAnatomicalStructureModel):
    """Model serosa of seminal vesicle"""

    name: Literal["serosa of seminal vesicle"] = "serosa of seminal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29775"] = "EMAPA_29775"


class _Epithelium_Of_Ejaculatory_Duct(_MouseAnatomicalStructureModel):
    """Model epithelium of ejaculatory duct"""

    name: Literal["epithelium of ejaculatory duct"] = "epithelium of ejaculatory duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29786"] = "EMAPA_29786"


class _Epithelium_Of_Bulbourethral_Gland_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of bulbourethral gland of male"""

    name: Literal["epithelium of bulbourethral gland of male"] = "epithelium of bulbourethral gland of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29790"] = "EMAPA_29790"


class _Lamina_Propria_Of_Bulbourethral_Gland_Of_Male(_MouseAnatomicalStructureModel):
    """Model lamina propria of bulbourethral gland of male"""

    name: Literal["lamina propria of bulbourethral gland of male"] = "lamina propria of bulbourethral gland of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29792"] = "EMAPA_29792"


class _Anterior_Prostate_Gland(_MouseAnatomicalStructureModel):
    """Model anterior prostate gland"""

    name: Literal["anterior prostate gland"] = "anterior prostate gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29794"] = "EMAPA_29794"


class _Anterior_Prostatic_Epithelium(_MouseAnatomicalStructureModel):
    """Model anterior prostatic epithelium"""

    name: Literal["anterior prostatic epithelium"] = "anterior prostatic epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29796"] = "EMAPA_29796"


class _Glandular_Epithelium_Of_Anterior_Prostate(_MouseAnatomicalStructureModel):
    """Model glandular epithelium of anterior prostate"""

    name: Literal["glandular epithelium of anterior prostate"] = "glandular epithelium of anterior prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29798"] = "EMAPA_29798"


class _Basal_Epithelium_Of_Anterior_Prostate(_MouseAnatomicalStructureModel):
    """Model basal epithelium of anterior prostate"""

    name: Literal["basal epithelium of anterior prostate"] = "basal epithelium of anterior prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29800"] = "EMAPA_29800"


class _Anterior_Prostatic_Interstitium(_MouseAnatomicalStructureModel):
    """Model anterior prostatic interstitium"""

    name: Literal["anterior prostatic interstitium"] = "anterior prostatic interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29802"] = "EMAPA_29802"


class _Smooth_Muscle_Of_Anterior_Prostate(_MouseAnatomicalStructureModel):
    """Model smooth muscle of anterior prostate"""

    name: Literal["smooth muscle of anterior prostate"] = "smooth muscle of anterior prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29804"] = "EMAPA_29804"


class _Rest_Of_Interstitium_Of_Anterior_Prostate(_MouseAnatomicalStructureModel):
    """Model rest of interstitium of anterior prostate"""

    name: Literal["rest of interstitium of anterior prostate"] = "rest of interstitium of anterior prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29806"] = "EMAPA_29806"


class _Dorsal_Prostate_Gland(_MouseAnatomicalStructureModel):
    """Model dorsal prostate gland"""

    name: Literal["dorsal prostate gland"] = "dorsal prostate gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29808"] = "EMAPA_29808"


class _Dorsal_Prostatic_Epithelium(_MouseAnatomicalStructureModel):
    """Model dorsal prostatic epithelium"""

    name: Literal["dorsal prostatic epithelium"] = "dorsal prostatic epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29810"] = "EMAPA_29810"


class _Glandular_Epithelium_Of_Dorsal_Prostate(_MouseAnatomicalStructureModel):
    """Model glandular epithelium of dorsal prostate"""

    name: Literal["glandular epithelium of dorsal prostate"] = "glandular epithelium of dorsal prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29812"] = "EMAPA_29812"


class _Basal_Epithelium_Of_Dorsal_Prostate(_MouseAnatomicalStructureModel):
    """Model basal epithelium of dorsal prostate"""

    name: Literal["basal epithelium of dorsal prostate"] = "basal epithelium of dorsal prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29814"] = "EMAPA_29814"


class _Dorsal_Prostatic_Interstitium(_MouseAnatomicalStructureModel):
    """Model dorsal prostatic interstitium"""

    name: Literal["dorsal prostatic interstitium"] = "dorsal prostatic interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29816"] = "EMAPA_29816"


class _Smooth_Muscle_Of_Dorsal_Prostate(_MouseAnatomicalStructureModel):
    """Model smooth muscle of dorsal prostate"""

    name: Literal["smooth muscle of dorsal prostate"] = "smooth muscle of dorsal prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29818"] = "EMAPA_29818"


class _Rest_Of_Interstitium_Of_Dorsal_Prostate(_MouseAnatomicalStructureModel):
    """Model rest of interstitium of dorsal prostate"""

    name: Literal["rest of interstitium of dorsal prostate"] = "rest of interstitium of dorsal prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29820"] = "EMAPA_29820"


class _Lateral_Prostate_Gland(_MouseAnatomicalStructureModel):
    """Model lateral prostate gland"""

    name: Literal["lateral prostate gland"] = "lateral prostate gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29822"] = "EMAPA_29822"


class _Lateral_Prostatic_Epithelium(_MouseAnatomicalStructureModel):
    """Model lateral prostatic epithelium"""

    name: Literal["lateral prostatic epithelium"] = "lateral prostatic epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29824"] = "EMAPA_29824"


class _Glandular_Epithelium_Of_Lateral_Prostate(_MouseAnatomicalStructureModel):
    """Model glandular epithelium of lateral prostate"""

    name: Literal["glandular epithelium of lateral prostate"] = "glandular epithelium of lateral prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29826"] = "EMAPA_29826"


class _Basal_Epithelium_Of_Lateral_Prostate(_MouseAnatomicalStructureModel):
    """Model basal epithelium of lateral prostate"""

    name: Literal["basal epithelium of lateral prostate"] = "basal epithelium of lateral prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29828"] = "EMAPA_29828"


class _Lateral_Prostatic_Interstitium(_MouseAnatomicalStructureModel):
    """Model lateral prostatic interstitium"""

    name: Literal["lateral prostatic interstitium"] = "lateral prostatic interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29830"] = "EMAPA_29830"


class _Smooth_Muscle_Of_Lateral_Prostate(_MouseAnatomicalStructureModel):
    """Model smooth muscle of lateral prostate"""

    name: Literal["smooth muscle of lateral prostate"] = "smooth muscle of lateral prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29832"] = "EMAPA_29832"


class _Rest_Of_Interstitium_Of_Lateral_Prostate(_MouseAnatomicalStructureModel):
    """Model rest of interstitium of lateral prostate"""

    name: Literal["rest of interstitium of lateral prostate"] = "rest of interstitium of lateral prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29834"] = "EMAPA_29834"


class _Ventral_Prostate_Gland(_MouseAnatomicalStructureModel):
    """Model ventral prostate gland"""

    name: Literal["ventral prostate gland"] = "ventral prostate gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29836"] = "EMAPA_29836"


class _Ventral_Prostatic_Epithelium(_MouseAnatomicalStructureModel):
    """Model ventral prostatic epithelium"""

    name: Literal["ventral prostatic epithelium"] = "ventral prostatic epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29838"] = "EMAPA_29838"


class _Glandular_Epithelium_Of_Ventral_Prostate(_MouseAnatomicalStructureModel):
    """Model glandular epithelium of ventral prostate"""

    name: Literal["glandular epithelium of ventral prostate"] = "glandular epithelium of ventral prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29840"] = "EMAPA_29840"


class _Basal_Epithelium_Of_Ventral_Prostate(_MouseAnatomicalStructureModel):
    """Model basal epithelium of ventral prostate"""

    name: Literal["basal epithelium of ventral prostate"] = "basal epithelium of ventral prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29842"] = "EMAPA_29842"


class _Ventral_Prostatic_Interstitium(_MouseAnatomicalStructureModel):
    """Model ventral prostatic interstitium"""

    name: Literal["ventral prostatic interstitium"] = "ventral prostatic interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29844"] = "EMAPA_29844"


class _Smooth_Muscle_Of_Ventral_Prostate(_MouseAnatomicalStructureModel):
    """Model smooth muscle of ventral prostate"""

    name: Literal["smooth muscle of ventral prostate"] = "smooth muscle of ventral prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29846"] = "EMAPA_29846"


class _Rest_Of_Interstitium_Of_Ventral_Prostate(_MouseAnatomicalStructureModel):
    """Model rest of interstitium of ventral prostate"""

    name: Literal["rest of interstitium of ventral prostate"] = "rest of interstitium of ventral prostate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29848"] = "EMAPA_29848"


class _Corpus_Cavernosum_Of_Penile_Body(_MouseAnatomicalStructureModel):
    """Model corpus cavernosum of penile body"""

    name: Literal["corpus cavernosum of penile body"] = "corpus cavernosum of penile body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29850"] = "EMAPA_29850"


class _Lamina_Propria_Of_Penile_Body(_MouseAnatomicalStructureModel):
    """Model lamina propria of penile body"""

    name: Literal["lamina propria of penile body"] = "lamina propria of penile body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29854"] = "EMAPA_29854"


class _Corpus_Cavernosum_Of_Glans_Penis(_MouseAnatomicalStructureModel):
    """Model corpus cavernosum of glans penis"""

    name: Literal["corpus cavernosum of glans penis"] = "corpus cavernosum of glans penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29856"] = "EMAPA_29856"


class _Lamina_Propria_Of_Glans_Penis(_MouseAnatomicalStructureModel):
    """Model lamina propria of glans penis"""

    name: Literal["lamina propria of glans penis"] = "lamina propria of glans penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29860"] = "EMAPA_29860"


class _Oocyte_Of_Secondary_Follicle(_MouseAnatomicalStructureModel):
    """Model oocyte of secondary follicle"""

    name: Literal["oocyte of secondary follicle"] = "oocyte of secondary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29864"] = "EMAPA_29864"


class _Follicle_Cell_Of_Secondary_Follicle(_MouseAnatomicalStructureModel):
    """Model follicle cell of secondary follicle"""

    name: Literal["follicle cell of secondary follicle"] = "follicle cell of secondary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29866"] = "EMAPA_29866"


class _Cumulus_Of_Secondary_Follicle(_MouseAnatomicalStructureModel):
    """Model cumulus of secondary follicle"""

    name: Literal["cumulus of secondary follicle"] = "cumulus of secondary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29868"] = "EMAPA_29868"


class _Mural_Of_Secondary_Follicle(_MouseAnatomicalStructureModel):
    """Model mural of secondary follicle"""

    name: Literal["mural of secondary follicle"] = "mural of secondary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29870"] = "EMAPA_29870"


class _Theca_Of_Secondary_Follicle(_MouseAnatomicalStructureModel):
    """Model theca of secondary follicle"""

    name: Literal["theca of secondary follicle"] = "theca of secondary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29872"] = "EMAPA_29872"


class _Ovary_Atretic_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary atretic follicle"""

    name: Literal["ovary atretic follicle"] = "ovary atretic follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29874"] = "EMAPA_29874"


class _Oocyte_Of_Atretic_Follicle(_MouseAnatomicalStructureModel):
    """Model oocyte of atretic follicle"""

    name: Literal["oocyte of atretic follicle"] = "oocyte of atretic follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29876"] = "EMAPA_29876"


class _Apoptotic_Germinal_Cell(_MouseAnatomicalStructureModel):
    """Model apoptotic germinal cell"""

    name: Literal["apoptotic germinal cell"] = "apoptotic germinal cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29878"] = "EMAPA_29878"


class _Ovary_Ruptured_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary ruptured follicle"""

    name: Literal["ovary ruptured follicle"] = "ovary ruptured follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29880"] = "EMAPA_29880"


class _Theca_Of_Ruptured_Follicle(_MouseAnatomicalStructureModel):
    """Model theca of ruptured follicle"""

    name: Literal["theca of ruptured follicle"] = "theca of ruptured follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29882"] = "EMAPA_29882"


class _Germinal_Cell_Of_Ruptured_Follicle(_MouseAnatomicalStructureModel):
    """Model germinal cell of ruptured follicle"""

    name: Literal["germinal cell of ruptured follicle"] = "germinal cell of ruptured follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29884"] = "EMAPA_29884"


class _Corpus_Luteum(_MouseAnatomicalStructureModel):
    """Model corpus luteum"""

    name: Literal["corpus luteum"] = "corpus luteum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29886"] = "EMAPA_29886"


class _Corpus_Albicans(_MouseAnatomicalStructureModel):
    """Model corpus albicans"""

    name: Literal["corpus albicans"] = "corpus albicans"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29888"] = "EMAPA_29888"


class _Oviduct_Infundibulum(_MouseAnatomicalStructureModel):
    """Model oviduct infundibulum"""

    name: Literal["oviduct infundibulum"] = "oviduct infundibulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29897"] = "EMAPA_29897"


class _Epithelial_Layer_Of_Infundibulum(_MouseAnatomicalStructureModel):
    """Model epithelial layer of infundibulum"""

    name: Literal["epithelial layer of infundibulum"] = "epithelial layer of infundibulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29899"] = "EMAPA_29899"


class _Serosa_Of_Infundibulum(_MouseAnatomicalStructureModel):
    """Model serosa of infundibulum"""

    name: Literal["serosa of infundibulum"] = "serosa of infundibulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29903"] = "EMAPA_29903"


class _Rest_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model rest of oviduct"""

    name: Literal["rest of oviduct"] = "rest of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29905"] = "EMAPA_29905"


class _Epithelial_Layer_Of_Rest_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model epithelial layer of rest of oviduct"""

    name: Literal["epithelial layer of rest of oviduct"] = "epithelial layer of rest of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29907"] = "EMAPA_29907"


class _Serosa_Of_Rest_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model serosa of rest of oviduct"""

    name: Literal["serosa of rest of oviduct"] = "serosa of rest of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29913"] = "EMAPA_29913"


class _Uterus(_MouseAnatomicalStructureModel):
    """Model uterus"""

    name: Literal["uterus"] = "uterus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29915"] = "EMAPA_29915"


class _Endometrium(_MouseAnatomicalStructureModel):
    """Model endometrium"""

    name: Literal["endometrium"] = "endometrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29917"] = "EMAPA_29917"


class _Uterine_Gland(_MouseAnatomicalStructureModel):
    """Model uterine gland"""

    name: Literal["uterine gland"] = "uterine gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29919"] = "EMAPA_29919"


class _Rest_Of_Endometrium(_MouseAnatomicalStructureModel):
    """Model rest of endometrium"""

    name: Literal["rest of endometrium"] = "rest of endometrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29921"] = "EMAPA_29921"


class _Myometrium(_MouseAnatomicalStructureModel):
    """Model myometrium"""

    name: Literal["myometrium"] = "myometrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29923"] = "EMAPA_29923"


class _Adventitia_Of_Uterus(_MouseAnatomicalStructureModel):
    """Model adventitia of uterus"""

    name: Literal["adventitia of uterus"] = "adventitia of uterus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29925"] = "EMAPA_29925"


class _Cervix_Uteri(_MouseAnatomicalStructureModel):
    """Model cervix uteri"""

    name: Literal["cervix uteri"] = "cervix uteri"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29927"] = "EMAPA_29927"


class _Epithelial_Layer_Of_Cervix_Uteri(_MouseAnatomicalStructureModel):
    """Model epithelial layer of cervix uteri"""

    name: Literal["epithelial layer of cervix uteri"] = "epithelial layer of cervix uteri"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29929"] = "EMAPA_29929"


class _Muscle_Layer_Of_Cervix_Uteri(_MouseAnatomicalStructureModel):
    """Model muscle layer of cervix uteri"""

    name: Literal["muscle layer of cervix uteri"] = "muscle layer of cervix uteri"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29931"] = "EMAPA_29931"


class _Adventitia_Of_Cervix_Uteri(_MouseAnatomicalStructureModel):
    """Model adventitia of cervix uteri"""

    name: Literal["adventitia of cervix uteri"] = "adventitia of cervix uteri"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29933"] = "EMAPA_29933"


class _Gland_Of_Lower_Vaginal_Epithelium(_MouseAnatomicalStructureModel):
    """Model gland of lower vaginal epithelium"""

    name: Literal["gland of lower vaginal epithelium"] = "gland of lower vaginal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29935"] = "EMAPA_29935"


class _Rest_Of_Epithelial_Layer_Of_Lower_Vagina(_MouseAnatomicalStructureModel):
    """Model rest of epithelial layer of lower vagina"""

    name: Literal["rest of epithelial layer of lower vagina"] = "rest of epithelial layer of lower vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29937"] = "EMAPA_29937"


class _Adventitia_Of_Sinovaginal_Bulb(_MouseAnatomicalStructureModel):
    """Model adventitia of sinovaginal bulb"""

    name: Literal["adventitia of sinovaginal bulb"] = "adventitia of sinovaginal bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29939"] = "EMAPA_29939"


class _Gland_Of_Upper_Vaginal_Epithelium(_MouseAnatomicalStructureModel):
    """Model gland of upper vaginal epithelium"""

    name: Literal["gland of upper vaginal epithelium"] = "gland of upper vaginal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29941"] = "EMAPA_29941"


class _Rest_Of_Epithelium_Of_Upper_Vagina(_MouseAnatomicalStructureModel):
    """Model rest of epithelium of upper vagina"""

    name: Literal["rest of epithelium of upper vagina"] = "rest of epithelium of upper vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29943"] = "EMAPA_29943"


class _Adventitia_Of_Upper_Vagina(_MouseAnatomicalStructureModel):
    """Model adventitia of upper vagina"""

    name: Literal["adventitia of upper vagina"] = "adventitia of upper vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29945"] = "EMAPA_29945"


class _Ureteral_Mesenchyme_Rest_Of(_MouseAnatomicalStructureModel):
    """Model ureteral mesenchyme, rest of"""

    name: Literal["ureteral mesenchyme, rest of"] = "ureteral mesenchyme, rest of"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29993"] = "EMAPA_29993"


class _Endothelium_Of_Renal_Artery(_MouseAnatomicalStructureModel):
    """Model endothelium of renal artery"""

    name: Literal["endothelium of renal artery"] = "endothelium of renal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_29995"] = "EMAPA_29995"


class _Smooth_Muscle_Layer_Of_Renal_Artery(_MouseAnatomicalStructureModel):
    """Model smooth muscle layer of renal artery"""

    name: Literal["smooth muscle layer of renal artery"] = "smooth muscle layer of renal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30003"] = "EMAPA_30003"


class _Endothelium_Of_Renal_Vein(_MouseAnatomicalStructureModel):
    """Model endothelium of renal vein"""

    name: Literal["endothelium of renal vein"] = "endothelium of renal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30011"] = "EMAPA_30011"


class _Smooth_Muscle_Layer_Of_Renal_Vein(_MouseAnatomicalStructureModel):
    """Model smooth muscle layer of renal vein"""

    name: Literal["smooth muscle layer of renal vein"] = "smooth muscle layer of renal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30019"] = "EMAPA_30019"


class _Glomerular_Mesangium_Of_Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model glomerular mesangium of maturing renal corpuscle"""

    name: Literal[
        "glomerular mesangium of maturing renal corpuscle"
    ] = "glomerular mesangium of maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30031"] = "EMAPA_30031"


class _Renal_Cortical_Capillary(_MouseAnatomicalStructureModel):
    """Model renal cortical capillary"""

    name: Literal["renal cortical capillary"] = "renal cortical capillary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30037"] = "EMAPA_30037"


class _Renal_Medullary_Capillary(_MouseAnatomicalStructureModel):
    """Model renal medullary capillary"""

    name: Literal["renal medullary capillary"] = "renal medullary capillary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30043"] = "EMAPA_30043"


class _Muscle_Layer_Of_Rest_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model muscle layer of rest of oviduct"""

    name: Literal["muscle layer of rest of oviduct"] = "muscle layer of rest of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30049"] = "EMAPA_30049"


class _Circular_Muscle_Layer_Of_Rest_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model circular muscle layer of rest of oviduct"""

    name: Literal["circular muscle layer of rest of oviduct"] = "circular muscle layer of rest of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30051"] = "EMAPA_30051"


class _Longitudinal_Muscle_Layer_Of_Rest_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model longitudinal muscle layer of rest of oviduct"""

    name: Literal["longitudinal muscle layer of rest of oviduct"] = "longitudinal muscle layer of rest of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30053"] = "EMAPA_30053"


class _Circular_Muscle_Of_Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model circular muscle of ductus deferens"""

    name: Literal["circular muscle of ductus deferens"] = "circular muscle of ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30055"] = "EMAPA_30055"


class _Longitudinal_Muscle_Of_Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model longitudinal muscle of ductus deferens"""

    name: Literal["longitudinal muscle of ductus deferens"] = "longitudinal muscle of ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30057"] = "EMAPA_30057"


class _Cranial_Suspensory_Ligament(_MouseAnatomicalStructureModel):
    """Model cranial suspensory ligament"""

    name: Literal["cranial suspensory ligament"] = "cranial suspensory ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30068"] = "EMAPA_30068"


class _Epithelium_Of_Paramesonephric_Duct_Of_Female_Mesonephric_Portion(_MouseAnatomicalStructureModel):
    """Model epithelium of paramesonephric duct of female, mesonephric portion"""

    name: Literal[
        "epithelium of paramesonephric duct of female, mesonephric portion"
    ] = "epithelium of paramesonephric duct of female, mesonephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30070"] = "EMAPA_30070"


class _Mesenchyme_Of_Paramesonephric_Duct_Of_Female_Mesonephric_Portion(_MouseAnatomicalStructureModel):
    """Model mesenchyme of paramesonephric duct of female, mesonephric portion"""

    name: Literal[
        "mesenchyme of paramesonephric duct of female, mesonephric portion"
    ] = "mesenchyme of paramesonephric duct of female, mesonephric portion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30072"] = "EMAPA_30072"


class _Genital_Swelling(_MouseAnatomicalStructureModel):
    """Model genital swelling"""

    name: Literal["genital swelling"] = "genital swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30074"] = "EMAPA_30074"


class _Dorsal_Genital_Swelling(_MouseAnatomicalStructureModel):
    """Model dorsal genital swelling"""

    name: Literal["dorsal genital swelling"] = "dorsal genital swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30077"] = "EMAPA_30077"


class _Ventrolateral_Genital_Swelling(_MouseAnatomicalStructureModel):
    """Model ventrolateral genital swelling"""

    name: Literal["ventrolateral genital swelling"] = "ventrolateral genital swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30079"] = "EMAPA_30079"


class _Urothelium_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model urothelium of ventral bladder neck"""

    name: Literal["urothelium of ventral bladder neck"] = "urothelium of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30081"] = "EMAPA_30081"


class _Lamina_Propria_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model lamina propria of bladder"""

    name: Literal["lamina propria of bladder"] = "lamina propria of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30088"] = "EMAPA_30088"


class _Lamina_Propria_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model lamina propria of bladder fundus"""

    name: Literal["lamina propria of bladder fundus"] = "lamina propria of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30102"] = "EMAPA_30102"


class _Lamina_Propria_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model lamina propria of bladder trigone"""

    name: Literal["lamina propria of bladder trigone"] = "lamina propria of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30109"] = "EMAPA_30109"


class _Lamina_Propria_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model lamina propria of ventral bladder neck"""

    name: Literal["lamina propria of ventral bladder neck"] = "lamina propria of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30116"] = "EMAPA_30116"


class _Detrusor_Muscle_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model detrusor muscle of ventral bladder neck"""

    name: Literal["detrusor muscle of ventral bladder neck"] = "detrusor muscle of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30123"] = "EMAPA_30123"


class _Serosa_Of_Neck(_MouseAnatomicalStructureModel):
    """Model serosa of neck"""

    name: Literal["serosa of neck"] = "serosa of neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30130"] = "EMAPA_30130"


class _Muscularis_Mucosa_Of_Neck(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of neck"""

    name: Literal["muscularis mucosa of neck"] = "muscularis mucosa of neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30137"] = "EMAPA_30137"


class _Adventitia_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model adventitia of ventral bladder neck"""

    name: Literal["adventitia of ventral bladder neck"] = "adventitia of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30144"] = "EMAPA_30144"


class _Ureteral_Smooth_Muscle_Layer_Interstitium(_MouseAnatomicalStructureModel):
    """Model ureteral smooth muscle layer interstitium"""

    name: Literal["ureteral smooth muscle layer interstitium"] = "ureteral smooth muscle layer interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30150"] = "EMAPA_30150"


class _Labial_Swelling(_MouseAnatomicalStructureModel):
    """Model labial swelling"""

    name: Literal["labial swelling"] = "labial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30423"] = "EMAPA_30423"


class _Mesenchyme_Of_Labial_Swelling(_MouseAnatomicalStructureModel):
    """Model mesenchyme of labial swelling"""

    name: Literal["mesenchyme of labial swelling"] = "mesenchyme of labial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30426"] = "EMAPA_30426"


class _Labial_Swelling_Skin(_MouseAnatomicalStructureModel):
    """Model labial swelling skin"""

    name: Literal["labial swelling skin"] = "labial swelling skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30429"] = "EMAPA_30429"


class _Mesenchyme_Of_Labial_Fold(_MouseAnatomicalStructureModel):
    """Model mesenchyme of labial fold"""

    name: Literal["mesenchyme of labial fold"] = "mesenchyme of labial fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30433"] = "EMAPA_30433"


class _Labial_Fold_Skin(_MouseAnatomicalStructureModel):
    """Model labial fold skin"""

    name: Literal["labial fold skin"] = "labial fold skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30438"] = "EMAPA_30438"


class _Adventitia_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model adventitia of epididymis"""

    name: Literal["adventitia of epididymis"] = "adventitia of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30443"] = "EMAPA_30443"


class _Epithelium_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model epithelium of epididymis"""

    name: Literal["epithelium of epididymis"] = "epithelium of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30445"] = "EMAPA_30445"


class _Juxtaglomerular_Complex(_MouseAnatomicalStructureModel):
    """Model juxtaglomerular complex"""

    name: Literal["juxtaglomerular complex"] = "juxtaglomerular complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30449"] = "EMAPA_30449"


class _Coelomic_Epithelium_Of_Male_Mesonephros(_MouseAnatomicalStructureModel):
    """Model coelomic epithelium of male mesonephros"""

    name: Literal["coelomic epithelium of male mesonephros"] = "coelomic epithelium of male mesonephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30460"] = "EMAPA_30460"


class _Epithelium_Of_Phallic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of phallic urethra of male"""

    name: Literal["epithelium of phallic urethra of male"] = "epithelium of phallic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30467"] = "EMAPA_30467"


class _Epithelium_Of_Phallic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model epithelium of phallic urethra of female"""

    name: Literal["epithelium of phallic urethra of female"] = "epithelium of phallic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30470"] = "EMAPA_30470"


class _Preputial_Swelling_Of_Female(_MouseAnatomicalStructureModel):
    """Model preputial swelling of female"""

    name: Literal["preputial swelling of female"] = "preputial swelling of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30478"] = "EMAPA_30478"


class _Distal_Genital_Tubercle_Of_Female(_MouseAnatomicalStructureModel):
    """Model distal genital tubercle of female"""

    name: Literal["distal genital tubercle of female"] = "distal genital tubercle of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30484"] = "EMAPA_30484"


class _Mesenchyme_Of_Distal_Genital_Tubercle_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchyme of distal genital tubercle of female"""

    name: Literal["mesenchyme of distal genital tubercle of female"] = "mesenchyme of distal genital tubercle of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30487"] = "EMAPA_30487"


class _Skin_Of_Distal_Genital_Tubercle_Of_Female(_MouseAnatomicalStructureModel):
    """Model skin of distal genital tubercle of female"""

    name: Literal["skin of distal genital tubercle of female"] = "skin of distal genital tubercle of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30490"] = "EMAPA_30490"


class _Mesenchyme_Of_Female_Preputial_Swelling(_MouseAnatomicalStructureModel):
    """Model mesenchyme of female preputial swelling"""

    name: Literal["mesenchyme of female preputial swelling"] = "mesenchyme of female preputial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30493"] = "EMAPA_30493"


class _Skin_Of_Female_Preputial_Swelling(_MouseAnatomicalStructureModel):
    """Model skin of female preputial swelling"""

    name: Literal["skin of female preputial swelling"] = "skin of female preputial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30496"] = "EMAPA_30496"


class _Scrotal_Swelling(_MouseAnatomicalStructureModel):
    """Model scrotal swelling"""

    name: Literal["scrotal swelling"] = "scrotal swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30509"] = "EMAPA_30509"


class _Mesenchyme_Of_Scrotal_Swelling(_MouseAnatomicalStructureModel):
    """Model mesenchyme of scrotal swelling"""

    name: Literal["mesenchyme of scrotal swelling"] = "mesenchyme of scrotal swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30512"] = "EMAPA_30512"


class _Scrotal_Swelling_Skin(_MouseAnatomicalStructureModel):
    """Model scrotal swelling skin"""

    name: Literal["scrotal swelling skin"] = "scrotal swelling skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30515"] = "EMAPA_30515"


class _Tunica_Albuginea_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model tunica albuginea of ovary"""

    name: Literal["tunica albuginea of ovary"] = "tunica albuginea of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30522"] = "EMAPA_30522"


class _Cranial_Mesonephric_Tubule_Of_Male(_MouseAnatomicalStructureModel):
    """Model cranial mesonephric tubule of male"""

    name: Literal["cranial mesonephric tubule of male"] = "cranial mesonephric tubule of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30528"] = "EMAPA_30528"


class _Mesonephric_Glomerulus_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesonephric glomerulus of male"""

    name: Literal["mesonephric glomerulus of male"] = "mesonephric glomerulus of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30532"] = "EMAPA_30532"


class _Rest_Of_Cranial_Mesonephric_Tubule_Of_Male(_MouseAnatomicalStructureModel):
    """Model rest of cranial mesonephric tubule of male"""

    name: Literal["rest of cranial mesonephric tubule of male"] = "rest of cranial mesonephric tubule of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30536"] = "EMAPA_30536"


class _Caudal_Mesonephric_Tubule_Of_Male(_MouseAnatomicalStructureModel):
    """Model caudal mesonephric tubule of male"""

    name: Literal["caudal mesonephric tubule of male"] = "caudal mesonephric tubule of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30540"] = "EMAPA_30540"


class _Cranial_Mesonephric_Tubule_Of_Female(_MouseAnatomicalStructureModel):
    """Model cranial mesonephric tubule of female"""

    name: Literal["cranial mesonephric tubule of female"] = "cranial mesonephric tubule of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30544"] = "EMAPA_30544"


class _Mesonephric_Glomerulus_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesonephric glomerulus of female"""

    name: Literal["mesonephric glomerulus of female"] = "mesonephric glomerulus of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30547"] = "EMAPA_30547"


class _Rest_Of_Cranial_Mesonephric_Tubule_Of_Female(_MouseAnatomicalStructureModel):
    """Model rest of cranial mesonephric tubule of female"""

    name: Literal["rest of cranial mesonephric tubule of female"] = "rest of cranial mesonephric tubule of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30550"] = "EMAPA_30550"


class _Caudal_Mesonephric_Tubule_Of_Female(_MouseAnatomicalStructureModel):
    """Model caudal mesonephric tubule of female"""

    name: Literal["caudal mesonephric tubule of female"] = "caudal mesonephric tubule of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30553"] = "EMAPA_30553"


class _Cranial_Mesonephric_Tubule(_MouseAnatomicalStructureModel):
    """Model cranial mesonephric tubule"""

    name: Literal["cranial mesonephric tubule"] = "cranial mesonephric tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30562"] = "EMAPA_30562"


class _Rest_Of_Cranial_Mesonephric_Tubule(_MouseAnatomicalStructureModel):
    """Model rest of cranial mesonephric tubule"""

    name: Literal["rest of cranial mesonephric tubule"] = "rest of cranial mesonephric tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30565"] = "EMAPA_30565"


class _Mesonephric_Glomerulus(_MouseAnatomicalStructureModel):
    """Model mesonephric glomerulus"""

    name: Literal["mesonephric glomerulus"] = "mesonephric glomerulus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30568"] = "EMAPA_30568"


class _Caudal_Mesonephric_Tubule(_MouseAnatomicalStructureModel):
    """Model caudal mesonephric tubule"""

    name: Literal["caudal mesonephric tubule"] = "caudal mesonephric tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30571"] = "EMAPA_30571"


class _Mesenchyme_Of_Scrotal_Fold(_MouseAnatomicalStructureModel):
    """Model mesenchyme of scrotal fold"""

    name: Literal["mesenchyme of scrotal fold"] = "mesenchyme of scrotal fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30624"] = "EMAPA_30624"


class _Scrotal_Fold_Skin(_MouseAnatomicalStructureModel):
    """Model scrotal fold skin"""

    name: Literal["scrotal fold skin"] = "scrotal fold skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30627"] = "EMAPA_30627"


class _Mesenchyme_Of_Glans_Penis(_MouseAnatomicalStructureModel):
    """Model mesenchyme of glans penis"""

    name: Literal["mesenchyme of glans penis"] = "mesenchyme of glans penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30642"] = "EMAPA_30642"


class _Glans_Penis_Skin(_MouseAnatomicalStructureModel):
    """Model glans penis skin"""

    name: Literal["glans penis skin"] = "glans penis skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30646"] = "EMAPA_30646"


class _Prepuce_Mesenchyme_Of_Male(_MouseAnatomicalStructureModel):
    """Model prepuce mesenchyme of male"""

    name: Literal["prepuce mesenchyme of male"] = "prepuce mesenchyme of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30650"] = "EMAPA_30650"


class _Male_Prepuce_Skin(_MouseAnatomicalStructureModel):
    """Model male prepuce skin"""

    name: Literal["male prepuce skin"] = "male prepuce skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30655"] = "EMAPA_30655"


class _Preputial_Gland_Of_Male(_MouseAnatomicalStructureModel):
    """Model preputial gland of male"""

    name: Literal["preputial gland of male"] = "preputial gland of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30659"] = "EMAPA_30659"


class _Mesenchyme_Of_Penile_Body(_MouseAnatomicalStructureModel):
    """Model mesenchyme of penile body"""

    name: Literal["mesenchyme of penile body"] = "mesenchyme of penile body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30664"] = "EMAPA_30664"


class _Penile_Body_Skin(_MouseAnatomicalStructureModel):
    """Model penile body skin"""

    name: Literal["penile body skin"] = "penile body skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30668"] = "EMAPA_30668"


class _Outer_Layer_Of_Uterine_Horn(_MouseAnatomicalStructureModel):
    """Model outer layer of uterine horn"""

    name: Literal["outer layer of uterine horn"] = "outer layer of uterine horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30675"] = "EMAPA_30675"


class _Prepuce_Of_Female(_MouseAnatomicalStructureModel):
    """Model prepuce of female"""

    name: Literal["prepuce of female"] = "prepuce of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30699"] = "EMAPA_30699"


class _Female_Prepuce_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model female prepuce mesenchyme"""

    name: Literal["female prepuce mesenchyme"] = "female prepuce mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30703"] = "EMAPA_30703"


class _Female_Prepuce_Skin(_MouseAnatomicalStructureModel):
    """Model female prepuce skin"""

    name: Literal["female prepuce skin"] = "female prepuce skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30707"] = "EMAPA_30707"


class _Preputial_Gland_Of_Female(_MouseAnatomicalStructureModel):
    """Model preputial gland of female"""

    name: Literal["preputial gland of female"] = "preputial gland of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30711"] = "EMAPA_30711"


class _Mesenchyme_Of_Glans_Clitoris(_MouseAnatomicalStructureModel):
    """Model mesenchyme of glans clitoris"""

    name: Literal["mesenchyme of glans clitoris"] = "mesenchyme of glans clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30715"] = "EMAPA_30715"


class _Skin_Of_Glans_Of_Female_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model skin of glans of female genital tubercle"""

    name: Literal["skin of glans of female genital tubercle"] = "skin of glans of female genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30720"] = "EMAPA_30720"


class _Muscle_Layer_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model muscle layer of epididymis"""

    name: Literal["muscle layer of epididymis"] = "muscle layer of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30747"] = "EMAPA_30747"


class _Ovary_Primordial_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary primordial follicle"""

    name: Literal["ovary primordial follicle"] = "ovary primordial follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30755"] = "EMAPA_30755"


class _Oocyte_Of_Primordial_Follicle(_MouseAnatomicalStructureModel):
    """Model oocyte of primordial follicle"""

    name: Literal["oocyte of primordial follicle"] = "oocyte of primordial follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30757"] = "EMAPA_30757"


class _Ovary_Tertiary_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary tertiary follicle"""

    name: Literal["ovary tertiary follicle"] = "ovary tertiary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30763"] = "EMAPA_30763"


class _Oocyte_Of_Tertiary_Follicle(_MouseAnatomicalStructureModel):
    """Model oocyte of tertiary follicle"""

    name: Literal["oocyte of tertiary follicle"] = "oocyte of tertiary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30765"] = "EMAPA_30765"


class _Follicle_Cell_Of_Tertiary_Follicle(_MouseAnatomicalStructureModel):
    """Model follicle cell of tertiary follicle"""

    name: Literal["follicle cell of tertiary follicle"] = "follicle cell of tertiary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30767"] = "EMAPA_30767"


class _Theca_Of_Tertiary_Follicle(_MouseAnatomicalStructureModel):
    """Model theca of tertiary follicle"""

    name: Literal["theca of tertiary follicle"] = "theca of tertiary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30769"] = "EMAPA_30769"


class _Antrum_Of_Tertiary_Follicle(_MouseAnatomicalStructureModel):
    """Model antrum of tertiary follicle"""

    name: Literal["antrum of tertiary follicle"] = "antrum of tertiary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30771"] = "EMAPA_30771"


class _Cumulus_Of_Tertiary_Follicle(_MouseAnatomicalStructureModel):
    """Model cumulus of tertiary follicle"""

    name: Literal["cumulus of tertiary follicle"] = "cumulus of tertiary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30773"] = "EMAPA_30773"


class _Mural_Of_Tertiary_Follicle(_MouseAnatomicalStructureModel):
    """Model mural of tertiary follicle"""

    name: Literal["mural of tertiary follicle"] = "mural of tertiary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30775"] = "EMAPA_30775"


class _Ovary_Mature_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary mature follicle"""

    name: Literal["ovary mature follicle"] = "ovary mature follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30777"] = "EMAPA_30777"


class _Oocyte_Of_Mature_Follicle(_MouseAnatomicalStructureModel):
    """Model oocyte of mature follicle"""

    name: Literal["oocyte of mature follicle"] = "oocyte of mature follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30779"] = "EMAPA_30779"


class _Germinal_Cell_Of_Mature_Follicle(_MouseAnatomicalStructureModel):
    """Model germinal cell of mature follicle"""

    name: Literal["germinal cell of mature follicle"] = "germinal cell of mature follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30781"] = "EMAPA_30781"


class _Cumulus_Of_Mature_Follicle(_MouseAnatomicalStructureModel):
    """Model cumulus of mature follicle"""

    name: Literal["cumulus of mature follicle"] = "cumulus of mature follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30783"] = "EMAPA_30783"


class _Mural_Of_Mature_Follicle(_MouseAnatomicalStructureModel):
    """Model mural of mature follicle"""

    name: Literal["mural of mature follicle"] = "mural of mature follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30785"] = "EMAPA_30785"


class _Theca_Of_Mature_Follicle(_MouseAnatomicalStructureModel):
    """Model theca of mature follicle"""

    name: Literal["theca of mature follicle"] = "theca of mature follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30787"] = "EMAPA_30787"


class _Antrum_Of_Mature_Follicle(_MouseAnatomicalStructureModel):
    """Model antrum of mature follicle"""

    name: Literal["antrum of mature follicle"] = "antrum of mature follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30789"] = "EMAPA_30789"


class _Vasculature_Of_Scrotum(_MouseAnatomicalStructureModel):
    """Model vasculature of scrotum"""

    name: Literal["vasculature of scrotum"] = "vasculature of scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30791"] = "EMAPA_30791"


class _Vasculature_Of_Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model vasculature of ductus deferens"""

    name: Literal["vasculature of ductus deferens"] = "vasculature of ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30793"] = "EMAPA_30793"


class _Vasculature_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model vasculature of epididymis"""

    name: Literal["vasculature of epididymis"] = "vasculature of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30795"] = "EMAPA_30795"


class _Vasculature_Of_Seminal_Vesicle(_MouseAnatomicalStructureModel):
    """Model vasculature of seminal vesicle"""

    name: Literal["vasculature of seminal vesicle"] = "vasculature of seminal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30797"] = "EMAPA_30797"


class _Vasculature_Of_Ejaculatory_Duct(_MouseAnatomicalStructureModel):
    """Model vasculature of ejaculatory duct"""

    name: Literal["vasculature of ejaculatory duct"] = "vasculature of ejaculatory duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30799"] = "EMAPA_30799"


class _Vasculature_Of_Bulbourethral_Gland_Of_Male(_MouseAnatomicalStructureModel):
    """Model vasculature of bulbourethral gland of male"""

    name: Literal["vasculature of bulbourethral gland of male"] = "vasculature of bulbourethral gland of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30801"] = "EMAPA_30801"


class _Vasculature_Of_Prostate_Gland(_MouseAnatomicalStructureModel):
    """Model vasculature of prostate gland"""

    name: Literal["vasculature of prostate gland"] = "vasculature of prostate gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30805"] = "EMAPA_30805"


class _Vasculature_Of_Penis(_MouseAnatomicalStructureModel):
    """Model vasculature of penis"""

    name: Literal["vasculature of penis"] = "vasculature of penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30807"] = "EMAPA_30807"


class _Vasculature_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model vasculature of oviduct"""

    name: Literal["vasculature of oviduct"] = "vasculature of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30809"] = "EMAPA_30809"


class _Vasculature_Of_Uterus(_MouseAnatomicalStructureModel):
    """Model vasculature of uterus"""

    name: Literal["vasculature of uterus"] = "vasculature of uterus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30811"] = "EMAPA_30811"


class _Vasculature_Of_Vagina(_MouseAnatomicalStructureModel):
    """Model vasculature of vagina"""

    name: Literal["vasculature of vagina"] = "vasculature of vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30813"] = "EMAPA_30813"


class _Clitoris(_MouseAnatomicalStructureModel):
    """Model clitoris"""

    name: Literal["clitoris"] = "clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30819"] = "EMAPA_30819"


class _Body_Of_Clitoris(_MouseAnatomicalStructureModel):
    """Model body of clitoris"""

    name: Literal["body of clitoris"] = "body of clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30821"] = "EMAPA_30821"


class _Os_Clitoridis(_MouseAnatomicalStructureModel):
    """Model os clitoridis"""

    name: Literal["os clitoridis"] = "os clitoridis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30823"] = "EMAPA_30823"


class _Epithelium_Of_Body_Of_Clitoris(_MouseAnatomicalStructureModel):
    """Model epithelium of body of clitoris"""

    name: Literal["epithelium of body of clitoris"] = "epithelium of body of clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30825"] = "EMAPA_30825"


class _Lamina_Propria_Of_Body_Of_Clitoris(_MouseAnatomicalStructureModel):
    """Model lamina propria of body of clitoris"""

    name: Literal["lamina propria of body of clitoris"] = "lamina propria of body of clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30827"] = "EMAPA_30827"


class _Glans_Clitoris(_MouseAnatomicalStructureModel):
    """Model glans clitoris"""

    name: Literal["glans clitoris"] = "glans clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30829"] = "EMAPA_30829"


class _Epithelium_Of_Glans_Clitoris(_MouseAnatomicalStructureModel):
    """Model epithelium of glans clitoris"""

    name: Literal["epithelium of glans clitoris"] = "epithelium of glans clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30831"] = "EMAPA_30831"


class _Lamina_Propria_Of_Glans_Clitoris(_MouseAnatomicalStructureModel):
    """Model lamina propria of glans clitoris"""

    name: Literal["lamina propria of glans clitoris"] = "lamina propria of glans clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30833"] = "EMAPA_30833"


class _Vasculature_Of_Clitoris(_MouseAnatomicalStructureModel):
    """Model vasculature of clitoris"""

    name: Literal["vasculature of clitoris"] = "vasculature of clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30835"] = "EMAPA_30835"


class _Labia(_MouseAnatomicalStructureModel):
    """Model labia"""

    name: Literal["labia"] = "labia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30837"] = "EMAPA_30837"


class _Labia_Skin(_MouseAnatomicalStructureModel):
    """Model labia skin"""

    name: Literal["labia skin"] = "labia skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30839"] = "EMAPA_30839"


class _Lamina_Propria_Of_Labia(_MouseAnatomicalStructureModel):
    """Model lamina propria of labia"""

    name: Literal["lamina propria of labia"] = "lamina propria of labia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30841"] = "EMAPA_30841"


class _Gland_Of_Labia(_MouseAnatomicalStructureModel):
    """Model gland of labia"""

    name: Literal["gland of labia"] = "gland of labia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30843"] = "EMAPA_30843"


class _Vasculature_Of_Labia(_MouseAnatomicalStructureModel):
    """Model vasculature of labia"""

    name: Literal["vasculature of labia"] = "vasculature of labia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30845"] = "EMAPA_30845"


class _Ureteral_Vasculature(_MouseAnatomicalStructureModel):
    """Model ureteral vasculature"""

    name: Literal["ureteral vasculature"] = "ureteral vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30850"] = "EMAPA_30850"


class _Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model primitive bladder"""

    name: Literal["primitive bladder"] = "primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30870"] = "EMAPA_30870"


class _Urothelium_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model urothelium of primitive bladder"""

    name: Literal["urothelium of primitive bladder"] = "urothelium of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30873"] = "EMAPA_30873"


class _Mesenchymal_Layer_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of primitive bladder"""

    name: Literal["mesenchymal layer of primitive bladder"] = "mesenchymal layer of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30876"] = "EMAPA_30876"


class _Caudal_Urogenital_Sinus(_MouseAnatomicalStructureModel):
    """Model caudal urogenital sinus"""

    name: Literal["caudal urogenital sinus"] = "caudal urogenital sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30879"] = "EMAPA_30879"


class _Caudal_Urogenital_Sinus_Epithelium(_MouseAnatomicalStructureModel):
    """Model caudal urogenital sinus epithelium"""

    name: Literal["caudal urogenital sinus epithelium"] = "caudal urogenital sinus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30882"] = "EMAPA_30882"


class _Caudal_Urogenital_Sinus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model caudal urogenital sinus mesenchyme"""

    name: Literal["caudal urogenital sinus mesenchyme"] = "caudal urogenital sinus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30885"] = "EMAPA_30885"


class _Urethral_Fold(_MouseAnatomicalStructureModel):
    """Model urethral fold"""

    name: Literal["urethral fold"] = "urethral fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30888"] = "EMAPA_30888"


class _Urethra(_MouseAnatomicalStructureModel):
    """Model urethra"""

    name: Literal["urethra"] = "urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30901"] = "EMAPA_30901"


class _Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model pelvic urethra"""

    name: Literal["pelvic urethra"] = "pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30903"] = "EMAPA_30903"


class _Epithelium_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model epithelium of pelvic urethra"""

    name: Literal["epithelium of pelvic urethra"] = "epithelium of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30905"] = "EMAPA_30905"


class _Mesenchymal_Layer_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of pelvic urethra"""

    name: Literal["mesenchymal layer of pelvic urethra"] = "mesenchymal layer of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30907"] = "EMAPA_30907"


class _Muscle_Layer_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model muscle layer of pelvic urethra"""

    name: Literal["muscle layer of pelvic urethra"] = "muscle layer of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30909"] = "EMAPA_30909"


class _Phallic_Urethra(_MouseAnatomicalStructureModel):
    """Model phallic urethra"""

    name: Literal["phallic urethra"] = "phallic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30911"] = "EMAPA_30911"


class _Urethral_Plate_Of_Phallic_Urethra(_MouseAnatomicalStructureModel):
    """Model urethral plate of phallic urethra"""

    name: Literal["urethral plate of phallic urethra"] = "urethral plate of phallic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30913"] = "EMAPA_30913"


class _Clitoral_Urethra(_MouseAnatomicalStructureModel):
    """Model clitoral urethra"""

    name: Literal["clitoral urethra"] = "clitoral urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30917"] = "EMAPA_30917"


class _Urethral_Plate_Epithelium_Of_Clitoral_Urethra(_MouseAnatomicalStructureModel):
    """Model urethral plate epithelium of clitoral urethra"""

    name: Literal["urethral plate epithelium of clitoral urethra"] = "urethral plate epithelium of clitoral urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30924"] = "EMAPA_30924"


class _Urethral_Fold_Of_Female(_MouseAnatomicalStructureModel):
    """Model urethral fold of female"""

    name: Literal["urethral fold of female"] = "urethral fold of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30927"] = "EMAPA_30927"


class _Epithelium_Of_Clitoral_Urethra(_MouseAnatomicalStructureModel):
    """Model epithelium of clitoral urethra"""

    name: Literal["epithelium of clitoral urethra"] = "epithelium of clitoral urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30930"] = "EMAPA_30930"


class _Mesenchymal_Layer_Of_Phallic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of phallic urethra of female"""

    name: Literal["mesenchymal layer of phallic urethra of female"] = "mesenchymal layer of phallic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30934"] = "EMAPA_30934"


class _Muscle_Layer_Of_Phallic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model muscle layer of phallic urethra of female"""

    name: Literal["muscle layer of phallic urethra of female"] = "muscle layer of phallic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30938"] = "EMAPA_30938"


class _Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model prostatic urethra"""

    name: Literal["prostatic urethra"] = "prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30942"] = "EMAPA_30942"


class _Penile_Urethra(_MouseAnatomicalStructureModel):
    """Model penile urethra"""

    name: Literal["penile urethra"] = "penile urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30944"] = "EMAPA_30944"


class _Epithelium_Of_Penile_Urethra(_MouseAnatomicalStructureModel):
    """Model epithelium of penile urethra"""

    name: Literal["epithelium of penile urethra"] = "epithelium of penile urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30946"] = "EMAPA_30946"


class _Mesenchymal_Layer_Of_Penile_Urethra(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of penile urethra"""

    name: Literal["mesenchymal layer of penile urethra"] = "mesenchymal layer of penile urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30948"] = "EMAPA_30948"


class _Muscle_Layer_Of_Penile_Urethra(_MouseAnatomicalStructureModel):
    """Model muscle layer of penile urethra"""

    name: Literal["muscle layer of penile urethra"] = "muscle layer of penile urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30950"] = "EMAPA_30950"


class _Epithelium_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model epithelium of prostatic urethra"""

    name: Literal["epithelium of prostatic urethra"] = "epithelium of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30952"] = "EMAPA_30952"


class _Mesenchymal_Layer_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of prostatic urethra"""

    name: Literal["mesenchymal layer of prostatic urethra"] = "mesenchymal layer of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30954"] = "EMAPA_30954"


class _Muscle_Layer_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model muscle layer of prostatic urethra"""

    name: Literal["muscle layer of prostatic urethra"] = "muscle layer of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30956"] = "EMAPA_30956"


class _Glomerular_Basement_Membrane_Of_Maturing_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model glomerular basement membrane of maturing renal corpuscle"""

    name: Literal[
        "glomerular basement membrane of maturing renal corpuscle"
    ] = "glomerular basement membrane of maturing renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30965"] = "EMAPA_30965"


class _Male_External_Genitalia(_MouseAnatomicalStructureModel):
    """Model male external genitalia"""

    name: Literal["male external genitalia"] = "male external genitalia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30977"] = "EMAPA_30977"


class _Female_External_Genitalia(_MouseAnatomicalStructureModel):
    """Model female external genitalia"""

    name: Literal["female external genitalia"] = "female external genitalia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30984"] = "EMAPA_30984"


class _Epithelium_Of_Vagina(_MouseAnatomicalStructureModel):
    """Model epithelium of vagina"""

    name: Literal["epithelium of vagina"] = "epithelium of vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30991"] = "EMAPA_30991"


class _Muscle_Of_Vagina(_MouseAnatomicalStructureModel):
    """Model muscle of vagina"""

    name: Literal["muscle of vagina"] = "muscle of vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_30997"] = "EMAPA_30997"


class _Adventitia_Of_Vagina(_MouseAnatomicalStructureModel):
    """Model adventitia of vagina"""

    name: Literal["adventitia of vagina"] = "adventitia of vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31003"] = "EMAPA_31003"


class _Straight_Limb_Of_Immature_Loop_Of_Henle(_MouseAnatomicalStructureModel):
    """Model straight limb of immature loop of Henle"""

    name: Literal["straight limb of immature loop of Henle"] = "straight limb of immature loop of Henle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31017"] = "EMAPA_31017"


class _Bend_Of_Immature_Loop_Of_Henle(_MouseAnatomicalStructureModel):
    """Model bend of immature loop of Henle"""

    name: Literal["bend of immature loop of Henle"] = "bend of immature loop of Henle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31021"] = "EMAPA_31021"


class _Oocyte(_MouseAnatomicalStructureModel):
    """Model oocyte"""

    name: Literal["oocyte"] = "oocyte"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31025"] = "EMAPA_31025"


class _Pre_Granulosa_Cell(_MouseAnatomicalStructureModel):
    """Model pre-granulosa cell"""

    name: Literal["pre-granulosa cell"] = "pre-granulosa cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31035"] = "EMAPA_31035"


class _Rest_Of_Cortical_Component_Of_Mesenchymal_Stroma_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model rest of cortical component of mesenchymal stroma of ovary"""

    name: Literal[
        "rest of cortical component of mesenchymal stroma of ovary"
    ] = "rest of cortical component of mesenchymal stroma of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31040"] = "EMAPA_31040"


class _Ureteric_Tree_Terminal_Branch_Excluding_Tip_Itself(_MouseAnatomicalStructureModel):
    """Model ureteric tree terminal branch excluding tip itself"""

    name: Literal[
        "ureteric tree terminal branch excluding tip itself"
    ] = "ureteric tree terminal branch excluding tip itself"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31045"] = "EMAPA_31045"


class _Ovigerous_Cord(_MouseAnatomicalStructureModel):
    """Model ovigerous cord"""

    name: Literal["ovigerous cord"] = "ovigerous cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31058"] = "EMAPA_31058"


class _Dermomyotome(_MouseAnatomicalStructureModel):
    """Model dermomyotome"""

    name: Literal["dermomyotome"] = "dermomyotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31109"] = "EMAPA_31109"


class _Trunk_Myocoele(_MouseAnatomicalStructureModel):
    """Model trunk myocoele"""

    name: Literal["trunk myocoele"] = "trunk myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31119"] = "EMAPA_31119"


class _Tail_Myocoele(_MouseAnatomicalStructureModel):
    """Model tail myocoele"""

    name: Literal["tail myocoele"] = "tail myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31126"] = "EMAPA_31126"


class _Myocoele(_MouseAnatomicalStructureModel):
    """Model myocoele"""

    name: Literal["myocoele"] = "myocoele"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31134"] = "EMAPA_31134"


class _Trunk_Sclerotome(_MouseAnatomicalStructureModel):
    """Model trunk sclerotome"""

    name: Literal["trunk sclerotome"] = "trunk sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31144"] = "EMAPA_31144"


class _Tail_Sclerotome(_MouseAnatomicalStructureModel):
    """Model tail sclerotome"""

    name: Literal["tail sclerotome"] = "tail sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31151"] = "EMAPA_31151"


class _Sclerotome(_MouseAnatomicalStructureModel):
    """Model sclerotome"""

    name: Literal["sclerotome"] = "sclerotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31159"] = "EMAPA_31159"


class _Somite(_MouseAnatomicalStructureModel):
    """Model somite"""

    name: Literal["somite"] = "somite"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31169"] = "EMAPA_31169"


class _Developing_Vasculature_Of_Cauda_Epididymis(_MouseAnatomicalStructureModel):
    """Model developing vasculature of cauda epididymis"""

    name: Literal["developing vasculature of cauda epididymis"] = "developing vasculature of cauda epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31194"] = "EMAPA_31194"


class _Developing_Vasculature_Of_Corpus_Epididymis(_MouseAnatomicalStructureModel):
    """Model developing vasculature of corpus epididymis"""

    name: Literal["developing vasculature of corpus epididymis"] = "developing vasculature of corpus epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31199"] = "EMAPA_31199"


class _Developing_Vasculature_Of_Caput_Epididymis(_MouseAnatomicalStructureModel):
    """Model developing vasculature of caput epididymis"""

    name: Literal["developing vasculature of caput epididymis"] = "developing vasculature of caput epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31204"] = "EMAPA_31204"


class _Developing_Vasculature_Of_Uterine_Horn(_MouseAnatomicalStructureModel):
    """Model developing vasculature of uterine horn"""

    name: Literal["developing vasculature of uterine horn"] = "developing vasculature of uterine horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31209"] = "EMAPA_31209"


class _Developing_Vasculature_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model developing vasculature of oviduct"""

    name: Literal["developing vasculature of oviduct"] = "developing vasculature of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31214"] = "EMAPA_31214"


class _Vasculature_Of_Upper_Vagina(_MouseAnatomicalStructureModel):
    """Model vasculature of upper vagina"""

    name: Literal["vasculature of upper vagina"] = "vasculature of upper vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31219"] = "EMAPA_31219"


class _Vasculature_Of_Sinovaginal_Bulb(_MouseAnatomicalStructureModel):
    """Model vasculature of sinovaginal bulb"""

    name: Literal["vasculature of sinovaginal bulb"] = "vasculature of sinovaginal bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31224"] = "EMAPA_31224"


class _Developing_Vasculature_Of_Vagina(_MouseAnatomicalStructureModel):
    """Model developing vasculature of vagina"""

    name: Literal["developing vasculature of vagina"] = "developing vasculature of vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31229"] = "EMAPA_31229"


class _Developing_Vasculature_System_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model developing vasculature system of epididymis"""

    name: Literal["developing vasculature system of epididymis"] = "developing vasculature system of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31235"] = "EMAPA_31235"


class _Surface_Epithelium_Of_Testis(_MouseAnatomicalStructureModel):
    """Model surface epithelium of testis"""

    name: Literal["surface epithelium of testis"] = "surface epithelium of testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31240"] = "EMAPA_31240"


class _Follicle_Cell_Of_Primordial_Follicle(_MouseAnatomicalStructureModel):
    """Model follicle cell of primordial follicle"""

    name: Literal["follicle cell of primordial follicle"] = "follicle cell of primordial follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31247"] = "EMAPA_31247"


class _Cremaster_Muscle(_MouseAnatomicalStructureModel):
    """Model cremaster muscle"""

    name: Literal["cremaster muscle"] = "cremaster muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31250"] = "EMAPA_31250"


class _Theca_Of_Atretic_Follicle(_MouseAnatomicalStructureModel):
    """Model theca of atretic follicle"""

    name: Literal["theca of atretic follicle"] = "theca of atretic follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31260"] = "EMAPA_31260"


class _Granulosa_Of_Ruptured_Follicle(_MouseAnatomicalStructureModel):
    """Model granulosa of ruptured follicle"""

    name: Literal["granulosa of ruptured follicle"] = "granulosa of ruptured follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31262"] = "EMAPA_31262"


class _Muscle_Layer_Of_Infundibulum(_MouseAnatomicalStructureModel):
    """Model muscle layer of infundibulum"""

    name: Literal["muscle layer of infundibulum"] = "muscle layer of infundibulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31264"] = "EMAPA_31264"


class _Longitudinal_Muscle_Layer_Of_Infundibulum(_MouseAnatomicalStructureModel):
    """Model longitudinal muscle layer of infundibulum"""

    name: Literal["longitudinal muscle layer of infundibulum"] = "longitudinal muscle layer of infundibulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31266"] = "EMAPA_31266"


class _Circular_Muscle_Layer_Of_Infundibulum(_MouseAnatomicalStructureModel):
    """Model circular muscle layer of infundibulum"""

    name: Literal["circular muscle layer of infundibulum"] = "circular muscle layer of infundibulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31268"] = "EMAPA_31268"


class _Resident_Macrophage(_MouseAnatomicalStructureModel):
    """Model resident macrophage"""

    name: Literal["resident macrophage"] = "resident macrophage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31273"] = "EMAPA_31273"


class _Rest_Of_Renal_Interstitium(_MouseAnatomicalStructureModel):
    """Model rest of renal interstitium"""

    name: Literal["rest of renal interstitium"] = "rest of renal interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31276"] = "EMAPA_31276"


class _Renal_Fibroblasts(_MouseAnatomicalStructureModel):
    """Model renal fibroblasts"""

    name: Literal["renal fibroblasts"] = "renal fibroblasts"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31279"] = "EMAPA_31279"


class _Anlage_Of_Loop_Of_Henle_Of_Cortical_Renal_Tubule(_MouseAnatomicalStructureModel):
    """Model anlage of loop of Henle of cortical renal tubule"""

    name: Literal[
        "anlage of loop of Henle of cortical renal tubule"
    ] = "anlage of loop of Henle of cortical renal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31281"] = "EMAPA_31281"


class _Renal_Cortical_Fibroblasts(_MouseAnatomicalStructureModel):
    """Model renal cortical fibroblasts"""

    name: Literal["renal cortical fibroblasts"] = "renal cortical fibroblasts"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31288"] = "EMAPA_31288"


class _Resident_Macrophage_Of_The_Cortex(_MouseAnatomicalStructureModel):
    """Model resident macrophage of the cortex"""

    name: Literal["resident macrophage of the cortex"] = "resident macrophage of the cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31296"] = "EMAPA_31296"


class _Rest_Of_Renal_Cortical_Interstitium(_MouseAnatomicalStructureModel):
    """Model rest of renal cortical interstitium"""

    name: Literal["rest of renal cortical interstitium"] = "rest of renal cortical interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31304"] = "EMAPA_31304"


class _Renal_Cortical_Lymphatics(_MouseAnatomicalStructureModel):
    """Model renal cortical lymphatics"""

    name: Literal["renal cortical lymphatics"] = "renal cortical lymphatics"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31312"] = "EMAPA_31312"


class _Renal_Cortical_Nerves(_MouseAnatomicalStructureModel):
    """Model renal cortical nerves"""

    name: Literal["renal cortical nerves"] = "renal cortical nerves"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31319"] = "EMAPA_31319"


class _Renal_Medullary_Fibroblasts(_MouseAnatomicalStructureModel):
    """Model renal medullary fibroblasts"""

    name: Literal["renal medullary fibroblasts"] = "renal medullary fibroblasts"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31326"] = "EMAPA_31326"


class _Resident_Macrophage_Of_The_Medulla(_MouseAnatomicalStructureModel):
    """Model resident macrophage of the medulla"""

    name: Literal["resident macrophage of the medulla"] = "resident macrophage of the medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31333"] = "EMAPA_31333"


class _Rest_Of_Renal_Medullary_Interstitium(_MouseAnatomicalStructureModel):
    """Model rest of renal medullary interstitium"""

    name: Literal["rest of renal medullary interstitium"] = "rest of renal medullary interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31340"] = "EMAPA_31340"


class _Renal_Medullary_Lymphatics(_MouseAnatomicalStructureModel):
    """Model renal medullary lymphatics"""

    name: Literal["renal medullary lymphatics"] = "renal medullary lymphatics"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31347"] = "EMAPA_31347"


class _Renal_Medullary_Nerves(_MouseAnatomicalStructureModel):
    """Model renal medullary nerves"""

    name: Literal["renal medullary nerves"] = "renal medullary nerves"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31354"] = "EMAPA_31354"


class _Perihilar_Fibroblast(_MouseAnatomicalStructureModel):
    """Model perihilar fibroblast"""

    name: Literal["perihilar fibroblast"] = "perihilar fibroblast"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31361"] = "EMAPA_31361"


class _Resident_Macrophage_Of_The_Perihilar_Interstitium(_MouseAnatomicalStructureModel):
    """Model resident macrophage of the perihilar interstitium"""

    name: Literal[
        "resident macrophage of the perihilar interstitium"
    ] = "resident macrophage of the perihilar interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31367"] = "EMAPA_31367"


class _Rest_Of_Perihilar_Interstitium(_MouseAnatomicalStructureModel):
    """Model rest of perihilar interstitium"""

    name: Literal["rest of perihilar interstitium"] = "rest of perihilar interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31373"] = "EMAPA_31373"


class _Premacula_Segment_Of_Distal_Straight_Tubule_Of_Renal_Cortex(_MouseAnatomicalStructureModel):
    """Model premacula segment of distal straight tubule of renal cortex"""

    name: Literal[
        "premacula segment of distal straight tubule of renal cortex"
    ] = "premacula segment of distal straight tubule of renal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31379"] = "EMAPA_31379"


class _Outer_Medullary_Fibroblast(_MouseAnatomicalStructureModel):
    """Model outer medullary fibroblast"""

    name: Literal["outer medullary fibroblast"] = "outer medullary fibroblast"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31384"] = "EMAPA_31384"


class _Resident_Macrophage_Of_The_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model resident macrophage of the outer medulla"""

    name: Literal["resident macrophage of the outer medulla"] = "resident macrophage of the outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31389"] = "EMAPA_31389"


class _Rest_Of_Outer_Medullary_Interstitium(_MouseAnatomicalStructureModel):
    """Model rest of outer medullary interstitium"""

    name: Literal["rest of outer medullary interstitium"] = "rest of outer medullary interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31394"] = "EMAPA_31394"


class _Inner_Medullary_Fibroblast(_MouseAnatomicalStructureModel):
    """Model inner medullary fibroblast"""

    name: Literal["inner medullary fibroblast"] = "inner medullary fibroblast"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31399"] = "EMAPA_31399"


class _Resident_Macrophage_Of_The_Inner_Medulla(_MouseAnatomicalStructureModel):
    """Model resident macrophage of the inner medulla"""

    name: Literal["resident macrophage of the inner medulla"] = "resident macrophage of the inner medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31404"] = "EMAPA_31404"


class _Rest_Of_Inner_Medullary_Interstitium(_MouseAnatomicalStructureModel):
    """Model rest of inner medullary interstitium"""

    name: Literal["rest of inner medullary interstitium"] = "rest of inner medullary interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31409"] = "EMAPA_31409"


class _Medullary_Renal_Tubule(_MouseAnatomicalStructureModel):
    """Model medullary renal tubule"""

    name: Literal["medullary renal tubule"] = "medullary renal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31414"] = "EMAPA_31414"


class _Rest_Of_Medullary_Renal_Tubule(_MouseAnatomicalStructureModel):
    """Model rest of medullary renal tubule"""

    name: Literal["rest of medullary renal tubule"] = "rest of medullary renal tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31418"] = "EMAPA_31418"


class _Peritubular_Fibroblasts_Of_Cortex(_MouseAnatomicalStructureModel):
    """Model peritubular fibroblasts of cortex"""

    name: Literal["peritubular fibroblasts of cortex"] = "peritubular fibroblasts of cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31424"] = "EMAPA_31424"


class _Periarterial_Fibroblasts_Of_Cortex(_MouseAnatomicalStructureModel):
    """Model periarterial fibroblasts of cortex"""

    name: Literal["periarterial fibroblasts of cortex"] = "periarterial fibroblasts of cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31426"] = "EMAPA_31426"


class _Peritubular_Fibroblasts_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model peritubular fibroblasts of outer medulla"""

    name: Literal["peritubular fibroblasts of outer medulla"] = "peritubular fibroblasts of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31428"] = "EMAPA_31428"


class _Periarterial_Fibroblasts_Of_Outer_Medulla(_MouseAnatomicalStructureModel):
    """Model periarterial fibroblasts of outer medulla"""

    name: Literal["periarterial fibroblasts of outer medulla"] = "periarterial fibroblasts of outer medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31430"] = "EMAPA_31430"


class _Peritubular_Fibroblasts_Of_Inner_Medulla(_MouseAnatomicalStructureModel):
    """Model peritubular fibroblasts of inner medulla"""

    name: Literal["peritubular fibroblasts of inner medulla"] = "peritubular fibroblasts of inner medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31432"] = "EMAPA_31432"


class _Periarterial_Fibroblasts_Of_Inner_Medulla(_MouseAnatomicalStructureModel):
    """Model periarterial fibroblasts of inner medulla"""

    name: Literal["periarterial fibroblasts of inner medulla"] = "periarterial fibroblasts of inner medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31434"] = "EMAPA_31434"


class _Renal_Arterial_System(_MouseAnatomicalStructureModel):
    """Model renal arterial system"""

    name: Literal["renal arterial system"] = "renal arterial system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31436"] = "EMAPA_31436"


class _Renal_Capillary(_MouseAnatomicalStructureModel):
    """Model renal capillary"""

    name: Literal["renal capillary"] = "renal capillary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31443"] = "EMAPA_31443"


class _Renal_Venous_System(_MouseAnatomicalStructureModel):
    """Model renal venous system"""

    name: Literal["renal venous system"] = "renal venous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31450"] = "EMAPA_31450"


class _Renal_Large_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model renal large blood vessel"""

    name: Literal["renal large blood vessel"] = "renal large blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31464"] = "EMAPA_31464"


class _Renal_Small_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model renal small blood vessel"""

    name: Literal["renal small blood vessel"] = "renal small blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31469"] = "EMAPA_31469"


class _Seminiferous_Tubule(_MouseAnatomicalStructureModel):
    """Model seminiferous tubule"""

    name: Literal["seminiferous tubule"] = "seminiferous tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31476"] = "EMAPA_31476"


class _Spermatogonium(_MouseAnatomicalStructureModel):
    """Model spermatogonium"""

    name: Literal["spermatogonium"] = "spermatogonium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31482"] = "EMAPA_31482"


class _Spermatocyte(_MouseAnatomicalStructureModel):
    """Model spermatocyte"""

    name: Literal["spermatocyte"] = "spermatocyte"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31484"] = "EMAPA_31484"


class _Spermatid(_MouseAnatomicalStructureModel):
    """Model spermatid"""

    name: Literal["spermatid"] = "spermatid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31486"] = "EMAPA_31486"


class _Spermatozoon(_MouseAnatomicalStructureModel):
    """Model spermatozoon"""

    name: Literal["spermatozoon"] = "spermatozoon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31488"] = "EMAPA_31488"


class _Mesenchyme_Of_Urogenital_Sinus(_MouseAnatomicalStructureModel):
    """Model mesenchyme of urogenital sinus"""

    name: Literal["mesenchyme of urogenital sinus"] = "mesenchyme of urogenital sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31500"] = "EMAPA_31500"


class _Mesenchyme_Of_Proximal_Genital_Tubercle_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchyme of proximal genital tubercle of male"""

    name: Literal["mesenchyme of proximal genital tubercle of male"] = "mesenchyme of proximal genital tubercle of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31501"] = "EMAPA_31501"


class _Skin_Of_Proximal_Genital_Tubercle_Of_Male(_MouseAnatomicalStructureModel):
    """Model skin of proximal genital tubercle of male"""

    name: Literal["skin of proximal genital tubercle of male"] = "skin of proximal genital tubercle of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31502"] = "EMAPA_31502"


class _Developing_Vasculature_Of_Female_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model developing vasculature of female genital tubercle"""

    name: Literal[
        "developing vasculature of female genital tubercle"
    ] = "developing vasculature of female genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31503"] = "EMAPA_31503"


class _Proximal_Genital_Tubercle_Of_Male(_MouseAnatomicalStructureModel):
    """Model proximal genital tubercle of male"""

    name: Literal["proximal genital tubercle of male"] = "proximal genital tubercle of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31504"] = "EMAPA_31504"


class _Proximal_Urethral_Meatus_Of_Male(_MouseAnatomicalStructureModel):
    """Model proximal urethral meatus of male"""

    name: Literal["proximal urethral meatus of male"] = "proximal urethral meatus of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31505"] = "EMAPA_31505"


class _Proximal_Genital_Tubercle_Of_Female(_MouseAnatomicalStructureModel):
    """Model proximal genital tubercle of female"""

    name: Literal["proximal genital tubercle of female"] = "proximal genital tubercle of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31506"] = "EMAPA_31506"


class _Urethral_Plate_Epithelium_Of_Male(_MouseAnatomicalStructureModel):
    """Model urethral plate epithelium of male"""

    name: Literal["urethral plate epithelium of male"] = "urethral plate epithelium of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31507"] = "EMAPA_31507"


class _Urethral_Tube_Epithelium_Of_Male(_MouseAnatomicalStructureModel):
    """Model urethral tube epithelium of male"""

    name: Literal["urethral tube epithelium of male"] = "urethral tube epithelium of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31508"] = "EMAPA_31508"


class _Epithelium_Of_Urogenital_Sinus(_MouseAnatomicalStructureModel):
    """Model epithelium of urogenital sinus"""

    name: Literal["epithelium of urogenital sinus"] = "epithelium of urogenital sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31509"] = "EMAPA_31509"


class _Developing_Vasculature_Of_Male_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model developing vasculature of male genital tubercle"""

    name: Literal["developing vasculature of male genital tubercle"] = "developing vasculature of male genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31510"] = "EMAPA_31510"


class _Early_Distal_Tubule_Of_Capillary_Loop_Nephron(_MouseAnatomicalStructureModel):
    """Model early distal tubule of capillary loop nephron"""

    name: Literal["early distal tubule of capillary loop nephron"] = "early distal tubule of capillary loop nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31511"] = "EMAPA_31511"


class _Early_Distal_Tubule_Of_Maturing_Nephron(_MouseAnatomicalStructureModel):
    """Model early distal tubule of maturing nephron"""

    name: Literal["early distal tubule of maturing nephron"] = "early distal tubule of maturing nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31513"] = "EMAPA_31513"


class _Renal_Connecting_Tubule_Of_Maturing_Nephron(_MouseAnatomicalStructureModel):
    """Model renal connecting tubule of maturing nephron"""

    name: Literal["renal connecting tubule of maturing nephron"] = "renal connecting tubule of maturing nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31516"] = "EMAPA_31516"


class _Renal_Connecting_Tubule_Of_Mature_Nephron(_MouseAnatomicalStructureModel):
    """Model renal connecting tubule of mature nephron"""

    name: Literal["renal connecting tubule of mature nephron"] = "renal connecting tubule of mature nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31517"] = "EMAPA_31517"


class _Urethral_Plate_Epithelium(_MouseAnatomicalStructureModel):
    """Model urethral plate epithelium"""

    name: Literal["urethral plate epithelium"] = "urethral plate epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31518"] = "EMAPA_31518"


class _Nerve_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model nerve of pelvic urethra"""

    name: Literal["nerve of pelvic urethra"] = "nerve of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31523"] = "EMAPA_31523"


class _Nerve_Of_Phallic_Urethra(_MouseAnatomicalStructureModel):
    """Model nerve of phallic urethra"""

    name: Literal["nerve of phallic urethra"] = "nerve of phallic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31524"] = "EMAPA_31524"


class _Mesenchymal_Layer_Of_Ventral_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of ventral primitive bladder"""

    name: Literal["mesenchymal layer of ventral primitive bladder"] = "mesenchymal layer of ventral primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31525"] = "EMAPA_31525"


class _Nerve_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of bladder"""

    name: Literal["nerve of bladder"] = "nerve of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31526"] = "EMAPA_31526"


class _Pelvic_Ganglion(_MouseAnatomicalStructureModel):
    """Model pelvic ganglion"""

    name: Literal["pelvic ganglion"] = "pelvic ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31527"] = "EMAPA_31527"


class _Nerve_Of_Urogenital_Sinus(_MouseAnatomicalStructureModel):
    """Model nerve of urogenital sinus"""

    name: Literal["nerve of urogenital sinus"] = "nerve of urogenital sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31528"] = "EMAPA_31528"


class _Mesenchymal_Layer_Of_Dorsal_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of dorsal primitive bladder"""

    name: Literal["mesenchymal layer of dorsal primitive bladder"] = "mesenchymal layer of dorsal primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31529"] = "EMAPA_31529"


class _Urethral_Tube_Epithelium_Of_Female(_MouseAnatomicalStructureModel):
    """Model urethral tube epithelium of female"""

    name: Literal["urethral tube epithelium of female"] = "urethral tube epithelium of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31530"] = "EMAPA_31530"


class _Proximal_Urethral_Meatus_Of_Female(_MouseAnatomicalStructureModel):
    """Model proximal urethral meatus of female"""

    name: Literal["proximal urethral meatus of female"] = "proximal urethral meatus of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31531"] = "EMAPA_31531"


class _Developing_Vasculature_Of_Urogenital_Sinus(_MouseAnatomicalStructureModel):
    """Model developing vasculature of urogenital sinus"""

    name: Literal["developing vasculature of urogenital sinus"] = "developing vasculature of urogenital sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31532"] = "EMAPA_31532"


class _Nerves_Of_Urogenital_Sinus(_MouseAnatomicalStructureModel):
    """Model nerves of urogenital sinus"""

    name: Literal["nerves of urogenital sinus"] = "nerves of urogenital sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31533"] = "EMAPA_31533"


class _Mesenchyme_Of_Proximal_Genital_Tubercle_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchyme of proximal genital tubercle of female"""

    name: Literal[
        "mesenchyme of proximal genital tubercle of female"
    ] = "mesenchyme of proximal genital tubercle of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31534"] = "EMAPA_31534"


class _Skin_Of_Proximal_Genital_Tubercle_Of_Female(_MouseAnatomicalStructureModel):
    """Model skin of proximal genital tubercle of female"""

    name: Literal["skin of proximal genital tubercle of female"] = "skin of proximal genital tubercle of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31535"] = "EMAPA_31535"


class _Urethral_Plate_Epithelium_Of_Female(_MouseAnatomicalStructureModel):
    """Model urethral plate epithelium of female"""

    name: Literal["urethral plate epithelium of female"] = "urethral plate epithelium of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31536"] = "EMAPA_31536"


class _Developing_Vasculature_Of_Male_Mesonephros(_MouseAnatomicalStructureModel):
    """Model developing vasculature of male mesonephros"""

    name: Literal["developing vasculature of male mesonephros"] = "developing vasculature of male mesonephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31537"] = "EMAPA_31537"


class _Developing_Vasculature_Of_Female_Mesonephros(_MouseAnatomicalStructureModel):
    """Model developing vasculature of female mesonephros"""

    name: Literal["developing vasculature of female mesonephros"] = "developing vasculature of female mesonephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31538"] = "EMAPA_31538"


class _Developing_Vasculature_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model developing vasculature of primitive bladder"""

    name: Literal["developing vasculature of primitive bladder"] = "developing vasculature of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31539"] = "EMAPA_31539"


class _Renal_Connecting_Segment_Of_Renal_Vesicle(_MouseAnatomicalStructureModel):
    """Model renal connecting segment of renal vesicle"""

    name: Literal["renal connecting segment of renal vesicle"] = "renal connecting segment of renal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31541"] = "EMAPA_31541"


class _Early_Proximal_Tubule_Of_Maturing_Nephron(_MouseAnatomicalStructureModel):
    """Model early proximal tubule of maturing nephron"""

    name: Literal["early proximal tubule of maturing nephron"] = "early proximal tubule of maturing nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31542"] = "EMAPA_31542"


class _Early_Proximal_Tubule_Of_Capillary_Loop_Nephron(_MouseAnatomicalStructureModel):
    """Model early proximal tubule of capillary loop nephron"""

    name: Literal["early proximal tubule of capillary loop nephron"] = "early proximal tubule of capillary loop nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31544"] = "EMAPA_31544"


class _Renal_Connecting_Segment_Of_Comma_Shaped_Body(_MouseAnatomicalStructureModel):
    """Model renal connecting segment of comma-shaped body"""

    name: Literal["renal connecting segment of comma-shaped body"] = "renal connecting segment of comma-shaped body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31546"] = "EMAPA_31546"


class _Proximal_Renal_Vesicle(_MouseAnatomicalStructureModel):
    """Model proximal renal vesicle"""

    name: Literal["proximal renal vesicle"] = "proximal renal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31549"] = "EMAPA_31549"


class _Mesenchymal_Layer_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of ventral pelvic urethra of male"""

    name: Literal[
        "mesenchymal layer of ventral pelvic urethra of male"
    ] = "mesenchymal layer of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31550"] = "EMAPA_31550"


class _Mesenchymal_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of dorsal pelvic urethra of male"""

    name: Literal[
        "mesenchymal layer of dorsal pelvic urethra of male"
    ] = "mesenchymal layer of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31552"] = "EMAPA_31552"


class _Mesenchymal_Layer_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of ventral pelvic urethra of female"""

    name: Literal[
        "mesenchymal layer of ventral pelvic urethra of female"
    ] = "mesenchymal layer of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31553"] = "EMAPA_31553"


class _Mesenchymal_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of dorsal pelvic urethra of female"""

    name: Literal[
        "mesenchymal layer of dorsal pelvic urethra of female"
    ] = "mesenchymal layer of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31554"] = "EMAPA_31554"


class _Muscle_Layer_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model muscle layer of ventral pelvic urethra of male"""

    name: Literal["muscle layer of ventral pelvic urethra of male"] = "muscle layer of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31555"] = "EMAPA_31555"


class _Muscle_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model muscle layer of dorsal pelvic urethra of male"""

    name: Literal["muscle layer of dorsal pelvic urethra of male"] = "muscle layer of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31556"] = "EMAPA_31556"


class _Muscle_Layer_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model muscle layer of ventral pelvic urethra of female"""

    name: Literal[
        "muscle layer of ventral pelvic urethra of female"
    ] = "muscle layer of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31559"] = "EMAPA_31559"


class _Muscle_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model muscle layer of dorsal pelvic urethra of female"""

    name: Literal["muscle layer of dorsal pelvic urethra of female"] = "muscle layer of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31560"] = "EMAPA_31560"


class _Nerve_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model nerve of pelvic urethra of male"""

    name: Literal["nerve of pelvic urethra of male"] = "nerve of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31565"] = "EMAPA_31565"


class _Cortical_Renal_Tubule_Of_Mature_Nephron_Group(_MouseAnatomicalStructureModel):
    """Model cortical renal tubule of mature nephron group"""

    name: Literal["cortical renal tubule of mature nephron group"] = "cortical renal tubule of mature nephron group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31566"] = "EMAPA_31566"


class _Nerve_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model nerve of pelvic urethra of female"""

    name: Literal["nerve of pelvic urethra of female"] = "nerve of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31567"] = "EMAPA_31567"


class _Nerve_Of_Urethra(_MouseAnatomicalStructureModel):
    """Model nerve of urethra"""

    name: Literal["nerve of urethra"] = "nerve of urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31569"] = "EMAPA_31569"


class _Cortical_Renal_Tubule_Of_Maturing_Nephron_Group(_MouseAnatomicalStructureModel):
    """Model cortical renal tubule of maturing nephron group"""

    name: Literal["cortical renal tubule of maturing nephron group"] = "cortical renal tubule of maturing nephron group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31570"] = "EMAPA_31570"


class _Cortical_Renal_Tubule_Of_Capillary_Loop_Nephron_Group(_MouseAnatomicalStructureModel):
    """Model cortical renal tubule of capillary loop nephron group"""

    name: Literal[
        "cortical renal tubule of capillary loop nephron group"
    ] = "cortical renal tubule of capillary loop nephron group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31571"] = "EMAPA_31571"


class _Mesenchymal_Layer_Of_Ventral_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of ventral pelvic urethra"""

    name: Literal["mesenchymal layer of ventral pelvic urethra"] = "mesenchymal layer of ventral pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31574"] = "EMAPA_31574"


class _Mesenchymal_Layer_Of_Dorsal_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model mesenchymal layer of dorsal pelvic urethra"""

    name: Literal["mesenchymal layer of dorsal pelvic urethra"] = "mesenchymal layer of dorsal pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31575"] = "EMAPA_31575"


class _Muscle_Layer_Of_Ventral_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model muscle layer of ventral pelvic urethra"""

    name: Literal["muscle layer of ventral pelvic urethra"] = "muscle layer of ventral pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31576"] = "EMAPA_31576"


class _Muscle_Layer_Of_Dorsal_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model muscle layer of dorsal pelvic urethra"""

    name: Literal["muscle layer of dorsal pelvic urethra"] = "muscle layer of dorsal pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31577"] = "EMAPA_31577"


class _Developing_Vasculature_Of_Genitourinary_System(_MouseAnatomicalStructureModel):
    """Model developing vasculature of genitourinary system"""

    name: Literal["developing vasculature of genitourinary system"] = "developing vasculature of genitourinary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31578"] = "EMAPA_31578"


class _Developing_Vasculature_Of_Urinary_System(_MouseAnatomicalStructureModel):
    """Model developing vasculature of urinary system"""

    name: Literal["developing vasculature of urinary system"] = "developing vasculature of urinary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31579"] = "EMAPA_31579"


class _Developing_Vasculature_Of_Reproductive_System(_MouseAnatomicalStructureModel):
    """Model developing vasculature of reproductive system"""

    name: Literal["developing vasculature of reproductive system"] = "developing vasculature of reproductive system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31580"] = "EMAPA_31580"


class _Distal_Renal_Vesicle(_MouseAnatomicalStructureModel):
    """Model distal renal vesicle"""

    name: Literal["distal renal vesicle"] = "distal renal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31582"] = "EMAPA_31582"


class _Trunk(_MouseAnatomicalStructureModel):
    """Model trunk"""

    name: Literal["trunk"] = "trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31857"] = "EMAPA_31857"


class _Head(_MouseAnatomicalStructureModel):
    """Model head"""

    name: Literal["head"] = "head"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31858"] = "EMAPA_31858"


class _Polar_Body(_MouseAnatomicalStructureModel):
    """Model polar body"""

    name: Literal["polar body"] = "polar body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31859"] = "EMAPA_31859"


class _Allantois_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model allantois blood vessel"""

    name: Literal["allantois blood vessel"] = "allantois blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31860"] = "EMAPA_31860"


class _Allantois_Endothelium(_MouseAnatomicalStructureModel):
    """Model allantois endothelium"""

    name: Literal["allantois endothelium"] = "allantois endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31861"] = "EMAPA_31861"


class _Extraembryonic_Mesoderm(_MouseAnatomicalStructureModel):
    """Model extraembryonic mesoderm"""

    name: Literal["extraembryonic mesoderm"] = "extraembryonic mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31862"] = "EMAPA_31862"


class _Extraembryonic_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model extraembryonic mesenchyme"""

    name: Literal["extraembryonic mesenchyme"] = "extraembryonic mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31863"] = "EMAPA_31863"


class _4_Cell_Stage_Embryo(_MouseAnatomicalStructureModel):
    """Model 4-cell stage embryo"""

    name: Literal["4-cell stage embryo"] = "4-cell stage embryo"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31864"] = "EMAPA_31864"


class _8_Cell_Stage_Embryo(_MouseAnatomicalStructureModel):
    """Model 8-cell stage embryo"""

    name: Literal["8-cell stage embryo"] = "8-cell stage embryo"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31865"] = "EMAPA_31865"


class _Yolk_Sac_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model yolk sac blood vessel"""

    name: Literal["yolk sac blood vessel"] = "yolk sac blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31866"] = "EMAPA_31866"


class _Trabecular_Cord_Mesodermal_Core(_MouseAnatomicalStructureModel):
    """Model trabecular cord mesodermal core"""

    name: Literal["trabecular cord mesodermal core"] = "trabecular cord mesodermal core"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31867"] = "EMAPA_31867"


class _Umbilical_Ring(_MouseAnatomicalStructureModel):
    """Model umbilical ring"""

    name: Literal["umbilical ring"] = "umbilical ring"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31868"] = "EMAPA_31868"


class _Trabecular_Cord(_MouseAnatomicalStructureModel):
    """Model trabecular cord"""

    name: Literal["trabecular cord"] = "trabecular cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31870"] = "EMAPA_31870"


class _Interplacental_Space(_MouseAnatomicalStructureModel):
    """Model interplacental space"""

    name: Literal["interplacental space"] = "interplacental space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31871"] = "EMAPA_31871"


class _Chorionic_Plate(_MouseAnatomicalStructureModel):
    """Model chorionic plate"""

    name: Literal["chorionic plate"] = "chorionic plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31872"] = "EMAPA_31872"


class _Chorioallantoic_Placenta(_MouseAnatomicalStructureModel):
    """Model chorioallantoic placenta"""

    name: Literal["chorioallantoic placenta"] = "chorioallantoic placenta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31873"] = "EMAPA_31873"


class _Secondary_Trophoblast_Giant_Cell(_MouseAnatomicalStructureModel):
    """Model secondary trophoblast giant cell"""

    name: Literal["secondary trophoblast giant cell"] = "secondary trophoblast giant cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31875"] = "EMAPA_31875"


class _Spongiotrophoblast(_MouseAnatomicalStructureModel):
    """Model spongiotrophoblast"""

    name: Literal["spongiotrophoblast"] = "spongiotrophoblast"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31876"] = "EMAPA_31876"


class _Trophoblast_Giant_Cell(_MouseAnatomicalStructureModel):
    """Model trophoblast giant cell"""

    name: Literal["trophoblast giant cell"] = "trophoblast giant cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31877"] = "EMAPA_31877"


class _Labyrinthine_Zone(_MouseAnatomicalStructureModel):
    """Model labyrinthine zone"""

    name: Literal["labyrinthine zone"] = "labyrinthine zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_31878"] = "EMAPA_31878"


class _Epithelium_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of ventral pelvic urethra of male"""

    name: Literal["epithelium of ventral pelvic urethra of male"] = "epithelium of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32258"] = "EMAPA_32258"


class _Lamina_Propria_Of_Sinovaginal_Bulb(_MouseAnatomicalStructureModel):
    """Model lamina propria of sinovaginal bulb"""

    name: Literal["lamina propria of sinovaginal bulb"] = "lamina propria of sinovaginal bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32259"] = "EMAPA_32259"


class _Basal_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model basal cell layer of dorsal pelvic urethra of male"""

    name: Literal[
        "basal cell layer of dorsal pelvic urethra of male"
    ] = "basal cell layer of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32260"] = "EMAPA_32260"


class _Basal_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model basal cell layer of ventral pelvic urethra of male"""

    name: Literal[
        "basal cell layer of ventral pelvic urethra of male"
    ] = "basal cell layer of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32261"] = "EMAPA_32261"


class _Vasculature_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model vasculature of pelvic urethra of male"""

    name: Literal["vasculature of pelvic urethra of male"] = "vasculature of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32262"] = "EMAPA_32262"


class _Superficial_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of dorsal pelvic urethra of male"""

    name: Literal[
        "superficial cell layer of dorsal pelvic urethra of male"
    ] = "superficial cell layer of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32263"] = "EMAPA_32263"


class _Epithelium_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model epithelium of dorsal pelvic urethra of female"""

    name: Literal["epithelium of dorsal pelvic urethra of female"] = "epithelium of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32264"] = "EMAPA_32264"


class _Vasculature_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model vasculature of prostatic urethra"""

    name: Literal["vasculature of prostatic urethra"] = "vasculature of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32265"] = "EMAPA_32265"


class _Superficial_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of dorsal pelvic urethra of female"""

    name: Literal[
        "superficial cell layer of dorsal pelvic urethra of female"
    ] = "superficial cell layer of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32266"] = "EMAPA_32266"


class _Basal_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model basal cell layer of dorsal pelvic urethra of female"""

    name: Literal[
        "basal cell layer of dorsal pelvic urethra of female"
    ] = "basal cell layer of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32267"] = "EMAPA_32267"


class _Superficial_Cell_Layer_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of prostatic urethra"""

    name: Literal["superficial cell layer of prostatic urethra"] = "superficial cell layer of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32268"] = "EMAPA_32268"


class _Rhabdosphincter_Of_Male(_MouseAnatomicalStructureModel):
    """Model rhabdosphincter of male"""

    name: Literal["rhabdosphincter of male"] = "rhabdosphincter of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32269"] = "EMAPA_32269"


class _Lamina_Propria_Of_Ejaculatory_Duct(_MouseAnatomicalStructureModel):
    """Model lamina propria of ejaculatory duct"""

    name: Literal["lamina propria of ejaculatory duct"] = "lamina propria of ejaculatory duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32270"] = "EMAPA_32270"


class _Basal_Cell_Layer_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model basal cell layer of prostatic urethra"""

    name: Literal["basal cell layer of prostatic urethra"] = "basal cell layer of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32271"] = "EMAPA_32271"


class _Lamina_Propria_Of_Upper_Vagina(_MouseAnatomicalStructureModel):
    """Model lamina propria of upper vagina"""

    name: Literal["lamina propria of upper vagina"] = "lamina propria of upper vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32272"] = "EMAPA_32272"


class _Superficial_Cell_Layer_Of_Bladder_Urothelium(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of bladder urothelium"""

    name: Literal["superficial cell layer of bladder urothelium"] = "superficial cell layer of bladder urothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32273"] = "EMAPA_32273"


class _Basal_Cell_Layer_Of_Bladder_Urothelium(_MouseAnatomicalStructureModel):
    """Model basal cell layer of bladder urothelium"""

    name: Literal["basal cell layer of bladder urothelium"] = "basal cell layer of bladder urothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32274"] = "EMAPA_32274"


class _Submucosa_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model submucosa of bladder"""

    name: Literal["submucosa of bladder"] = "submucosa of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32275"] = "EMAPA_32275"


class _Submucosa_Of_Neck(_MouseAnatomicalStructureModel):
    """Model submucosa of neck"""

    name: Literal["submucosa of neck"] = "submucosa of neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32276"] = "EMAPA_32276"


class _Submucosa_Of_Fundus(_MouseAnatomicalStructureModel):
    """Model submucosa of fundus"""

    name: Literal["submucosa of fundus"] = "submucosa of fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32277"] = "EMAPA_32277"


class _Smooth_Muscle_Layer_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model smooth muscle layer of prostatic urethra"""

    name: Literal["smooth muscle layer of prostatic urethra"] = "smooth muscle layer of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32278"] = "EMAPA_32278"


class _Nerve_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model nerve of prostatic urethra"""

    name: Literal["nerve of prostatic urethra"] = "nerve of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32279"] = "EMAPA_32279"


class _Mesenchymal_Pad_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchymal pad of pelvic urethra of male"""

    name: Literal["mesenchymal pad of pelvic urethra of male"] = "mesenchymal pad of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32280"] = "EMAPA_32280"


class _Peri_Prostatic_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model peri-prostatic mesenchyme"""

    name: Literal["peri-prostatic mesenchyme"] = "peri-prostatic mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32281"] = "EMAPA_32281"


class _Epithelium_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model epithelium of ventral pelvic urethra of female"""

    name: Literal["epithelium of ventral pelvic urethra of female"] = "epithelium of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32282"] = "EMAPA_32282"


class _Vasculature_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model vasculature of pelvic urethra of female"""

    name: Literal["vasculature of pelvic urethra of female"] = "vasculature of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32283"] = "EMAPA_32283"


class _Superficial_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of ventral pelvic urethra of male"""

    name: Literal[
        "superficial cell layer of ventral pelvic urethra of male"
    ] = "superficial cell layer of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32284"] = "EMAPA_32284"


class _Nerve_Of_Prostate_Gland(_MouseAnatomicalStructureModel):
    """Model nerve of prostate gland"""

    name: Literal["nerve of prostate gland"] = "nerve of prostate gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32285"] = "EMAPA_32285"


class _Presumptive_Neural_Crest_Derivative_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model presumptive neural crest derivative of pelvic urethra of male"""

    name: Literal[
        "presumptive neural crest derivative of pelvic urethra of male"
    ] = "presumptive neural crest derivative of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32286"] = "EMAPA_32286"


class _Mesenchymal_Pad_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchymal pad of pelvic urethra of female"""

    name: Literal["mesenchymal pad of pelvic urethra of female"] = "mesenchymal pad of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32287"] = "EMAPA_32287"


class _Presumptive_Neural_Crest_Derivative_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model presumptive neural crest derivative of pelvic urethra of female"""

    name: Literal[
        "presumptive neural crest derivative of pelvic urethra of female"
    ] = "presumptive neural crest derivative of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32288"] = "EMAPA_32288"


class _Muscle_Of_Ejaculatory_Duct(_MouseAnatomicalStructureModel):
    """Model muscle of ejaculatory duct"""

    name: Literal["muscle of ejaculatory duct"] = "muscle of ejaculatory duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32289"] = "EMAPA_32289"


class _Superficial_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of ventral pelvic urethra of female"""

    name: Literal[
        "superficial cell layer of ventral pelvic urethra of female"
    ] = "superficial cell layer of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32291"] = "EMAPA_32291"


class _Basal_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model basal cell layer of ventral pelvic urethra of female"""

    name: Literal[
        "basal cell layer of ventral pelvic urethra of female"
    ] = "basal cell layer of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32292"] = "EMAPA_32292"


class _Submucosa_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model submucosa of dorsal pelvic urethra of male"""

    name: Literal["submucosa of dorsal pelvic urethra of male"] = "submucosa of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32293"] = "EMAPA_32293"


class _Lamina_Propria_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model lamina propria of ventral pelvic urethra of male"""

    name: Literal[
        "lamina propria of ventral pelvic urethra of male"
    ] = "lamina propria of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32294"] = "EMAPA_32294"


class _Muscularis_Mucosa_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of dorsal pelvic urethra of female"""

    name: Literal[
        "muscularis mucosa of dorsal pelvic urethra of female"
    ] = "muscularis mucosa of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32295"] = "EMAPA_32295"


class _Lamina_Propria_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model lamina propria of dorsal pelvic urethra of female"""

    name: Literal[
        "lamina propria of dorsal pelvic urethra of female"
    ] = "lamina propria of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32296"] = "EMAPA_32296"


class _Muscularis_Mucosa_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of ventral pelvic urethra of male"""

    name: Literal[
        "muscularis mucosa of ventral pelvic urethra of male"
    ] = "muscularis mucosa of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32297"] = "EMAPA_32297"


class _Submucosa_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model submucosa of ventral pelvic urethra of male"""

    name: Literal["submucosa of ventral pelvic urethra of male"] = "submucosa of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32298"] = "EMAPA_32298"


class _Intermediate_Cell_Layer_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of prostatic urethra"""

    name: Literal["intermediate cell layer of prostatic urethra"] = "intermediate cell layer of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32299"] = "EMAPA_32299"


class _Epithelium_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of dorsal pelvic urethra of male"""

    name: Literal["epithelium of dorsal pelvic urethra of male"] = "epithelium of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32300"] = "EMAPA_32300"


class _Submucosa_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model submucosa of prostatic urethra"""

    name: Literal["submucosa of prostatic urethra"] = "submucosa of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32301"] = "EMAPA_32301"


class _Muscularis_Mucosa_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of prostatic urethra"""

    name: Literal["muscularis mucosa of prostatic urethra"] = "muscularis mucosa of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32302"] = "EMAPA_32302"


class _Lamina_Propria_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model lamina propria of prostatic urethra"""

    name: Literal["lamina propria of prostatic urethra"] = "lamina propria of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32303"] = "EMAPA_32303"


class _Submucosa_Of_Trigone(_MouseAnatomicalStructureModel):
    """Model submucosa of trigone"""

    name: Literal["submucosa of trigone"] = "submucosa of trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32304"] = "EMAPA_32304"


class _Intermediate_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of ventral pelvic urethra of female"""

    name: Literal[
        "intermediate cell layer of ventral pelvic urethra of female"
    ] = "intermediate cell layer of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32305"] = "EMAPA_32305"


class _Intermediate_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of dorsal pelvic urethra of female"""

    name: Literal[
        "intermediate cell layer of dorsal pelvic urethra of female"
    ] = "intermediate cell layer of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32306"] = "EMAPA_32306"


class _Intermediate_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of dorsal pelvic urethra of male"""

    name: Literal[
        "intermediate cell layer of dorsal pelvic urethra of male"
    ] = "intermediate cell layer of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32307"] = "EMAPA_32307"


class _Submucosa_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model submucosa of ventral pelvic urethra of female"""

    name: Literal["submucosa of ventral pelvic urethra of female"] = "submucosa of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32308"] = "EMAPA_32308"


class _Muscularis_Mucosa_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of ventral pelvic urethra of female"""

    name: Literal[
        "muscularis mucosa of ventral pelvic urethra of female"
    ] = "muscularis mucosa of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32309"] = "EMAPA_32309"


class _Lamina_Propria_Of_Ventral_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model lamina propria of ventral pelvic urethra of female"""

    name: Literal[
        "lamina propria of ventral pelvic urethra of female"
    ] = "lamina propria of ventral pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32310"] = "EMAPA_32310"


class _Lamina_Propria_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model lamina propria of dorsal pelvic urethra of male"""

    name: Literal["lamina propria of dorsal pelvic urethra of male"] = "lamina propria of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32311"] = "EMAPA_32311"


class _Muscularis_Mucosa_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of dorsal pelvic urethra of male"""

    name: Literal[
        "muscularis mucosa of dorsal pelvic urethra of male"
    ] = "muscularis mucosa of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32312"] = "EMAPA_32312"


class _Submucosa_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model submucosa of dorsal pelvic urethra of female"""

    name: Literal["submucosa of dorsal pelvic urethra of female"] = "submucosa of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32313"] = "EMAPA_32313"


class _Intermediate_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of ventral pelvic urethra of male"""

    name: Literal[
        "intermediate cell layer of ventral pelvic urethra of male"
    ] = "intermediate cell layer of ventral pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32314"] = "EMAPA_32314"


class _Limb_Interdigital_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model limb interdigital region mesenchyme"""

    name: Literal["limb interdigital region mesenchyme"] = "limb interdigital region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32609"] = "EMAPA_32609"


class _Limb_Interdigital_Region_Skin(_MouseAnatomicalStructureModel):
    """Model limb interdigital region skin"""

    name: Literal["limb interdigital region skin"] = "limb interdigital region skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32610"] = "EMAPA_32610"


class _Forelimb_Epithelium(_MouseAnatomicalStructureModel):
    """Model forelimb epithelium"""

    name: Literal["forelimb epithelium"] = "forelimb epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32611"] = "EMAPA_32611"


class _Forelimb_Skin(_MouseAnatomicalStructureModel):
    """Model forelimb skin"""

    name: Literal["forelimb skin"] = "forelimb skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32612"] = "EMAPA_32612"


class _Forelimb_Dermis(_MouseAnatomicalStructureModel):
    """Model forelimb dermis"""

    name: Literal["forelimb dermis"] = "forelimb dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32613"] = "EMAPA_32613"


class _Phalanx(_MouseAnatomicalStructureModel):
    """Model phalanx"""

    name: Literal["phalanx"] = "phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32614"] = "EMAPA_32614"


class _Digit_Skin(_MouseAnatomicalStructureModel):
    """Model digit skin"""

    name: Literal["digit skin"] = "digit skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32615"] = "EMAPA_32615"


class _Digit_Epithelium(_MouseAnatomicalStructureModel):
    """Model digit epithelium"""

    name: Literal["digit epithelium"] = "digit epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32616"] = "EMAPA_32616"


class _Interdigital_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model interdigital region epithelium"""

    name: Literal["interdigital region epithelium"] = "interdigital region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32617"] = "EMAPA_32617"


class _Limb_Interdigital_Region(_MouseAnatomicalStructureModel):
    """Model limb interdigital region"""

    name: Literal["limb interdigital region"] = "limb interdigital region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32618"] = "EMAPA_32618"


class _Hindlimb_Dermis(_MouseAnatomicalStructureModel):
    """Model hindlimb dermis"""

    name: Literal["hindlimb dermis"] = "hindlimb dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32619"] = "EMAPA_32619"


class _Hindlimb_Skin(_MouseAnatomicalStructureModel):
    """Model hindlimb skin"""

    name: Literal["hindlimb skin"] = "hindlimb skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32620"] = "EMAPA_32620"


class _Hindlimb_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindlimb epithelium"""

    name: Literal["hindlimb epithelium"] = "hindlimb epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32621"] = "EMAPA_32621"


class _Forearm_Muscle(_MouseAnatomicalStructureModel):
    """Model forearm muscle"""

    name: Literal["forearm muscle"] = "forearm muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32622"] = "EMAPA_32622"


class _Forelimb_Skeleton(_MouseAnatomicalStructureModel):
    """Model forelimb skeleton"""

    name: Literal["forelimb skeleton"] = "forelimb skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32623"] = "EMAPA_32623"


class _Forelimb_Musculature(_MouseAnatomicalStructureModel):
    """Model forelimb musculature"""

    name: Literal["forelimb musculature"] = "forelimb musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32624"] = "EMAPA_32624"


class _Forelimb_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb pre-cartilage condensation"""

    name: Literal["forelimb pre-cartilage condensation"] = "forelimb pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32625"] = "EMAPA_32625"


class _Forelimb_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb cartilage condensation"""

    name: Literal["forelimb cartilage condensation"] = "forelimb cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32626"] = "EMAPA_32626"


class _Forelimb_Epidermis(_MouseAnatomicalStructureModel):
    """Model forelimb epidermis"""

    name: Literal["forelimb epidermis"] = "forelimb epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32627"] = "EMAPA_32627"


class _Forelimb_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb mesenchyme"""

    name: Literal["forelimb mesenchyme"] = "forelimb mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32628"] = "EMAPA_32628"


class _Hand_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hand pre-cartilage condensation"""

    name: Literal["hand pre-cartilage condensation"] = "hand pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32629"] = "EMAPA_32629"


class _Hand_Epithelium(_MouseAnatomicalStructureModel):
    """Model hand epithelium"""

    name: Literal["hand epithelium"] = "hand epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32630"] = "EMAPA_32630"


class _Hand_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hand cartilage condensation"""

    name: Literal["hand cartilage condensation"] = "hand cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32631"] = "EMAPA_32631"


class _Hindlimb_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb cartilage condensation"""

    name: Literal["hindlimb cartilage condensation"] = "hindlimb cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32632"] = "EMAPA_32632"


class _Hindlimb_Skeleton(_MouseAnatomicalStructureModel):
    """Model hindlimb skeleton"""

    name: Literal["hindlimb skeleton"] = "hindlimb skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32633"] = "EMAPA_32633"


class _Hindlimb_Musculature(_MouseAnatomicalStructureModel):
    """Model hindlimb musculature"""

    name: Literal["hindlimb musculature"] = "hindlimb musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32634"] = "EMAPA_32634"


class _Hindlimb_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb joint"""

    name: Literal["hindlimb joint"] = "hindlimb joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32635"] = "EMAPA_32635"


class _Hindlimb_Epidermis(_MouseAnatomicalStructureModel):
    """Model hindlimb epidermis"""

    name: Literal["hindlimb epidermis"] = "hindlimb epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32636"] = "EMAPA_32636"


class _Hindlimb_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb mesenchyme"""

    name: Literal["hindlimb mesenchyme"] = "hindlimb mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32637"] = "EMAPA_32637"


class _Hindlimb_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb pre-cartilage condensation"""

    name: Literal["hindlimb pre-cartilage condensation"] = "hindlimb pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32638"] = "EMAPA_32638"


class _Forelimb_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb phalanx pre-cartilage condensation"""

    name: Literal["forelimb phalanx pre-cartilage condensation"] = "forelimb phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32639"] = "EMAPA_32639"


class _Forelimb_Digit_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit cartilage condensation"""

    name: Literal["forelimb digit cartilage condensation"] = "forelimb digit cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32640"] = "EMAPA_32640"


class _Hand_Joint(_MouseAnatomicalStructureModel):
    """Model hand joint"""

    name: Literal["hand joint"] = "hand joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32641"] = "EMAPA_32641"


class _Forelimb_Digit(_MouseAnatomicalStructureModel):
    """Model forelimb digit"""

    name: Literal["forelimb digit"] = "forelimb digit"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32642"] = "EMAPA_32642"


class _Hand_Skeleton(_MouseAnatomicalStructureModel):
    """Model hand skeleton"""

    name: Literal["hand skeleton"] = "hand skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32643"] = "EMAPA_32643"


class _Hand_Muscle(_MouseAnatomicalStructureModel):
    """Model hand muscle"""

    name: Literal["hand muscle"] = "hand muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32644"] = "EMAPA_32644"


class _Forelimb_Digit_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb digit mesenchyme"""

    name: Literal["forelimb digit mesenchyme"] = "forelimb digit mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32645"] = "EMAPA_32645"


class _Forelimb_Digit_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb digit pre-cartilage condensation"""

    name: Literal["forelimb digit pre-cartilage condensation"] = "forelimb digit pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32646"] = "EMAPA_32646"


class _Forelimb_Digit_Epithelium(_MouseAnatomicalStructureModel):
    """Model forelimb digit epithelium"""

    name: Literal["forelimb digit epithelium"] = "forelimb digit epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32647"] = "EMAPA_32647"


class _Forelimb_Digit_Skin(_MouseAnatomicalStructureModel):
    """Model forelimb digit skin"""

    name: Literal["forelimb digit skin"] = "forelimb digit skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32648"] = "EMAPA_32648"


class _Hindlimb_Digit(_MouseAnatomicalStructureModel):
    """Model hindlimb digit"""

    name: Literal["hindlimb digit"] = "hindlimb digit"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32649"] = "EMAPA_32649"


class _Forelimb_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb phalanx"""

    name: Literal["forelimb phalanx"] = "forelimb phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32650"] = "EMAPA_32650"


class _Forelimb_Interdigital_Region(_MouseAnatomicalStructureModel):
    """Model forelimb interdigital region"""

    name: Literal["forelimb interdigital region"] = "forelimb interdigital region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32651"] = "EMAPA_32651"


class _Forelimb_Interdigital_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model forelimb interdigital region epithelium"""

    name: Literal["forelimb interdigital region epithelium"] = "forelimb interdigital region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32652"] = "EMAPA_32652"


class _Forelimb_Interdigital_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model forelimb interdigital region mesenchyme"""

    name: Literal["forelimb interdigital region mesenchyme"] = "forelimb interdigital region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32653"] = "EMAPA_32653"


class _Metacarpus(_MouseAnatomicalStructureModel):
    """Model metacarpus"""

    name: Literal["metacarpus"] = "metacarpus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32654"] = "EMAPA_32654"


class _Foot_Epithelium(_MouseAnatomicalStructureModel):
    """Model foot epithelium"""

    name: Literal["foot epithelium"] = "foot epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32655"] = "EMAPA_32655"


class _Foot_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model foot pre-cartilage condensation"""

    name: Literal["foot pre-cartilage condensation"] = "foot pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32656"] = "EMAPA_32656"


class _Foot_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model foot cartilage condensation"""

    name: Literal["foot cartilage condensation"] = "foot cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32657"] = "EMAPA_32657"


class _Forelimb_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model forelimb phalanx cartilage condensation"""

    name: Literal["forelimb phalanx cartilage condensation"] = "forelimb phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32658"] = "EMAPA_32658"


class _Arachnoid_Mater(_MouseAnatomicalStructureModel):
    """Model arachnoid mater"""

    name: Literal["arachnoid mater"] = "arachnoid mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32659"] = "EMAPA_32659"


class _Meninges(_MouseAnatomicalStructureModel):
    """Model meninges"""

    name: Literal["meninges"] = "meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32660"] = "EMAPA_32660"


class _Brain_Arachnoid_Mater(_MouseAnatomicalStructureModel):
    """Model brain arachnoid mater"""

    name: Literal["brain arachnoid mater"] = "brain arachnoid mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32661"] = "EMAPA_32661"


class _Brain_Meninges(_MouseAnatomicalStructureModel):
    """Model brain meninges"""

    name: Literal["brain meninges"] = "brain meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32662"] = "EMAPA_32662"


class _Pia_Mater(_MouseAnatomicalStructureModel):
    """Model pia mater"""

    name: Literal["pia mater"] = "pia mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32663"] = "EMAPA_32663"


class _Dura_Mater(_MouseAnatomicalStructureModel):
    """Model dura mater"""

    name: Literal["dura mater"] = "dura mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32664"] = "EMAPA_32664"


class _Ganglionic_Eminence(_MouseAnatomicalStructureModel):
    """Model ganglionic eminence"""

    name: Literal["ganglionic eminence"] = "ganglionic eminence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32665"] = "EMAPA_32665"


class _Brain_Subarachnoid_Space(_MouseAnatomicalStructureModel):
    """Model brain subarachnoid space"""

    name: Literal["brain subarachnoid space"] = "brain subarachnoid space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32666"] = "EMAPA_32666"


class _Brain_Pia_Mater(_MouseAnatomicalStructureModel):
    """Model brain pia mater"""

    name: Literal["brain pia mater"] = "brain pia mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32667"] = "EMAPA_32667"


class _Brain_Dura_Mater(_MouseAnatomicalStructureModel):
    """Model brain dura mater"""

    name: Literal["brain dura mater"] = "brain dura mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32668"] = "EMAPA_32668"


class _Vertebral_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model vertebral cartilage condensation"""

    name: Literal["vertebral cartilage condensation"] = "vertebral cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32669"] = "EMAPA_32669"


class _Annulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model annulus fibrosus"""

    name: Literal["annulus fibrosus"] = "annulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32670"] = "EMAPA_32670"


class _Vertebral_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model vertebral pre-cartilage condensation"""

    name: Literal["vertebral pre-cartilage condensation"] = "vertebral pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32671"] = "EMAPA_32671"


class _Amygdala(_MouseAnatomicalStructureModel):
    """Model amygdala"""

    name: Literal["amygdala"] = "amygdala"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32672"] = "EMAPA_32672"


class _Basal_Ganglia(_MouseAnatomicalStructureModel):
    """Model basal ganglia"""

    name: Literal["basal ganglia"] = "basal ganglia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32673"] = "EMAPA_32673"


class _Brain_Ventricle(_MouseAnatomicalStructureModel):
    """Model brain ventricle"""

    name: Literal["brain ventricle"] = "brain ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32674"] = "EMAPA_32674"


class _Brain_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model brain floor plate"""

    name: Literal["brain floor plate"] = "brain floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32676"] = "EMAPA_32676"


class _Future_Brain_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model future brain floor plate"""

    name: Literal["future brain floor plate"] = "future brain floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32677"] = "EMAPA_32677"


class _Brainstem(_MouseAnatomicalStructureModel):
    """Model brainstem"""

    name: Literal["brainstem"] = "brainstem"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32678"] = "EMAPA_32678"


class _Brain_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model brain ventricular layer"""

    name: Literal["brain ventricular layer"] = "brain ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32679"] = "EMAPA_32679"


class _Brain_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model brain marginal layer"""

    name: Literal["brain marginal layer"] = "brain marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32680"] = "EMAPA_32680"


class _Brain_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model brain mantle layer"""

    name: Literal["brain mantle layer"] = "brain mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32681"] = "EMAPA_32681"


class _Lung_Alveolus(_MouseAnatomicalStructureModel):
    """Model lung alveolus"""

    name: Literal["lung alveolus"] = "lung alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32682"] = "EMAPA_32682"


class _Alimentary_System_Epithelium(_MouseAnatomicalStructureModel):
    """Model alimentary system epithelium"""

    name: Literal["alimentary system epithelium"] = "alimentary system epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32683"] = "EMAPA_32683"


class _Floor_Plate(_MouseAnatomicalStructureModel):
    """Model floor plate"""

    name: Literal["floor plate"] = "floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32684"] = "EMAPA_32684"


class _Endocardial_Tube(_MouseAnatomicalStructureModel):
    """Model endocardial tube"""

    name: Literal["endocardial tube"] = "endocardial tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32685"] = "EMAPA_32685"


class _Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model endocardial lining"""

    name: Literal["endocardial lining"] = "endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32686"] = "EMAPA_32686"


class _Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model cardiac jelly"""

    name: Literal["cardiac jelly"] = "cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32687"] = "EMAPA_32687"


class _Cardiac_Muscle_Tissue(_MouseAnatomicalStructureModel):
    """Model cardiac muscle tissue"""

    name: Literal["cardiac muscle tissue"] = "cardiac muscle tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32688"] = "EMAPA_32688"


class _Bronchus(_MouseAnatomicalStructureModel):
    """Model bronchus"""

    name: Literal["bronchus"] = "bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32689"] = "EMAPA_32689"


class _Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model bronchus mesenchyme"""

    name: Literal["bronchus mesenchyme"] = "bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32690"] = "EMAPA_32690"


class _Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model bronchus epithelium"""

    name: Literal["bronchus epithelium"] = "bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32691"] = "EMAPA_32691"


class _Alveolar_System(_MouseAnatomicalStructureModel):
    """Model alveolar system"""

    name: Literal["alveolar system"] = "alveolar system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32692"] = "EMAPA_32692"


class _Bronchiole_Epithelium(_MouseAnatomicalStructureModel):
    """Model bronchiole epithelium"""

    name: Literal["bronchiole epithelium"] = "bronchiole epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32693"] = "EMAPA_32693"


class _Alveolar_Duct(_MouseAnatomicalStructureModel):
    """Model alveolar duct"""

    name: Literal["alveolar duct"] = "alveolar duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32694"] = "EMAPA_32694"


class _Lobar_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model lobar bronchus epithelium"""

    name: Literal["lobar bronchus epithelium"] = "lobar bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32695"] = "EMAPA_32695"


class _Lobar_Bronchus(_MouseAnatomicalStructureModel):
    """Model lobar bronchus"""

    name: Literal["lobar bronchus"] = "lobar bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32696"] = "EMAPA_32696"


class _Bronchiole(_MouseAnatomicalStructureModel):
    """Model bronchiole"""

    name: Literal["bronchiole"] = "bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32697"] = "EMAPA_32697"


class _Lobar_Bronchus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lobar bronchus mesenchyme"""

    name: Literal["lobar bronchus mesenchyme"] = "lobar bronchus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32698"] = "EMAPA_32698"


class _Limb_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model limb joint primordium"""

    name: Literal["limb joint primordium"] = "limb joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32699"] = "EMAPA_32699"


class _Limb_Musculature(_MouseAnatomicalStructureModel):
    """Model limb musculature"""

    name: Literal["limb musculature"] = "limb musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32700"] = "EMAPA_32700"


class _Limb_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model limb cartilage condensation"""

    name: Literal["limb cartilage condensation"] = "limb cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32701"] = "EMAPA_32701"


class _Limb_Skeleton(_MouseAnatomicalStructureModel):
    """Model limb skeleton"""

    name: Literal["limb skeleton"] = "limb skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32702"] = "EMAPA_32702"


class _Cortical_Subplate(_MouseAnatomicalStructureModel):
    """Model cortical subplate"""

    name: Literal["cortical subplate"] = "cortical subplate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32703"] = "EMAPA_32703"


class _Cerebral_Cortex_Subventricular_Zone(_MouseAnatomicalStructureModel):
    """Model cerebral cortex subventricular zone"""

    name: Literal["cerebral cortex subventricular zone"] = "cerebral cortex subventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32704"] = "EMAPA_32704"


class _Limb_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model limb mesenchyme"""

    name: Literal["limb mesenchyme"] = "limb mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32705"] = "EMAPA_32705"


class _Limb_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model limb pre-cartilage condensation"""

    name: Literal["limb pre-cartilage condensation"] = "limb pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32706"] = "EMAPA_32706"


class _Cerebral_Cortex_Ventricular_Zone(_MouseAnatomicalStructureModel):
    """Model cerebral cortex ventricular zone"""

    name: Literal["cerebral cortex ventricular zone"] = "cerebral cortex ventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32707"] = "EMAPA_32707"


class _Limb_Ectoderm(_MouseAnatomicalStructureModel):
    """Model limb ectoderm"""

    name: Literal["limb ectoderm"] = "limb ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32708"] = "EMAPA_32708"


class _Diencephalon_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model diencephalon marginal layer"""

    name: Literal["diencephalon marginal layer"] = "diencephalon marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32709"] = "EMAPA_32709"


class _Diencephalon_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model diencephalon ventricular layer"""

    name: Literal["diencephalon ventricular layer"] = "diencephalon ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32710"] = "EMAPA_32710"


class _Cortical_Plate(_MouseAnatomicalStructureModel):
    """Model cortical plate"""

    name: Literal["cortical plate"] = "cortical plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32711"] = "EMAPA_32711"


class _Cerebral_Cortex_Intermediate_Zone(_MouseAnatomicalStructureModel):
    """Model cerebral cortex intermediate zone"""

    name: Literal["cerebral cortex intermediate zone"] = "cerebral cortex intermediate zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32712"] = "EMAPA_32712"


class _Cerebral_Cortex_Marginal_Zone(_MouseAnatomicalStructureModel):
    """Model cerebral cortex marginal zone"""

    name: Literal["cerebral cortex marginal zone"] = "cerebral cortex marginal zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32713"] = "EMAPA_32713"


class _Musculoskeletal_System(_MouseAnatomicalStructureModel):
    """Model musculoskeletal system"""

    name: Literal["musculoskeletal system"] = "musculoskeletal system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32714"] = "EMAPA_32714"


class _Muscle_Tissue(_MouseAnatomicalStructureModel):
    """Model muscle tissue"""

    name: Literal["muscle tissue"] = "muscle tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32715"] = "EMAPA_32715"


class _Skeletal_Muscle_Tissue(_MouseAnatomicalStructureModel):
    """Model skeletal muscle tissue"""

    name: Literal["skeletal muscle tissue"] = "skeletal muscle tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32716"] = "EMAPA_32716"


class _Smooth_Muscle_Tissue(_MouseAnatomicalStructureModel):
    """Model smooth muscle tissue"""

    name: Literal["smooth muscle tissue"] = "smooth muscle tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32717"] = "EMAPA_32717"


class _Diencephalon_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model diencephalon mantle layer"""

    name: Literal["diencephalon mantle layer"] = "diencephalon mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32718"] = "EMAPA_32718"


class _Digit_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model digit mesenchyme"""

    name: Literal["digit mesenchyme"] = "digit mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32719"] = "EMAPA_32719"


class _Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model phalanx pre-cartilage condensation"""

    name: Literal["phalanx pre-cartilage condensation"] = "phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32720"] = "EMAPA_32720"


class _Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model phalanx cartilage condensation"""

    name: Literal["phalanx cartilage condensation"] = "phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32721"] = "EMAPA_32721"


class _Autopod(_MouseAnatomicalStructureModel):
    """Model autopod"""

    name: Literal["autopod"] = "autopod"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32722"] = "EMAPA_32722"


class _Autopod_Skin(_MouseAnatomicalStructureModel):
    """Model autopod skin"""

    name: Literal["autopod skin"] = "autopod skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32723"] = "EMAPA_32723"


class _Limb_Epithelium(_MouseAnatomicalStructureModel):
    """Model limb epithelium"""

    name: Literal["limb epithelium"] = "limb epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32724"] = "EMAPA_32724"


class _Limb_Digit(_MouseAnatomicalStructureModel):
    """Model limb digit"""

    name: Literal["limb digit"] = "limb digit"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32725"] = "EMAPA_32725"


class _Limb_Skin(_MouseAnatomicalStructureModel):
    """Model limb skin"""

    name: Literal["limb skin"] = "limb skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32726"] = "EMAPA_32726"


class _Limb_Dermis(_MouseAnatomicalStructureModel):
    """Model limb dermis"""

    name: Literal["limb dermis"] = "limb dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32727"] = "EMAPA_32727"


class _Limb_Epidermis(_MouseAnatomicalStructureModel):
    """Model limb epidermis"""

    name: Literal["limb epidermis"] = "limb epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32728"] = "EMAPA_32728"


class _Appendicular_Skeleton(_MouseAnatomicalStructureModel):
    """Model appendicular skeleton"""

    name: Literal["appendicular skeleton"] = "appendicular skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32729"] = "EMAPA_32729"


class _Cartilage(_MouseAnatomicalStructureModel):
    """Model cartilage"""

    name: Literal["cartilage"] = "cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32730"] = "EMAPA_32730"


class _Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model cartilage condensation"""

    name: Literal["cartilage condensation"] = "cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32731"] = "EMAPA_32731"


class _Neural_Fold(_MouseAnatomicalStructureModel):
    """Model neural fold"""

    name: Literal["neural fold"] = "neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32732"] = "EMAPA_32732"


class _Extraembryonic_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model extraembryonic blood vessel"""

    name: Literal["extraembryonic blood vessel"] = "extraembryonic blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32734"] = "EMAPA_32734"


class _Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model mesenchyme derived from neural crest"""

    name: Literal["mesenchyme derived from neural crest"] = "mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32735"] = "EMAPA_32735"


class _Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model pre-cartilage condensation"""

    name: Literal["pre-cartilage condensation"] = "pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32736"] = "EMAPA_32736"


class _Neural_Crest(_MouseAnatomicalStructureModel):
    """Model neural crest"""

    name: Literal["neural crest"] = "neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32737"] = "EMAPA_32737"


class _Epithelium(_MouseAnatomicalStructureModel):
    """Model epithelium"""

    name: Literal["epithelium"] = "epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32738"] = "EMAPA_32738"


class _Intervertebral_Disc(_MouseAnatomicalStructureModel):
    """Model intervertebral disc"""

    name: Literal["intervertebral disc"] = "intervertebral disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32739"] = "EMAPA_32739"


class _Vertebra(_MouseAnatomicalStructureModel):
    """Model vertebra"""

    name: Literal["vertebra"] = "vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32740"] = "EMAPA_32740"


class _Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model choroid plexus"""

    name: Literal["choroid plexus"] = "choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32741"] = "EMAPA_32741"


class _4Th_Ventricle_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model 4th ventricle choroid plexus"""

    name: Literal["4th ventricle choroid plexus"] = "4th ventricle choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32742"] = "EMAPA_32742"


class _Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model blood vessel"""

    name: Literal["blood vessel"] = "blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32743"] = "EMAPA_32743"


class _Apical_Ectodermal_Ridge(_MouseAnatomicalStructureModel):
    """Model apical ectodermal ridge"""

    name: Literal["apical ectodermal ridge"] = "apical ectodermal ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32744"] = "EMAPA_32744"


class _Atrium_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model atrium endocardial lining"""

    name: Literal["atrium endocardial lining"] = "atrium endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32745"] = "EMAPA_32745"


class _Atrium_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model atrium cardiac muscle"""

    name: Literal["atrium cardiac muscle"] = "atrium cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32746"] = "EMAPA_32746"


class _Ventricle_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model ventricle endocardial lining"""

    name: Literal["ventricle endocardial lining"] = "ventricle endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32747"] = "EMAPA_32747"


class _Ventricle_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model ventricle cardiac muscle"""

    name: Literal["ventricle cardiac muscle"] = "ventricle cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32748"] = "EMAPA_32748"


class _Branchial_Arch_Membrane(_MouseAnatomicalStructureModel):
    """Model branchial arch membrane"""

    name: Literal["branchial arch membrane"] = "branchial arch membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32749"] = "EMAPA_32749"


class _Branchial_Groove(_MouseAnatomicalStructureModel):
    """Model branchial groove"""

    name: Literal["branchial groove"] = "branchial groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32750"] = "EMAPA_32750"


class _Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm(_MouseAnatomicalStructureModel):
    """Model branchial arch mesenchyme derived from head mesoderm"""

    name: Literal[
        "branchial arch mesenchyme derived from head mesoderm"
    ] = "branchial arch mesenchyme derived from head mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32751"] = "EMAPA_32751"


class _Branchial_Pouch(_MouseAnatomicalStructureModel):
    """Model branchial pouch"""

    name: Literal["branchial pouch"] = "branchial pouch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32752"] = "EMAPA_32752"


class _Branchial_Arch_Ectoderm(_MouseAnatomicalStructureModel):
    """Model branchial arch ectoderm"""

    name: Literal["branchial arch ectoderm"] = "branchial arch ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32753"] = "EMAPA_32753"


class _Branchial_Arch_Endoderm(_MouseAnatomicalStructureModel):
    """Model branchial arch endoderm"""

    name: Literal["branchial arch endoderm"] = "branchial arch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32754"] = "EMAPA_32754"


class _Branchial_Arch_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model branchial arch mesenchyme"""

    name: Literal["branchial arch mesenchyme"] = "branchial arch mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32755"] = "EMAPA_32755"


class _Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model branchial arch mesenchyme derived from neural crest"""

    name: Literal[
        "branchial arch mesenchyme derived from neural crest"
    ] = "branchial arch mesenchyme derived from neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32756"] = "EMAPA_32756"


class _Paraxial_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model paraxial mesenchyme"""

    name: Literal["paraxial mesenchyme"] = "paraxial mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32757"] = "EMAPA_32757"


class _Eyelid_Epithelium(_MouseAnatomicalStructureModel):
    """Model eyelid epithelium"""

    name: Literal["eyelid epithelium"] = "eyelid epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32758"] = "EMAPA_32758"


class _Eyelid_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model eyelid mesenchyme"""

    name: Literal["eyelid mesenchyme"] = "eyelid mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32759"] = "EMAPA_32759"


class _Bone_Marrow(_MouseAnatomicalStructureModel):
    """Model bone marrow"""

    name: Literal["bone marrow"] = "bone marrow"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32760"] = "EMAPA_32760"


class _Body_Wall(_MouseAnatomicalStructureModel):
    """Model body wall"""

    name: Literal["body wall"] = "body wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32761"] = "EMAPA_32761"


class _Mesendoderm(_MouseAnatomicalStructureModel):
    """Model mesendoderm"""

    name: Literal["mesendoderm"] = "mesendoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32762"] = "EMAPA_32762"


class _Face(_MouseAnatomicalStructureModel):
    """Model face"""

    name: Literal["face"] = "face"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32763"] = "EMAPA_32763"


class _Ileum(_MouseAnatomicalStructureModel):
    """Model ileum"""

    name: Literal["ileum"] = "ileum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32764"] = "EMAPA_32764"


class _6Th_Branchial_Arch_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model 6th branchial arch mesenchyme"""

    name: Literal["6th branchial arch mesenchyme"] = "6th branchial arch mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32765"] = "EMAPA_32765"


class _6Th_Branchial_Arch(_MouseAnatomicalStructureModel):
    """Model 6th branchial arch"""

    name: Literal["6th branchial arch"] = "6th branchial arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32766"] = "EMAPA_32766"


class _Piriform_Cortex(_MouseAnatomicalStructureModel):
    """Model piriform cortex"""

    name: Literal["piriform cortex"] = "piriform cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32767"] = "EMAPA_32767"


class _Hippocampus_Ca1(_MouseAnatomicalStructureModel):
    """Model hippocampus CA1"""

    name: Literal["hippocampus CA1"] = "hippocampus CA1"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32768"] = "EMAPA_32768"


class _Hippocampus_Ca2(_MouseAnatomicalStructureModel):
    """Model hippocampus CA2"""

    name: Literal["hippocampus CA2"] = "hippocampus CA2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32769"] = "EMAPA_32769"


class _Hippocampus_Ca3(_MouseAnatomicalStructureModel):
    """Model hippocampus CA3"""

    name: Literal["hippocampus CA3"] = "hippocampus CA3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32770"] = "EMAPA_32770"


class _Hippocampus_Ca4(_MouseAnatomicalStructureModel):
    """Model hippocampus CA4"""

    name: Literal["hippocampus CA4"] = "hippocampus CA4"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32771"] = "EMAPA_32771"


class _Hippocampus_Region(_MouseAnatomicalStructureModel):
    """Model hippocampus region"""

    name: Literal["hippocampus region"] = "hippocampus region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32772"] = "EMAPA_32772"


class _Tail_Surface_Ectoderm(_MouseAnatomicalStructureModel):
    """Model tail surface ectoderm"""

    name: Literal["tail surface ectoderm"] = "tail surface ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32773"] = "EMAPA_32773"


class _Lingual_Swelling_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lingual swelling mesenchyme"""

    name: Literal["lingual swelling mesenchyme"] = "lingual swelling mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32774"] = "EMAPA_32774"


class _Lingual_Swelling_Epithelium(_MouseAnatomicalStructureModel):
    """Model lingual swelling epithelium"""

    name: Literal["lingual swelling epithelium"] = "lingual swelling epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32775"] = "EMAPA_32775"


class _Forelimb_Bud_Presumptive_Apical_Ectodermal_Ridge(_MouseAnatomicalStructureModel):
    """Model forelimb bud presumptive apical ectodermal ridge"""

    name: Literal[
        "forelimb bud presumptive apical ectodermal ridge"
    ] = "forelimb bud presumptive apical ectodermal ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32776"] = "EMAPA_32776"


class _Tongue_Papillae(_MouseAnatomicalStructureModel):
    """Model tongue papillae"""

    name: Literal["tongue papillae"] = "tongue papillae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32777"] = "EMAPA_32777"


class _Pretectum(_MouseAnatomicalStructureModel):
    """Model pretectum"""

    name: Literal["pretectum"] = "pretectum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32778"] = "EMAPA_32778"


class _Epidermis_Basal_Layer(_MouseAnatomicalStructureModel):
    """Model epidermis basal layer"""

    name: Literal["epidermis basal layer"] = "epidermis basal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32779"] = "EMAPA_32779"


class _Pallidum(_MouseAnatomicalStructureModel):
    """Model pallidum"""

    name: Literal["pallidum"] = "pallidum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32780"] = "EMAPA_32780"


class _Periaqueductal_Grey(_MouseAnatomicalStructureModel):
    """Model periaqueductal grey"""

    name: Literal["periaqueductal grey"] = "periaqueductal grey"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32781"] = "EMAPA_32781"


class _Bone(_MouseAnatomicalStructureModel):
    """Model bone"""

    name: Literal["bone"] = "bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32782"] = "EMAPA_32782"


class _Ankle(_MouseAnatomicalStructureModel):
    """Model ankle"""

    name: Literal["ankle"] = "ankle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32783"] = "EMAPA_32783"


class _Wrist(_MouseAnatomicalStructureModel):
    """Model wrist"""

    name: Literal["wrist"] = "wrist"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32784"] = "EMAPA_32784"


class _Epidermis_Spinous_Layer(_MouseAnatomicalStructureModel):
    """Model epidermis spinous layer"""

    name: Literal["epidermis spinous layer"] = "epidermis spinous layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32785"] = "EMAPA_32785"


class _Epidermis_Granular_Layer(_MouseAnatomicalStructureModel):
    """Model epidermis granular layer"""

    name: Literal["epidermis granular layer"] = "epidermis granular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32786"] = "EMAPA_32786"


class _Epidermis_Cornified_Layer(_MouseAnatomicalStructureModel):
    """Model epidermis cornified layer"""

    name: Literal["epidermis cornified layer"] = "epidermis cornified layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32787"] = "EMAPA_32787"


class _Foliate_Papillae(_MouseAnatomicalStructureModel):
    """Model foliate papillae"""

    name: Literal["foliate papillae"] = "foliate papillae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32788"] = "EMAPA_32788"


class _Accumbens_Nucleus(_MouseAnatomicalStructureModel):
    """Model accumbens nucleus"""

    name: Literal["accumbens nucleus"] = "accumbens nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32789"] = "EMAPA_32789"


class _Brainstem_Nucleus(_MouseAnatomicalStructureModel):
    """Model brainstem nucleus"""

    name: Literal["brainstem nucleus"] = "brainstem nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32790"] = "EMAPA_32790"


class _Crista_Ampullaris(_MouseAnatomicalStructureModel):
    """Model crista ampullaris"""

    name: Literal["crista ampullaris"] = "crista ampullaris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32791"] = "EMAPA_32791"


class _Hair_Inner_Root_Sheath(_MouseAnatomicalStructureModel):
    """Model hair inner root sheath"""

    name: Literal["hair inner root sheath"] = "hair inner root sheath"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32792"] = "EMAPA_32792"


class _Hair_Outer_Root_Sheath(_MouseAnatomicalStructureModel):
    """Model hair outer root sheath"""

    name: Literal["hair outer root sheath"] = "hair outer root sheath"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32793"] = "EMAPA_32793"


class _Olfactory_Cortex_Subventricular_Zone(_MouseAnatomicalStructureModel):
    """Model olfactory cortex subventricular zone"""

    name: Literal["olfactory cortex subventricular zone"] = "olfactory cortex subventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32794"] = "EMAPA_32794"


class _Left_Hepatic_Duct(_MouseAnatomicalStructureModel):
    """Model left hepatic duct"""

    name: Literal["left hepatic duct"] = "left hepatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32795"] = "EMAPA_32795"


class _Future_Pituitary(_MouseAnatomicalStructureModel):
    """Model future pituitary"""

    name: Literal["future pituitary"] = "future pituitary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32796"] = "EMAPA_32796"


class _Right_Hepatic_Duct(_MouseAnatomicalStructureModel):
    """Model right hepatic duct"""

    name: Literal["right hepatic duct"] = "right hepatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32797"] = "EMAPA_32797"


class _Tail_Neural_Tube_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model tail neural tube floor plate"""

    name: Literal["tail neural tube floor plate"] = "tail neural tube floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32798"] = "EMAPA_32798"


class _Chondrocranium_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model chondrocranium pre-cartilage condensation"""

    name: Literal["chondrocranium pre-cartilage condensation"] = "chondrocranium pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32799"] = "EMAPA_32799"


class _Ear_Epithelium(_MouseAnatomicalStructureModel):
    """Model ear epithelium"""

    name: Literal["ear epithelium"] = "ear epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32800"] = "EMAPA_32800"


class _Pharyngo_Tympanic_Tube_Epithelium(_MouseAnatomicalStructureModel):
    """Model pharyngo-tympanic tube epithelium"""

    name: Literal["pharyngo-tympanic tube epithelium"] = "pharyngo-tympanic tube epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32801"] = "EMAPA_32801"


class _Chondrocranium_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model chondrocranium cartilage condensation"""

    name: Literal["chondrocranium cartilage condensation"] = "chondrocranium cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32802"] = "EMAPA_32802"


class _Brain_Subventricular_Zone(_MouseAnatomicalStructureModel):
    """Model brain subventricular zone"""

    name: Literal["brain subventricular zone"] = "brain subventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32804"] = "EMAPA_32804"


class _Alveolar_Sulcus(_MouseAnatomicalStructureModel):
    """Model alveolar sulcus"""

    name: Literal["alveolar sulcus"] = "alveolar sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32805"] = "EMAPA_32805"


class _Snout(_MouseAnatomicalStructureModel):
    """Model snout"""

    name: Literal["snout"] = "snout"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32806"] = "EMAPA_32806"


class _Presumptive_Iris(_MouseAnatomicalStructureModel):
    """Model presumptive iris"""

    name: Literal["presumptive iris"] = "presumptive iris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32807"] = "EMAPA_32807"


class _Nerve(_MouseAnatomicalStructureModel):
    """Model nerve"""

    name: Literal["nerve"] = "nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32808"] = "EMAPA_32808"


class _Main_Olfactory_Bulb(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb"""

    name: Literal["main olfactory bulb"] = "main olfactory bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32809"] = "EMAPA_32809"


class _Palate_Epithelium(_MouseAnatomicalStructureModel):
    """Model palate epithelium"""

    name: Literal["palate epithelium"] = "palate epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32810"] = "EMAPA_32810"


class _Palate_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model palate mesenchyme"""

    name: Literal["palate mesenchyme"] = "palate mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32811"] = "EMAPA_32811"


class _Parathyroid_Gland(_MouseAnatomicalStructureModel):
    """Model parathyroid gland"""

    name: Literal["parathyroid gland"] = "parathyroid gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32812"] = "EMAPA_32812"


class _Parasympathetic_Ganglion(_MouseAnatomicalStructureModel):
    """Model parasympathetic ganglion"""

    name: Literal["parasympathetic ganglion"] = "parasympathetic ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32813"] = "EMAPA_32813"


class _Peripheral_Nervous_System_Ganglion(_MouseAnatomicalStructureModel):
    """Model peripheral nervous system ganglion"""

    name: Literal["peripheral nervous system ganglion"] = "peripheral nervous system ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32814"] = "EMAPA_32814"


class _Peripheral_Nerve(_MouseAnatomicalStructureModel):
    """Model peripheral nerve"""

    name: Literal["peripheral nerve"] = "peripheral nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32815"] = "EMAPA_32815"


class _Salivary_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model salivary gland epithelium"""

    name: Literal["salivary gland epithelium"] = "salivary gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32816"] = "EMAPA_32816"


class _Salivary_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model salivary gland mesenchyme"""

    name: Literal["salivary gland mesenchyme"] = "salivary gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32817"] = "EMAPA_32817"


class _Rhombomere_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere floor plate"""

    name: Literal["rhombomere floor plate"] = "rhombomere floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32818"] = "EMAPA_32818"


class _Rhombomere_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model rhombomere lateral wall"""

    name: Literal["rhombomere lateral wall"] = "rhombomere lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32819"] = "EMAPA_32819"


class _Rhombomere(_MouseAnatomicalStructureModel):
    """Model rhombomere"""

    name: Literal["rhombomere"] = "rhombomere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32820"] = "EMAPA_32820"


class _Rhombomere_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere marginal layer"""

    name: Literal["rhombomere marginal layer"] = "rhombomere marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32822"] = "EMAPA_32822"


class _Rhombomere_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere ventricular layer"""

    name: Literal["rhombomere ventricular layer"] = "rhombomere ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32823"] = "EMAPA_32823"


class _Rhombomere_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model rhombomere roof plate"""

    name: Literal["rhombomere roof plate"] = "rhombomere roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32824"] = "EMAPA_32824"


class _Rhombomere_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model rhombomere mantle layer"""

    name: Literal["rhombomere mantle layer"] = "rhombomere mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32825"] = "EMAPA_32825"


class _Respiratory_System_Epithelium(_MouseAnatomicalStructureModel):
    """Model respiratory system epithelium"""

    name: Literal["respiratory system epithelium"] = "respiratory system epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32826"] = "EMAPA_32826"


class _Respiratory_Tract_Epithelium(_MouseAnatomicalStructureModel):
    """Model respiratory tract epithelium"""

    name: Literal["respiratory tract epithelium"] = "respiratory tract epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32827"] = "EMAPA_32827"


class _Semicircular_Canal_Epithelium(_MouseAnatomicalStructureModel):
    """Model semicircular canal epithelium"""

    name: Literal["semicircular canal epithelium"] = "semicircular canal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32828"] = "EMAPA_32828"


class _Semicircular_Canal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model semicircular canal mesenchyme"""

    name: Literal["semicircular canal mesenchyme"] = "semicircular canal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32829"] = "EMAPA_32829"


class _Semicircular_Duct(_MouseAnatomicalStructureModel):
    """Model semicircular duct"""

    name: Literal["semicircular duct"] = "semicircular duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32830"] = "EMAPA_32830"


class _Semicircular_Duct_Ampulla(_MouseAnatomicalStructureModel):
    """Model semicircular duct ampulla"""

    name: Literal["semicircular duct ampulla"] = "semicircular duct ampulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32831"] = "EMAPA_32831"


class _Semicircular_Canal(_MouseAnatomicalStructureModel):
    """Model semicircular canal"""

    name: Literal["semicircular canal"] = "semicircular canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32832"] = "EMAPA_32832"


class _Small_Intestine(_MouseAnatomicalStructureModel):
    """Model small intestine"""

    name: Literal["small intestine"] = "small intestine"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32834"] = "EMAPA_32834"


class _Telencephalon_Septum(_MouseAnatomicalStructureModel):
    """Model telencephalon septum"""

    name: Literal["telencephalon septum"] = "telencephalon septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32837"] = "EMAPA_32837"


class _Dermatome(_MouseAnatomicalStructureModel):
    """Model dermatome"""

    name: Literal["dermatome"] = "dermatome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32838"] = "EMAPA_32838"


class _Lip(_MouseAnatomicalStructureModel):
    """Model lip"""

    name: Literal["lip"] = "lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32839"] = "EMAPA_32839"


class _Trunk_Dermatome(_MouseAnatomicalStructureModel):
    """Model trunk dermatome"""

    name: Literal["trunk dermatome"] = "trunk dermatome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32840"] = "EMAPA_32840"


class _Myotome(_MouseAnatomicalStructureModel):
    """Model myotome"""

    name: Literal["myotome"] = "myotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32841"] = "EMAPA_32841"


class _Neocortex(_MouseAnatomicalStructureModel):
    """Model neocortex"""

    name: Literal["neocortex"] = "neocortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32842"] = "EMAPA_32842"


class _Trunk_Myotome(_MouseAnatomicalStructureModel):
    """Model trunk myotome"""

    name: Literal["trunk myotome"] = "trunk myotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32843"] = "EMAPA_32843"


class _Myelencephalon_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model myelencephalon ventricular layer"""

    name: Literal["myelencephalon ventricular layer"] = "myelencephalon ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32844"] = "EMAPA_32844"


class _Hippocampus(_MouseAnatomicalStructureModel):
    """Model hippocampus"""

    name: Literal["hippocampus"] = "hippocampus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32845"] = "EMAPA_32845"


class _Ganglion(_MouseAnatomicalStructureModel):
    """Model ganglion"""

    name: Literal["ganglion"] = "ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32846"] = "EMAPA_32846"


class _Myenteric_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model myenteric nerve plexus"""

    name: Literal["myenteric nerve plexus"] = "myenteric nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32847"] = "EMAPA_32847"


class _Medulla_Oblongata_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata mantle layer"""

    name: Literal["medulla oblongata mantle layer"] = "medulla oblongata mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32848"] = "EMAPA_32848"


class _Metacarpus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model metacarpus cartilage condensation"""

    name: Literal["metacarpus cartilage condensation"] = "metacarpus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32849"] = "EMAPA_32849"


class _Metacarpus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model metacarpus pre-cartilage condensation"""

    name: Literal["metacarpus pre-cartilage condensation"] = "metacarpus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32850"] = "EMAPA_32850"


class _Medulla_Oblongata_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata ventricular layer"""

    name: Literal["medulla oblongata ventricular layer"] = "medulla oblongata ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32851"] = "EMAPA_32851"


class _Medulla_Oblongata_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model medulla oblongata marginal layer"""

    name: Literal["medulla oblongata marginal layer"] = "medulla oblongata marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32852"] = "EMAPA_32852"


class _Metencephalon_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon ventricular layer"""

    name: Literal["metencephalon ventricular layer"] = "metencephalon ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32855"] = "EMAPA_32855"


class _Mesothelium(_MouseAnatomicalStructureModel):
    """Model mesothelium"""

    name: Literal["mesothelium"] = "mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32856"] = "EMAPA_32856"


class _Midbrain_Hindbrain_Junction(_MouseAnatomicalStructureModel):
    """Model midbrain-hindbrain junction"""

    name: Literal["midbrain-hindbrain junction"] = "midbrain-hindbrain junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32857"] = "EMAPA_32857"


class _Upper_Jaw_Tooth_Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model upper jaw tooth enamel organ"""

    name: Literal["upper jaw tooth enamel organ"] = "upper jaw tooth enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32858"] = "EMAPA_32858"


class _Upper_Jaw_Tooth_Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model upper jaw tooth dental lamina"""

    name: Literal["upper jaw tooth dental lamina"] = "upper jaw tooth dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32859"] = "EMAPA_32859"


class _Lung_Epithelium(_MouseAnatomicalStructureModel):
    """Model lung epithelium"""

    name: Literal["lung epithelium"] = "lung epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32860"] = "EMAPA_32860"


class _Upper_Jaw_Tooth_Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model upper jaw tooth dental papilla"""

    name: Literal["upper jaw tooth dental papilla"] = "upper jaw tooth dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32861"] = "EMAPA_32861"


class _Upper_Jaw_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper jaw epithelium"""

    name: Literal["upper jaw epithelium"] = "upper jaw epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32862"] = "EMAPA_32862"


class _Lower_Jaw_Tooth_Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model lower jaw tooth dental papilla"""

    name: Literal["lower jaw tooth dental papilla"] = "lower jaw tooth dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32863"] = "EMAPA_32863"


class _Upper_Jaw_Tooth_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model upper jaw tooth mesenchyme"""

    name: Literal["upper jaw tooth mesenchyme"] = "upper jaw tooth mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32864"] = "EMAPA_32864"


class _Upper_Jaw_Tooth_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper jaw tooth epithelium"""

    name: Literal["upper jaw tooth epithelium"] = "upper jaw tooth epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32865"] = "EMAPA_32865"


class _Lung_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lung mesenchyme"""

    name: Literal["lung mesenchyme"] = "lung mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32866"] = "EMAPA_32866"


class _Lung_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model lung vascular element"""

    name: Literal["lung vascular element"] = "lung vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32867"] = "EMAPA_32867"


class _Lower_Jaw_Tooth_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower jaw tooth epithelium"""

    name: Literal["lower jaw tooth epithelium"] = "lower jaw tooth epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32868"] = "EMAPA_32868"


class _Superior_Colliculus(_MouseAnatomicalStructureModel):
    """Model superior colliculus"""

    name: Literal["superior colliculus"] = "superior colliculus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32869"] = "EMAPA_32869"


class _Inferior_Colliculus(_MouseAnatomicalStructureModel):
    """Model inferior colliculus"""

    name: Literal["inferior colliculus"] = "inferior colliculus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32870"] = "EMAPA_32870"


class _Lens_Epithelium(_MouseAnatomicalStructureModel):
    """Model lens epithelium"""

    name: Literal["lens epithelium"] = "lens epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32871"] = "EMAPA_32871"


class _Intestine_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model intestine mesenchyme"""

    name: Literal["intestine mesenchyme"] = "intestine mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32872"] = "EMAPA_32872"


class _Intestine_Epithelium(_MouseAnatomicalStructureModel):
    """Model intestine epithelium"""

    name: Literal["intestine epithelium"] = "intestine epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32873"] = "EMAPA_32873"


class _Intestine(_MouseAnatomicalStructureModel):
    """Model intestine"""

    name: Literal["intestine"] = "intestine"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32874"] = "EMAPA_32874"


class _Lower_Jaw_Tooth_Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model lower jaw tooth enamel organ"""

    name: Literal["lower jaw tooth enamel organ"] = "lower jaw tooth enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32875"] = "EMAPA_32875"


class _Lower_Jaw_Tooth_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower jaw tooth mesenchyme"""

    name: Literal["lower jaw tooth mesenchyme"] = "lower jaw tooth mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32876"] = "EMAPA_32876"


class _Lower_Jaw_Tooth_Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model lower jaw tooth dental lamina"""

    name: Literal["lower jaw tooth dental lamina"] = "lower jaw tooth dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32877"] = "EMAPA_32877"


class _Molar_Epithelium(_MouseAnatomicalStructureModel):
    """Model molar epithelium"""

    name: Literal["molar epithelium"] = "molar epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32878"] = "EMAPA_32878"


class _Molar_Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model molar dental lamina"""

    name: Literal["molar dental lamina"] = "molar dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32879"] = "EMAPA_32879"


class _Molar_Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model molar enamel organ"""

    name: Literal["molar enamel organ"] = "molar enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32880"] = "EMAPA_32880"


class _Molar_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model molar mesenchyme"""

    name: Literal["molar mesenchyme"] = "molar mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32881"] = "EMAPA_32881"


class _Molar_Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model molar dental papilla"""

    name: Literal["molar dental papilla"] = "molar dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32882"] = "EMAPA_32882"


class _Inner_Ear_Epithelium(_MouseAnatomicalStructureModel):
    """Model inner ear epithelium"""

    name: Literal["inner ear epithelium"] = "inner ear epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32883"] = "EMAPA_32883"


class _Vestibular_Component_Epithelium(_MouseAnatomicalStructureModel):
    """Model vestibular component epithelium"""

    name: Literal["vestibular component epithelium"] = "vestibular component epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32884"] = "EMAPA_32884"


class _Inner_Ear_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model inner ear mesenchyme"""

    name: Literal["inner ear mesenchyme"] = "inner ear mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32885"] = "EMAPA_32885"


class _Alimentary_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model alimentary system mesenchyme"""

    name: Literal["alimentary system mesenchyme"] = "alimentary system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32886"] = "EMAPA_32886"


class _Vestibular_Component_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model vestibular component mesenchyme"""

    name: Literal["vestibular component mesenchyme"] = "vestibular component mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32887"] = "EMAPA_32887"


class _Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model enamel organ"""

    name: Literal["enamel organ"] = "enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32888"] = "EMAPA_32888"


class _Incisor(_MouseAnatomicalStructureModel):
    """Model incisor"""

    name: Literal["incisor"] = "incisor"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32889"] = "EMAPA_32889"


class _Incisor_Epithelium(_MouseAnatomicalStructureModel):
    """Model incisor epithelium"""

    name: Literal["incisor epithelium"] = "incisor epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32890"] = "EMAPA_32890"


class _Tooth_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model tooth mesenchyme"""

    name: Literal["tooth mesenchyme"] = "tooth mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32891"] = "EMAPA_32891"


class _Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model dental papilla"""

    name: Literal["dental papilla"] = "dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32892"] = "EMAPA_32892"


class _Incisor_Dental_Papilla(_MouseAnatomicalStructureModel):
    """Model incisor dental papilla"""

    name: Literal["incisor dental papilla"] = "incisor dental papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32893"] = "EMAPA_32893"


class _Incisor_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model incisor mesenchyme"""

    name: Literal["incisor mesenchyme"] = "incisor mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32894"] = "EMAPA_32894"


class _Incisor_Enamel_Organ(_MouseAnatomicalStructureModel):
    """Model incisor enamel organ"""

    name: Literal["incisor enamel organ"] = "incisor enamel organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32895"] = "EMAPA_32895"


class _Incisor_Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model incisor dental lamina"""

    name: Literal["incisor dental lamina"] = "incisor dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32896"] = "EMAPA_32896"


class _Molar(_MouseAnatomicalStructureModel):
    """Model molar"""

    name: Literal["molar"] = "molar"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32897"] = "EMAPA_32897"


class _Hindbrain_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model hindbrain ventricular layer"""

    name: Literal["hindbrain ventricular layer"] = "hindbrain ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32898"] = "EMAPA_32898"


class _Hindbrain_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model hindbrain roof plate"""

    name: Literal["hindbrain roof plate"] = "hindbrain roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32899"] = "EMAPA_32899"


class _Hindbrain_Roof(_MouseAnatomicalStructureModel):
    """Model hindbrain roof"""

    name: Literal["hindbrain roof"] = "hindbrain roof"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32900"] = "EMAPA_32900"


class _Jaw_Primordium(_MouseAnatomicalStructureModel):
    """Model jaw primordium"""

    name: Literal["jaw primordium"] = "jaw primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32901"] = "EMAPA_32901"


class _Dental_Lamina(_MouseAnatomicalStructureModel):
    """Model dental lamina"""

    name: Literal["dental lamina"] = "dental lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32902"] = "EMAPA_32902"


class _Tooth_Epithelium(_MouseAnatomicalStructureModel):
    """Model tooth epithelium"""

    name: Literal["tooth epithelium"] = "tooth epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32903"] = "EMAPA_32903"


class _Jaw_Epithelium(_MouseAnatomicalStructureModel):
    """Model jaw epithelium"""

    name: Literal["jaw epithelium"] = "jaw epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32904"] = "EMAPA_32904"


class _Jaw(_MouseAnatomicalStructureModel):
    """Model jaw"""

    name: Literal["jaw"] = "jaw"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32905"] = "EMAPA_32905"


class _Tooth(_MouseAnatomicalStructureModel):
    """Model tooth"""

    name: Literal["tooth"] = "tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32906"] = "EMAPA_32906"


class _Jaw_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model jaw mesenchyme"""

    name: Literal["jaw mesenchyme"] = "jaw mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32907"] = "EMAPA_32907"


class _Gut_Lumen(_MouseAnatomicalStructureModel):
    """Model gut lumen"""

    name: Literal["gut lumen"] = "gut lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32908"] = "EMAPA_32908"


class _Gut_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model gut mesenchyme"""

    name: Literal["gut mesenchyme"] = "gut mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32909"] = "EMAPA_32909"


class _Gut_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model gut dorsal mesentery"""

    name: Literal["gut dorsal mesentery"] = "gut dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32910"] = "EMAPA_32910"


class _Gut_Mesentery(_MouseAnatomicalStructureModel):
    """Model gut mesentery"""

    name: Literal["gut mesentery"] = "gut mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32911"] = "EMAPA_32911"


class _Hindbrain_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model hindbrain lateral wall"""

    name: Literal["hindbrain lateral wall"] = "hindbrain lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32912"] = "EMAPA_32912"


class _Hindbrain_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model hindbrain floor plate"""

    name: Literal["hindbrain floor plate"] = "hindbrain floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32913"] = "EMAPA_32913"


class _Hindbrain_Basal_Plate(_MouseAnatomicalStructureModel):
    """Model hindbrain basal plate"""

    name: Literal["hindbrain basal plate"] = "hindbrain basal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32914"] = "EMAPA_32914"


class _Hindbrain_Alar_Plate(_MouseAnatomicalStructureModel):
    """Model hindbrain alar plate"""

    name: Literal["hindbrain alar plate"] = "hindbrain alar plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32915"] = "EMAPA_32915"


class _Hindbrain_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model hindbrain marginal layer"""

    name: Literal["hindbrain marginal layer"] = "hindbrain marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32916"] = "EMAPA_32916"


class _Hindbrain_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model hindbrain mantle layer"""

    name: Literal["hindbrain mantle layer"] = "hindbrain mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32917"] = "EMAPA_32917"


class _Fronto_Nasal_Process_Epithelium(_MouseAnatomicalStructureModel):
    """Model fronto-nasal process epithelium"""

    name: Literal["fronto-nasal process epithelium"] = "fronto-nasal process epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32918"] = "EMAPA_32918"


class _Future_Forebrain_Floor_Plate(_MouseAnatomicalStructureModel):
    """Model future forebrain floor plate"""

    name: Literal["future forebrain floor plate"] = "future forebrain floor plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32919"] = "EMAPA_32919"


class _Forebrain_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model forebrain marginal layer"""

    name: Literal["forebrain marginal layer"] = "forebrain marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32920"] = "EMAPA_32920"


class _Forebrain_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model forebrain ventricular layer"""

    name: Literal["forebrain ventricular layer"] = "forebrain ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32921"] = "EMAPA_32921"


class _Foregut_Epithelium(_MouseAnatomicalStructureModel):
    """Model foregut epithelium"""

    name: Literal["foregut epithelium"] = "foregut epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32922"] = "EMAPA_32922"


class _Foregut_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model foregut mesenchyme"""

    name: Literal["foregut mesenchyme"] = "foregut mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32923"] = "EMAPA_32923"


class _Pancreas_Parenchyma(_MouseAnatomicalStructureModel):
    """Model pancreas parenchyma"""

    name: Literal["pancreas parenchyma"] = "pancreas parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32925"] = "EMAPA_32925"


class _Islets_Of_Langerhans(_MouseAnatomicalStructureModel):
    """Model islets of Langerhans"""

    name: Literal["islets of Langerhans"] = "islets of Langerhans"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32927"] = "EMAPA_32927"


class _Gut_Epithelium(_MouseAnatomicalStructureModel):
    """Model gut epithelium"""

    name: Literal["gut epithelium"] = "gut epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32928"] = "EMAPA_32928"


class _Gut_Endoderm(_MouseAnatomicalStructureModel):
    """Model gut endoderm"""

    name: Literal["gut endoderm"] = "gut endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32930"] = "EMAPA_32930"


class _Future_Forebrain_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model future forebrain roof plate"""

    name: Literal["future forebrain roof plate"] = "future forebrain roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32935"] = "EMAPA_32935"


class _Future_Forebrain_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model future forebrain lateral wall"""

    name: Literal["future forebrain lateral wall"] = "future forebrain lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32937"] = "EMAPA_32937"


class _Hindlimb_Digit_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit pre-cartilage condensation"""

    name: Literal["hindlimb digit pre-cartilage condensation"] = "hindlimb digit pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32938"] = "EMAPA_32938"


class _Hindlimb_Digit_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb digit cartilage condensation"""

    name: Literal["hindlimb digit cartilage condensation"] = "hindlimb digit cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32939"] = "EMAPA_32939"


class _Metatarsus(_MouseAnatomicalStructureModel):
    """Model metatarsus"""

    name: Literal["metatarsus"] = "metatarsus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32940"] = "EMAPA_32940"


class _Hindlimb_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb phalanx"""

    name: Literal["hindlimb phalanx"] = "hindlimb phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32941"] = "EMAPA_32941"


class _Hindlimb_Digit_Skin(_MouseAnatomicalStructureModel):
    """Model hindlimb digit skin"""

    name: Literal["hindlimb digit skin"] = "hindlimb digit skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32942"] = "EMAPA_32942"


class _Hindlimb_Digit_Dermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit dermis"""

    name: Literal["hindlimb digit dermis"] = "hindlimb digit dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32943"] = "EMAPA_32943"


class _Hindlimb_Digit_Epidermis(_MouseAnatomicalStructureModel):
    """Model hindlimb digit epidermis"""

    name: Literal["hindlimb digit epidermis"] = "hindlimb digit epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32944"] = "EMAPA_32944"


class _Hindlimb_Interdigital_Region(_MouseAnatomicalStructureModel):
    """Model hindlimb interdigital region"""

    name: Literal["hindlimb interdigital region"] = "hindlimb interdigital region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32945"] = "EMAPA_32945"


class _Hindlimb_Digit_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindlimb digit epithelium"""

    name: Literal["hindlimb digit epithelium"] = "hindlimb digit epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32946"] = "EMAPA_32946"


class _Hindlimb_Digit_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb digit mesenchyme"""

    name: Literal["hindlimb digit mesenchyme"] = "hindlimb digit mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32947"] = "EMAPA_32947"


class _Hindlimb_Phalanx_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb phalanx cartilage condensation"""

    name: Literal["hindlimb phalanx cartilage condensation"] = "hindlimb phalanx cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32948"] = "EMAPA_32948"


class _Foot_Joint(_MouseAnatomicalStructureModel):
    """Model foot joint"""

    name: Literal["foot joint"] = "foot joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32949"] = "EMAPA_32949"


class _Hindlimb_Phalanx_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model hindlimb phalanx pre-cartilage condensation"""

    name: Literal["hindlimb phalanx pre-cartilage condensation"] = "hindlimb phalanx pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32950"] = "EMAPA_32950"


class _Metatarsus_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model metatarsus cartilage condensation"""

    name: Literal["metatarsus cartilage condensation"] = "metatarsus cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32951"] = "EMAPA_32951"


class _Pancreatic_Duct(_MouseAnatomicalStructureModel):
    """Model pancreatic duct"""

    name: Literal["pancreatic duct"] = "pancreatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32952"] = "EMAPA_32952"


class _Dorsal_Pancreatic_Duct(_MouseAnatomicalStructureModel):
    """Model dorsal pancreatic duct"""

    name: Literal["dorsal pancreatic duct"] = "dorsal pancreatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32953"] = "EMAPA_32953"


class _Hindlimb_Interdigital_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hindlimb interdigital region mesenchyme"""

    name: Literal["hindlimb interdigital region mesenchyme"] = "hindlimb interdigital region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32955"] = "EMAPA_32955"


class _Metatarsus_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model metatarsus pre-cartilage condensation"""

    name: Literal["metatarsus pre-cartilage condensation"] = "metatarsus pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32956"] = "EMAPA_32956"


class _Hindlimb_Interdigital_Region_Epithelium(_MouseAnatomicalStructureModel):
    """Model hindlimb interdigital region epithelium"""

    name: Literal["hindlimb interdigital region epithelium"] = "hindlimb interdigital region epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_32957"] = "EMAPA_32957"


class _Nerve_Of_Uterus(_MouseAnatomicalStructureModel):
    """Model nerve of uterus"""

    name: Literal["nerve of uterus"] = "nerve of uterus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35041"] = "EMAPA_35041"


class _Nerve_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of primitive bladder"""

    name: Literal["nerve of primitive bladder"] = "nerve of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35042"] = "EMAPA_35042"


class _Nerve_Of_Labia(_MouseAnatomicalStructureModel):
    """Model nerve of labia"""

    name: Literal["nerve of labia"] = "nerve of labia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35043"] = "EMAPA_35043"


class _Nerve_Of_Clitoris(_MouseAnatomicalStructureModel):
    """Model nerve of clitoris"""

    name: Literal["nerve of clitoris"] = "nerve of clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35044"] = "EMAPA_35044"


class _Nerve_Of_Genital_Tubercle_Of_Female(_MouseAnatomicalStructureModel):
    """Model nerve of genital tubercle of female"""

    name: Literal["nerve of genital tubercle of female"] = "nerve of genital tubercle of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35045"] = "EMAPA_35045"


class _Nerve_Of_Vagina(_MouseAnatomicalStructureModel):
    """Model nerve of vagina"""

    name: Literal["nerve of vagina"] = "nerve of vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35046"] = "EMAPA_35046"


class _Nerve_Of_Epididymis(_MouseAnatomicalStructureModel):
    """Model nerve of epididymis"""

    name: Literal["nerve of epididymis"] = "nerve of epididymis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35047"] = "EMAPA_35047"


class _Nerve_Of_Seminal_Vesicle(_MouseAnatomicalStructureModel):
    """Model nerve of seminal vesicle"""

    name: Literal["nerve of seminal vesicle"] = "nerve of seminal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35048"] = "EMAPA_35048"


class _Nerve_Of_Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model nerve of ductus deferens"""

    name: Literal["nerve of ductus deferens"] = "nerve of ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35049"] = "EMAPA_35049"


class _Nerve_Of_Scrotum(_MouseAnatomicalStructureModel):
    """Model nerve of scrotum"""

    name: Literal["nerve of scrotum"] = "nerve of scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35050"] = "EMAPA_35050"


class _Nerve_Of_Ovary(_MouseAnatomicalStructureModel):
    """Model nerve of ovary"""

    name: Literal["nerve of ovary"] = "nerve of ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35051"] = "EMAPA_35051"


class _Nerve_Of_Oviduct(_MouseAnatomicalStructureModel):
    """Model nerve of oviduct"""

    name: Literal["nerve of oviduct"] = "nerve of oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35052"] = "EMAPA_35052"


class _Nerve_Of_Uterine_Horn(_MouseAnatomicalStructureModel):
    """Model nerve of uterine horn"""

    name: Literal["nerve of uterine horn"] = "nerve of uterine horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35053"] = "EMAPA_35053"


class _Nerve_Of_Ejaculatory_Duct(_MouseAnatomicalStructureModel):
    """Model nerve of ejaculatory duct"""

    name: Literal["nerve of ejaculatory duct"] = "nerve of ejaculatory duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35054"] = "EMAPA_35054"


class _Nerve_Of_Bulbourethral_Gland_Of_Male(_MouseAnatomicalStructureModel):
    """Model nerve of bulbourethral gland of male"""

    name: Literal["nerve of bulbourethral gland of male"] = "nerve of bulbourethral gland of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35055"] = "EMAPA_35055"


class _Nerve_Of_Genital_Tubercle_Of_Male(_MouseAnatomicalStructureModel):
    """Model nerve of genital tubercle of male"""

    name: Literal["nerve of genital tubercle of male"] = "nerve of genital tubercle of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35056"] = "EMAPA_35056"


class _Nerve_Of_Penis(_MouseAnatomicalStructureModel):
    """Model nerve of penis"""

    name: Literal["nerve of penis"] = "nerve of penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35057"] = "EMAPA_35057"


class _Nerve_Of_Penile_Urethra(_MouseAnatomicalStructureModel):
    """Model nerve of penile urethra"""

    name: Literal["nerve of penile urethra"] = "nerve of penile urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35058"] = "EMAPA_35058"


class _Nerve_Of_Ureter(_MouseAnatomicalStructureModel):
    """Model nerve of ureter"""

    name: Literal["nerve of ureter"] = "nerve of ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35059"] = "EMAPA_35059"


class _3Rd_Ventricle_Ependyma(_MouseAnatomicalStructureModel):
    """Model 3rd ventricle ependyma"""

    name: Literal["3rd ventricle ependyma"] = "3rd ventricle ependyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35100"] = "EMAPA_35100"


class _6Th_Branchial_Arch_Ectoderm(_MouseAnatomicalStructureModel):
    """Model 6th branchial arch ectoderm"""

    name: Literal["6th branchial arch ectoderm"] = "6th branchial arch ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35101"] = "EMAPA_35101"


class _Abdomen(_MouseAnatomicalStructureModel):
    """Model abdomen"""

    name: Literal["abdomen"] = "abdomen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35102"] = "EMAPA_35102"


class _Abdomen_Musculature(_MouseAnatomicalStructureModel):
    """Model abdomen musculature"""

    name: Literal["abdomen musculature"] = "abdomen musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35103"] = "EMAPA_35103"


class _Abdominal_Segment_Of_Trunk(_MouseAnatomicalStructureModel):
    """Model abdominal segment of trunk"""

    name: Literal["abdominal segment of trunk"] = "abdominal segment of trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35104"] = "EMAPA_35104"


class _Abducens_Nucleus(_MouseAnatomicalStructureModel):
    """Model abducens nucleus"""

    name: Literal["abducens nucleus"] = "abducens nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35105"] = "EMAPA_35105"


class _Accessory_Olfactory_Bulb(_MouseAnatomicalStructureModel):
    """Model accessory olfactory bulb"""

    name: Literal["accessory olfactory bulb"] = "accessory olfactory bulb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35106"] = "EMAPA_35106"


class _Accessory_Olfactory_Bulb_External_Plexiform_Layer(_MouseAnatomicalStructureModel):
    """Model accessory olfactory bulb external plexiform layer"""

    name: Literal[
        "accessory olfactory bulb external plexiform layer"
    ] = "accessory olfactory bulb external plexiform layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35107"] = "EMAPA_35107"


class _Accessory_Olfactory_Bulb_Glomerular_Layer(_MouseAnatomicalStructureModel):
    """Model accessory olfactory bulb glomerular layer"""

    name: Literal["accessory olfactory bulb glomerular layer"] = "accessory olfactory bulb glomerular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35108"] = "EMAPA_35108"


class _Accessory_Olfactory_Bulb_Granule_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model accessory olfactory bulb granule cell layer"""

    name: Literal["accessory olfactory bulb granule cell layer"] = "accessory olfactory bulb granule cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35109"] = "EMAPA_35109"


class _Accessory_Olfactory_Bulb_Internal_Plexiform_Layer(_MouseAnatomicalStructureModel):
    """Model accessory olfactory bulb internal plexiform layer"""

    name: Literal[
        "accessory olfactory bulb internal plexiform layer"
    ] = "accessory olfactory bulb internal plexiform layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35110"] = "EMAPA_35110"


class _Accessory_Olfactory_Bulb_Mitral_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model accessory olfactory bulb mitral cell layer"""

    name: Literal["accessory olfactory bulb mitral cell layer"] = "accessory olfactory bulb mitral cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35111"] = "EMAPA_35111"


class _Adipose_Tissue(_MouseAnatomicalStructureModel):
    """Model adipose tissue"""

    name: Literal["adipose tissue"] = "adipose tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35112"] = "EMAPA_35112"


class _Adrenal_Cortex_Zone(_MouseAnatomicalStructureModel):
    """Model adrenal cortex zone"""

    name: Literal["adrenal cortex zone"] = "adrenal cortex zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35113"] = "EMAPA_35113"


class _Adrenal_Gland_Zona_Fasciculata(_MouseAnatomicalStructureModel):
    """Model adrenal gland zona fasciculata"""

    name: Literal["adrenal gland zona fasciculata"] = "adrenal gland zona fasciculata"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35114"] = "EMAPA_35114"


class _Adrenal_Gland_Zona_Glomerulosa(_MouseAnatomicalStructureModel):
    """Model adrenal gland zona glomerulosa"""

    name: Literal["adrenal gland zona glomerulosa"] = "adrenal gland zona glomerulosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35115"] = "EMAPA_35115"


class _Adrenal_Gland_Zona_Reticularis(_MouseAnatomicalStructureModel):
    """Model adrenal gland zona reticularis"""

    name: Literal["adrenal gland zona reticularis"] = "adrenal gland zona reticularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35116"] = "EMAPA_35116"


class _Alimentary_System_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model alimentary system smooth muscle"""

    name: Literal["alimentary system smooth muscle"] = "alimentary system smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35117"] = "EMAPA_35117"


class _Alveolar_Process(_MouseAnatomicalStructureModel):
    """Model alveolar process"""

    name: Literal["alveolar process"] = "alveolar process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35118"] = "EMAPA_35118"


class _Alveolar_Sac(_MouseAnatomicalStructureModel):
    """Model alveolar sac"""

    name: Literal["alveolar sac"] = "alveolar sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35119"] = "EMAPA_35119"


class _Alveolar_Wall(_MouseAnatomicalStructureModel):
    """Model alveolar wall"""

    name: Literal["alveolar wall"] = "alveolar wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35120"] = "EMAPA_35120"


class _Alveolus_Epithelium(_MouseAnatomicalStructureModel):
    """Model alveolus epithelium"""

    name: Literal["alveolus epithelium"] = "alveolus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35121"] = "EMAPA_35121"


class _Alveolus_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model alveolus smooth muscle"""

    name: Literal["alveolus smooth muscle"] = "alveolus smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35122"] = "EMAPA_35122"


class _Ampullary_Gland(_MouseAnatomicalStructureModel):
    """Model ampullary gland"""

    name: Literal["ampullary gland"] = "ampullary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35123"] = "EMAPA_35123"


class _Amygdalohippocampal_Area(_MouseAnatomicalStructureModel):
    """Model amygdalohippocampal area"""

    name: Literal["amygdalohippocampal area"] = "amygdalohippocampal area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35124"] = "EMAPA_35124"


class _Amygdalopiriform_Transition_Area(_MouseAnatomicalStructureModel):
    """Model amygdalopiriform transition area"""

    name: Literal["amygdalopiriform transition area"] = "amygdalopiriform transition area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35125"] = "EMAPA_35125"


class _Ankle_Joint(_MouseAnatomicalStructureModel):
    """Model ankle joint"""

    name: Literal["ankle joint"] = "ankle joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35126"] = "EMAPA_35126"


class _Anterior_Amygdaloid_Area(_MouseAnatomicalStructureModel):
    """Model anterior amygdaloid area"""

    name: Literal["anterior amygdaloid area"] = "anterior amygdaloid area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35127"] = "EMAPA_35127"


class _Anterior_Cortical_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model anterior cortical amygdaloid nucleus"""

    name: Literal["anterior cortical amygdaloid nucleus"] = "anterior cortical amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35128"] = "EMAPA_35128"


class _Anterior_Dorsal_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model anterior dorsal thalamic nucleus"""

    name: Literal["anterior dorsal thalamic nucleus"] = "anterior dorsal thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35129"] = "EMAPA_35129"


class _Anterior_Medial_Cortex(_MouseAnatomicalStructureModel):
    """Model anterior medial cortex"""

    name: Literal["anterior medial cortex"] = "anterior medial cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35130"] = "EMAPA_35130"


class _Anterior_Olfactory_Nucleus(_MouseAnatomicalStructureModel):
    """Model anterior olfactory nucleus"""

    name: Literal["anterior olfactory nucleus"] = "anterior olfactory nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35131"] = "EMAPA_35131"


class _Anterior_Thalamic_Group(_MouseAnatomicalStructureModel):
    """Model anterior thalamic group"""

    name: Literal["anterior thalamic group"] = "anterior thalamic group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35132"] = "EMAPA_35132"


class _Anterior_Ventral_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model anterior ventral thalamic nucleus"""

    name: Literal["anterior ventral thalamic nucleus"] = "anterior ventral thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35133"] = "EMAPA_35133"


class _Aorta_Endothelium(_MouseAnatomicalStructureModel):
    """Model aorta endothelium"""

    name: Literal["aorta endothelium"] = "aorta endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35134"] = "EMAPA_35134"


class _Aorta_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model aorta smooth muscle"""

    name: Literal["aorta smooth muscle"] = "aorta smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35135"] = "EMAPA_35135"


class _Aorta_Tunica_Adventitia(_MouseAnatomicalStructureModel):
    """Model aorta tunica adventitia"""

    name: Literal["aorta tunica adventitia"] = "aorta tunica adventitia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35136"] = "EMAPA_35136"


class _Aorta_Tunica_Intima(_MouseAnatomicalStructureModel):
    """Model aorta tunica intima"""

    name: Literal["aorta tunica intima"] = "aorta tunica intima"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35137"] = "EMAPA_35137"


class _Aorta_Tunica_Media(_MouseAnatomicalStructureModel):
    """Model aorta tunica media"""

    name: Literal["aorta tunica media"] = "aorta tunica media"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35138"] = "EMAPA_35138"


class _Aorta_Wall(_MouseAnatomicalStructureModel):
    """Model aorta wall"""

    name: Literal["aorta wall"] = "aorta wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35139"] = "EMAPA_35139"


class _Apex_Of_Cecum(_MouseAnatomicalStructureModel):
    """Model apex of cecum"""

    name: Literal["apex of cecum"] = "apex of cecum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35140"] = "EMAPA_35140"


class _Apocrine_Gland(_MouseAnatomicalStructureModel):
    """Model apocrine gland"""

    name: Literal["apocrine gland"] = "apocrine gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35141"] = "EMAPA_35141"


class _Arcuate_Nucleus(_MouseAnatomicalStructureModel):
    """Model arcuate nucleus"""

    name: Literal["arcuate nucleus"] = "arcuate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35142"] = "EMAPA_35142"


class _Area_Postrema(_MouseAnatomicalStructureModel):
    """Model area postrema"""

    name: Literal["area postrema"] = "area postrema"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35143"] = "EMAPA_35143"


class _Arterial_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model arterial blood vessel"""

    name: Literal["arterial blood vessel"] = "arterial blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35144"] = "EMAPA_35144"


class _Arterial_System_Endothelium(_MouseAnatomicalStructureModel):
    """Model arterial system endothelium"""

    name: Literal["arterial system endothelium"] = "arterial system endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35145"] = "EMAPA_35145"


class _Arteriole(_MouseAnatomicalStructureModel):
    """Model arteriole"""

    name: Literal["arteriole"] = "arteriole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35146"] = "EMAPA_35146"


class _Artery(_MouseAnatomicalStructureModel):
    """Model artery"""

    name: Literal["artery"] = "artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35147"] = "EMAPA_35147"


class _Artery_Endothelium(_MouseAnatomicalStructureModel):
    """Model artery endothelium"""

    name: Literal["artery endothelium"] = "artery endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35148"] = "EMAPA_35148"


class _Articular_Cartilage(_MouseAnatomicalStructureModel):
    """Model articular cartilage"""

    name: Literal["articular cartilage"] = "articular cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35149"] = "EMAPA_35149"


class _Articular_System(_MouseAnatomicalStructureModel):
    """Model articular system"""

    name: Literal["articular system"] = "articular system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35150"] = "EMAPA_35150"


class _Ascending_Colon(_MouseAnatomicalStructureModel):
    """Model ascending colon"""

    name: Literal["ascending colon"] = "ascending colon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35151"] = "EMAPA_35151"


class _Atrioventricular_Bundle(_MouseAnatomicalStructureModel):
    """Model atrioventricular bundle"""

    name: Literal["atrioventricular bundle"] = "atrioventricular bundle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35152"] = "EMAPA_35152"


class _Atrioventricular_Node(_MouseAnatomicalStructureModel):
    """Model atrioventricular node"""

    name: Literal["atrioventricular node"] = "atrioventricular node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35153"] = "EMAPA_35153"


class _Atrioventricular_Valve(_MouseAnatomicalStructureModel):
    """Model atrioventricular valve"""

    name: Literal["atrioventricular valve"] = "atrioventricular valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35154"] = "EMAPA_35154"


class _Right_Lung_Lobe(_MouseAnatomicalStructureModel):
    """Model right lung lobe"""

    name: Literal["right lung lobe"] = "right lung lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35155"] = "EMAPA_35155"


class _Auditory_Cortex(_MouseAnatomicalStructureModel):
    """Model auditory cortex"""

    name: Literal["auditory cortex"] = "auditory cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35156"] = "EMAPA_35156"


class _Pinna_Cartilage(_MouseAnatomicalStructureModel):
    """Model pinna cartilage"""

    name: Literal["pinna cartilage"] = "pinna cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35158"] = "EMAPA_35158"


class _Pinna_Muscle(_MouseAnatomicalStructureModel):
    """Model pinna muscle"""

    name: Literal["pinna muscle"] = "pinna muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35159"] = "EMAPA_35159"


class _Autopod_Joint(_MouseAnatomicalStructureModel):
    """Model autopod joint"""

    name: Literal["autopod joint"] = "autopod joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35160"] = "EMAPA_35160"


class _Back_Musculature(_MouseAnatomicalStructureModel):
    """Model back musculature"""

    name: Literal["back musculature"] = "back musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35161"] = "EMAPA_35161"


class _Back_Of_Trunk(_MouseAnatomicalStructureModel):
    """Model back of trunk"""

    name: Literal["back of trunk"] = "back of trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35162"] = "EMAPA_35162"


class _Barrel_Cortex(_MouseAnatomicalStructureModel):
    """Model barrel cortex"""

    name: Literal["barrel cortex"] = "barrel cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35163"] = "EMAPA_35163"


class _Basal_Forebrain(_MouseAnatomicalStructureModel):
    """Model basal forebrain"""

    name: Literal["basal forebrain"] = "basal forebrain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35164"] = "EMAPA_35164"


class _Basal_Ventral_Medial_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model basal ventral medial thalamic nucleus"""

    name: Literal["basal ventral medial thalamic nucleus"] = "basal ventral medial thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35165"] = "EMAPA_35165"


class _Basilar_Membrane(_MouseAnatomicalStructureModel):
    """Model basilar membrane"""

    name: Literal["basilar membrane"] = "basilar membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35166"] = "EMAPA_35166"


class _Basolateral_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model basolateral amygdaloid nucleus"""

    name: Literal["basolateral amygdaloid nucleus"] = "basolateral amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35167"] = "EMAPA_35167"


class _Basomedial_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model basomedial amygdaloid nucleus"""

    name: Literal["basomedial amygdaloid nucleus"] = "basomedial amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35168"] = "EMAPA_35168"


class _Bed_Nucleus_Of_Stria_Terminalis(_MouseAnatomicalStructureModel):
    """Model bed nucleus of stria terminalis"""

    name: Literal["bed nucleus of stria terminalis"] = "bed nucleus of stria terminalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35169"] = "EMAPA_35169"


class _Biceps_Femoris(_MouseAnatomicalStructureModel):
    """Model biceps femoris"""

    name: Literal["biceps femoris"] = "biceps femoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35170"] = "EMAPA_35170"


class _Bile_Duct(_MouseAnatomicalStructureModel):
    """Model bile duct"""

    name: Literal["bile duct"] = "bile duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35171"] = "EMAPA_35171"


class _Biliary_Tract(_MouseAnatomicalStructureModel):
    """Model biliary tract"""

    name: Literal["biliary tract"] = "biliary tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35172"] = "EMAPA_35172"


class _Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model bladder fundus"""

    name: Literal["bladder fundus"] = "bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35173"] = "EMAPA_35173"


class _Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model bladder trigone"""

    name: Literal["bladder trigone"] = "bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35174"] = "EMAPA_35174"


class _Bladder_Wall(_MouseAnatomicalStructureModel):
    """Model bladder wall"""

    name: Literal["bladder wall"] = "bladder wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35175"] = "EMAPA_35175"


class _Blood_Vessel_Endothelium(_MouseAnatomicalStructureModel):
    """Model blood vessel endothelium"""

    name: Literal["blood vessel endothelium"] = "blood vessel endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35176"] = "EMAPA_35176"


class _Blood_Vessel_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model blood vessel smooth muscle"""

    name: Literal["blood vessel smooth muscle"] = "blood vessel smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35177"] = "EMAPA_35177"


class _Body_Fluid_Or_Substance(_MouseAnatomicalStructureModel):
    """Model body fluid or substance"""

    name: Literal["body fluid or substance"] = "body fluid or substance"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35178"] = "EMAPA_35178"


class _Bone_Tissue(_MouseAnatomicalStructureModel):
    """Model bone tissue"""

    name: Literal["bone tissue"] = "bone tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35179"] = "EMAPA_35179"


class _Brain_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model brain blood vessel"""

    name: Literal["brain blood vessel"] = "brain blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35182"] = "EMAPA_35182"


class _Brain_Ependyma(_MouseAnatomicalStructureModel):
    """Model brain ependyma"""

    name: Literal["brain ependyma"] = "brain ependyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35183"] = "EMAPA_35183"


class _Brain_Gray_Matter(_MouseAnatomicalStructureModel):
    """Model brain gray matter"""

    name: Literal["brain gray matter"] = "brain gray matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35184"] = "EMAPA_35184"


class _Brain_Nucleus(_MouseAnatomicalStructureModel):
    """Model brain nucleus"""

    name: Literal["brain nucleus"] = "brain nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35185"] = "EMAPA_35185"


class _Brain_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model brain vascular element"""

    name: Literal["brain vascular element"] = "brain vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35186"] = "EMAPA_35186"


class _Brain_White_Matter(_MouseAnatomicalStructureModel):
    """Model brain white matter"""

    name: Literal["brain white matter"] = "brain white matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35187"] = "EMAPA_35187"


class _Brainstem_Reticular_Formation(_MouseAnatomicalStructureModel):
    """Model brainstem reticular formation"""

    name: Literal["brainstem reticular formation"] = "brainstem reticular formation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35188"] = "EMAPA_35188"


class _Brainstem_White_Matter(_MouseAnatomicalStructureModel):
    """Model brainstem white matter"""

    name: Literal["brainstem white matter"] = "brainstem white matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35189"] = "EMAPA_35189"


class _Branchial_Groove_Ectoderm(_MouseAnatomicalStructureModel):
    """Model branchial groove ectoderm"""

    name: Literal["branchial groove ectoderm"] = "branchial groove ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35190"] = "EMAPA_35190"


class _Branchial_Pouch_Endoderm(_MouseAnatomicalStructureModel):
    """Model branchial pouch endoderm"""

    name: Literal["branchial pouch endoderm"] = "branchial pouch endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35191"] = "EMAPA_35191"


class _Bronchus_Cartilage(_MouseAnatomicalStructureModel):
    """Model bronchus cartilage"""

    name: Literal["bronchus cartilage"] = "bronchus cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35192"] = "EMAPA_35192"


class _Bronchus_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model bronchus connective tissue"""

    name: Literal["bronchus connective tissue"] = "bronchus connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35193"] = "EMAPA_35193"


class _Bronchus_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model bronchus lamina propria"""

    name: Literal["bronchus lamina propria"] = "bronchus lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35194"] = "EMAPA_35194"


class _Bronchus_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model bronchus smooth muscle"""

    name: Literal["bronchus smooth muscle"] = "bronchus smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35195"] = "EMAPA_35195"


class _Ca1_Pyramidal_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model CA1 pyramidal cell layer"""

    name: Literal["CA1 pyramidal cell layer"] = "CA1 pyramidal cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35196"] = "EMAPA_35196"


class _Cecum(_MouseAnatomicalStructureModel):
    """Model cecum"""

    name: Literal["cecum"] = "cecum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35197"] = "EMAPA_35197"


class _Capillary(_MouseAnatomicalStructureModel):
    """Model capillary"""

    name: Literal["capillary"] = "capillary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35198"] = "EMAPA_35198"


class _Cardiovascular_System_Endothelium(_MouseAnatomicalStructureModel):
    """Model cardiovascular system endothelium"""

    name: Literal["cardiovascular system endothelium"] = "cardiovascular system endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35201"] = "EMAPA_35201"


class _Celiac_Artery(_MouseAnatomicalStructureModel):
    """Model celiac artery"""

    name: Literal["celiac artery"] = "celiac artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35202"] = "EMAPA_35202"


class _Cementum(_MouseAnatomicalStructureModel):
    """Model cementum"""

    name: Literal["cementum"] = "cementum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35203"] = "EMAPA_35203"


class _Central_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model central amygdaloid nucleus"""

    name: Literal["central amygdaloid nucleus"] = "central amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35204"] = "EMAPA_35204"


class _Central_Lateral_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model central lateral thalamic nucleus"""

    name: Literal["central lateral thalamic nucleus"] = "central lateral thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35205"] = "EMAPA_35205"


class _Central_Medial_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model central medial thalamic nucleus"""

    name: Literal["central medial thalamic nucleus"] = "central medial thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35206"] = "EMAPA_35206"


class _Central_Nervous_System_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model central nervous system roof plate"""

    name: Literal["central nervous system roof plate"] = "central nervous system roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35207"] = "EMAPA_35207"


class _Central_Nervous_System_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model central nervous system vascular element"""

    name: Literal["central nervous system vascular element"] = "central nervous system vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35208"] = "EMAPA_35208"


class _Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model ventricular layer"""

    name: Literal["ventricular layer"] = "ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35209"] = "EMAPA_35209"


class _Central_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model central thalamic nucleus"""

    name: Literal["central thalamic nucleus"] = "central thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35210"] = "EMAPA_35210"


class _Cerebellar_Cortex(_MouseAnatomicalStructureModel):
    """Model cerebellar cortex"""

    name: Literal["cerebellar cortex"] = "cerebellar cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35211"] = "EMAPA_35211"


class _Cerebellum_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum layer"""

    name: Literal["cerebellum layer"] = "cerebellum layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35212"] = "EMAPA_35212"


class _Cerebellar_Peduncle(_MouseAnatomicalStructureModel):
    """Model cerebellar peduncle"""

    name: Literal["cerebellar peduncle"] = "cerebellar peduncle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35213"] = "EMAPA_35213"


class _Cerebellum_Vermis(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis"""

    name: Literal["cerebellum vermis"] = "cerebellum vermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35214"] = "EMAPA_35214"


class _Cerebellum_Anterior_Lobe(_MouseAnatomicalStructureModel):
    """Model cerebellum anterior lobe"""

    name: Literal["cerebellum anterior lobe"] = "cerebellum anterior lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35215"] = "EMAPA_35215"


class _Cerebellum_External_Granule_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum external granule cell layer"""

    name: Literal["cerebellum external granule cell layer"] = "cerebellum external granule cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35216"] = "EMAPA_35216"


class _Cerebellum_Granule_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum granule cell layer"""

    name: Literal["cerebellum granule cell layer"] = "cerebellum granule cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35217"] = "EMAPA_35217"


class _Cerebellar_Hemisphere(_MouseAnatomicalStructureModel):
    """Model cerebellar hemisphere"""

    name: Literal["cerebellar hemisphere"] = "cerebellar hemisphere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35218"] = "EMAPA_35218"


class _Cerebellum_Internal_Granule_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum internal granule cell layer"""

    name: Literal["cerebellum internal granule cell layer"] = "cerebellum internal granule cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35219"] = "EMAPA_35219"


class _Cerebellum_Lobe(_MouseAnatomicalStructureModel):
    """Model cerebellum lobe"""

    name: Literal["cerebellum lobe"] = "cerebellum lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35220"] = "EMAPA_35220"


class _Cerebellum_Molecular_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum molecular layer"""

    name: Literal["cerebellum molecular layer"] = "cerebellum molecular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35221"] = "EMAPA_35221"


class _Cerebellum_Posterior_Lobe(_MouseAnatomicalStructureModel):
    """Model cerebellum posterior lobe"""

    name: Literal["cerebellum posterior lobe"] = "cerebellum posterior lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35222"] = "EMAPA_35222"


class _Cerebellum_Purkinje_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model cerebellum Purkinje cell layer"""

    name: Literal["cerebellum Purkinje cell layer"] = "cerebellum Purkinje cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35223"] = "EMAPA_35223"


class _Cerebellum_Vermis_Lobule(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule"""

    name: Literal["cerebellum vermis lobule"] = "cerebellum vermis lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35224"] = "EMAPA_35224"


class _Cerebellum_Vermis_Lobule_I(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule I"""

    name: Literal["cerebellum vermis lobule I"] = "cerebellum vermis lobule I"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35225"] = "EMAPA_35225"


class _Cerebellum_Vermis_Lobule_Ii(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule II"""

    name: Literal["cerebellum vermis lobule II"] = "cerebellum vermis lobule II"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35226"] = "EMAPA_35226"


class _Cerebellum_Vermis_Lobule_Iii(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule III"""

    name: Literal["cerebellum vermis lobule III"] = "cerebellum vermis lobule III"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35227"] = "EMAPA_35227"


class _Cerebellum_Vermis_Lobule_Iv(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule IV"""

    name: Literal["cerebellum vermis lobule IV"] = "cerebellum vermis lobule IV"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35228"] = "EMAPA_35228"


class _Cerebellum_Vermis_Lobule_Ix(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule IX"""

    name: Literal["cerebellum vermis lobule IX"] = "cerebellum vermis lobule IX"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35229"] = "EMAPA_35229"


class _Cerebellum_Vermis_Lobule_V(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule V"""

    name: Literal["cerebellum vermis lobule V"] = "cerebellum vermis lobule V"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35230"] = "EMAPA_35230"


class _Cerebellum_Vermis_Lobule_Vi(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule VI"""

    name: Literal["cerebellum vermis lobule VI"] = "cerebellum vermis lobule VI"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35231"] = "EMAPA_35231"


class _Cerebellum_Vermis_Lobule_Vii(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule VII"""

    name: Literal["cerebellum vermis lobule VII"] = "cerebellum vermis lobule VII"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35232"] = "EMAPA_35232"


class _Cerebellum_Vermis_Lobule_Viii(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule VIII"""

    name: Literal["cerebellum vermis lobule VIII"] = "cerebellum vermis lobule VIII"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35233"] = "EMAPA_35233"


class _Cerebellum_Vermis_Lobule_X(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule X"""

    name: Literal["cerebellum vermis lobule X"] = "cerebellum vermis lobule X"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35234"] = "EMAPA_35234"


class _Cerebellum_White_Matter(_MouseAnatomicalStructureModel):
    """Model cerebellum white matter"""

    name: Literal["cerebellum white matter"] = "cerebellum white matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35235"] = "EMAPA_35235"


class _Cerebral_Cortex_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model cerebral cortex vascular element"""

    name: Literal["cerebral cortex vascular element"] = "cerebral cortex vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35236"] = "EMAPA_35236"


class _Cerebral_Hemisphere_White_Matter(_MouseAnatomicalStructureModel):
    """Model cerebral hemisphere white matter"""

    name: Literal["cerebral hemisphere white matter"] = "cerebral hemisphere white matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35237"] = "EMAPA_35237"


class _Chondrocranium_Bone(_MouseAnatomicalStructureModel):
    """Model chondrocranium bone"""

    name: Literal["chondrocranium bone"] = "chondrocranium bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35238"] = "EMAPA_35238"


class _Ciliary_Epithelium(_MouseAnatomicalStructureModel):
    """Model ciliary epithelium"""

    name: Literal["ciliary epithelium"] = "ciliary epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35239"] = "EMAPA_35239"


class _Ciliary_Muscle(_MouseAnatomicalStructureModel):
    """Model ciliary muscle"""

    name: Literal["ciliary muscle"] = "ciliary muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35240"] = "EMAPA_35240"


class _Ciliary_Stroma(_MouseAnatomicalStructureModel):
    """Model ciliary stroma"""

    name: Literal["ciliary stroma"] = "ciliary stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35241"] = "EMAPA_35241"


class _Cingulate_Cortex(_MouseAnatomicalStructureModel):
    """Model cingulate cortex"""

    name: Literal["cingulate cortex"] = "cingulate cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35242"] = "EMAPA_35242"


class _Circumventricular_Organ(_MouseAnatomicalStructureModel):
    """Model circumventricular organ"""

    name: Literal["circumventricular organ"] = "circumventricular organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35243"] = "EMAPA_35243"


class _Claustrum(_MouseAnatomicalStructureModel):
    """Model claustrum"""

    name: Literal["claustrum"] = "claustrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35244"] = "EMAPA_35244"


class _Coat_Hair_Follicle(_MouseAnatomicalStructureModel):
    """Model coat hair follicle"""

    name: Literal["coat hair follicle"] = "coat hair follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35246"] = "EMAPA_35246"


class _Cochlea_Epithelium(_MouseAnatomicalStructureModel):
    """Model cochlea epithelium"""

    name: Literal["cochlea epithelium"] = "cochlea epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35247"] = "EMAPA_35247"


class _Cochlear_Nucleus(_MouseAnatomicalStructureModel):
    """Model cochlear nucleus"""

    name: Literal["cochlear nucleus"] = "cochlear nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35248"] = "EMAPA_35248"


class _Coelomic_Epithelium_Of_Reproductive_System(_MouseAnatomicalStructureModel):
    """Model coelomic epithelium of reproductive system"""

    name: Literal["coelomic epithelium of reproductive system"] = "coelomic epithelium of reproductive system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35249"] = "EMAPA_35249"


class _Compact_Bone(_MouseAnatomicalStructureModel):
    """Model compact bone"""

    name: Literal["compact bone"] = "compact bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35250"] = "EMAPA_35250"


class _Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model connective tissue"""

    name: Literal["connective tissue"] = "connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35251"] = "EMAPA_35251"


class _Coronary_Vascular_Plexus(_MouseAnatomicalStructureModel):
    """Model coronary vascular plexus"""

    name: Literal["coronary vascular plexus"] = "coronary vascular plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35252"] = "EMAPA_35252"


class _Corpus_Callosum(_MouseAnatomicalStructureModel):
    """Model corpus callosum"""

    name: Literal["corpus callosum"] = "corpus callosum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35253"] = "EMAPA_35253"


class _Cortical_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model cortical amygdaloid nucleus"""

    name: Literal["cortical amygdaloid nucleus"] = "cortical amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35254"] = "EMAPA_35254"


class _Cortical_Layer_I(_MouseAnatomicalStructureModel):
    """Model cortical layer I"""

    name: Literal["cortical layer I"] = "cortical layer I"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35255"] = "EMAPA_35255"


class _Cortical_Layer_Ii(_MouseAnatomicalStructureModel):
    """Model cortical layer II"""

    name: Literal["cortical layer II"] = "cortical layer II"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35256"] = "EMAPA_35256"


class _Cortical_Layer_Iii(_MouseAnatomicalStructureModel):
    """Model cortical layer III"""

    name: Literal["cortical layer III"] = "cortical layer III"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35257"] = "EMAPA_35257"


class _Cortical_Layer_Iv(_MouseAnatomicalStructureModel):
    """Model cortical layer IV"""

    name: Literal["cortical layer IV"] = "cortical layer IV"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35258"] = "EMAPA_35258"


class _Cortical_Layer_V(_MouseAnatomicalStructureModel):
    """Model cortical layer V"""

    name: Literal["cortical layer V"] = "cortical layer V"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35259"] = "EMAPA_35259"


class _Cortical_Layer_Vi(_MouseAnatomicalStructureModel):
    """Model cortical layer VI"""

    name: Literal["cortical layer VI"] = "cortical layer VI"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35260"] = "EMAPA_35260"


class _Cortical_Preplate(_MouseAnatomicalStructureModel):
    """Model cortical preplate"""

    name: Literal["cortical preplate"] = "cortical preplate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35261"] = "EMAPA_35261"


class _Costal_Cartilage(_MouseAnatomicalStructureModel):
    """Model costal cartilage"""

    name: Literal["costal cartilage"] = "costal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35262"] = "EMAPA_35262"


class _Cranial_Suture(_MouseAnatomicalStructureModel):
    """Model cranial suture"""

    name: Literal["cranial suture"] = "cranial suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35263"] = "EMAPA_35263"


class _Cranial_Synchondrosis(_MouseAnatomicalStructureModel):
    """Model cranial synchondrosis"""

    name: Literal["cranial synchondrosis"] = "cranial synchondrosis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35264"] = "EMAPA_35264"


class _Crypt_Of_Lieberkuhn(_MouseAnatomicalStructureModel):
    """Model crypt of lieberkuhn"""

    name: Literal["crypt of lieberkuhn"] = "crypt of lieberkuhn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35266"] = "EMAPA_35266"


class _Cumulus_Oophorus(_MouseAnatomicalStructureModel):
    """Model cumulus oophorus"""

    name: Literal["cumulus oophorus"] = "cumulus oophorus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35267"] = "EMAPA_35267"


class _Cuneate_Nucleus(_MouseAnatomicalStructureModel):
    """Model cuneate nucleus"""

    name: Literal["cuneate nucleus"] = "cuneate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35268"] = "EMAPA_35268"


class _Decidua(_MouseAnatomicalStructureModel):
    """Model decidua"""

    name: Literal["decidua"] = "decidua"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35269"] = "EMAPA_35269"


class _Decidua_Basalis(_MouseAnatomicalStructureModel):
    """Model decidua basalis"""

    name: Literal["decidua basalis"] = "decidua basalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35270"] = "EMAPA_35270"


class _Decidua_Capsularis(_MouseAnatomicalStructureModel):
    """Model decidua capsularis"""

    name: Literal["decidua capsularis"] = "decidua capsularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35271"] = "EMAPA_35271"


class _Deep_Cerebellar_Nucleus(_MouseAnatomicalStructureModel):
    """Model deep cerebellar nucleus"""

    name: Literal["deep cerebellar nucleus"] = "deep cerebellar nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35272"] = "EMAPA_35272"


class _Degenerating_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model degenerating paramesonephric duct of male"""

    name: Literal["degenerating paramesonephric duct of male"] = "degenerating paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35273"] = "EMAPA_35273"


class _Dental_Pulp(_MouseAnatomicalStructureModel):
    """Model dental pulp"""

    name: Literal["dental pulp"] = "dental pulp"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35274"] = "EMAPA_35274"


class _Dental_Sac(_MouseAnatomicalStructureModel):
    """Model dental sac"""

    name: Literal["dental sac"] = "dental sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35275"] = "EMAPA_35275"


class _Dentate_Gyrus_Granule_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model dentate gyrus granule cell layer"""

    name: Literal["dentate gyrus granule cell layer"] = "dentate gyrus granule cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35276"] = "EMAPA_35276"


class _Dentate_Gyrus_Hilus(_MouseAnatomicalStructureModel):
    """Model dentate gyrus hilus"""

    name: Literal["dentate gyrus hilus"] = "dentate gyrus hilus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35277"] = "EMAPA_35277"


class _Dentate_Gyrus_Layer(_MouseAnatomicalStructureModel):
    """Model dentate gyrus layer"""

    name: Literal["dentate gyrus layer"] = "dentate gyrus layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35278"] = "EMAPA_35278"


class _Dentate_Gyrus_Molecular_Layer(_MouseAnatomicalStructureModel):
    """Model dentate gyrus molecular layer"""

    name: Literal["dentate gyrus molecular layer"] = "dentate gyrus molecular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35279"] = "EMAPA_35279"


class _Dentate_Gyrus_Polymorphic_Layer(_MouseAnatomicalStructureModel):
    """Model dentate gyrus polymorphic layer"""

    name: Literal["dentate gyrus polymorphic layer"] = "dentate gyrus polymorphic layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35280"] = "EMAPA_35280"


class _Dentin(_MouseAnatomicalStructureModel):
    """Model dentin"""

    name: Literal["dentin"] = "dentin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35281"] = "EMAPA_35281"


class _Dermis_Papillary_Layer(_MouseAnatomicalStructureModel):
    """Model dermis papillary layer"""

    name: Literal["dermis papillary layer"] = "dermis papillary layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35282"] = "EMAPA_35282"


class _Dermis_Reticular_Layer(_MouseAnatomicalStructureModel):
    """Model dermis reticular layer"""

    name: Literal["dermis reticular layer"] = "dermis reticular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35283"] = "EMAPA_35283"


class _Descending_Colon(_MouseAnatomicalStructureModel):
    """Model descending colon"""

    name: Literal["descending colon"] = "descending colon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35285"] = "EMAPA_35285"


class _Dilatator_Pupillae(_MouseAnatomicalStructureModel):
    """Model dilatator pupillae"""

    name: Literal["dilatator pupillae"] = "dilatator pupillae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35286"] = "EMAPA_35286"


class _Distal_Phalanx(_MouseAnatomicalStructureModel):
    """Model distal phalanx"""

    name: Literal["distal phalanx"] = "distal phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35287"] = "EMAPA_35287"


class _Distal_Urethral_Epithelium(_MouseAnatomicalStructureModel):
    """Model distal urethral epithelium"""

    name: Literal["distal urethral epithelium"] = "distal urethral epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35288"] = "EMAPA_35288"


class _Dorsal_Cochlear_Nucleus(_MouseAnatomicalStructureModel):
    """Model dorsal cochlear nucleus"""

    name: Literal["dorsal cochlear nucleus"] = "dorsal cochlear nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35289"] = "EMAPA_35289"


class _Dorsal_Lateral_Geniculate_Nucleus(_MouseAnatomicalStructureModel):
    """Model dorsal lateral geniculate nucleus"""

    name: Literal["dorsal lateral geniculate nucleus"] = "dorsal lateral geniculate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35290"] = "EMAPA_35290"


class _Dorsal_Motor_Nucleus_Of_Vagus_Nerve(_MouseAnatomicalStructureModel):
    """Model dorsal motor nucleus of vagus nerve"""

    name: Literal["dorsal motor nucleus of vagus nerve"] = "dorsal motor nucleus of vagus nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35291"] = "EMAPA_35291"


class _Dorsal_Nasal_Artery(_MouseAnatomicalStructureModel):
    """Model dorsal nasal artery"""

    name: Literal["dorsal nasal artery"] = "dorsal nasal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35292"] = "EMAPA_35292"


class _Dorsal_Raphe_Nucleus(_MouseAnatomicalStructureModel):
    """Model dorsal raphe nucleus"""

    name: Literal["dorsal raphe nucleus"] = "dorsal raphe nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35293"] = "EMAPA_35293"


class _Dorsal_Tegmental_Nucleus(_MouseAnatomicalStructureModel):
    """Model dorsal tegmental nucleus"""

    name: Literal["dorsal tegmental nucleus"] = "dorsal tegmental nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35294"] = "EMAPA_35294"


class _Dorsal_Thalamus(_MouseAnatomicalStructureModel):
    """Model dorsal thalamus"""

    name: Literal["dorsal thalamus"] = "dorsal thalamus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35295"] = "EMAPA_35295"


class _Medial_Thalamic_Group(_MouseAnatomicalStructureModel):
    """Model medial thalamic group"""

    name: Literal["medial thalamic group"] = "medial thalamic group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35296"] = "EMAPA_35296"


class _Dorsomedial_Hypothalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model dorsomedial hypothalamic nucleus"""

    name: Literal["dorsomedial hypothalamic nucleus"] = "dorsomedial hypothalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35297"] = "EMAPA_35297"


class _Ear_Skin(_MouseAnatomicalStructureModel):
    """Model ear skin"""

    name: Literal["ear skin"] = "ear skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35301"] = "EMAPA_35301"


class _Edinger_Westphal_Nucleus(_MouseAnatomicalStructureModel):
    """Model edinger-westphal nucleus"""

    name: Literal["edinger-westphal nucleus"] = "edinger-westphal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35302"] = "EMAPA_35302"


class _Enamel(_MouseAnatomicalStructureModel):
    """Model enamel"""

    name: Literal["enamel"] = "enamel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35303"] = "EMAPA_35303"


class _Endochondral_Bone(_MouseAnatomicalStructureModel):
    """Model endochondral bone"""

    name: Literal["endochondral bone"] = "endochondral bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35304"] = "EMAPA_35304"


class _Endocrine_Pancreas(_MouseAnatomicalStructureModel):
    """Model endocrine pancreas"""

    name: Literal["endocrine pancreas"] = "endocrine pancreas"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35305"] = "EMAPA_35305"


class _Endocrine_System(_MouseAnatomicalStructureModel):
    """Model endocrine system"""

    name: Literal["endocrine system"] = "endocrine system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35306"] = "EMAPA_35306"


class _Endometrium_Epithelium(_MouseAnatomicalStructureModel):
    """Model endometrium epithelium"""

    name: Literal["endometrium epithelium"] = "endometrium epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35307"] = "EMAPA_35307"


class _Endometrium_Glandular_Epithelium(_MouseAnatomicalStructureModel):
    """Model endometrium glandular epithelium"""

    name: Literal["endometrium glandular epithelium"] = "endometrium glandular epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35308"] = "EMAPA_35308"


class _Endometrium_Luminal_Epithelium(_MouseAnatomicalStructureModel):
    """Model endometrium luminal epithelium"""

    name: Literal["endometrium luminal epithelium"] = "endometrium luminal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35309"] = "EMAPA_35309"


class _Endometrium_Stroma(_MouseAnatomicalStructureModel):
    """Model endometrium stroma"""

    name: Literal["endometrium stroma"] = "endometrium stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35310"] = "EMAPA_35310"


class _Endopiriform_Nucleus(_MouseAnatomicalStructureModel):
    """Model endopiriform nucleus"""

    name: Literal["endopiriform nucleus"] = "endopiriform nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35311"] = "EMAPA_35311"


class _Enteric_Ganglion(_MouseAnatomicalStructureModel):
    """Model enteric ganglion"""

    name: Literal["enteric ganglion"] = "enteric ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35312"] = "EMAPA_35312"


class _Entorhinal_Cortex(_MouseAnatomicalStructureModel):
    """Model entorhinal cortex"""

    name: Literal["entorhinal cortex"] = "entorhinal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35313"] = "EMAPA_35313"


class _Epidermis_Stratum_Lucidum(_MouseAnatomicalStructureModel):
    """Model epidermis stratum lucidum"""

    name: Literal["epidermis stratum lucidum"] = "epidermis stratum lucidum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35314"] = "EMAPA_35314"


class _Epidermis_Suprabasal_Layer(_MouseAnatomicalStructureModel):
    """Model epidermis suprabasal layer"""

    name: Literal["epidermis suprabasal layer"] = "epidermis suprabasal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35315"] = "EMAPA_35315"


class _Epididymal_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model epididymal fat pad"""

    name: Literal["epididymal fat pad"] = "epididymal fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35316"] = "EMAPA_35316"


class _Epithelium_Of_Capillary_Loop_Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model epithelium of capillary loop renal corpuscle"""

    name: Literal["epithelium of capillary loop renal corpuscle"] = "epithelium of capillary loop renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35317"] = "EMAPA_35317"


class _Epithelium_Of_Degenerating_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of degenerating paramesonephric duct of male"""

    name: Literal[
        "epithelium of degenerating paramesonephric duct of male"
    ] = "epithelium of degenerating paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35318"] = "EMAPA_35318"


class _Epithelium_Of_Paramesonephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model epithelium of paramesonephric duct of female"""

    name: Literal["epithelium of paramesonephric duct of female"] = "epithelium of paramesonephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35319"] = "EMAPA_35319"


class _Epithelium_Of_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model epithelium of paramesonephric duct of male"""

    name: Literal["epithelium of paramesonephric duct of male"] = "epithelium of paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35320"] = "EMAPA_35320"


class _Esophagus_Basal_Epithelium(_MouseAnatomicalStructureModel):
    """Model esophagus basal epithelium"""

    name: Literal["esophagus basal epithelium"] = "esophagus basal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35321"] = "EMAPA_35321"


class _Esophagus_Serosa(_MouseAnatomicalStructureModel):
    """Model esophagus serosa"""

    name: Literal["esophagus serosa"] = "esophagus serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35322"] = "EMAPA_35322"


class _Esophagus_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model esophagus smooth muscle"""

    name: Literal["esophagus smooth muscle"] = "esophagus smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35323"] = "EMAPA_35323"


class _Esophagus_Squamous_Epithelium(_MouseAnatomicalStructureModel):
    """Model esophagus squamous epithelium"""

    name: Literal["esophagus squamous epithelium"] = "esophagus squamous epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35324"] = "EMAPA_35324"


class _Esophagus_Submucosa(_MouseAnatomicalStructureModel):
    """Model esophagus submucosa"""

    name: Literal["esophagus submucosa"] = "esophagus submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35325"] = "EMAPA_35325"


class _Esophagus_Wall(_MouseAnatomicalStructureModel):
    """Model esophagus wall"""

    name: Literal["esophagus wall"] = "esophagus wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35326"] = "EMAPA_35326"


class _Exocrine_Gland(_MouseAnatomicalStructureModel):
    """Model exocrine gland"""

    name: Literal["exocrine gland"] = "exocrine gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35327"] = "EMAPA_35327"


class _Exocrine_Pancreas(_MouseAnatomicalStructureModel):
    """Model exocrine pancreas"""

    name: Literal["exocrine pancreas"] = "exocrine pancreas"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35328"] = "EMAPA_35328"


class _Exocrine_System(_MouseAnatomicalStructureModel):
    """Model exocrine system"""

    name: Literal["exocrine system"] = "exocrine system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35329"] = "EMAPA_35329"


class _Extensor_Digitorum_Longus(_MouseAnatomicalStructureModel):
    """Model extensor digitorum longus"""

    name: Literal["extensor digitorum longus"] = "extensor digitorum longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35330"] = "EMAPA_35330"


class _External_Capsule(_MouseAnatomicalStructureModel):
    """Model external capsule"""

    name: Literal["external capsule"] = "external capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35331"] = "EMAPA_35331"


class _External_Spiral_Sulcus(_MouseAnatomicalStructureModel):
    """Model external spiral sulcus"""

    name: Literal["external spiral sulcus"] = "external spiral sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35332"] = "EMAPA_35332"


class _Eye_Gland(_MouseAnatomicalStructureModel):
    """Model eye gland"""

    name: Literal["eye gland"] = "eye gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35334"] = "EMAPA_35334"


class _Eye_Muscle(_MouseAnatomicalStructureModel):
    """Model eye muscle"""

    name: Literal["eye muscle"] = "eye muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35335"] = "EMAPA_35335"


class _Eye_Surface_Region(_MouseAnatomicalStructureModel):
    """Model eye surface region"""

    name: Literal["eye surface region"] = "eye surface region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35336"] = "EMAPA_35336"


class _Face_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model face mesenchyme"""

    name: Literal["face mesenchyme"] = "face mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35337"] = "EMAPA_35337"


class _Facial_Nucleus(_MouseAnatomicalStructureModel):
    """Model facial nucleus"""

    name: Literal["facial nucleus"] = "facial nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35338"] = "EMAPA_35338"


class _Fasciola_Cinereum(_MouseAnatomicalStructureModel):
    """Model fasciola cinereum"""

    name: Literal["fasciola cinereum"] = "fasciola cinereum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35339"] = "EMAPA_35339"


class _Fat_Pad(_MouseAnatomicalStructureModel):
    """Model fat pad"""

    name: Literal["fat pad"] = "fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35340"] = "EMAPA_35340"


class _Femoral_Artery(_MouseAnatomicalStructureModel):
    """Model femoral artery"""

    name: Literal["femoral artery"] = "femoral artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35342"] = "EMAPA_35342"


class _Femoral_Nerve(_MouseAnatomicalStructureModel):
    """Model femoral nerve"""

    name: Literal["femoral nerve"] = "femoral nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35343"] = "EMAPA_35343"


class _Fibrous_Joint(_MouseAnatomicalStructureModel):
    """Model fibrous joint"""

    name: Literal["fibrous joint"] = "fibrous joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35344"] = "EMAPA_35344"


class _Fimbria_Hippocampus(_MouseAnatomicalStructureModel):
    """Model fimbria hippocampus"""

    name: Literal["fimbria hippocampus"] = "fimbria hippocampus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35345"] = "EMAPA_35345"


class _Flocculus(_MouseAnatomicalStructureModel):
    """Model flocculus"""

    name: Literal["flocculus"] = "flocculus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35346"] = "EMAPA_35346"


class _Forearm_Bone(_MouseAnatomicalStructureModel):
    """Model forearm bone"""

    name: Literal["forearm bone"] = "forearm bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35347"] = "EMAPA_35347"


class _Forebrain_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model forebrain vascular element"""

    name: Literal["forebrain vascular element"] = "forebrain vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35348"] = "EMAPA_35348"


class _Forelimb_Nail(_MouseAnatomicalStructureModel):
    """Model forelimb nail"""

    name: Literal["forelimb nail"] = "forelimb nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35349"] = "EMAPA_35349"


class _Forelimb_Long_Bone(_MouseAnatomicalStructureModel):
    """Model forelimb long bone"""

    name: Literal["forelimb long bone"] = "forelimb long bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35350"] = "EMAPA_35350"


class _Fornix(_MouseAnatomicalStructureModel):
    """Model fornix"""

    name: Literal["fornix"] = "fornix"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35352"] = "EMAPA_35352"


class _Nasal_Artery(_MouseAnatomicalStructureModel):
    """Model nasal artery"""

    name: Literal["nasal artery"] = "nasal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35353"] = "EMAPA_35353"


class _Foot_Bone(_MouseAnatomicalStructureModel):
    """Model foot bone"""

    name: Literal["foot bone"] = "foot bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35354"] = "EMAPA_35354"


class _4Th_Ventricle_Ependyma(_MouseAnatomicalStructureModel):
    """Model 4th ventricle ependyma"""

    name: Literal["4th ventricle ependyma"] = "4th ventricle ependyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35355"] = "EMAPA_35355"


class _Frontal_Association_Cortex(_MouseAnatomicalStructureModel):
    """Model frontal association cortex"""

    name: Literal["frontal association cortex"] = "frontal association cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35356"] = "EMAPA_35356"


class _Frontal_Cortex(_MouseAnatomicalStructureModel):
    """Model frontal cortex"""

    name: Literal["frontal cortex"] = "frontal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35357"] = "EMAPA_35357"


class _Frontonasal_Suture(_MouseAnatomicalStructureModel):
    """Model frontonasal suture"""

    name: Literal["frontonasal suture"] = "frontonasal suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35359"] = "EMAPA_35359"


class _Future_Brain_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model future brain marginal layer"""

    name: Literal["future brain marginal layer"] = "future brain marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35360"] = "EMAPA_35360"


class _Future_Brain_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model future brain roof plate"""

    name: Literal["future brain roof plate"] = "future brain roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35361"] = "EMAPA_35361"


class _Future_Brain_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model future brain ventricular layer"""

    name: Literal["future brain ventricular layer"] = "future brain ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35362"] = "EMAPA_35362"


class _Future_Hindbrain_Lateral_Wall(_MouseAnatomicalStructureModel):
    """Model future hindbrain lateral wall"""

    name: Literal["future hindbrain lateral wall"] = "future hindbrain lateral wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35364"] = "EMAPA_35364"


class _Future_Hindbrain_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model future hindbrain roof plate"""

    name: Literal["future hindbrain roof plate"] = "future hindbrain roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35367"] = "EMAPA_35367"


class _Future_Hindbrain_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model future hindbrain ventricular layer"""

    name: Literal["future hindbrain ventricular layer"] = "future hindbrain ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35368"] = "EMAPA_35368"


class _Future_Spinal_Cord_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model future spinal cord vascular element"""

    name: Literal["future spinal cord vascular element"] = "future spinal cord vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35369"] = "EMAPA_35369"


class _Gallbladder_Epithelium(_MouseAnatomicalStructureModel):
    """Model gallbladder epithelium"""

    name: Literal["gallbladder epithelium"] = "gallbladder epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35370"] = "EMAPA_35370"


class _Gallbladder_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model gallbladder lamina propria"""

    name: Literal["gallbladder lamina propria"] = "gallbladder lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35371"] = "EMAPA_35371"


class _Gallbladder_Serosa(_MouseAnatomicalStructureModel):
    """Model gallbladder serosa"""

    name: Literal["gallbladder serosa"] = "gallbladder serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35372"] = "EMAPA_35372"


class _Gallbladder_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model gallbladder smooth muscle"""

    name: Literal["gallbladder smooth muscle"] = "gallbladder smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35373"] = "EMAPA_35373"


class _Gastric_Artery(_MouseAnatomicalStructureModel):
    """Model gastric artery"""

    name: Literal["gastric artery"] = "gastric artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35374"] = "EMAPA_35374"


class _Gastrocnemius_Muscle(_MouseAnatomicalStructureModel):
    """Model gastrocnemius muscle"""

    name: Literal["gastrocnemius muscle"] = "gastrocnemius muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35375"] = "EMAPA_35375"


class _Geniculate_Thalamic_Group(_MouseAnatomicalStructureModel):
    """Model geniculate thalamic group"""

    name: Literal["geniculate thalamic group"] = "geniculate thalamic group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35376"] = "EMAPA_35376"


class _Genital_Swelling_Of_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model genital swelling of genital tubercle"""

    name: Literal["genital swelling of genital tubercle"] = "genital swelling of genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35377"] = "EMAPA_35377"


class _Gigantocellular_Reticular_Nucleus(_MouseAnatomicalStructureModel):
    """Model gigantocellular reticular nucleus"""

    name: Literal["gigantocellular reticular nucleus"] = "gigantocellular reticular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35378"] = "EMAPA_35378"


class _Girdle_Bone(_MouseAnatomicalStructureModel):
    """Model girdle bone"""

    name: Literal["girdle bone"] = "girdle bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35379"] = "EMAPA_35379"


class _Globus_Pallidus(_MouseAnatomicalStructureModel):
    """Model globus pallidus"""

    name: Literal["globus pallidus"] = "globus pallidus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35380"] = "EMAPA_35380"


class _Gonad_Germinal_Epithelium(_MouseAnatomicalStructureModel):
    """Model gonad germinal epithelium"""

    name: Literal["gonad germinal epithelium"] = "gonad germinal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35382"] = "EMAPA_35382"


class _Greater_Epithelial_Ridge(_MouseAnatomicalStructureModel):
    """Model greater epithelial ridge"""

    name: Literal["greater epithelial ridge"] = "greater epithelial ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35384"] = "EMAPA_35384"


class _Gut_Muscularis(_MouseAnatomicalStructureModel):
    """Model gut muscularis"""

    name: Literal["gut muscularis"] = "gut muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35385"] = "EMAPA_35385"


class _Habenula(_MouseAnatomicalStructureModel):
    """Model habenula"""

    name: Literal["habenula"] = "habenula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35386"] = "EMAPA_35386"


class _Hair_Cortex(_MouseAnatomicalStructureModel):
    """Model hair cortex"""

    name: Literal["hair cortex"] = "hair cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35387"] = "EMAPA_35387"


class _Hair_Cuticle(_MouseAnatomicalStructureModel):
    """Model hair cuticle"""

    name: Literal["hair cuticle"] = "hair cuticle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35388"] = "EMAPA_35388"


class _Hair_Medulla(_MouseAnatomicalStructureModel):
    """Model hair medulla"""

    name: Literal["hair medulla"] = "hair medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35389"] = "EMAPA_35389"


class _Hair_Root_Sheath_Matrix(_MouseAnatomicalStructureModel):
    """Model hair root sheath matrix"""

    name: Literal["hair root sheath matrix"] = "hair root sheath matrix"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35390"] = "EMAPA_35390"


class _Hand_Bone(_MouseAnatomicalStructureModel):
    """Model hand bone"""

    name: Literal["hand bone"] = "hand bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35391"] = "EMAPA_35391"


class _Hand_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model hand connective tissue"""

    name: Literal["hand connective tissue"] = "hand connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35392"] = "EMAPA_35392"


class _Forelimb_Distal_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb distal phalanx"""

    name: Literal["forelimb distal phalanx"] = "forelimb distal phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35393"] = "EMAPA_35393"


class _Hassall_S_Corpuscle(_MouseAnatomicalStructureModel):
    """Model hassall's corpuscle"""

    name: Literal["hassall's corpuscle"] = "hassall's corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35395"] = "EMAPA_35395"


class _Heart_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model heart blood vessel"""

    name: Literal["heart blood vessel"] = "heart blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35397"] = "EMAPA_35397"


class _Forelimb_Digit_Dermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit dermis"""

    name: Literal["forelimb digit dermis"] = "forelimb digit dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35399"] = "EMAPA_35399"


class _Heart_Septum(_MouseAnatomicalStructureModel):
    """Model heart septum"""

    name: Literal["heart septum"] = "heart septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35400"] = "EMAPA_35400"


class _Branchial_Arch_Epithelium(_MouseAnatomicalStructureModel):
    """Model branchial arch epithelium"""

    name: Literal["branchial arch epithelium"] = "branchial arch epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35401"] = "EMAPA_35401"


class _Hematopoietic_System(_MouseAnatomicalStructureModel):
    """Model hematopoietic system"""

    name: Literal["hematopoietic system"] = "hematopoietic system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35402"] = "EMAPA_35402"


class _Hindlimb_Long_Bone(_MouseAnatomicalStructureModel):
    """Model hindlimb long bone"""

    name: Literal["hindlimb long bone"] = "hindlimb long bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35403"] = "EMAPA_35403"


class _Hippocampal_Commissure(_MouseAnatomicalStructureModel):
    """Model hippocampal commissure"""

    name: Literal["hippocampal commissure"] = "hippocampal commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35404"] = "EMAPA_35404"


class _Hippocampal_Formation(_MouseAnatomicalStructureModel):
    """Model hippocampal formation"""

    name: Literal["hippocampal formation"] = "hippocampal formation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35405"] = "EMAPA_35405"


class _Hippocampus_Granule_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model hippocampus granule cell layer"""

    name: Literal["hippocampus granule cell layer"] = "hippocampus granule cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35406"] = "EMAPA_35406"


class _Hippocampus_Layer(_MouseAnatomicalStructureModel):
    """Model hippocampus layer"""

    name: Literal["hippocampus layer"] = "hippocampus layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35407"] = "EMAPA_35407"


class _Hippocampus_Molecular_Layer(_MouseAnatomicalStructureModel):
    """Model hippocampus molecular layer"""

    name: Literal["hippocampus molecular layer"] = "hippocampus molecular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35408"] = "EMAPA_35408"


class _Hippocampus_Pyramidal_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model hippocampus pyramidal cell layer"""

    name: Literal["hippocampus pyramidal cell layer"] = "hippocampus pyramidal cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35409"] = "EMAPA_35409"


class _Hippocampus_Stratum_Lacunosum(_MouseAnatomicalStructureModel):
    """Model hippocampus stratum lacunosum"""

    name: Literal["hippocampus stratum lacunosum"] = "hippocampus stratum lacunosum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35410"] = "EMAPA_35410"


class _Hippocampus_Stratum_Lucidum(_MouseAnatomicalStructureModel):
    """Model hippocampus stratum lucidum"""

    name: Literal["hippocampus stratum lucidum"] = "hippocampus stratum lucidum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35411"] = "EMAPA_35411"


class _Hippocampus_Stratum_Oriens(_MouseAnatomicalStructureModel):
    """Model hippocampus stratum oriens"""

    name: Literal["hippocampus stratum oriens"] = "hippocampus stratum oriens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35412"] = "EMAPA_35412"


class _Hippocampus_Stratum_Radiatum(_MouseAnatomicalStructureModel):
    """Model hippocampus stratum radiatum"""

    name: Literal["hippocampus stratum radiatum"] = "hippocampus stratum radiatum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35413"] = "EMAPA_35413"


class _Hyaline_Cartilage(_MouseAnatomicalStructureModel):
    """Model hyaline cartilage"""

    name: Literal["hyaline cartilage"] = "hyaline cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35414"] = "EMAPA_35414"


class _Hypertrophic_Cartilage_Zone(_MouseAnatomicalStructureModel):
    """Model hypertrophic cartilage zone"""

    name: Literal["hypertrophic cartilage zone"] = "hypertrophic cartilage zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35415"] = "EMAPA_35415"


class _Hypoglossal_Nucleus(_MouseAnatomicalStructureModel):
    """Model hypoglossal nucleus"""

    name: Literal["hypoglossal nucleus"] = "hypoglossal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35416"] = "EMAPA_35416"


class _Hypothalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model hypothalamic nucleus"""

    name: Literal["hypothalamic nucleus"] = "hypothalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35417"] = "EMAPA_35417"


class _Hypothalamus_Lateral_Zone(_MouseAnatomicalStructureModel):
    """Model hypothalamus lateral zone"""

    name: Literal["hypothalamus lateral zone"] = "hypothalamus lateral zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35418"] = "EMAPA_35418"


class _Hypothalamus_Medial_Zone(_MouseAnatomicalStructureModel):
    """Model hypothalamus medial zone"""

    name: Literal["hypothalamus medial zone"] = "hypothalamus medial zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35419"] = "EMAPA_35419"


class _Hypothalamus_Medial_Zone_Tuberal_Area(_MouseAnatomicalStructureModel):
    """Model hypothalamus medial zone tuberal area"""

    name: Literal["hypothalamus medial zone tuberal area"] = "hypothalamus medial zone tuberal area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35420"] = "EMAPA_35420"


class _Hypothalamus_Periventricular_Zone(_MouseAnatomicalStructureModel):
    """Model hypothalamus periventricular zone"""

    name: Literal["hypothalamus periventricular zone"] = "hypothalamus periventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35421"] = "EMAPA_35421"


class _Hypothalamus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model hypothalamus vascular element"""

    name: Literal["hypothalamus vascular element"] = "hypothalamus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35422"] = "EMAPA_35422"


class _Ileum_Epithelium(_MouseAnatomicalStructureModel):
    """Model ileum epithelium"""

    name: Literal["ileum epithelium"] = "ileum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35423"] = "EMAPA_35423"


class _Ileum_Mucosa(_MouseAnatomicalStructureModel):
    """Model ileum mucosa"""

    name: Literal["ileum mucosa"] = "ileum mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35424"] = "EMAPA_35424"


class _Right_Lung_Bronchiole(_MouseAnatomicalStructureModel):
    """Model right lung bronchiole"""

    name: Literal["right lung bronchiole"] = "right lung bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35425"] = "EMAPA_35425"


class _Immature_Loop_Of_Henle_Ascending_Limb(_MouseAnatomicalStructureModel):
    """Model immature loop of Henle ascending limb"""

    name: Literal["immature loop of Henle ascending limb"] = "immature loop of Henle ascending limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35426"] = "EMAPA_35426"


class _Immature_Loop_Of_Henle_Descending_Limb(_MouseAnatomicalStructureModel):
    """Model immature loop of Henle descending limb"""

    name: Literal["immature loop of Henle descending limb"] = "immature loop of Henle descending limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35427"] = "EMAPA_35427"


class _Impulse_Conducting_System(_MouseAnatomicalStructureModel):
    """Model impulse conducting system"""

    name: Literal["impulse conducting system"] = "impulse conducting system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35428"] = "EMAPA_35428"


class _Incisor_Dental_Pulp(_MouseAnatomicalStructureModel):
    """Model incisor dental pulp"""

    name: Literal["incisor dental pulp"] = "incisor dental pulp"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35429"] = "EMAPA_35429"


class _Indusium_Griseum(_MouseAnatomicalStructureModel):
    """Model indusium griseum"""

    name: Literal["indusium griseum"] = "indusium griseum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35430"] = "EMAPA_35430"


class _Inguinal_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model inguinal lymph node"""

    name: Literal["inguinal lymph node"] = "inguinal lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35431"] = "EMAPA_35431"


class _Insular_Cortex(_MouseAnatomicalStructureModel):
    """Model insular cortex"""

    name: Literal["insular cortex"] = "insular cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35432"] = "EMAPA_35432"


class _Alveolar_Septum(_MouseAnatomicalStructureModel):
    """Model alveolar septum"""

    name: Literal["alveolar septum"] = "alveolar septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35433"] = "EMAPA_35433"


class _Intercalated_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model intercalated amygdaloid nucleus"""

    name: Literal["intercalated amygdaloid nucleus"] = "intercalated amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35434"] = "EMAPA_35434"


class _Intercerebral_Commissure(_MouseAnatomicalStructureModel):
    """Model intercerebral commissure"""

    name: Literal["intercerebral commissure"] = "intercerebral commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35435"] = "EMAPA_35435"


class _Cerebral_Internal_Capsule(_MouseAnatomicalStructureModel):
    """Model cerebral internal capsule"""

    name: Literal["cerebral internal capsule"] = "cerebral internal capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35437"] = "EMAPA_35437"


class _Internal_Spiral_Sulcus(_MouseAnatomicalStructureModel):
    """Model internal spiral sulcus"""

    name: Literal["internal spiral sulcus"] = "internal spiral sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35438"] = "EMAPA_35438"


class _Interpeduncular_Nucleus(_MouseAnatomicalStructureModel):
    """Model interpeduncular nucleus"""

    name: Literal["interpeduncular nucleus"] = "interpeduncular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35439"] = "EMAPA_35439"


class _Intestine_Mucosa(_MouseAnatomicalStructureModel):
    """Model intestine mucosa"""

    name: Literal["intestine mucosa"] = "intestine mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35440"] = "EMAPA_35440"


class _Intestine_Muscularis(_MouseAnatomicalStructureModel):
    """Model intestine muscularis"""

    name: Literal["intestine muscularis"] = "intestine muscularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35441"] = "EMAPA_35441"


class _Intestine_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model intestine muscularis mucosa"""

    name: Literal["intestine muscularis mucosa"] = "intestine muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35442"] = "EMAPA_35442"


class _Intestine_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model intestine smooth muscle"""

    name: Literal["intestine smooth muscle"] = "intestine smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35443"] = "EMAPA_35443"


class _Intestine_Wall(_MouseAnatomicalStructureModel):
    """Model intestine wall"""

    name: Literal["intestine wall"] = "intestine wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35444"] = "EMAPA_35444"


class _Intralaminar_Thalamic_Group(_MouseAnatomicalStructureModel):
    """Model intralaminar thalamic group"""

    name: Literal["intralaminar thalamic group"] = "intralaminar thalamic group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35445"] = "EMAPA_35445"


class _Intrinsic_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model intrinsic nerve plexus"""

    name: Literal["intrinsic nerve plexus"] = "intrinsic nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35446"] = "EMAPA_35446"


class _Iris_Epithelium(_MouseAnatomicalStructureModel):
    """Model iris epithelium"""

    name: Literal["iris epithelium"] = "iris epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35447"] = "EMAPA_35447"


class _Iris_Muscle(_MouseAnatomicalStructureModel):
    """Model iris muscle"""

    name: Literal["iris muscle"] = "iris muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35448"] = "EMAPA_35448"


class _Iris_Nerve(_MouseAnatomicalStructureModel):
    """Model iris nerve"""

    name: Literal["iris nerve"] = "iris nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35449"] = "EMAPA_35449"


class _Iris_Stroma(_MouseAnatomicalStructureModel):
    """Model iris stroma"""

    name: Literal["iris stroma"] = "iris stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35451"] = "EMAPA_35451"


class _Islands_Of_Calleja(_MouseAnatomicalStructureModel):
    """Model islands of Calleja"""

    name: Literal["islands of Calleja"] = "islands of Calleja"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35452"] = "EMAPA_35452"


class _Jaw_Bone(_MouseAnatomicalStructureModel):
    """Model jaw bone"""

    name: Literal["jaw bone"] = "jaw bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35453"] = "EMAPA_35453"


class _Jaw_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model jaw primordium mesenchyme"""

    name: Literal["jaw primordium mesenchyme"] = "jaw primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35454"] = "EMAPA_35454"


class _Jaw_Skeleton(_MouseAnatomicalStructureModel):
    """Model jaw skeleton"""

    name: Literal["jaw skeleton"] = "jaw skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35455"] = "EMAPA_35455"


class _Skeletal_Joint(_MouseAnatomicalStructureModel):
    """Model skeletal joint"""

    name: Literal["skeletal joint"] = "skeletal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35456"] = "EMAPA_35456"


class _Metanephros_Epithelium(_MouseAnatomicalStructureModel):
    """Model metanephros epithelium"""

    name: Literal["metanephros epithelium"] = "metanephros epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35457"] = "EMAPA_35457"


class _Metanephros_Glomerular_Epithelium(_MouseAnatomicalStructureModel):
    """Model metanephros glomerular epithelium"""

    name: Literal["metanephros glomerular epithelium"] = "metanephros glomerular epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35458"] = "EMAPA_35458"


class _Loop_Of_Henle_Of_Renal_Medulla(_MouseAnatomicalStructureModel):
    """Model loop of Henle of renal medulla"""

    name: Literal["loop of Henle of renal medulla"] = "loop of Henle of renal medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35460"] = "EMAPA_35460"


class _Kidney_Outer_Medulla_Peritubular_Capillary(_MouseAnatomicalStructureModel):
    """Model kidney outer medulla peritubular capillary"""

    name: Literal["kidney outer medulla peritubular capillary"] = "kidney outer medulla peritubular capillary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35461"] = "EMAPA_35461"


class _Lacrimal_Apparatus(_MouseAnatomicalStructureModel):
    """Model lacrimal apparatus"""

    name: Literal["lacrimal apparatus"] = "lacrimal apparatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35462"] = "EMAPA_35462"


class _Lacrimal_Gland(_MouseAnatomicalStructureModel):
    """Model lacrimal gland"""

    name: Literal["lacrimal gland"] = "lacrimal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35463"] = "EMAPA_35463"


class _Lacrimal_Gland_Bud(_MouseAnatomicalStructureModel):
    """Model lacrimal gland bud"""

    name: Literal["lacrimal gland bud"] = "lacrimal gland bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35464"] = "EMAPA_35464"


class _Large_Intestine_Crypt_Of_Lieberkuhn(_MouseAnatomicalStructureModel):
    """Model large intestine crypt of lieberkuhn"""

    name: Literal["large intestine crypt of lieberkuhn"] = "large intestine crypt of lieberkuhn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35465"] = "EMAPA_35465"


class _Large_Intestine_Epithelium(_MouseAnatomicalStructureModel):
    """Model large intestine epithelium"""

    name: Literal["large intestine epithelium"] = "large intestine epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35466"] = "EMAPA_35466"


class _Large_Intestine_Mucosa(_MouseAnatomicalStructureModel):
    """Model large intestine mucosa"""

    name: Literal["large intestine mucosa"] = "large intestine mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35467"] = "EMAPA_35467"


class _Large_Intestine_Peyer_S_Patch(_MouseAnatomicalStructureModel):
    """Model large intestine Peyer's patch"""

    name: Literal["large intestine Peyer's patch"] = "large intestine Peyer's patch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35468"] = "EMAPA_35468"


class _Large_Intestine_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model large intestine smooth muscle"""

    name: Literal["large intestine smooth muscle"] = "large intestine smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35469"] = "EMAPA_35469"


class _Large_Intestine_Wall(_MouseAnatomicalStructureModel):
    """Model large intestine wall"""

    name: Literal["large intestine wall"] = "large intestine wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35470"] = "EMAPA_35470"


class _Larynx_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model larynx connective tissue"""

    name: Literal["larynx connective tissue"] = "larynx connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35471"] = "EMAPA_35471"


class _Larynx_Epithelium(_MouseAnatomicalStructureModel):
    """Model larynx epithelium"""

    name: Literal["larynx epithelium"] = "larynx epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35472"] = "EMAPA_35472"


class _Larynx_Muscle(_MouseAnatomicalStructureModel):
    """Model larynx muscle"""

    name: Literal["larynx muscle"] = "larynx muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35473"] = "EMAPA_35473"


class _Larynx_Submucosa(_MouseAnatomicalStructureModel):
    """Model larynx submucosa"""

    name: Literal["larynx submucosa"] = "larynx submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35474"] = "EMAPA_35474"


class _Larynx_Submucosa_Gland(_MouseAnatomicalStructureModel):
    """Model larynx submucosa gland"""

    name: Literal["larynx submucosa gland"] = "larynx submucosa gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35475"] = "EMAPA_35475"


class _Lateral_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral amygdaloid nucleus"""

    name: Literal["lateral amygdaloid nucleus"] = "lateral amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35476"] = "EMAPA_35476"


class _Lateral_Entorhinal_Cortex(_MouseAnatomicalStructureModel):
    """Model lateral entorhinal cortex"""

    name: Literal["lateral entorhinal cortex"] = "lateral entorhinal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35477"] = "EMAPA_35477"


class _Lateral_Geniculate_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral geniculate nucleus"""

    name: Literal["lateral geniculate nucleus"] = "lateral geniculate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35478"] = "EMAPA_35478"


class _Lateral_Habenular_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral habenular nucleus"""

    name: Literal["lateral habenular nucleus"] = "lateral habenular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35479"] = "EMAPA_35479"


class _Lateral_Hypothalamic_Area(_MouseAnatomicalStructureModel):
    """Model lateral hypothalamic area"""

    name: Literal["lateral hypothalamic area"] = "lateral hypothalamic area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35480"] = "EMAPA_35480"


class _Lateral_Mammillary_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral mammillary nucleus"""

    name: Literal["lateral mammillary nucleus"] = "lateral mammillary nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35481"] = "EMAPA_35481"


class _Lateral_Medullary_Reticular_Formation(_MouseAnatomicalStructureModel):
    """Model lateral medullary reticular formation"""

    name: Literal["lateral medullary reticular formation"] = "lateral medullary reticular formation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35482"] = "EMAPA_35482"


class _Lateral_Preoptic_Area(_MouseAnatomicalStructureModel):
    """Model lateral preoptic area"""

    name: Literal["lateral preoptic area"] = "lateral preoptic area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35483"] = "EMAPA_35483"


class _Lateral_Reticular_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral reticular nucleus"""

    name: Literal["lateral reticular nucleus"] = "lateral reticular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35484"] = "EMAPA_35484"


class _Lateral_Septal_Complex(_MouseAnatomicalStructureModel):
    """Model lateral septal complex"""

    name: Literal["lateral septal complex"] = "lateral septal complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35485"] = "EMAPA_35485"


class _Lateral_Septal_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral septal nucleus"""

    name: Literal["lateral septal nucleus"] = "lateral septal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35486"] = "EMAPA_35486"


class _Lateral_Thalamic_Group(_MouseAnatomicalStructureModel):
    """Model lateral thalamic group"""

    name: Literal["lateral thalamic group"] = "lateral thalamic group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35487"] = "EMAPA_35487"


class _Lateral_Ventricle_Ependyma(_MouseAnatomicalStructureModel):
    """Model lateral ventricle ependyma"""

    name: Literal["lateral ventricle ependyma"] = "lateral ventricle ependyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35488"] = "EMAPA_35488"


class _Lateral_Ventricle_Subependymal_Layer(_MouseAnatomicalStructureModel):
    """Model lateral ventricle subependymal layer"""

    name: Literal["lateral ventricle subependymal layer"] = "lateral ventricle subependymal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35489"] = "EMAPA_35489"


class _Laterodorsal_Tegmental_Nucleus(_MouseAnatomicalStructureModel):
    """Model laterodorsal tegmental nucleus"""

    name: Literal["laterodorsal tegmental nucleus"] = "laterodorsal tegmental nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35490"] = "EMAPA_35490"


class _Left_Common_Carotid_Artery(_MouseAnatomicalStructureModel):
    """Model left common carotid artery"""

    name: Literal["left common carotid artery"] = "left common carotid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35491"] = "EMAPA_35491"


class _Lesser_Epithelial_Ridge(_MouseAnatomicalStructureModel):
    """Model lesser epithelial ridge"""

    name: Literal["lesser epithelial ridge"] = "lesser epithelial ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35492"] = "EMAPA_35492"


class _Ligament(_MouseAnatomicalStructureModel):
    """Model ligament"""

    name: Literal["ligament"] = "ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35493"] = "EMAPA_35493"


class _Limb_Bone(_MouseAnatomicalStructureModel):
    """Model limb bone"""

    name: Literal["limb bone"] = "limb bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35494"] = "EMAPA_35494"


class _Limb_Long_Bone(_MouseAnatomicalStructureModel):
    """Model limb long bone"""

    name: Literal["limb long bone"] = "limb long bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35495"] = "EMAPA_35495"


class _Spiral_Limbus(_MouseAnatomicalStructureModel):
    """Model spiral limbus"""

    name: Literal["spiral limbus"] = "spiral limbus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35496"] = "EMAPA_35496"


class _Liver_Acinus(_MouseAnatomicalStructureModel):
    """Model liver acinus"""

    name: Literal["liver acinus"] = "liver acinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35497"] = "EMAPA_35497"


class _Liver_Vasculature(_MouseAnatomicalStructureModel):
    """Model liver vasculature"""

    name: Literal["liver vasculature"] = "liver vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35498"] = "EMAPA_35498"


class _Liver_Lobule(_MouseAnatomicalStructureModel):
    """Model liver lobule"""

    name: Literal["liver lobule"] = "liver lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35499"] = "EMAPA_35499"


class _Liver_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model liver vascular element"""

    name: Literal["liver vascular element"] = "liver vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35501"] = "EMAPA_35501"


class _Locus_Coeruleus(_MouseAnatomicalStructureModel):
    """Model locus coeruleus"""

    name: Literal["locus coeruleus"] = "locus coeruleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35502"] = "EMAPA_35502"


class _Long_Bone(_MouseAnatomicalStructureModel):
    """Model long bone"""

    name: Literal["long bone"] = "long bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35503"] = "EMAPA_35503"


class _Long_Bone_Diaphysis(_MouseAnatomicalStructureModel):
    """Model long bone diaphysis"""

    name: Literal["long bone diaphysis"] = "long bone diaphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35504"] = "EMAPA_35504"


class _Long_Bone_Epiphyseal_Plate(_MouseAnatomicalStructureModel):
    """Model long bone epiphyseal plate"""

    name: Literal["long bone epiphyseal plate"] = "long bone epiphyseal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35505"] = "EMAPA_35505"


class _Long_Bone_Epiphyseal_Plate_Hypertrophic_Zone(_MouseAnatomicalStructureModel):
    """Model long bone epiphyseal plate hypertrophic zone"""

    name: Literal["long bone epiphyseal plate hypertrophic zone"] = "long bone epiphyseal plate hypertrophic zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35506"] = "EMAPA_35506"


class _Long_Bone_Epiphyseal_Plate_Proliferative_Zone(_MouseAnatomicalStructureModel):
    """Model long bone epiphyseal plate proliferative zone"""

    name: Literal["long bone epiphyseal plate proliferative zone"] = "long bone epiphyseal plate proliferative zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35507"] = "EMAPA_35507"


class _Long_Bone_Epiphysis(_MouseAnatomicalStructureModel):
    """Model long bone epiphysis"""

    name: Literal["long bone epiphysis"] = "long bone epiphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35508"] = "EMAPA_35508"


class _Long_Bone_Metaphysis(_MouseAnatomicalStructureModel):
    """Model long bone metaphysis"""

    name: Literal["long bone metaphysis"] = "long bone metaphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35509"] = "EMAPA_35509"


class _Loop_Of_Henle_Ascending_Limb(_MouseAnatomicalStructureModel):
    """Model loop of Henle ascending limb"""

    name: Literal["loop of Henle ascending limb"] = "loop of Henle ascending limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35510"] = "EMAPA_35510"


class _Loop_Of_Henle_Descending_Limb(_MouseAnatomicalStructureModel):
    """Model loop of Henle descending limb"""

    name: Literal["loop of Henle descending limb"] = "loop of Henle descending limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35511"] = "EMAPA_35511"


class _Loop_Of_Henle_Distal_Straight_Tubule(_MouseAnatomicalStructureModel):
    """Model loop of Henle distal straight tubule"""

    name: Literal["loop of Henle distal straight tubule"] = "loop of Henle distal straight tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35512"] = "EMAPA_35512"


class _Loop_Of_Henle_Thick_Limb(_MouseAnatomicalStructureModel):
    """Model loop of Henle thick limb"""

    name: Literal["loop of Henle thick limb"] = "loop of Henle thick limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35513"] = "EMAPA_35513"


class _Loop_Of_Henle_Thin_Descending_Limb(_MouseAnatomicalStructureModel):
    """Model loop of Henle thin descending limb"""

    name: Literal["loop of Henle thin descending limb"] = "loop of Henle thin descending limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35514"] = "EMAPA_35514"


class _Loop_Of_Henle_Thin_Limb(_MouseAnatomicalStructureModel):
    """Model loop of Henle thin limb"""

    name: Literal["loop of Henle thin limb"] = "loop of Henle thin limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35515"] = "EMAPA_35515"


class _Lower_Jaw_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower jaw epithelium"""

    name: Literal["lower jaw epithelium"] = "lower jaw epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35516"] = "EMAPA_35516"


class _Lower_Jaw_Incisor_Dental_Follicle(_MouseAnatomicalStructureModel):
    """Model lower jaw incisor dental follicle"""

    name: Literal["lower jaw incisor dental follicle"] = "lower jaw incisor dental follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35517"] = "EMAPA_35517"


class _Lower_Jaw_Molar_Dental_Follicle(_MouseAnatomicalStructureModel):
    """Model lower jaw molar dental follicle"""

    name: Literal["lower jaw molar dental follicle"] = "lower jaw molar dental follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35518"] = "EMAPA_35518"


class _Lower_Leg_Bone(_MouseAnatomicalStructureModel):
    """Model lower leg bone"""

    name: Literal["lower leg bone"] = "lower leg bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35519"] = "EMAPA_35519"


class _Lower_Respiratory_Tract_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model lower respiratory tract smooth muscle"""

    name: Literal["lower respiratory tract smooth muscle"] = "lower respiratory tract smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35520"] = "EMAPA_35520"


class _Lung_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model lung connective tissue"""

    name: Literal["lung connective tissue"] = "lung connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35521"] = "EMAPA_35521"


class _Lung_Parenchyma(_MouseAnatomicalStructureModel):
    """Model lung parenchyma"""

    name: Literal["lung parenchyma"] = "lung parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35522"] = "EMAPA_35522"


class _Lymph_Node(_MouseAnatomicalStructureModel):
    """Model lymph node"""

    name: Literal["lymph node"] = "lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35523"] = "EMAPA_35523"


class _Lymph_Node_Capsule(_MouseAnatomicalStructureModel):
    """Model lymph node capsule"""

    name: Literal["lymph node capsule"] = "lymph node capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35524"] = "EMAPA_35524"


class _Lymph_Node_Cortex(_MouseAnatomicalStructureModel):
    """Model lymph node cortex"""

    name: Literal["lymph node cortex"] = "lymph node cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35525"] = "EMAPA_35525"


class _Lymph_Node_Endothelium(_MouseAnatomicalStructureModel):
    """Model lymph node endothelium"""

    name: Literal["lymph node endothelium"] = "lymph node endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35526"] = "EMAPA_35526"


class _Lymph_Node_Follicle(_MouseAnatomicalStructureModel):
    """Model lymph node follicle"""

    name: Literal["lymph node follicle"] = "lymph node follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35527"] = "EMAPA_35527"


class _Lymph_Node_Germinal_Center(_MouseAnatomicalStructureModel):
    """Model lymph node germinal center"""

    name: Literal["lymph node germinal center"] = "lymph node germinal center"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35528"] = "EMAPA_35528"


class _Lymph_Node_Medulla(_MouseAnatomicalStructureModel):
    """Model lymph node medulla"""

    name: Literal["lymph node medulla"] = "lymph node medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35529"] = "EMAPA_35529"


class _Lymph_Node_Primary_Follicle(_MouseAnatomicalStructureModel):
    """Model lymph node primary follicle"""

    name: Literal["lymph node primary follicle"] = "lymph node primary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35530"] = "EMAPA_35530"


class _Lymph_Node_Secondary_Follicle(_MouseAnatomicalStructureModel):
    """Model lymph node secondary follicle"""

    name: Literal["lymph node secondary follicle"] = "lymph node secondary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35531"] = "EMAPA_35531"


class _Lymphatic_Vessel(_MouseAnatomicalStructureModel):
    """Model lymphatic vessel"""

    name: Literal["lymphatic vessel"] = "lymphatic vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35532"] = "EMAPA_35532"


class _Lymphatic_Vessel_Endothelium(_MouseAnatomicalStructureModel):
    """Model lymphatic vessel endothelium"""

    name: Literal["lymphatic vessel endothelium"] = "lymphatic vessel endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35533"] = "EMAPA_35533"


class _Macula_Of_Saccule(_MouseAnatomicalStructureModel):
    """Model macula of saccule"""

    name: Literal["macula of saccule"] = "macula of saccule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35534"] = "EMAPA_35534"


class _Macula_Of_Utricle(_MouseAnatomicalStructureModel):
    """Model macula of utricle"""

    name: Literal["macula of utricle"] = "macula of utricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35535"] = "EMAPA_35535"


class _Mammary_Bud(_MouseAnatomicalStructureModel):
    """Model mammary bud"""

    name: Literal["mammary bud"] = "mammary bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35536"] = "EMAPA_35536"


class _Mammary_Gland_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model mammary gland connective tissue"""

    name: Literal["mammary gland connective tissue"] = "mammary gland connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35537"] = "EMAPA_35537"


class _Mammary_Gland_Duct(_MouseAnatomicalStructureModel):
    """Model mammary gland duct"""

    name: Literal["mammary gland duct"] = "mammary gland duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35538"] = "EMAPA_35538"


class _Mammary_Gland_Fat(_MouseAnatomicalStructureModel):
    """Model mammary gland fat"""

    name: Literal["mammary gland fat"] = "mammary gland fat"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35539"] = "EMAPA_35539"


class _Mammary_Placode(_MouseAnatomicalStructureModel):
    """Model mammary placode"""

    name: Literal["mammary placode"] = "mammary placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35541"] = "EMAPA_35541"


class _Mammillary_Body(_MouseAnatomicalStructureModel):
    """Model mammillary body"""

    name: Literal["mammillary body"] = "mammillary body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35542"] = "EMAPA_35542"


class _Medial_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model medial amygdaloid nucleus"""

    name: Literal["medial amygdaloid nucleus"] = "medial amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35543"] = "EMAPA_35543"


class _Medial_Dorsal_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model medial dorsal thalamic nucleus"""

    name: Literal["medial dorsal thalamic nucleus"] = "medial dorsal thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35544"] = "EMAPA_35544"


class _Medial_Entorhinal_Cortex(_MouseAnatomicalStructureModel):
    """Model medial entorhinal cortex"""

    name: Literal["medial entorhinal cortex"] = "medial entorhinal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35545"] = "EMAPA_35545"


class _Medial_Geniculate_Nucleus(_MouseAnatomicalStructureModel):
    """Model medial geniculate nucleus"""

    name: Literal["medial geniculate nucleus"] = "medial geniculate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35546"] = "EMAPA_35546"


class _Medial_Habenular_Nucleus(_MouseAnatomicalStructureModel):
    """Model medial habenular nucleus"""

    name: Literal["medial habenular nucleus"] = "medial habenular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35547"] = "EMAPA_35547"


class _Medial_Mammillary_Nucleus(_MouseAnatomicalStructureModel):
    """Model medial mammillary nucleus"""

    name: Literal["medial mammillary nucleus"] = "medial mammillary nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35548"] = "EMAPA_35548"


class _Medial_Preoptic_Nucleus(_MouseAnatomicalStructureModel):
    """Model medial preoptic nucleus"""

    name: Literal["medial preoptic nucleus"] = "medial preoptic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35549"] = "EMAPA_35549"


class _Medial_Preoptic_Area(_MouseAnatomicalStructureModel):
    """Model medial preoptic area"""

    name: Literal["medial preoptic area"] = "medial preoptic area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35550"] = "EMAPA_35550"


class _Median_Raphe_Nucleus(_MouseAnatomicalStructureModel):
    """Model median raphe nucleus"""

    name: Literal["median raphe nucleus"] = "median raphe nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35551"] = "EMAPA_35551"


class _Medial_Septal_Complex(_MouseAnatomicalStructureModel):
    """Model medial septal complex"""

    name: Literal["medial septal complex"] = "medial septal complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35552"] = "EMAPA_35552"


class _Medial_Septal_Nucleus(_MouseAnatomicalStructureModel):
    """Model medial septal nucleus"""

    name: Literal["medial septal nucleus"] = "medial septal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35553"] = "EMAPA_35553"


class _Medial_Vestibular_Nucleus(_MouseAnatomicalStructureModel):
    """Model medial vestibular nucleus"""

    name: Literal["medial vestibular nucleus"] = "medial vestibular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35554"] = "EMAPA_35554"


class _Mediastinal_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model mediastinal lymph node"""

    name: Literal["mediastinal lymph node"] = "mediastinal lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35555"] = "EMAPA_35555"


class _Medullary_Reticular_Formation(_MouseAnatomicalStructureModel):
    """Model medullary reticular formation"""

    name: Literal["medullary reticular formation"] = "medullary reticular formation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35556"] = "EMAPA_35556"


class _Medullary_Tubule(_MouseAnatomicalStructureModel):
    """Model medullary tubule"""

    name: Literal["medullary tubule"] = "medullary tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35557"] = "EMAPA_35557"


class _Mesenchyme_Of_Degenerating_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchyme of degenerating paramesonephric duct of male"""

    name: Literal[
        "mesenchyme of degenerating paramesonephric duct of male"
    ] = "mesenchyme of degenerating paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35558"] = "EMAPA_35558"


class _Mesenchyme_Of_Paramesonephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model mesenchyme of paramesonephric duct of female"""

    name: Literal["mesenchyme of paramesonephric duct of female"] = "mesenchyme of paramesonephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35559"] = "EMAPA_35559"


class _Mesenchyme_Of_Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model mesenchyme of paramesonephric duct of male"""

    name: Literal["mesenchyme of paramesonephric duct of male"] = "mesenchyme of paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35560"] = "EMAPA_35560"


class _Mesenteric_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model mesenteric lymph node"""

    name: Literal["mesenteric lymph node"] = "mesenteric lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35561"] = "EMAPA_35561"


class _Mesometrium(_MouseAnatomicalStructureModel):
    """Model mesometrium"""

    name: Literal["mesometrium"] = "mesometrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35562"] = "EMAPA_35562"


class _Branchial_Groove_Epithelium(_MouseAnatomicalStructureModel):
    """Model branchial groove epithelium"""

    name: Literal["branchial groove epithelium"] = "branchial groove epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35567"] = "EMAPA_35567"


class _Metatarsus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model metatarsus mesenchyme"""

    name: Literal["metatarsus mesenchyme"] = "metatarsus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35568"] = "EMAPA_35568"


class _Midbrain_Reticular_Formation(_MouseAnatomicalStructureModel):
    """Model midbrain reticular formation"""

    name: Literal["midbrain reticular formation"] = "midbrain reticular formation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35570"] = "EMAPA_35570"


class _Midbrain_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model midbrain vascular element"""

    name: Literal["midbrain vascular element"] = "midbrain vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35571"] = "EMAPA_35571"


class _Middle_Phalanx(_MouseAnatomicalStructureModel):
    """Model middle phalanx"""

    name: Literal["middle phalanx"] = "middle phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35572"] = "EMAPA_35572"


class _Midline_Thalamic_Group(_MouseAnatomicalStructureModel):
    """Model midline thalamic group"""

    name: Literal["midline thalamic group"] = "midline thalamic group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35573"] = "EMAPA_35573"


class _Minor_Salivary_Gland(_MouseAnatomicalStructureModel):
    """Model minor salivary gland"""

    name: Literal["minor salivary gland"] = "minor salivary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35574"] = "EMAPA_35574"


class _Modiolus(_MouseAnatomicalStructureModel):
    """Model modiolus"""

    name: Literal["modiolus"] = "modiolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35575"] = "EMAPA_35575"


class _Molar_Dental_Pulp(_MouseAnatomicalStructureModel):
    """Model molar dental pulp"""

    name: Literal["molar dental pulp"] = "molar dental pulp"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35576"] = "EMAPA_35576"


class _Musculature(_MouseAnatomicalStructureModel):
    """Model musculature"""

    name: Literal["musculature"] = "musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35577"] = "EMAPA_35577"


class _Skeletal_Musculature(_MouseAnatomicalStructureModel):
    """Model skeletal musculature"""

    name: Literal["skeletal musculature"] = "skeletal musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35578"] = "EMAPA_35578"


class _Nail(_MouseAnatomicalStructureModel):
    """Model nail"""

    name: Literal["nail"] = "nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35580"] = "EMAPA_35580"


class _Nail_Bed(_MouseAnatomicalStructureModel):
    """Model nail bed"""

    name: Literal["nail bed"] = "nail bed"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35581"] = "EMAPA_35581"


class _Nail_Matrix(_MouseAnatomicalStructureModel):
    """Model nail matrix"""

    name: Literal["nail matrix"] = "nail matrix"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35582"] = "EMAPA_35582"


class _Nail_Plate(_MouseAnatomicalStructureModel):
    """Model nail plate"""

    name: Literal["nail plate"] = "nail plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35583"] = "EMAPA_35583"


class _Nasal_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model nasal mesenchyme"""

    name: Literal["nasal mesenchyme"] = "nasal mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35584"] = "EMAPA_35584"


class _Nasal_Process_Ectoderm(_MouseAnatomicalStructureModel):
    """Model nasal process ectoderm"""

    name: Literal["nasal process ectoderm"] = "nasal process ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35585"] = "EMAPA_35585"


class _Nasal_Process_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model nasal process mesenchyme"""

    name: Literal["nasal process mesenchyme"] = "nasal process mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35586"] = "EMAPA_35586"


class _Neck(_MouseAnatomicalStructureModel):
    """Model neck"""

    name: Literal["neck"] = "neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35587"] = "EMAPA_35587"


class _Neocortex_Layer(_MouseAnatomicalStructureModel):
    """Model neocortex layer"""

    name: Literal["neocortex layer"] = "neocortex layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35588"] = "EMAPA_35588"


class _Neocortex_Region(_MouseAnatomicalStructureModel):
    """Model neocortex region"""

    name: Literal["neocortex region"] = "neocortex region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35589"] = "EMAPA_35589"


class _Nephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model nephric duct of female"""

    name: Literal["nephric duct of female"] = "nephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35590"] = "EMAPA_35590"


class _Nephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model nephric duct of male"""

    name: Literal["nephric duct of male"] = "nephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35591"] = "EMAPA_35591"


class _Nephron(_MouseAnatomicalStructureModel):
    """Model nephron"""

    name: Literal["nephron"] = "nephron"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35592"] = "EMAPA_35592"


class _Neural_Plate(_MouseAnatomicalStructureModel):
    """Model neural plate"""

    name: Literal["neural plate"] = "neural plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35593"] = "EMAPA_35593"


class _Neural_Groove(_MouseAnatomicalStructureModel):
    """Model neural groove"""

    name: Literal["neural groove"] = "neural groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35594"] = "EMAPA_35594"


class _Neurohypophysis_Pars_Nervosa(_MouseAnatomicalStructureModel):
    """Model neurohypophysis pars nervosa"""

    name: Literal["neurohypophysis pars nervosa"] = "neurohypophysis pars nervosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35595"] = "EMAPA_35595"


class _Nucleus_Ambiguus(_MouseAnatomicalStructureModel):
    """Model nucleus ambiguus"""

    name: Literal["nucleus ambiguus"] = "nucleus ambiguus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35596"] = "EMAPA_35596"


class _Nucleus_Of_Darkschewitsch(_MouseAnatomicalStructureModel):
    """Model nucleus of darkschewitsch"""

    name: Literal["nucleus of darkschewitsch"] = "nucleus of darkschewitsch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35597"] = "EMAPA_35597"


class _Nucleus_Of_Diagonal_Band(_MouseAnatomicalStructureModel):
    """Model nucleus of diagonal band"""

    name: Literal["nucleus of diagonal band"] = "nucleus of diagonal band"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35598"] = "EMAPA_35598"


class _Nucleus_Of_Lateral_Olfactory_Tract(_MouseAnatomicalStructureModel):
    """Model nucleus of lateral olfactory tract"""

    name: Literal["nucleus of lateral olfactory tract"] = "nucleus of lateral olfactory tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35599"] = "EMAPA_35599"


class _Nucleus_Of_Trapezoid_Body(_MouseAnatomicalStructureModel):
    """Model nucleus of trapezoid body"""

    name: Literal["nucleus of trapezoid body"] = "nucleus of trapezoid body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35600"] = "EMAPA_35600"


class _Nucleus_Related_To_Visual_Cortex(_MouseAnatomicalStructureModel):
    """Model nucleus related to visual cortex"""

    name: Literal["nucleus related to visual cortex"] = "nucleus related to visual cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35601"] = "EMAPA_35601"


class _Nucleus_Reuniens(_MouseAnatomicalStructureModel):
    """Model nucleus reuniens"""

    name: Literal["nucleus reuniens"] = "nucleus reuniens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35602"] = "EMAPA_35602"


class _Oblique_Abdominal_Muscle(_MouseAnatomicalStructureModel):
    """Model oblique abdominal muscle"""

    name: Literal["oblique abdominal muscle"] = "oblique abdominal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35603"] = "EMAPA_35603"


class _Occipital_Cortex(_MouseAnatomicalStructureModel):
    """Model occipital cortex"""

    name: Literal["occipital cortex"] = "occipital cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35604"] = "EMAPA_35604"


class _Oculomotor_Nucleus(_MouseAnatomicalStructureModel):
    """Model oculomotor nucleus"""

    name: Literal["oculomotor nucleus"] = "oculomotor nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35605"] = "EMAPA_35605"


class _Main_Olfactory_Bulb_External_Plexiform_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb external plexiform layer"""

    name: Literal["main olfactory bulb external plexiform layer"] = "main olfactory bulb external plexiform layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35607"] = "EMAPA_35607"


class _Main_Olfactory_Bulb_Glomerular_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb glomerular layer"""

    name: Literal["main olfactory bulb glomerular layer"] = "main olfactory bulb glomerular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35608"] = "EMAPA_35608"


class _Main_Olfactory_Bulb_Granule_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb granule cell layer"""

    name: Literal["main olfactory bulb granule cell layer"] = "main olfactory bulb granule cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35609"] = "EMAPA_35609"


class _Main_Olfactory_Bulb_Internal_Plexiform_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb internal plexiform layer"""

    name: Literal["main olfactory bulb internal plexiform layer"] = "main olfactory bulb internal plexiform layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35610"] = "EMAPA_35610"


class _Main_Olfactory_Bulb_Mitral_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb mitral cell layer"""

    name: Literal["main olfactory bulb mitral cell layer"] = "main olfactory bulb mitral cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35611"] = "EMAPA_35611"


class _Main_Olfactory_Bulb_Subependymal_Zone(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb subependymal zone"""

    name: Literal["main olfactory bulb subependymal zone"] = "main olfactory bulb subependymal zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35612"] = "EMAPA_35612"


class _Olfactory_Gland(_MouseAnatomicalStructureModel):
    """Model olfactory gland"""

    name: Literal["olfactory gland"] = "olfactory gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35613"] = "EMAPA_35613"


class _Main_Olfactory_Bulb_Olfactory_Nerve_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb olfactory nerve layer"""

    name: Literal["main olfactory bulb olfactory nerve layer"] = "main olfactory bulb olfactory nerve layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35614"] = "EMAPA_35614"


class _Olfactory_Tract(_MouseAnatomicalStructureModel):
    """Model olfactory tract"""

    name: Literal["olfactory tract"] = "olfactory tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35615"] = "EMAPA_35615"


class _Olfactory_Tubercle(_MouseAnatomicalStructureModel):
    """Model olfactory tubercle"""

    name: Literal["olfactory tubercle"] = "olfactory tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35616"] = "EMAPA_35616"


class _Optic_Tract(_MouseAnatomicalStructureModel):
    """Model optic tract"""

    name: Literal["optic tract"] = "optic tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35617"] = "EMAPA_35617"


class _Oral_Region_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model oral region mesenchyme"""

    name: Literal["oral region mesenchyme"] = "oral region mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35618"] = "EMAPA_35618"


class _Orbicularis_Oculi(_MouseAnatomicalStructureModel):
    """Model orbicularis oculi"""

    name: Literal["orbicularis oculi"] = "orbicularis oculi"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35619"] = "EMAPA_35619"


class _Osseus_Cochlea(_MouseAnatomicalStructureModel):
    """Model osseus cochlea"""

    name: Literal["osseus cochlea"] = "osseus cochlea"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35620"] = "EMAPA_35620"


class _Osseus_Cochlear_Canal(_MouseAnatomicalStructureModel):
    """Model osseus cochlear canal"""

    name: Literal["osseus cochlear canal"] = "osseus cochlear canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35621"] = "EMAPA_35621"


class _Osseus_Spiral_Lamina(_MouseAnatomicalStructureModel):
    """Model osseus spiral lamina"""

    name: Literal["osseus spiral lamina"] = "osseus spiral lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35622"] = "EMAPA_35622"


class _Outflow_Tract_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model outflow tract cardiac muscle"""

    name: Literal["outflow tract cardiac muscle"] = "outflow tract cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35623"] = "EMAPA_35623"


class _Outflow_Tract_Pulmonary_Component_Distal_Part(_MouseAnatomicalStructureModel):
    """Model outflow tract pulmonary component distal part"""

    name: Literal["outflow tract pulmonary component distal part"] = "outflow tract pulmonary component distal part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35624"] = "EMAPA_35624"


class _Ovary_Antral_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary antral follicle"""

    name: Literal["ovary antral follicle"] = "ovary antral follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35625"] = "EMAPA_35625"


class _Ovary_Capsule(_MouseAnatomicalStructureModel):
    """Model ovary capsule"""

    name: Literal["ovary capsule"] = "ovary capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35626"] = "EMAPA_35626"


class _Ovary_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary follicle"""

    name: Literal["ovary follicle"] = "ovary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35627"] = "EMAPA_35627"


class _Ovary_Growing_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary growing follicle"""

    name: Literal["ovary growing follicle"] = "ovary growing follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35628"] = "EMAPA_35628"


class _Ovary_Preantral_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary preantral follicle"""

    name: Literal["ovary preantral follicle"] = "ovary preantral follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35630"] = "EMAPA_35630"


class _Ovary_Primary_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary primary follicle"""

    name: Literal["ovary primary follicle"] = "ovary primary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35631"] = "EMAPA_35631"


class _Ovary_Secondary_Follicle(_MouseAnatomicalStructureModel):
    """Model ovary secondary follicle"""

    name: Literal["ovary secondary follicle"] = "ovary secondary follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35632"] = "EMAPA_35632"


class _Ovary_Stratum_Granulosum(_MouseAnatomicalStructureModel):
    """Model ovary stratum granulosum"""

    name: Literal["ovary stratum granulosum"] = "ovary stratum granulosum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35633"] = "EMAPA_35633"


class _Ovary_Theca(_MouseAnatomicalStructureModel):
    """Model ovary theca"""

    name: Literal["ovary theca"] = "ovary theca"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35636"] = "EMAPA_35636"


class _Palatal_Rugae(_MouseAnatomicalStructureModel):
    """Model palatal rugae"""

    name: Literal["palatal rugae"] = "palatal rugae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35637"] = "EMAPA_35637"


class _Hard_Palate_Palatal_Rugae(_MouseAnatomicalStructureModel):
    """Model hard palate palatal rugae"""

    name: Literal["hard palate palatal rugae"] = "hard palate palatal rugae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35638"] = "EMAPA_35638"


class _Palatal_Rugae_Epithelium(_MouseAnatomicalStructureModel):
    """Model palatal rugae epithelium"""

    name: Literal["palatal rugae epithelium"] = "palatal rugae epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35639"] = "EMAPA_35639"


class _Hard_Palate_Palatal_Rugae_Epithelium(_MouseAnatomicalStructureModel):
    """Model hard palate palatal rugae epithelium"""

    name: Literal["hard palate palatal rugae epithelium"] = "hard palate palatal rugae epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35640"] = "EMAPA_35640"


class _Palatal_Rugae_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model palatal rugae mesenchyme"""

    name: Literal["palatal rugae mesenchyme"] = "palatal rugae mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35641"] = "EMAPA_35641"


class _Hard_Palate_Palatal_Rugae_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model hard palate palatal rugae mesenchyme"""

    name: Literal["hard palate palatal rugae mesenchyme"] = "hard palate palatal rugae mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35642"] = "EMAPA_35642"


class _Palatine_Gland(_MouseAnatomicalStructureModel):
    """Model palatine gland"""

    name: Literal["palatine gland"] = "palatine gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35643"] = "EMAPA_35643"


class _Palatine_Tonsil(_MouseAnatomicalStructureModel):
    """Model palatine tonsil"""

    name: Literal["palatine tonsil"] = "palatine tonsil"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35644"] = "EMAPA_35644"


class _Pancreas_Epithelium(_MouseAnatomicalStructureModel):
    """Model pancreas epithelium"""

    name: Literal["pancreas epithelium"] = "pancreas epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35645"] = "EMAPA_35645"


class _Pancreas_Primordium_Epithelium(_MouseAnatomicalStructureModel):
    """Model pancreas primordium epithelium"""

    name: Literal["pancreas primordium epithelium"] = "pancreas primordium epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35647"] = "EMAPA_35647"


class _Pancreas_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model pancreas primordium mesenchyme"""

    name: Literal["pancreas primordium mesenchyme"] = "pancreas primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35648"] = "EMAPA_35648"


class _Pancreas_Tip_Epithelium(_MouseAnatomicalStructureModel):
    """Model pancreas tip epithelium"""

    name: Literal["pancreas tip epithelium"] = "pancreas tip epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35649"] = "EMAPA_35649"


class _Pancreas_Trunk_Epithelium(_MouseAnatomicalStructureModel):
    """Model pancreas trunk epithelium"""

    name: Literal["pancreas trunk epithelium"] = "pancreas trunk epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35650"] = "EMAPA_35650"


class _Pancreatic_Acinus(_MouseAnatomicalStructureModel):
    """Model pancreatic acinus"""

    name: Literal["pancreatic acinus"] = "pancreatic acinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35651"] = "EMAPA_35651"


class _Pancreatic_Islet_Core(_MouseAnatomicalStructureModel):
    """Model pancreatic islet core"""

    name: Literal["pancreatic islet core"] = "pancreatic islet core"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35653"] = "EMAPA_35653"


class _Pancreatic_Islet_Mantle(_MouseAnatomicalStructureModel):
    """Model pancreatic islet mantle"""

    name: Literal["pancreatic islet mantle"] = "pancreatic islet mantle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35654"] = "EMAPA_35654"


class _Papillary_Duct(_MouseAnatomicalStructureModel):
    """Model papillary duct"""

    name: Literal["papillary duct"] = "papillary duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35655"] = "EMAPA_35655"


class _Parabigeminal_Nucleus(_MouseAnatomicalStructureModel):
    """Model parabigeminal nucleus"""

    name: Literal["parabigeminal nucleus"] = "parabigeminal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35656"] = "EMAPA_35656"


class _Parabrachial_Nucleus(_MouseAnatomicalStructureModel):
    """Model parabrachial nucleus"""

    name: Literal["parabrachial nucleus"] = "parabrachial nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35657"] = "EMAPA_35657"


class _Paracentral_Nucleus(_MouseAnatomicalStructureModel):
    """Model paracentral nucleus"""

    name: Literal["paracentral nucleus"] = "paracentral nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35658"] = "EMAPA_35658"


class _Parafascicular_Nucleus(_MouseAnatomicalStructureModel):
    """Model parafascicular nucleus"""

    name: Literal["parafascicular nucleus"] = "parafascicular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35659"] = "EMAPA_35659"


class _Paramesonephric_Duct_Of_Female(_MouseAnatomicalStructureModel):
    """Model paramesonephric duct of female"""

    name: Literal["paramesonephric duct of female"] = "paramesonephric duct of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35660"] = "EMAPA_35660"


class _Paramesonephric_Duct_Of_Male(_MouseAnatomicalStructureModel):
    """Model paramesonephric duct of male"""

    name: Literal["paramesonephric duct of male"] = "paramesonephric duct of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35661"] = "EMAPA_35661"


class _Paranasal_Sinus(_MouseAnatomicalStructureModel):
    """Model paranasal sinus"""

    name: Literal["paranasal sinus"] = "paranasal sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35662"] = "EMAPA_35662"


class _Parathyroid_Gland_Capsule(_MouseAnatomicalStructureModel):
    """Model parathyroid gland capsule"""

    name: Literal["parathyroid gland capsule"] = "parathyroid gland capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35663"] = "EMAPA_35663"


class _Parathyroid_Gland_Parenchyma(_MouseAnatomicalStructureModel):
    """Model parathyroid gland parenchyma"""

    name: Literal["parathyroid gland parenchyma"] = "parathyroid gland parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35664"] = "EMAPA_35664"


class _Paraventricular_Hypothalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model paraventricular hypothalamic nucleus"""

    name: Literal["paraventricular hypothalamic nucleus"] = "paraventricular hypothalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35665"] = "EMAPA_35665"


class _Paraventricular_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model paraventricular thalamic nucleus"""

    name: Literal["paraventricular thalamic nucleus"] = "paraventricular thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35666"] = "EMAPA_35666"


class _Parietal_Cortex(_MouseAnatomicalStructureModel):
    """Model parietal cortex"""

    name: Literal["parietal cortex"] = "parietal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35667"] = "EMAPA_35667"


class _Patella(_MouseAnatomicalStructureModel):
    """Model patella"""

    name: Literal["patella"] = "patella"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35668"] = "EMAPA_35668"


class _Pectoral_Girdle_Skeleton(_MouseAnatomicalStructureModel):
    """Model pectoral girdle skeleton"""

    name: Literal["pectoral girdle skeleton"] = "pectoral girdle skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35669"] = "EMAPA_35669"


class _Pectoralis(_MouseAnatomicalStructureModel):
    """Model pectoralis"""

    name: Literal["pectoralis"] = "pectoralis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35670"] = "EMAPA_35670"


class _Forelimb_Digit_Epidermis(_MouseAnatomicalStructureModel):
    """Model forelimb digit epidermis"""

    name: Literal["forelimb digit epidermis"] = "forelimb digit epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35671"] = "EMAPA_35671"


class _Peduncular_Pontine_Nucleus(_MouseAnatomicalStructureModel):
    """Model peduncular pontine nucleus"""

    name: Literal["peduncular pontine nucleus"] = "peduncular pontine nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35672"] = "EMAPA_35672"


class _Middle_Ear_Epithelium(_MouseAnatomicalStructureModel):
    """Model middle ear epithelium"""

    name: Literal["middle ear epithelium"] = "middle ear epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35673"] = "EMAPA_35673"


class _Penis_Epithelium(_MouseAnatomicalStructureModel):
    """Model penis epithelium"""

    name: Literal["penis epithelium"] = "penis epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35674"] = "EMAPA_35674"


class _Penis_Skin(_MouseAnatomicalStructureModel):
    """Model penis skin"""

    name: Literal["penis skin"] = "penis skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35675"] = "EMAPA_35675"


class _Perichondrium(_MouseAnatomicalStructureModel):
    """Model perichondrium"""

    name: Literal["perichondrium"] = "perichondrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35676"] = "EMAPA_35676"


class _Perilymphatic_Channel(_MouseAnatomicalStructureModel):
    """Model perilymphatic channel"""

    name: Literal["perilymphatic channel"] = "perilymphatic channel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35677"] = "EMAPA_35677"


class _Perineural_Vascular_Plexus(_MouseAnatomicalStructureModel):
    """Model perineural vascular plexus"""

    name: Literal["perineural vascular plexus"] = "perineural vascular plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35678"] = "EMAPA_35678"


class _Periodontal_Ligament(_MouseAnatomicalStructureModel):
    """Model periodontal ligament"""

    name: Literal["periodontal ligament"] = "periodontal ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35679"] = "EMAPA_35679"


class _Periolivary_Nucleus(_MouseAnatomicalStructureModel):
    """Model periolivary nucleus"""

    name: Literal["periolivary nucleus"] = "periolivary nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35680"] = "EMAPA_35680"


class _Periosteum(_MouseAnatomicalStructureModel):
    """Model periosteum"""

    name: Literal["periosteum"] = "periosteum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35681"] = "EMAPA_35681"


class _Perirhinal_Cortex(_MouseAnatomicalStructureModel):
    """Model perirhinal cortex"""

    name: Literal["perirhinal cortex"] = "perirhinal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35682"] = "EMAPA_35682"


class _Peritoneal_Fluid(_MouseAnatomicalStructureModel):
    """Model peritoneal fluid"""

    name: Literal["peritoneal fluid"] = "peritoneal fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35683"] = "EMAPA_35683"


class _Peyer_S_Patch_Germinal_Center(_MouseAnatomicalStructureModel):
    """Model Peyer's patch germinal center"""

    name: Literal["Peyer's patch germinal center"] = "Peyer's patch germinal center"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35684"] = "EMAPA_35684"


class _Photoreceptor_Layer(_MouseAnatomicalStructureModel):
    """Model photoreceptor layer"""

    name: Literal["photoreceptor layer"] = "photoreceptor layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35686"] = "EMAPA_35686"


class _Photoreceptor_Layer_Inner_Segment(_MouseAnatomicalStructureModel):
    """Model photoreceptor layer inner segment"""

    name: Literal["photoreceptor layer inner segment"] = "photoreceptor layer inner segment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35687"] = "EMAPA_35687"


class _Photoreceptor_Layer_Outer_Segment(_MouseAnatomicalStructureModel):
    """Model photoreceptor layer outer segment"""

    name: Literal["photoreceptor layer outer segment"] = "photoreceptor layer outer segment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35688"] = "EMAPA_35688"


class _Placenta(_MouseAnatomicalStructureModel):
    """Model placenta"""

    name: Literal["placenta"] = "placenta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35689"] = "EMAPA_35689"


class _Plasma(_MouseAnatomicalStructureModel):
    """Model plasma"""

    name: Literal["plasma"] = "plasma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35690"] = "EMAPA_35690"


class _Spinal_Cord_Intermediate_Grey(_MouseAnatomicalStructureModel):
    """Model spinal cord intermediate grey"""

    name: Literal["spinal cord intermediate grey"] = "spinal cord intermediate grey"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35691"] = "EMAPA_35691"


class _Pontine_Nucleus(_MouseAnatomicalStructureModel):
    """Model pontine nucleus"""

    name: Literal["pontine nucleus"] = "pontine nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35692"] = "EMAPA_35692"


class _Pontine_Reticular_Formation(_MouseAnatomicalStructureModel):
    """Model pontine reticular formation"""

    name: Literal["pontine reticular formation"] = "pontine reticular formation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35693"] = "EMAPA_35693"


class _Posterior_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model posterior amygdaloid nucleus"""

    name: Literal["posterior amygdaloid nucleus"] = "posterior amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35694"] = "EMAPA_35694"


class _Posterior_Commissure(_MouseAnatomicalStructureModel):
    """Model posterior commissure"""

    name: Literal["posterior commissure"] = "posterior commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35695"] = "EMAPA_35695"


class _Posterior_Septal_Complex(_MouseAnatomicalStructureModel):
    """Model posterior septal complex"""

    name: Literal["posterior septal complex"] = "posterior septal complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35696"] = "EMAPA_35696"


class _Posterior_Thalamic_Group(_MouseAnatomicalStructureModel):
    """Model posterior thalamic group"""

    name: Literal["posterior thalamic group"] = "posterior thalamic group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35697"] = "EMAPA_35697"


class _Posterior_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model posterior thalamic nucleus"""

    name: Literal["posterior thalamic nucleus"] = "posterior thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35698"] = "EMAPA_35698"


class _Posterolateral_Cortical_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model posterolateral cortical amygdaloid nucleus"""

    name: Literal["posterolateral cortical amygdaloid nucleus"] = "posterolateral cortical amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35699"] = "EMAPA_35699"


class _Posteromedial_Cortical_Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model posteromedial cortical amygdaloid nucleus"""

    name: Literal["posteromedial cortical amygdaloid nucleus"] = "posteromedial cortical amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35700"] = "EMAPA_35700"


class _Preputial_Gland(_MouseAnatomicalStructureModel):
    """Model preputial gland"""

    name: Literal["preputial gland"] = "preputial gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35701"] = "EMAPA_35701"


class _Preputial_Swelling(_MouseAnatomicalStructureModel):
    """Model preputial swelling"""

    name: Literal["preputial swelling"] = "preputial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35702"] = "EMAPA_35702"


class _Presubiculum(_MouseAnatomicalStructureModel):
    """Model presubiculum"""

    name: Literal["presubiculum"] = "presubiculum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35703"] = "EMAPA_35703"


class _Primary_Motor_Cortex(_MouseAnatomicalStructureModel):
    """Model primary motor cortex"""

    name: Literal["primary motor cortex"] = "primary motor cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35704"] = "EMAPA_35704"


class _Primary_Oocyte(_MouseAnatomicalStructureModel):
    """Model primary oocyte"""

    name: Literal["primary oocyte"] = "primary oocyte"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35705"] = "EMAPA_35705"


class _Primary_Somatosensory_Cortex(_MouseAnatomicalStructureModel):
    """Model primary somatosensory cortex"""

    name: Literal["primary somatosensory cortex"] = "primary somatosensory cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35706"] = "EMAPA_35706"


class _Primary_Spermatocyte(_MouseAnatomicalStructureModel):
    """Model primary spermatocyte"""

    name: Literal["primary spermatocyte"] = "primary spermatocyte"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35707"] = "EMAPA_35707"


class _Primary_Visual_Cortex(_MouseAnatomicalStructureModel):
    """Model primary visual cortex"""

    name: Literal["primary visual cortex"] = "primary visual cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35708"] = "EMAPA_35708"


class _Forelimb_Interdigital_Region_Skin(_MouseAnatomicalStructureModel):
    """Model forelimb interdigital region skin"""

    name: Literal["forelimb interdigital region skin"] = "forelimb interdigital region skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35709"] = "EMAPA_35709"


class _Prostate_Gland_Dorsolateral_Lobe(_MouseAnatomicalStructureModel):
    """Model prostate gland dorsolateral lobe"""

    name: Literal["prostate gland dorsolateral lobe"] = "prostate gland dorsolateral lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35710"] = "EMAPA_35710"


class _Prostate_Epithelium(_MouseAnatomicalStructureModel):
    """Model prostate epithelium"""

    name: Literal["prostate epithelium"] = "prostate epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35711"] = "EMAPA_35711"


class _Prostate_Gland_Lobe(_MouseAnatomicalStructureModel):
    """Model prostate gland lobe"""

    name: Literal["prostate gland lobe"] = "prostate gland lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35712"] = "EMAPA_35712"


class _Prostate_Gland_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model prostate gland smooth muscle"""

    name: Literal["prostate gland smooth muscle"] = "prostate gland smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35713"] = "EMAPA_35713"


class _Prostate_Stroma(_MouseAnatomicalStructureModel):
    """Model prostate stroma"""

    name: Literal["prostate stroma"] = "prostate stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35714"] = "EMAPA_35714"


class _Forelimb_Interdigital_Region_Dermis(_MouseAnatomicalStructureModel):
    """Model forelimb interdigital region dermis"""

    name: Literal["forelimb interdigital region dermis"] = "forelimb interdigital region dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35715"] = "EMAPA_35715"


class _Proximal_Phalanx(_MouseAnatomicalStructureModel):
    """Model proximal phalanx"""

    name: Literal["proximal phalanx"] = "proximal phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35716"] = "EMAPA_35716"


class _Right_Lung_Alveolar_System(_MouseAnatomicalStructureModel):
    """Model right lung alveolar system"""

    name: Literal["right lung alveolar system"] = "right lung alveolar system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35717"] = "EMAPA_35717"


class _Purkinje_Fiber(_MouseAnatomicalStructureModel):
    """Model purkinje fiber"""

    name: Literal["purkinje fiber"] = "purkinje fiber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35718"] = "EMAPA_35718"


class _Putamen(_MouseAnatomicalStructureModel):
    """Model putamen"""

    name: Literal["putamen"] = "putamen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35719"] = "EMAPA_35719"


class _Raphe_Magnus_Nucleus(_MouseAnatomicalStructureModel):
    """Model raphe magnus nucleus"""

    name: Literal["raphe magnus nucleus"] = "raphe magnus nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35720"] = "EMAPA_35720"


class _Raphe_Nucleus(_MouseAnatomicalStructureModel):
    """Model raphe nucleus"""

    name: Literal["raphe nucleus"] = "raphe nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35721"] = "EMAPA_35721"


class _Raphe_Pallidus_Nucleus(_MouseAnatomicalStructureModel):
    """Model raphe pallidus nucleus"""

    name: Literal["raphe pallidus nucleus"] = "raphe pallidus nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35722"] = "EMAPA_35722"


class _Red_Nucleus(_MouseAnatomicalStructureModel):
    """Model red nucleus"""

    name: Literal["red nucleus"] = "red nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35724"] = "EMAPA_35724"


class _Renal_Convoluted_Tubule(_MouseAnatomicalStructureModel):
    """Model renal convoluted tubule"""

    name: Literal["renal convoluted tubule"] = "renal convoluted tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35725"] = "EMAPA_35725"


class _Renal_Corpuscle(_MouseAnatomicalStructureModel):
    """Model renal corpuscle"""

    name: Literal["renal corpuscle"] = "renal corpuscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35726"] = "EMAPA_35726"


class _Renal_Papilla(_MouseAnatomicalStructureModel):
    """Model renal papilla"""

    name: Literal["renal papilla"] = "renal papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35727"] = "EMAPA_35727"


class _Reproductive_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model reproductive system mesenchyme"""

    name: Literal["reproductive system mesenchyme"] = "reproductive system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35728"] = "EMAPA_35728"


class _Respiratory_Bronchiole(_MouseAnatomicalStructureModel):
    """Model respiratory bronchiole"""

    name: Literal["respiratory bronchiole"] = "respiratory bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35729"] = "EMAPA_35729"


class _Respiratory_Bronchiole_Epithelium(_MouseAnatomicalStructureModel):
    """Model respiratory bronchiole epithelium"""

    name: Literal["respiratory bronchiole epithelium"] = "respiratory bronchiole epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35730"] = "EMAPA_35730"


class _Respiratory_System_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model respiratory system blood vessel"""

    name: Literal["respiratory system blood vessel"] = "respiratory system blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35731"] = "EMAPA_35731"


class _Respiratory_System_Blood_Vessel_Endothelium(_MouseAnatomicalStructureModel):
    """Model respiratory system blood vessel endothelium"""

    name: Literal["respiratory system blood vessel endothelium"] = "respiratory system blood vessel endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35732"] = "EMAPA_35732"


class _Respiratory_System_Muscle(_MouseAnatomicalStructureModel):
    """Model respiratory system muscle"""

    name: Literal["respiratory system muscle"] = "respiratory system muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35733"] = "EMAPA_35733"


class _Respiratory_System_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model respiratory system smooth muscle"""

    name: Literal["respiratory system smooth muscle"] = "respiratory system smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35734"] = "EMAPA_35734"


class _Reticular_Membrane(_MouseAnatomicalStructureModel):
    """Model reticular membrane"""

    name: Literal["reticular membrane"] = "reticular membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35735"] = "EMAPA_35735"


class _Reticular_Tegmental_Nucleus(_MouseAnatomicalStructureModel):
    """Model reticular tegmental nucleus"""

    name: Literal["reticular tegmental nucleus"] = "reticular tegmental nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35736"] = "EMAPA_35736"


class _Reticular_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model reticular thalamic nucleus"""

    name: Literal["reticular thalamic nucleus"] = "reticular thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35737"] = "EMAPA_35737"


class _Retina_Epithelium(_MouseAnatomicalStructureModel):
    """Model retina epithelium"""

    name: Literal["retina epithelium"] = "retina epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35738"] = "EMAPA_35738"


class _Retina_Ganglion_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model retina ganglion cell layer"""

    name: Literal["retina ganglion cell layer"] = "retina ganglion cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35739"] = "EMAPA_35739"


class _Retina_Inner_Plexiform_Layer(_MouseAnatomicalStructureModel):
    """Model retina inner plexiform layer"""

    name: Literal["retina inner plexiform layer"] = "retina inner plexiform layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35741"] = "EMAPA_35741"


class _Retina_Layer(_MouseAnatomicalStructureModel):
    """Model retina layer"""

    name: Literal["retina layer"] = "retina layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35742"] = "EMAPA_35742"


class _Retina_Outer_Plexiform_Layer(_MouseAnatomicalStructureModel):
    """Model retina outer plexiform layer"""

    name: Literal["retina outer plexiform layer"] = "retina outer plexiform layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35744"] = "EMAPA_35744"


class _Retrohippocampal_Cortex(_MouseAnatomicalStructureModel):
    """Model retrohippocampal cortex"""

    name: Literal["retrohippocampal cortex"] = "retrohippocampal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35745"] = "EMAPA_35745"


class _Rhombomere_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model rhombomere neural crest"""

    name: Literal["rhombomere neural crest"] = "rhombomere neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35747"] = "EMAPA_35747"


class _Rhombomere_Neural_Fold(_MouseAnatomicalStructureModel):
    """Model rhombomere neural fold"""

    name: Literal["rhombomere neural fold"] = "rhombomere neural fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35748"] = "EMAPA_35748"


class _Right_Common_Carotid_Artery(_MouseAnatomicalStructureModel):
    """Model right common carotid artery"""

    name: Literal["right common carotid artery"] = "right common carotid artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35749"] = "EMAPA_35749"


class _Salivary_Duct(_MouseAnatomicalStructureModel):
    """Model salivary duct"""

    name: Literal["salivary duct"] = "salivary duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35750"] = "EMAPA_35750"


class _Scala_Media(_MouseAnatomicalStructureModel):
    """Model scala media"""

    name: Literal["scala media"] = "scala media"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35751"] = "EMAPA_35751"


class _Scala_Tympani(_MouseAnatomicalStructureModel):
    """Model scala tympani"""

    name: Literal["scala tympani"] = "scala tympani"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35752"] = "EMAPA_35752"


class _Scala_Vestibuli(_MouseAnatomicalStructureModel):
    """Model scala vestibuli"""

    name: Literal["scala vestibuli"] = "scala vestibuli"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35753"] = "EMAPA_35753"


class _Sebaceous_Gland(_MouseAnatomicalStructureModel):
    """Model sebaceous gland"""

    name: Literal["sebaceous gland"] = "sebaceous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35754"] = "EMAPA_35754"


class _Secondary_Oocyte(_MouseAnatomicalStructureModel):
    """Model secondary oocyte"""

    name: Literal["secondary oocyte"] = "secondary oocyte"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35755"] = "EMAPA_35755"


class _Secondary_Somatosensory_Cortex(_MouseAnatomicalStructureModel):
    """Model secondary somatosensory cortex"""

    name: Literal["secondary somatosensory cortex"] = "secondary somatosensory cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35756"] = "EMAPA_35756"


class _Secondary_Spermatocyte(_MouseAnatomicalStructureModel):
    """Model secondary spermatocyte"""

    name: Literal["secondary spermatocyte"] = "secondary spermatocyte"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35757"] = "EMAPA_35757"


class _Secondary_Visual_Cortex(_MouseAnatomicalStructureModel):
    """Model secondary visual cortex"""

    name: Literal["secondary visual cortex"] = "secondary visual cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35758"] = "EMAPA_35758"


class _Secretory_Circumventricular_Organ(_MouseAnatomicalStructureModel):
    """Model secretory circumventricular organ"""

    name: Literal["secretory circumventricular organ"] = "secretory circumventricular organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35759"] = "EMAPA_35759"


class _Semilunar_Valve(_MouseAnatomicalStructureModel):
    """Model semilunar valve"""

    name: Literal["semilunar valve"] = "semilunar valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35760"] = "EMAPA_35760"


class _Seminiferous_Tubule_Epithelium(_MouseAnatomicalStructureModel):
    """Model seminiferous tubule epithelium"""

    name: Literal["seminiferous tubule epithelium"] = "seminiferous tubule epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35761"] = "EMAPA_35761"


class _Semitendinosus(_MouseAnatomicalStructureModel):
    """Model semitendinosus"""

    name: Literal["semitendinosus"] = "semitendinosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35762"] = "EMAPA_35762"


class _Septal_Nucleus(_MouseAnatomicalStructureModel):
    """Model septal nucleus"""

    name: Literal["septal nucleus"] = "septal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35763"] = "EMAPA_35763"


class _Septal_Olfactory_Organ(_MouseAnatomicalStructureModel):
    """Model septal olfactory organ"""

    name: Literal["septal olfactory organ"] = "septal olfactory organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35764"] = "EMAPA_35764"


class _Grueneberg_Ganglion(_MouseAnatomicalStructureModel):
    """Model Grueneberg ganglion"""

    name: Literal["Grueneberg ganglion"] = "Grueneberg ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35765"] = "EMAPA_35765"


class _Septal_Organ_Of_Masera(_MouseAnatomicalStructureModel):
    """Model septal organ of Masera"""

    name: Literal["septal organ of Masera"] = "septal organ of Masera"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35766"] = "EMAPA_35766"


class _Septofimbrial_Nucleus(_MouseAnatomicalStructureModel):
    """Model septofimbrial nucleus"""

    name: Literal["septofimbrial nucleus"] = "septofimbrial nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35767"] = "EMAPA_35767"


class _Septohippocampal_Nucleus(_MouseAnatomicalStructureModel):
    """Model septohippocampal nucleus"""

    name: Literal["septohippocampal nucleus"] = "septohippocampal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35768"] = "EMAPA_35768"


class _Serratus_Muscle(_MouseAnatomicalStructureModel):
    """Model serratus muscle"""

    name: Literal["serratus muscle"] = "serratus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35769"] = "EMAPA_35769"


class _Serum(_MouseAnatomicalStructureModel):
    """Model serum"""

    name: Literal["serum"] = "serum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35770"] = "EMAPA_35770"


class _Sesamoid_Bone_Of_Gastrocnemius(_MouseAnatomicalStructureModel):
    """Model sesamoid bone of gastrocnemius"""

    name: Literal["sesamoid bone of gastrocnemius"] = "sesamoid bone of gastrocnemius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35771"] = "EMAPA_35771"


class _Sinoatrial_Node(_MouseAnatomicalStructureModel):
    """Model sinoatrial node"""

    name: Literal["sinoatrial node"] = "sinoatrial node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35772"] = "EMAPA_35772"


class _Skeletal_System(_MouseAnatomicalStructureModel):
    """Model skeletal system"""

    name: Literal["skeletal system"] = "skeletal system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35773"] = "EMAPA_35773"


class _Skin_Gland(_MouseAnatomicalStructureModel):
    """Model skin gland"""

    name: Literal["skin gland"] = "skin gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35774"] = "EMAPA_35774"


class _Skin_Mucous_Gland(_MouseAnatomicalStructureModel):
    """Model skin mucous gland"""

    name: Literal["skin mucous gland"] = "skin mucous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35775"] = "EMAPA_35775"


class _Skin_Muscle(_MouseAnatomicalStructureModel):
    """Model skin muscle"""

    name: Literal["skin muscle"] = "skin muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35776"] = "EMAPA_35776"


class _Small_Intestine_Crypt_Of_Lieberkuhn(_MouseAnatomicalStructureModel):
    """Model small intestine crypt of lieberkuhn"""

    name: Literal["small intestine crypt of lieberkuhn"] = "small intestine crypt of lieberkuhn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35777"] = "EMAPA_35777"


class _Small_Intestine_Epithelium(_MouseAnatomicalStructureModel):
    """Model small intestine epithelium"""

    name: Literal["small intestine epithelium"] = "small intestine epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35778"] = "EMAPA_35778"


class _Small_Intestine_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model small intestine lamina propria"""

    name: Literal["small intestine lamina propria"] = "small intestine lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35779"] = "EMAPA_35779"


class _Small_Intestine_Mucosa(_MouseAnatomicalStructureModel):
    """Model small intestine mucosa"""

    name: Literal["small intestine mucosa"] = "small intestine mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35780"] = "EMAPA_35780"


class _Small_Intestine_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model small intestine muscularis mucosa"""

    name: Literal["small intestine muscularis mucosa"] = "small intestine muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35781"] = "EMAPA_35781"


class _Small_Intestine_Peyer_S_Patch(_MouseAnatomicalStructureModel):
    """Model small intestine Peyer's patch"""

    name: Literal["small intestine Peyer's patch"] = "small intestine Peyer's patch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35782"] = "EMAPA_35782"


class _Small_Intestine_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model small intestine smooth muscle"""

    name: Literal["small intestine smooth muscle"] = "small intestine smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35783"] = "EMAPA_35783"


class _Intestinal_Villus(_MouseAnatomicalStructureModel):
    """Model intestinal villus"""

    name: Literal["intestinal villus"] = "intestinal villus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35784"] = "EMAPA_35784"


class _Small_Intestine_Wall(_MouseAnatomicalStructureModel):
    """Model small intestine wall"""

    name: Literal["small intestine wall"] = "small intestine wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35785"] = "EMAPA_35785"


class _Soleus(_MouseAnatomicalStructureModel):
    """Model soleus"""

    name: Literal["soleus"] = "soleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35786"] = "EMAPA_35786"


class _Solitary_Tract_Nucleus(_MouseAnatomicalStructureModel):
    """Model solitary tract nucleus"""

    name: Literal["solitary tract nucleus"] = "solitary tract nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35787"] = "EMAPA_35787"


class _Sphincter_Pupillae(_MouseAnatomicalStructureModel):
    """Model sphincter pupillae"""

    name: Literal["sphincter pupillae"] = "sphincter pupillae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35788"] = "EMAPA_35788"


class _Spinal_Cord_Central_Canal(_MouseAnatomicalStructureModel):
    """Model spinal cord central canal"""

    name: Literal["spinal cord central canal"] = "spinal cord central canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35789"] = "EMAPA_35789"


class _Spinal_Cord_Dorsal_Horn(_MouseAnatomicalStructureModel):
    """Model spinal cord dorsal horn"""

    name: Literal["spinal cord dorsal horn"] = "spinal cord dorsal horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35790"] = "EMAPA_35790"


class _Spinal_Cord_Ependymal_Layer(_MouseAnatomicalStructureModel):
    """Model spinal cord ependymal layer"""

    name: Literal["spinal cord ependymal layer"] = "spinal cord ependymal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35791"] = "EMAPA_35791"


class _Spinal_Cord_Gray_Matter(_MouseAnatomicalStructureModel):
    """Model spinal cord gray matter"""

    name: Literal["spinal cord gray matter"] = "spinal cord gray matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35792"] = "EMAPA_35792"


class _Spinal_Cord_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model spinal cord vascular element"""

    name: Literal["spinal cord vascular element"] = "spinal cord vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35793"] = "EMAPA_35793"


class _Spinal_Cord_Ventral_Horn(_MouseAnatomicalStructureModel):
    """Model spinal cord ventral horn"""

    name: Literal["spinal cord ventral horn"] = "spinal cord ventral horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35794"] = "EMAPA_35794"


class _Spinal_Cord_White_Matter(_MouseAnatomicalStructureModel):
    """Model spinal cord white matter"""

    name: Literal["spinal cord white matter"] = "spinal cord white matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35795"] = "EMAPA_35795"


class _Spinal_Ganglion_Or_Nerve(_MouseAnatomicalStructureModel):
    """Model spinal ganglion or nerve"""

    name: Literal["spinal ganglion or nerve"] = "spinal ganglion or nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35796"] = "EMAPA_35796"


class _Spinal_Vestibular_Nucleus(_MouseAnatomicalStructureModel):
    """Model spinal vestibular nucleus"""

    name: Literal["spinal vestibular nucleus"] = "spinal vestibular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35797"] = "EMAPA_35797"


class _Spiral_Ligament(_MouseAnatomicalStructureModel):
    """Model spiral ligament"""

    name: Literal["spiral ligament"] = "spiral ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35798"] = "EMAPA_35798"


class _Spiral_Prominence(_MouseAnatomicalStructureModel):
    """Model spiral prominence"""

    name: Literal["spiral prominence"] = "spiral prominence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35799"] = "EMAPA_35799"


class _Spiral_Sulcus(_MouseAnatomicalStructureModel):
    """Model spiral sulcus"""

    name: Literal["spiral sulcus"] = "spiral sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35800"] = "EMAPA_35800"


class _Spiral_Vessel(_MouseAnatomicalStructureModel):
    """Model spiral vessel"""

    name: Literal["spiral vessel"] = "spiral vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35801"] = "EMAPA_35801"


class _Spleen_Capsule(_MouseAnatomicalStructureModel):
    """Model spleen capsule"""

    name: Literal["spleen capsule"] = "spleen capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35802"] = "EMAPA_35802"


class _Spleen_Germinal_Center(_MouseAnatomicalStructureModel):
    """Model spleen germinal center"""

    name: Literal["spleen germinal center"] = "spleen germinal center"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35803"] = "EMAPA_35803"


class _Spleen_Lymphoid_Follicle(_MouseAnatomicalStructureModel):
    """Model spleen lymphoid follicle"""

    name: Literal["spleen lymphoid follicle"] = "spleen lymphoid follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35804"] = "EMAPA_35804"


class _Spleen_Pulp(_MouseAnatomicalStructureModel):
    """Model spleen pulp"""

    name: Literal["spleen pulp"] = "spleen pulp"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35805"] = "EMAPA_35805"


class _Spleen_Red_Pulp(_MouseAnatomicalStructureModel):
    """Model spleen red pulp"""

    name: Literal["spleen red pulp"] = "spleen red pulp"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35806"] = "EMAPA_35806"


class _Spleen_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model spleen smooth muscle"""

    name: Literal["spleen smooth muscle"] = "spleen smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35807"] = "EMAPA_35807"


class _Spleen_Trabeculum(_MouseAnatomicalStructureModel):
    """Model spleen trabeculum"""

    name: Literal["spleen trabeculum"] = "spleen trabeculum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35808"] = "EMAPA_35808"


class _Spleen_White_Pulp(_MouseAnatomicalStructureModel):
    """Model spleen white pulp"""

    name: Literal["spleen white pulp"] = "spleen white pulp"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35809"] = "EMAPA_35809"


class _Body_Of_Stomach(_MouseAnatomicalStructureModel):
    """Model body of stomach"""

    name: Literal["body of stomach"] = "body of stomach"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35810"] = "EMAPA_35810"


class _Stomach_Cardiac_Region(_MouseAnatomicalStructureModel):
    """Model stomach cardiac region"""

    name: Literal["stomach cardiac region"] = "stomach cardiac region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35811"] = "EMAPA_35811"


class _Stomach_Glandular_Epithelium(_MouseAnatomicalStructureModel):
    """Model stomach glandular epithelium"""

    name: Literal["stomach glandular epithelium"] = "stomach glandular epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35814"] = "EMAPA_35814"


class _Stomach_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach mucosa"""

    name: Literal["stomach mucosa"] = "stomach mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35817"] = "EMAPA_35817"


class _Stomach_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model stomach muscularis mucosa"""

    name: Literal["stomach muscularis mucosa"] = "stomach muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35818"] = "EMAPA_35818"


class _Right_Lung_Alveolar_Duct(_MouseAnatomicalStructureModel):
    """Model right lung alveolar duct"""

    name: Literal["right lung alveolar duct"] = "right lung alveolar duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35819"] = "EMAPA_35819"


class _Stomach_Region(_MouseAnatomicalStructureModel):
    """Model stomach region"""

    name: Literal["stomach region"] = "stomach region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35821"] = "EMAPA_35821"


class _Stomach_Serosa(_MouseAnatomicalStructureModel):
    """Model stomach serosa"""

    name: Literal["stomach serosa"] = "stomach serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35822"] = "EMAPA_35822"


class _Stomach_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model stomach smooth muscle"""

    name: Literal["stomach smooth muscle"] = "stomach smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35823"] = "EMAPA_35823"


class _Stomach_Squamous_Epithelium(_MouseAnatomicalStructureModel):
    """Model stomach squamous epithelium"""

    name: Literal["stomach squamous epithelium"] = "stomach squamous epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35824"] = "EMAPA_35824"


class _Stomach_Submucosa(_MouseAnatomicalStructureModel):
    """Model stomach submucosa"""

    name: Literal["stomach submucosa"] = "stomach submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35825"] = "EMAPA_35825"


class _Stomach_Wall(_MouseAnatomicalStructureModel):
    """Model stomach wall"""

    name: Literal["stomach wall"] = "stomach wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35826"] = "EMAPA_35826"


class _Stria_Vascularis(_MouseAnatomicalStructureModel):
    """Model stria vascularis"""

    name: Literal["stria vascularis"] = "stria vascularis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35827"] = "EMAPA_35827"


class _Subcommissural_Organ(_MouseAnatomicalStructureModel):
    """Model subcommissural organ"""

    name: Literal["subcommissural organ"] = "subcommissural organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35828"] = "EMAPA_35828"


class _Subcutaneous_Adipose_Tissue(_MouseAnatomicalStructureModel):
    """Model subcutaneous adipose tissue"""

    name: Literal["subcutaneous adipose tissue"] = "subcutaneous adipose tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35829"] = "EMAPA_35829"


class _Subfornical_Organ(_MouseAnatomicalStructureModel):
    """Model subfornical organ"""

    name: Literal["subfornical organ"] = "subfornical organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35830"] = "EMAPA_35830"


class _Dentate_Gyrus_Subgranular_Zone(_MouseAnatomicalStructureModel):
    """Model dentate gyrus subgranular zone"""

    name: Literal["dentate gyrus subgranular zone"] = "dentate gyrus subgranular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35831"] = "EMAPA_35831"


class _Subiculum(_MouseAnatomicalStructureModel):
    """Model subiculum"""

    name: Literal["subiculum"] = "subiculum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35832"] = "EMAPA_35832"


class _Submandibular_Duct(_MouseAnatomicalStructureModel):
    """Model submandibular duct"""

    name: Literal["submandibular duct"] = "submandibular duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35833"] = "EMAPA_35833"


class _Submucous_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model submucous nerve plexus"""

    name: Literal["submucous nerve plexus"] = "submucous nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35834"] = "EMAPA_35834"


class _Substantia_Nigra(_MouseAnatomicalStructureModel):
    """Model substantia nigra"""

    name: Literal["substantia nigra"] = "substantia nigra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35835"] = "EMAPA_35835"


class _Substantia_Nigra_Pars_Compacta(_MouseAnatomicalStructureModel):
    """Model substantia nigra pars compacta"""

    name: Literal["substantia nigra pars compacta"] = "substantia nigra pars compacta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35836"] = "EMAPA_35836"


class _Substantia_Nigra_Pars_Lateralis(_MouseAnatomicalStructureModel):
    """Model substantia nigra pars lateralis"""

    name: Literal["substantia nigra pars lateralis"] = "substantia nigra pars lateralis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35837"] = "EMAPA_35837"


class _Substantia_Nigra_Pars_Reticulata(_MouseAnatomicalStructureModel):
    """Model substantia nigra pars reticulata"""

    name: Literal["substantia nigra pars reticulata"] = "substantia nigra pars reticulata"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35838"] = "EMAPA_35838"


class _Subthalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model subthalamic nucleus"""

    name: Literal["subthalamic nucleus"] = "subthalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35839"] = "EMAPA_35839"


class _Superior_Olivary_Nucleus(_MouseAnatomicalStructureModel):
    """Model superior olivary nucleus"""

    name: Literal["superior olivary nucleus"] = "superior olivary nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35840"] = "EMAPA_35840"


class _Suprachiasmatic_Nucleus(_MouseAnatomicalStructureModel):
    """Model suprachiasmatic nucleus"""

    name: Literal["suprachiasmatic nucleus"] = "suprachiasmatic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35841"] = "EMAPA_35841"


class _Supramammillary_Nucleus(_MouseAnatomicalStructureModel):
    """Model supramammillary nucleus"""

    name: Literal["supramammillary nucleus"] = "supramammillary nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35842"] = "EMAPA_35842"


class _Supraoptic_Nucleus(_MouseAnatomicalStructureModel):
    """Model supraoptic nucleus"""

    name: Literal["supraoptic nucleus"] = "supraoptic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35843"] = "EMAPA_35843"


class _Sweat_Gland(_MouseAnatomicalStructureModel):
    """Model sweat gland"""

    name: Literal["sweat gland"] = "sweat gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35844"] = "EMAPA_35844"


class _Sympathetic_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model sympathetic nerve trunk"""

    name: Literal["sympathetic nerve trunk"] = "sympathetic nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35845"] = "EMAPA_35845"


class _Synchondrosis(_MouseAnatomicalStructureModel):
    """Model synchondrosis"""

    name: Literal["synchondrosis"] = "synchondrosis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35846"] = "EMAPA_35846"


class _Taenia_Tecta(_MouseAnatomicalStructureModel):
    """Model taenia tecta"""

    name: Literal["taenia tecta"] = "taenia tecta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35847"] = "EMAPA_35847"


class _Tail_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model tail blood vessel"""

    name: Literal["tail blood vessel"] = "tail blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35848"] = "EMAPA_35848"


class _Tail_Myotome(_MouseAnatomicalStructureModel):
    """Model tail myotome"""

    name: Literal["tail myotome"] = "tail myotome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35849"] = "EMAPA_35849"


class _Taste_Bud(_MouseAnatomicalStructureModel):
    """Model taste bud"""

    name: Literal["taste bud"] = "taste bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35850"] = "EMAPA_35850"


class _Tectorial_Membrane(_MouseAnatomicalStructureModel):
    """Model tectorial membrane"""

    name: Literal["tectorial membrane"] = "tectorial membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35851"] = "EMAPA_35851"


class _Temporal_Cortex_Association_Area(_MouseAnatomicalStructureModel):
    """Model temporal cortex association area"""

    name: Literal["temporal cortex association area"] = "temporal cortex association area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35852"] = "EMAPA_35852"


class _Tendo_Calcaneus(_MouseAnatomicalStructureModel):
    """Model tendo calcaneus"""

    name: Literal["tendo calcaneus"] = "tendo calcaneus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35853"] = "EMAPA_35853"


class _Tendon(_MouseAnatomicalStructureModel):
    """Model tendon"""

    name: Literal["tendon"] = "tendon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35854"] = "EMAPA_35854"


class _Tensor_Fasciae_Lata(_MouseAnatomicalStructureModel):
    """Model tensor fasciae lata"""

    name: Literal["tensor fasciae lata"] = "tensor fasciae lata"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35855"] = "EMAPA_35855"


class _Testis_Cortical_Region(_MouseAnatomicalStructureModel):
    """Model testis cortical region"""

    name: Literal["testis cortical region"] = "testis cortical region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35856"] = "EMAPA_35856"


class _Testis_Medullary_Region(_MouseAnatomicalStructureModel):
    """Model testis medullary region"""

    name: Literal["testis medullary region"] = "testis medullary region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35857"] = "EMAPA_35857"


class _Testis_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model testis mesenchyme"""

    name: Literal["testis mesenchyme"] = "testis mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35858"] = "EMAPA_35858"


class _Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model thalamic nucleus"""

    name: Literal["thalamic nucleus"] = "thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35859"] = "EMAPA_35859"


class _Thalamus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model thalamus vascular element"""

    name: Literal["thalamus vascular element"] = "thalamus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35860"] = "EMAPA_35860"


class _Thin_Ascending_Limb_Of_Medulla(_MouseAnatomicalStructureModel):
    """Model thin ascending limb of medulla"""

    name: Literal["thin ascending limb of medulla"] = "thin ascending limb of medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35861"] = "EMAPA_35861"


class _Thoracic_Segment_Of_Trunk(_MouseAnatomicalStructureModel):
    """Model thoracic segment of trunk"""

    name: Literal["thoracic segment of trunk"] = "thoracic segment of trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35862"] = "EMAPA_35862"


class _Thymus_Cortex(_MouseAnatomicalStructureModel):
    """Model thymus cortex"""

    name: Literal["thymus cortex"] = "thymus cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35863"] = "EMAPA_35863"


class _Thymus_Epithelium(_MouseAnatomicalStructureModel):
    """Model thymus epithelium"""

    name: Literal["thymus epithelium"] = "thymus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35864"] = "EMAPA_35864"


class _Thymus_Parathyroid_Primordium(_MouseAnatomicalStructureModel):
    """Model thymus/parathyroid primordium"""

    name: Literal["thymus/parathyroid primordium"] = "thymus/parathyroid primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35865"] = "EMAPA_35865"


class _Tibialis_Anterior(_MouseAnatomicalStructureModel):
    """Model tibialis anterior"""

    name: Literal["tibialis anterior"] = "tibialis anterior"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35866"] = "EMAPA_35866"


class _Tibialis_Muscle(_MouseAnatomicalStructureModel):
    """Model tibialis muscle"""

    name: Literal["tibialis muscle"] = "tibialis muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35867"] = "EMAPA_35867"


class _Tissue(_MouseAnatomicalStructureModel):
    """Model tissue"""

    name: Literal["tissue"] = "tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35868"] = "EMAPA_35868"


class _Tongue_Papilla_Epithelium(_MouseAnatomicalStructureModel):
    """Model tongue papilla epithelium"""

    name: Literal["tongue papilla epithelium"] = "tongue papilla epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35869"] = "EMAPA_35869"


class _Tongue_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model tongue vascular element"""

    name: Literal["tongue vascular element"] = "tongue vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35870"] = "EMAPA_35870"


class _Tonsil(_MouseAnatomicalStructureModel):
    """Model tonsil"""

    name: Literal["tonsil"] = "tonsil"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35871"] = "EMAPA_35871"


class _Tooth_Substance(_MouseAnatomicalStructureModel):
    """Model tooth substance"""

    name: Literal["tooth substance"] = "tooth substance"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35872"] = "EMAPA_35872"


class _Trabecular_Bone(_MouseAnatomicalStructureModel):
    """Model trabecular bone"""

    name: Literal["trabecular bone"] = "trabecular bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35873"] = "EMAPA_35873"


class _Trachea_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model trachea blood vessel"""

    name: Literal["trachea blood vessel"] = "trachea blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35874"] = "EMAPA_35874"


class _Trachea_Cartilage(_MouseAnatomicalStructureModel):
    """Model trachea cartilage"""

    name: Literal["trachea cartilage"] = "trachea cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35875"] = "EMAPA_35875"


class _Trachea_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model trachea connective tissue"""

    name: Literal["trachea connective tissue"] = "trachea connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35876"] = "EMAPA_35876"


class _Trachea_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model trachea lamina propria"""

    name: Literal["trachea lamina propria"] = "trachea lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35877"] = "EMAPA_35877"


class _Trachea_Non_Cartilage_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model trachea non-cartilage connective tissue"""

    name: Literal["trachea non-cartilage connective tissue"] = "trachea non-cartilage connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35878"] = "EMAPA_35878"


class _Trachea_Submucosa(_MouseAnatomicalStructureModel):
    """Model trachea submucosa"""

    name: Literal["trachea submucosa"] = "trachea submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35879"] = "EMAPA_35879"


class _Transverse_Colon(_MouseAnatomicalStructureModel):
    """Model transverse colon"""

    name: Literal["transverse colon"] = "transverse colon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35880"] = "EMAPA_35880"


class _Trigeminal_V_Mesencephalic_Nucleus(_MouseAnatomicalStructureModel):
    """Model trigeminal V mesencephalic nucleus"""

    name: Literal["trigeminal V mesencephalic nucleus"] = "trigeminal V mesencephalic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35881"] = "EMAPA_35881"


class _Trigeminal_V_Motor_Nucleus(_MouseAnatomicalStructureModel):
    """Model trigeminal V motor nucleus"""

    name: Literal["trigeminal V motor nucleus"] = "trigeminal V motor nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35882"] = "EMAPA_35882"


class _Trigeminal_Nucleus(_MouseAnatomicalStructureModel):
    """Model trigeminal nucleus"""

    name: Literal["trigeminal nucleus"] = "trigeminal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35883"] = "EMAPA_35883"


class _Trigeminal_V_Sensory_Nucleus(_MouseAnatomicalStructureModel):
    """Model trigeminal V sensory nucleus"""

    name: Literal["trigeminal V sensory nucleus"] = "trigeminal V sensory nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35884"] = "EMAPA_35884"


class _Trigeminal_V_Spinal_Sensory_Nucleus(_MouseAnatomicalStructureModel):
    """Model trigeminal V spinal sensory nucleus"""

    name: Literal["trigeminal V spinal sensory nucleus"] = "trigeminal V spinal sensory nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35885"] = "EMAPA_35885"


class _Trochlear_Nucleus(_MouseAnatomicalStructureModel):
    """Model trochlear nucleus"""

    name: Literal["trochlear nucleus"] = "trochlear nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35886"] = "EMAPA_35886"


class _Truncus_Arteriosus(_MouseAnatomicalStructureModel):
    """Model truncus arteriosus"""

    name: Literal["truncus arteriosus"] = "truncus arteriosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35887"] = "EMAPA_35887"


class _Trunk_Musculature(_MouseAnatomicalStructureModel):
    """Model trunk musculature"""

    name: Literal["trunk musculature"] = "trunk musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35888"] = "EMAPA_35888"


class _Tuberomammillary_Nucleus(_MouseAnatomicalStructureModel):
    """Model tuberomammillary nucleus"""

    name: Literal["tuberomammillary nucleus"] = "tuberomammillary nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35889"] = "EMAPA_35889"


class _Turbinate_Bone_Primordium(_MouseAnatomicalStructureModel):
    """Model turbinate bone primordium"""

    name: Literal["turbinate bone primordium"] = "turbinate bone primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35890"] = "EMAPA_35890"


class _Upper_Arm_Bone(_MouseAnatomicalStructureModel):
    """Model upper arm bone"""

    name: Literal["upper arm bone"] = "upper arm bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35892"] = "EMAPA_35892"


class _Upper_Leg_Bone(_MouseAnatomicalStructureModel):
    """Model upper leg bone"""

    name: Literal["upper leg bone"] = "upper leg bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35893"] = "EMAPA_35893"


class _Upper_Respiratory_Tract_Epithelium(_MouseAnatomicalStructureModel):
    """Model upper respiratory tract epithelium"""

    name: Literal["upper respiratory tract epithelium"] = "upper respiratory tract epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35894"] = "EMAPA_35894"


class _Ureter_Interstitium(_MouseAnatomicalStructureModel):
    """Model ureter interstitium"""

    name: Literal["ureter interstitium"] = "ureter interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35895"] = "EMAPA_35895"


class _Urethra_Epithelium(_MouseAnatomicalStructureModel):
    """Model urethra epithelium"""

    name: Literal["urethra epithelium"] = "urethra epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35896"] = "EMAPA_35896"


class _Bladder_Mucosa(_MouseAnatomicalStructureModel):
    """Model bladder mucosa"""

    name: Literal["bladder mucosa"] = "bladder mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35897"] = "EMAPA_35897"


class _Urinary_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model urinary system mesenchyme"""

    name: Literal["urinary system mesenchyme"] = "urinary system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35898"] = "EMAPA_35898"


class _Urogenital_Ridge(_MouseAnatomicalStructureModel):
    """Model urogenital ridge"""

    name: Literal["urogenital ridge"] = "urogenital ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35899"] = "EMAPA_35899"


class _Uterus_Stroma(_MouseAnatomicalStructureModel):
    """Model uterus stroma"""

    name: Literal["uterus stroma"] = "uterus stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35900"] = "EMAPA_35900"


class _Uvea(_MouseAnatomicalStructureModel):
    """Model uvea"""

    name: Literal["uvea"] = "uvea"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35901"] = "EMAPA_35901"


class _Lamina_Propria_Of_Vagina(_MouseAnatomicalStructureModel):
    """Model lamina propria of vagina"""

    name: Literal["lamina propria of vagina"] = "lamina propria of vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35902"] = "EMAPA_35902"


class _Cardiac_Valve_Leaflet(_MouseAnatomicalStructureModel):
    """Model cardiac valve leaflet"""

    name: Literal["cardiac valve leaflet"] = "cardiac valve leaflet"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35903"] = "EMAPA_35903"


class _Vascular_Plexus(_MouseAnatomicalStructureModel):
    """Model vascular plexus"""

    name: Literal["vascular plexus"] = "vascular plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35904"] = "EMAPA_35904"


class _Vascular_System(_MouseAnatomicalStructureModel):
    """Model vascular system"""

    name: Literal["vascular system"] = "vascular system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35905"] = "EMAPA_35905"


class _Vein(_MouseAnatomicalStructureModel):
    """Model vein"""

    name: Literal["vein"] = "vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35906"] = "EMAPA_35906"


class _Venous_System_Endothelium(_MouseAnatomicalStructureModel):
    """Model venous system endothelium"""

    name: Literal["venous system endothelium"] = "venous system endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35907"] = "EMAPA_35907"


class _Ventral_Lateral_Geniculate_Nucleus(_MouseAnatomicalStructureModel):
    """Model ventral lateral geniculate nucleus"""

    name: Literal["ventral lateral geniculate nucleus"] = "ventral lateral geniculate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35908"] = "EMAPA_35908"


class _Ventral_Nasal_Artery(_MouseAnatomicalStructureModel):
    """Model ventral nasal artery"""

    name: Literal["ventral nasal artery"] = "ventral nasal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35909"] = "EMAPA_35909"


class _Ventral_Posterior_Lateral_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model ventral posterior lateral thalamic nucleus"""

    name: Literal["ventral posterior lateral thalamic nucleus"] = "ventral posterior lateral thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35910"] = "EMAPA_35910"


class _Ventral_Posterior_Medial_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model ventral posterior medial thalamic nucleus"""

    name: Literal["ventral posterior medial thalamic nucleus"] = "ventral posterior medial thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35911"] = "EMAPA_35911"


class _Ventral_Posterior_Thalamic_Group(_MouseAnatomicalStructureModel):
    """Model ventral posterior thalamic group"""

    name: Literal["ventral posterior thalamic group"] = "ventral posterior thalamic group"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35912"] = "EMAPA_35912"


class _Ventral_Tegmental_Area(_MouseAnatomicalStructureModel):
    """Model ventral tegmental area"""

    name: Literal["ventral tegmental area"] = "ventral tegmental area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35913"] = "EMAPA_35913"


class _Ventral_Tegmental_Nucleus(_MouseAnatomicalStructureModel):
    """Model ventral tegmental nucleus"""

    name: Literal["ventral tegmental nucleus"] = "ventral tegmental nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35914"] = "EMAPA_35914"


class _Prethalamus(_MouseAnatomicalStructureModel):
    """Model prethalamus"""

    name: Literal["prethalamus"] = "prethalamus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35915"] = "EMAPA_35915"


class _Ventromedial_Hypothalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model ventromedial hypothalamic nucleus"""

    name: Literal["ventromedial hypothalamic nucleus"] = "ventromedial hypothalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35916"] = "EMAPA_35916"


class _Venule(_MouseAnatomicalStructureModel):
    """Model venule"""

    name: Literal["venule"] = "venule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35917"] = "EMAPA_35917"


class _Vertebra_Caudal_Articular_Process(_MouseAnatomicalStructureModel):
    """Model vertebra caudal articular process"""

    name: Literal["vertebra caudal articular process"] = "vertebra caudal articular process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35918"] = "EMAPA_35918"


class _Vertebral_Column(_MouseAnatomicalStructureModel):
    """Model vertebral column"""

    name: Literal["vertebral column"] = "vertebral column"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35919"] = "EMAPA_35919"


class _Vestibular_Epithelium(_MouseAnatomicalStructureModel):
    """Model vestibular epithelium"""

    name: Literal["vestibular epithelium"] = "vestibular epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35921"] = "EMAPA_35921"


class _Vestibular_Membrane(_MouseAnatomicalStructureModel):
    """Model vestibular membrane"""

    name: Literal["vestibular membrane"] = "vestibular membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35922"] = "EMAPA_35922"


class _Vestibular_Nucleus(_MouseAnatomicalStructureModel):
    """Model vestibular nucleus"""

    name: Literal["vestibular nucleus"] = "vestibular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35923"] = "EMAPA_35923"


class _Viscerocranium_Bone(_MouseAnatomicalStructureModel):
    """Model viscerocranium bone"""

    name: Literal["viscerocranium bone"] = "viscerocranium bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35924"] = "EMAPA_35924"


class _Wharton_S_Jelly(_MouseAnatomicalStructureModel):
    """Model Wharton's jelly"""

    name: Literal["Wharton's jelly"] = "Wharton's jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35925"] = "EMAPA_35925"


class _White_Fat(_MouseAnatomicalStructureModel):
    """Model white fat"""

    name: Literal["white fat"] = "white fat"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35926"] = "EMAPA_35926"


class _White_Matter(_MouseAnatomicalStructureModel):
    """Model white matter"""

    name: Literal["white matter"] = "white matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35927"] = "EMAPA_35927"


class _Yolk_Sac_Parietal_Endoderm(_MouseAnatomicalStructureModel):
    """Model yolk sac parietal endoderm"""

    name: Literal["yolk sac parietal endoderm"] = "yolk sac parietal endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35928"] = "EMAPA_35928"


class _Yolk_Sac_Visceral_Endoderm(_MouseAnatomicalStructureModel):
    """Model yolk sac visceral endoderm"""

    name: Literal["yolk sac visceral endoderm"] = "yolk sac visceral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35929"] = "EMAPA_35929"


class _Zona_Incerta(_MouseAnatomicalStructureModel):
    """Model zona incerta"""

    name: Literal["zona incerta"] = "zona incerta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35930"] = "EMAPA_35930"


class _Pelvic_Region_Of_Trunk(_MouseAnatomicalStructureModel):
    """Model pelvic region of trunk"""

    name: Literal["pelvic region of trunk"] = "pelvic region of trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35931"] = "EMAPA_35931"


class _Venous_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model venous blood vessel"""

    name: Literal["venous blood vessel"] = "venous blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35932"] = "EMAPA_35932"


class _Forelimb_Bone(_MouseAnatomicalStructureModel):
    """Model forelimb bone"""

    name: Literal["forelimb bone"] = "forelimb bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35933"] = "EMAPA_35933"


class _Hindlimb_Bone(_MouseAnatomicalStructureModel):
    """Model hindlimb bone"""

    name: Literal["hindlimb bone"] = "hindlimb bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35934"] = "EMAPA_35934"


class _Cornea_Endothelium(_MouseAnatomicalStructureModel):
    """Model cornea endothelium"""

    name: Literal["cornea endothelium"] = "cornea endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35935"] = "EMAPA_35935"


class _Forelimb_Interdigital_Region_Epidermis(_MouseAnatomicalStructureModel):
    """Model forelimb interdigital region epidermis"""

    name: Literal["forelimb interdigital region epidermis"] = "forelimb interdigital region epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35936"] = "EMAPA_35936"


class _Hindlimb_Interdigital_Region_Skin(_MouseAnatomicalStructureModel):
    """Model hindlimb interdigital region skin"""

    name: Literal["hindlimb interdigital region skin"] = "hindlimb interdigital region skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35937"] = "EMAPA_35937"


class _Hindlimb_Interdigital_Region_Dermis(_MouseAnatomicalStructureModel):
    """Model hindlimb interdigital region dermis"""

    name: Literal["hindlimb interdigital region dermis"] = "hindlimb interdigital region dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35938"] = "EMAPA_35938"


class _Hindlimb_Interdigital_Region_Epidermis(_MouseAnatomicalStructureModel):
    """Model hindlimb interdigital region epidermis"""

    name: Literal["hindlimb interdigital region epidermis"] = "hindlimb interdigital region epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35939"] = "EMAPA_35939"


class _Limb_Interdigital_Region_Dermis(_MouseAnatomicalStructureModel):
    """Model limb interdigital region dermis"""

    name: Literal["limb interdigital region dermis"] = "limb interdigital region dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35940"] = "EMAPA_35940"


class _Limb_Interdigital_Region_Epidermis(_MouseAnatomicalStructureModel):
    """Model limb interdigital region epidermis"""

    name: Literal["limb interdigital region epidermis"] = "limb interdigital region epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35941"] = "EMAPA_35941"


class _Future_Forebrain_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model future forebrain ventricular layer"""

    name: Literal["future forebrain ventricular layer"] = "future forebrain ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35942"] = "EMAPA_35942"


class _Limb_Bud(_MouseAnatomicalStructureModel):
    """Model limb bud"""

    name: Literal["limb bud"] = "limb bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35944"] = "EMAPA_35944"


class _Gum(_MouseAnatomicalStructureModel):
    """Model gum"""

    name: Literal["gum"] = "gum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35945"] = "EMAPA_35945"


class _Nerve_Of_Female_Reproductive_System(_MouseAnatomicalStructureModel):
    """Model nerve of female reproductive system"""

    name: Literal["nerve of female reproductive system"] = "nerve of female reproductive system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35946"] = "EMAPA_35946"


class _Nerve_Of_Male_Reproductive_System(_MouseAnatomicalStructureModel):
    """Model nerve of male reproductive system"""

    name: Literal["nerve of male reproductive system"] = "nerve of male reproductive system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35947"] = "EMAPA_35947"


class _Nerve_Of_Urinary_System(_MouseAnatomicalStructureModel):
    """Model nerve of urinary system"""

    name: Literal["nerve of urinary system"] = "nerve of urinary system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35948"] = "EMAPA_35948"


class _Organ(_MouseAnatomicalStructureModel):
    """Model organ"""

    name: Literal["organ"] = "organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35949"] = "EMAPA_35949"


class _Liver_And_Biliary_System_Epithelium(_MouseAnatomicalStructureModel):
    """Model liver and biliary system epithelium"""

    name: Literal["liver and biliary system epithelium"] = "liver and biliary system epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35950"] = "EMAPA_35950"


class _Reproductive_System_Epithelium(_MouseAnatomicalStructureModel):
    """Model reproductive system epithelium"""

    name: Literal["reproductive system epithelium"] = "reproductive system epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35951"] = "EMAPA_35951"


class _Sensory_Organ_Epithelium(_MouseAnatomicalStructureModel):
    """Model sensory organ epithelium"""

    name: Literal["sensory organ epithelium"] = "sensory organ epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35952"] = "EMAPA_35952"


class _Urinary_System_Epithelium(_MouseAnatomicalStructureModel):
    """Model urinary system epithelium"""

    name: Literal["urinary system epithelium"] = "urinary system epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35953"] = "EMAPA_35953"


class _Genitourinary_System_Epithelium(_MouseAnatomicalStructureModel):
    """Model genitourinary system epithelium"""

    name: Literal["genitourinary system epithelium"] = "genitourinary system epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35954"] = "EMAPA_35954"


class _Sensory_Organ(_MouseAnatomicalStructureModel):
    """Model sensory organ"""

    name: Literal["sensory organ"] = "sensory organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35955"] = "EMAPA_35955"


class _Outer_Ear_Epithelium(_MouseAnatomicalStructureModel):
    """Model outer ear epithelium"""

    name: Literal["outer ear epithelium"] = "outer ear epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35956"] = "EMAPA_35956"


class _Eye_Epithelium(_MouseAnatomicalStructureModel):
    """Model eye epithelium"""

    name: Literal["eye epithelium"] = "eye epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35957"] = "EMAPA_35957"


class _Nasal_Epithelium(_MouseAnatomicalStructureModel):
    """Model nasal epithelium"""

    name: Literal["nasal epithelium"] = "nasal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35958"] = "EMAPA_35958"


class _Naris_Epithelium(_MouseAnatomicalStructureModel):
    """Model naris epithelium"""

    name: Literal["naris epithelium"] = "naris epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35959"] = "EMAPA_35959"


class _Nasal_Process_Epithelium(_MouseAnatomicalStructureModel):
    """Model nasal process epithelium"""

    name: Literal["nasal process epithelium"] = "nasal process epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35960"] = "EMAPA_35960"


class _Embryo_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model embryo mesenchyme"""

    name: Literal["embryo mesenchyme"] = "embryo mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35961"] = "EMAPA_35961"


class _Female_Reproductive_System_Epithelium(_MouseAnatomicalStructureModel):
    """Model female reproductive system epithelium"""

    name: Literal["female reproductive system epithelium"] = "female reproductive system epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35962"] = "EMAPA_35962"


class _Male_Reproductive_System_Epithelium(_MouseAnatomicalStructureModel):
    """Model male reproductive system epithelium"""

    name: Literal["male reproductive system epithelium"] = "male reproductive system epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35963"] = "EMAPA_35963"


class _Proximal_Urethral_Epithelium(_MouseAnatomicalStructureModel):
    """Model proximal urethral epithelium"""

    name: Literal["proximal urethral epithelium"] = "proximal urethral epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35964"] = "EMAPA_35964"


class _Proximal_Urethral_Meatus(_MouseAnatomicalStructureModel):
    """Model proximal urethral meatus"""

    name: Literal["proximal urethral meatus"] = "proximal urethral meatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35965"] = "EMAPA_35965"


class _Gum_Epithelium(_MouseAnatomicalStructureModel):
    """Model gum epithelium"""

    name: Literal["gum epithelium"] = "gum epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35966"] = "EMAPA_35966"


class _Integumental_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model integumental system mesenchyme"""

    name: Literal["integumental system mesenchyme"] = "integumental system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35967"] = "EMAPA_35967"


class _Respiratory_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model respiratory system mesenchyme"""

    name: Literal["respiratory system mesenchyme"] = "respiratory system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35968"] = "EMAPA_35968"


class _Metanephros_Parietal_Epithelium(_MouseAnatomicalStructureModel):
    """Model metanephros parietal epithelium"""

    name: Literal["metanephros parietal epithelium"] = "metanephros parietal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35969"] = "EMAPA_35969"


class _Metanephros_Visceral_Epithelium(_MouseAnatomicalStructureModel):
    """Model metanephros visceral epithelium"""

    name: Literal["metanephros visceral epithelium"] = "metanephros visceral epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35970"] = "EMAPA_35970"


class _Sensory_Organ_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model sensory organ mesenchyme"""

    name: Literal["sensory organ mesenchyme"] = "sensory organ mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35971"] = "EMAPA_35971"


class _Ear_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model ear mesenchyme"""

    name: Literal["ear mesenchyme"] = "ear mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35972"] = "EMAPA_35972"


class _Cardiovascular_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model cardiovascular system mesenchyme"""

    name: Literal["cardiovascular system mesenchyme"] = "cardiovascular system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35973"] = "EMAPA_35973"


class _Female_Reproductive_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model female reproductive system mesenchyme"""

    name: Literal["female reproductive system mesenchyme"] = "female reproductive system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35974"] = "EMAPA_35974"


class _Male_Reproductive_System_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model male reproductive system mesenchyme"""

    name: Literal["male reproductive system mesenchyme"] = "male reproductive system mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35975"] = "EMAPA_35975"


class _Cartilage_Primordium_Of_Future_Spinous_Process(_MouseAnatomicalStructureModel):
    """Model cartilage primordium of future spinous process"""

    name: Literal["cartilage primordium of future spinous process"] = "cartilage primordium of future spinous process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35976"] = "EMAPA_35976"


class _Respiratory_System_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model respiratory system connective tissue"""

    name: Literal["respiratory system connective tissue"] = "respiratory system connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35977"] = "EMAPA_35977"


class _Sensory_Organ_Cartilage(_MouseAnatomicalStructureModel):
    """Model sensory organ cartilage"""

    name: Literal["sensory organ cartilage"] = "sensory organ cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35978"] = "EMAPA_35978"


class _Ossicle_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model ossicle cartilage condensation"""

    name: Literal["ossicle cartilage condensation"] = "ossicle cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35979"] = "EMAPA_35979"


class _Pectoral_Thoracic_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model pectoral-thoracic cartilage condensation"""

    name: Literal["pectoral-thoracic cartilage condensation"] = "pectoral-thoracic cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35980"] = "EMAPA_35980"


class _Pelvic_Girdle_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model pelvic girdle cartilage condensation"""

    name: Literal["pelvic girdle cartilage condensation"] = "pelvic girdle cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35981"] = "EMAPA_35981"


class _Ossicle_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model ossicle pre-cartilage condensation"""

    name: Literal["ossicle pre-cartilage condensation"] = "ossicle pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35982"] = "EMAPA_35982"


class _Pectoral_Thoracic_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model pectoral-thoracic pre-cartilage condensation"""

    name: Literal["pectoral-thoracic pre-cartilage condensation"] = "pectoral-thoracic pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35983"] = "EMAPA_35983"


class _Pelvic_Girdle_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model pelvic girdle pre-cartilage condensation"""

    name: Literal["pelvic girdle pre-cartilage condensation"] = "pelvic girdle pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35984"] = "EMAPA_35984"


class _Ectoderm(_MouseAnatomicalStructureModel):
    """Model ectoderm"""

    name: Literal["ectoderm"] = "ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35985"] = "EMAPA_35985"


class _Endoderm(_MouseAnatomicalStructureModel):
    """Model endoderm"""

    name: Literal["endoderm"] = "endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35986"] = "EMAPA_35986"


class _Mesoderm(_MouseAnatomicalStructureModel):
    """Model mesoderm"""

    name: Literal["mesoderm"] = "mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35987"] = "EMAPA_35987"


class _Skeletal_Muscle(_MouseAnatomicalStructureModel):
    """Model skeletal muscle"""

    name: Literal["skeletal muscle"] = "skeletal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35988"] = "EMAPA_35988"


class _Eye_Neural_Ectoderm(_MouseAnatomicalStructureModel):
    """Model eye neural ectoderm"""

    name: Literal["eye neural ectoderm"] = "eye neural ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35989"] = "EMAPA_35989"


class _Alimentary_System_Ectoderm(_MouseAnatomicalStructureModel):
    """Model alimentary system ectoderm"""

    name: Literal["alimentary system ectoderm"] = "alimentary system ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35990"] = "EMAPA_35990"


class _Alimentary_System_Endoderm(_MouseAnatomicalStructureModel):
    """Model alimentary system endoderm"""

    name: Literal["alimentary system endoderm"] = "alimentary system endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35991"] = "EMAPA_35991"


class _Abdominal_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model abdominal lymph node"""

    name: Literal["abdominal lymph node"] = "abdominal lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35992"] = "EMAPA_35992"


class _Vascular_Element(_MouseAnatomicalStructureModel):
    """Model vascular element"""

    name: Literal["vascular element"] = "vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35993"] = "EMAPA_35993"


class _Alimentary_System_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model alimentary system vascular element"""

    name: Literal["alimentary system vascular element"] = "alimentary system vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35994"] = "EMAPA_35994"


class _Respiratory_System_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model respiratory system vascular element"""

    name: Literal["respiratory system vascular element"] = "respiratory system vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35995"] = "EMAPA_35995"


class _Head_Bone(_MouseAnatomicalStructureModel):
    """Model head bone"""

    name: Literal["head bone"] = "head bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35996"] = "EMAPA_35996"


class _Right_Lung_Alveolus(_MouseAnatomicalStructureModel):
    """Model right lung alveolus"""

    name: Literal["right lung alveolus"] = "right lung alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35997"] = "EMAPA_35997"


class _Pituitary_Gland(_MouseAnatomicalStructureModel):
    """Model pituitary gland"""

    name: Literal["pituitary gland"] = "pituitary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35998"] = "EMAPA_35998"


class _Endocrine_Gland(_MouseAnatomicalStructureModel):
    """Model endocrine gland"""

    name: Literal["endocrine gland"] = "endocrine gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_35999"] = "EMAPA_35999"


class _Germ_Cell_Of_Gonad(_MouseAnatomicalStructureModel):
    """Model germ cell of gonad"""

    name: Literal["germ cell of gonad"] = "germ cell of gonad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36000"] = "EMAPA_36000"


class _Mediastinum(_MouseAnatomicalStructureModel):
    """Model mediastinum"""

    name: Literal["mediastinum"] = "mediastinum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36001"] = "EMAPA_36001"


class _Auditory_System(_MouseAnatomicalStructureModel):
    """Model auditory system"""

    name: Literal["auditory system"] = "auditory system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36002"] = "EMAPA_36002"


class _Visual_System(_MouseAnatomicalStructureModel):
    """Model visual system"""

    name: Literal["visual system"] = "visual system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36003"] = "EMAPA_36003"


class _Olfactory_System(_MouseAnatomicalStructureModel):
    """Model olfactory system"""

    name: Literal["olfactory system"] = "olfactory system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36004"] = "EMAPA_36004"


class _Lung_Hilus(_MouseAnatomicalStructureModel):
    """Model lung hilus"""

    name: Literal["lung hilus"] = "lung hilus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36005"] = "EMAPA_36005"


class _Lobar_Bronchus_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model lobar bronchus vascular element"""

    name: Literal["lobar bronchus vascular element"] = "lobar bronchus vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36006"] = "EMAPA_36006"


class _Lung_Rudiment(_MouseAnatomicalStructureModel):
    """Model lung rudiment"""

    name: Literal["lung rudiment"] = "lung rudiment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36007"] = "EMAPA_36007"


class _Lung_Rudiment_Epithelium(_MouseAnatomicalStructureModel):
    """Model lung rudiment epithelium"""

    name: Literal["lung rudiment epithelium"] = "lung rudiment epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36008"] = "EMAPA_36008"


class _Lung_Rudiment_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lung rudiment mesenchyme"""

    name: Literal["lung rudiment mesenchyme"] = "lung rudiment mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36009"] = "EMAPA_36009"


class _Lung_Rudiment_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model lung rudiment vascular element"""

    name: Literal["lung rudiment vascular element"] = "lung rudiment vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36010"] = "EMAPA_36010"


class _Rib_Head_Cartilage(_MouseAnatomicalStructureModel):
    """Model rib head cartilage"""

    name: Literal["rib head cartilage"] = "rib head cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36012"] = "EMAPA_36012"


class _Rib_Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model rib neck cartilage"""

    name: Literal["rib neck cartilage"] = "rib neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36013"] = "EMAPA_36013"


class _Rib_Shaft(_MouseAnatomicalStructureModel):
    """Model rib shaft"""

    name: Literal["rib shaft"] = "rib shaft"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36014"] = "EMAPA_36014"


class _Rib_Shaft_Non_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model rib shaft non-ossified region"""

    name: Literal["rib shaft non-ossified region"] = "rib shaft non-ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36015"] = "EMAPA_36015"


class _Rib_Shaft_Ossified_Region(_MouseAnatomicalStructureModel):
    """Model rib shaft ossified region"""

    name: Literal["rib shaft ossified region"] = "rib shaft ossified region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36016"] = "EMAPA_36016"


class _Umbilical_Artery(_MouseAnatomicalStructureModel):
    """Model umbilical artery"""

    name: Literal["umbilical artery"] = "umbilical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36017"] = "EMAPA_36017"


class _Umbilical_Vein(_MouseAnatomicalStructureModel):
    """Model umbilical vein"""

    name: Literal["umbilical vein"] = "umbilical vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36018"] = "EMAPA_36018"


class _Left_Umbilical_Vein(_MouseAnatomicalStructureModel):
    """Model left umbilical vein"""

    name: Literal["left umbilical vein"] = "left umbilical vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36019"] = "EMAPA_36019"


class _Right_Umbilical_Vein(_MouseAnatomicalStructureModel):
    """Model right umbilical vein"""

    name: Literal["right umbilical vein"] = "right umbilical vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36020"] = "EMAPA_36020"


class _Vitelline_Vein(_MouseAnatomicalStructureModel):
    """Model vitelline vein"""

    name: Literal["vitelline vein"] = "vitelline vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36021"] = "EMAPA_36021"


class _Left_Vitelline_Vein(_MouseAnatomicalStructureModel):
    """Model left vitelline vein"""

    name: Literal["left vitelline vein"] = "left vitelline vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36022"] = "EMAPA_36022"


class _Right_Vitelline_Vein(_MouseAnatomicalStructureModel):
    """Model right vitelline vein"""

    name: Literal["right vitelline vein"] = "right vitelline vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36023"] = "EMAPA_36023"


class _Future_Telencephalon(_MouseAnatomicalStructureModel):
    """Model future telencephalon"""

    name: Literal["future telencephalon"] = "future telencephalon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36024"] = "EMAPA_36024"


class _Proepicardium(_MouseAnatomicalStructureModel):
    """Model proepicardium"""

    name: Literal["proepicardium"] = "proepicardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36025"] = "EMAPA_36025"


class _Nasal_Cavity_Mucosa(_MouseAnatomicalStructureModel):
    """Model nasal cavity mucosa"""

    name: Literal["nasal cavity mucosa"] = "nasal cavity mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36026"] = "EMAPA_36026"


class _Nasal_Cavity_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model nasal cavity lamina propria"""

    name: Literal["nasal cavity lamina propria"] = "nasal cavity lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36027"] = "EMAPA_36027"


class _Nasal_Septum_Mucosa(_MouseAnatomicalStructureModel):
    """Model nasal septum mucosa"""

    name: Literal["nasal septum mucosa"] = "nasal septum mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36028"] = "EMAPA_36028"


class _Nasal_Septum_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model nasal septum lamina propria"""

    name: Literal["nasal septum lamina propria"] = "nasal septum lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36029"] = "EMAPA_36029"


class _Ultimobranchial_Body(_MouseAnatomicalStructureModel):
    """Model ultimobranchial body"""

    name: Literal["ultimobranchial body"] = "ultimobranchial body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36030"] = "EMAPA_36030"


class _Body_Region(_MouseAnatomicalStructureModel):
    """Model body region"""

    name: Literal["body region"] = "body region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36031"] = "EMAPA_36031"


class _Early_Embryo(_MouseAnatomicalStructureModel):
    """Model early embryo"""

    name: Literal["early embryo"] = "early embryo"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36032"] = "EMAPA_36032"


class _Germ_Layer(_MouseAnatomicalStructureModel):
    """Model germ layer"""

    name: Literal["germ layer"] = "germ layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36033"] = "EMAPA_36033"


class _Umbilical_Or_Vitelline_Vessel(_MouseAnatomicalStructureModel):
    """Model umbilical or vitelline vessel"""

    name: Literal["umbilical or vitelline vessel"] = "umbilical or vitelline vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36034"] = "EMAPA_36034"


class _Blastocyst(_MouseAnatomicalStructureModel):
    """Model blastocyst"""

    name: Literal["blastocyst"] = "blastocyst"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36035"] = "EMAPA_36035"


class _Rib_Cartilage(_MouseAnatomicalStructureModel):
    """Model rib cartilage"""

    name: Literal["rib cartilage"] = "rib cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36036"] = "EMAPA_36036"


class _Cavity_Or_Lining(_MouseAnatomicalStructureModel):
    """Model cavity or lining"""

    name: Literal["cavity or lining"] = "cavity or lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36037"] = "EMAPA_36037"


class _Proamniotic_Cavity(_MouseAnatomicalStructureModel):
    """Model proamniotic cavity"""

    name: Literal["proamniotic cavity"] = "proamniotic cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36038"] = "EMAPA_36038"


class _Primary_Yolk_Sac_Cavity(_MouseAnatomicalStructureModel):
    """Model primary yolk sac cavity"""

    name: Literal["primary yolk sac cavity"] = "primary yolk sac cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36039"] = "EMAPA_36039"


class _Conceptus(_MouseAnatomicalStructureModel):
    """Model conceptus"""

    name: Literal["conceptus"] = "conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36040"] = "EMAPA_36040"


class _1_Cell_Stage_Conceptus(_MouseAnatomicalStructureModel):
    """Model 1-cell stage conceptus"""

    name: Literal["1-cell stage conceptus"] = "1-cell stage conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36041"] = "EMAPA_36041"


class _2_Cell_Stage_Conceptus(_MouseAnatomicalStructureModel):
    """Model 2-cell stage conceptus"""

    name: Literal["2-cell stage conceptus"] = "2-cell stage conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36042"] = "EMAPA_36042"


class _4_Cell_Stage_Conceptus(_MouseAnatomicalStructureModel):
    """Model 4-cell stage conceptus"""

    name: Literal["4-cell stage conceptus"] = "4-cell stage conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36043"] = "EMAPA_36043"


class _8_Cell_Stage_Conceptus(_MouseAnatomicalStructureModel):
    """Model 8-cell stage conceptus"""

    name: Literal["8-cell stage conceptus"] = "8-cell stage conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36044"] = "EMAPA_36044"


class _Morula_Stage_Conceptus(_MouseAnatomicalStructureModel):
    """Model morula-stage conceptus"""

    name: Literal["morula-stage conceptus"] = "morula-stage conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36045"] = "EMAPA_36045"


class _Blastocyst_Stage_Conceptus(_MouseAnatomicalStructureModel):
    """Model blastocyst-stage conceptus"""

    name: Literal["blastocyst-stage conceptus"] = "blastocyst-stage conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36046"] = "EMAPA_36046"


class _Limb_Muscle(_MouseAnatomicalStructureModel):
    """Model limb muscle"""

    name: Literal["limb muscle"] = "limb muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36047"] = "EMAPA_36047"


class _Hindlimb_Muscle(_MouseAnatomicalStructureModel):
    """Model hindlimb muscle"""

    name: Literal["hindlimb muscle"] = "hindlimb muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36048"] = "EMAPA_36048"


class _Forelimb_Muscle(_MouseAnatomicalStructureModel):
    """Model forelimb muscle"""

    name: Literal["forelimb muscle"] = "forelimb muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36049"] = "EMAPA_36049"


class _Neck_Muscle(_MouseAnatomicalStructureModel):
    """Model neck muscle"""

    name: Literal["neck muscle"] = "neck muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36050"] = "EMAPA_36050"


class _Amygdaloid_Nucleus(_MouseAnatomicalStructureModel):
    """Model amygdaloid nucleus"""

    name: Literal["amygdaloid nucleus"] = "amygdaloid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36051"] = "EMAPA_36051"


class _Anal_Sphincter(_MouseAnatomicalStructureModel):
    """Model anal sphincter"""

    name: Literal["anal sphincter"] = "anal sphincter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36052"] = "EMAPA_36052"


class _Arm_Muscle(_MouseAnatomicalStructureModel):
    """Model arm muscle"""

    name: Literal["arm muscle"] = "arm muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36053"] = "EMAPA_36053"


class _Leg_Muscle(_MouseAnatomicalStructureModel):
    """Model leg muscle"""

    name: Literal["leg muscle"] = "leg muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36054"] = "EMAPA_36054"


class _Atrium_Auricular_Region(_MouseAnatomicalStructureModel):
    """Model atrium auricular region"""

    name: Literal["atrium auricular region"] = "atrium auricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36055"] = "EMAPA_36055"


class _Atrium_Auricular_Region_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model atrium auricular region cardiac muscle"""

    name: Literal["atrium auricular region cardiac muscle"] = "atrium auricular region cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36056"] = "EMAPA_36056"


class _Atrium_Auricular_Region_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model atrium auricular region endocardial lining"""

    name: Literal["atrium auricular region endocardial lining"] = "atrium auricular region endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36057"] = "EMAPA_36057"


class _Atrium_Lumen(_MouseAnatomicalStructureModel):
    """Model atrium lumen"""

    name: Literal["atrium lumen"] = "atrium lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36058"] = "EMAPA_36058"


class _Common_Atrial_Chamber_Auricular_Region(_MouseAnatomicalStructureModel):
    """Model common atrial chamber auricular region"""

    name: Literal["common atrial chamber auricular region"] = "common atrial chamber auricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36059"] = "EMAPA_36059"


class _Common_Atrial_Chamber_Auricular_Region_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model common atrial chamber auricular region cardiac muscle"""

    name: Literal[
        "common atrial chamber auricular region cardiac muscle"
    ] = "common atrial chamber auricular region cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36060"] = "EMAPA_36060"


class _Common_Atrial_Chamber_Auricular_Region_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model common atrial chamber auricular region endocardial lining"""

    name: Literal[
        "common atrial chamber auricular region endocardial lining"
    ] = "common atrial chamber auricular region endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36061"] = "EMAPA_36061"


class _Cranium_Bone_Primordium(_MouseAnatomicalStructureModel):
    """Model cranium bone primordium"""

    name: Literal["cranium bone primordium"] = "cranium bone primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36062"] = "EMAPA_36062"


class _4_8_Cell_Stage_Conceptus(_MouseAnatomicalStructureModel):
    """Model 4-8 cell stage conceptus"""

    name: Literal["4-8 cell stage conceptus"] = "4-8 cell stage conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36063"] = "EMAPA_36063"


class _Cranial_Preganglion(_MouseAnatomicalStructureModel):
    """Model cranial preganglion"""

    name: Literal["cranial preganglion"] = "cranial preganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36064"] = "EMAPA_36064"


class _Hyoid_Cartilage_Primordium(_MouseAnatomicalStructureModel):
    """Model hyoid cartilage primordium"""

    name: Literal["hyoid cartilage primordium"] = "hyoid cartilage primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36065"] = "EMAPA_36065"


class _Interventricular_Foramen(_MouseAnatomicalStructureModel):
    """Model interventricular foramen"""

    name: Literal["interventricular foramen"] = "interventricular foramen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36067"] = "EMAPA_36067"


class _Anterior_Visceral_Endoderm(_MouseAnatomicalStructureModel):
    """Model anterior visceral endoderm"""

    name: Literal["anterior visceral endoderm"] = "anterior visceral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36068"] = "EMAPA_36068"


class _Posterior_Visceral_Endoderm(_MouseAnatomicalStructureModel):
    """Model posterior visceral endoderm"""

    name: Literal["posterior visceral endoderm"] = "posterior visceral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36069"] = "EMAPA_36069"


class _Cloacal_Epithelium_Of_Cloacal_Membrane(_MouseAnatomicalStructureModel):
    """Model cloacal epithelium of cloacal membrane"""

    name: Literal["cloacal epithelium of cloacal membrane"] = "cloacal epithelium of cloacal membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36070"] = "EMAPA_36070"


class _Surface_Ectoderm_Of_Cloacal_Membrane(_MouseAnatomicalStructureModel):
    """Model surface ectoderm of cloacal membrane"""

    name: Literal["surface ectoderm of cloacal membrane"] = "surface ectoderm of cloacal membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36071"] = "EMAPA_36071"


class _Superficial_Cell_Of_Bladder_Urothelium(_MouseAnatomicalStructureModel):
    """Model superficial cell of bladder urothelium"""

    name: Literal["superficial cell of bladder urothelium"] = "superficial cell of bladder urothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36072"] = "EMAPA_36072"


class _Intermediate_Cell_Layer_Of_Bladder_Urothelium(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of bladder urothelium"""

    name: Literal["intermediate cell layer of bladder urothelium"] = "intermediate cell layer of bladder urothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36073"] = "EMAPA_36073"


class _Krt5_Expressing_Basal_Cell_Of_Bladder_Urothelium(_MouseAnatomicalStructureModel):
    """Model Krt5-expressing basal cell of bladder urothelium"""

    name: Literal[
        "Krt5-expressing basal cell of bladder urothelium"
    ] = "Krt5-expressing basal cell of bladder urothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36074"] = "EMAPA_36074"


class _Suburothelial_Lamina_Propria_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model suburothelial lamina propria of bladder"""

    name: Literal["suburothelial lamina propria of bladder"] = "suburothelial lamina propria of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36075"] = "EMAPA_36075"


class _Outer_Lamina_Propria_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model outer lamina propria of bladder"""

    name: Literal["outer lamina propria of bladder"] = "outer lamina propria of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36076"] = "EMAPA_36076"


class _Outer_Layer_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model outer layer of bladder"""

    name: Literal["outer layer of bladder"] = "outer layer of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36077"] = "EMAPA_36077"


class _Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model bladder neck"""

    name: Literal["bladder neck"] = "bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36078"] = "EMAPA_36078"


class _Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model ventral bladder neck"""

    name: Literal["ventral bladder neck"] = "ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36079"] = "EMAPA_36079"


class _Ureter_Junction_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model ureter junction of bladder trigone"""

    name: Literal["ureter junction of bladder trigone"] = "ureter junction of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36080"] = "EMAPA_36080"


class _Urethra_Junction_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model urethra junction of bladder trigone"""

    name: Literal["urethra junction of bladder trigone"] = "urethra junction of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36081"] = "EMAPA_36081"


class _Ureteral_Smooth_Muscle_Of_Trigone(_MouseAnatomicalStructureModel):
    """Model ureteral smooth muscle of trigone"""

    name: Literal["ureteral smooth muscle of trigone"] = "ureteral smooth muscle of trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36082"] = "EMAPA_36082"


class _Fundus_Junction_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model fundus junction of ventral bladder neck"""

    name: Literal["fundus junction of ventral bladder neck"] = "fundus junction of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36083"] = "EMAPA_36083"


class _Urethra_Junction_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model urethra junction of ventral bladder neck"""

    name: Literal["urethra junction of ventral bladder neck"] = "urethra junction of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36084"] = "EMAPA_36084"


class _Undifferentiated_Epithelial_Cell_Of_Urothelium_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model undifferentiated epithelial cell of urothelium of primitive bladder"""

    name: Literal[
        "undifferentiated epithelial cell of urothelium of primitive bladder"
    ] = "undifferentiated epithelial cell of urothelium of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36085"] = "EMAPA_36085"


class _Intermediate_Cell_Of_Urothelium_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model intermediate cell of urothelium of primitive bladder"""

    name: Literal[
        "intermediate cell of urothelium of primitive bladder"
    ] = "intermediate cell of urothelium of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36086"] = "EMAPA_36086"


class _P_0_Cell_Of_Urothelium_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model P-0 cell of urothelium of primitive bladder"""

    name: Literal["P-0 cell of urothelium of primitive bladder"] = "P-0 cell of urothelium of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36087"] = "EMAPA_36087"


class _Inner_Mesenchymal_Layer_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model inner mesenchymal layer of primitive bladder"""

    name: Literal["inner mesenchymal layer of primitive bladder"] = "inner mesenchymal layer of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36088"] = "EMAPA_36088"


class _Outer_Mesenchymal_Layer_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model outer mesenchymal layer of primitive bladder"""

    name: Literal["outer mesenchymal layer of primitive bladder"] = "outer mesenchymal layer of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36089"] = "EMAPA_36089"


class _Muscle_Layer_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model muscle layer of primitive bladder"""

    name: Literal["muscle layer of primitive bladder"] = "muscle layer of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36090"] = "EMAPA_36090"


class _Smooth_Muscle_Cell_Of_Outer_Mesenchymal_Layer_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model smooth muscle cell of outer mesenchymal layer of primitive bladder"""

    name: Literal[
        "smooth muscle cell of outer mesenchymal layer of primitive bladder"
    ] = "smooth muscle cell of outer mesenchymal layer of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36091"] = "EMAPA_36091"


class _Mesenchymal_Cell_Of_Outer_Mesenchymal_Layer_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model mesenchymal cell of outer mesenchymal layer of primitive bladder"""

    name: Literal[
        "mesenchymal cell of outer mesenchymal layer of primitive bladder"
    ] = "mesenchymal cell of outer mesenchymal layer of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36092"] = "EMAPA_36092"


class _Outer_Layer_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model outer layer of primitive bladder"""

    name: Literal["outer layer of primitive bladder"] = "outer layer of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36093"] = "EMAPA_36093"


class _Serosa_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model serosa of primitive bladder"""

    name: Literal["serosa of primitive bladder"] = "serosa of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36094"] = "EMAPA_36094"


class _Adventitia_Of_Primitive_Bladder(_MouseAnatomicalStructureModel):
    """Model adventitia of primitive bladder"""

    name: Literal["adventitia of primitive bladder"] = "adventitia of primitive bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36095"] = "EMAPA_36095"


class _Primitive_Bladder_Caudal_Urogenital_Sinus_Transition_Zone(_MouseAnatomicalStructureModel):
    """Model primitive bladder-caudal urogenital sinus transition zone"""

    name: Literal[
        "primitive bladder-caudal urogenital sinus transition zone"
    ] = "primitive bladder-caudal urogenital sinus transition zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36096"] = "EMAPA_36096"


class _Epithelium_Of_Primitive_Bladder_Caudal_Urogenital_Sinus_Transition_Zone(_MouseAnatomicalStructureModel):
    """Model epithelium of primitive bladder-caudal urogenital sinus transition zone"""

    name: Literal[
        "epithelium of primitive bladder-caudal urogenital sinus transition zone"
    ] = "epithelium of primitive bladder-caudal urogenital sinus transition zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36097"] = "EMAPA_36097"


class _Mesenchyme_Of_Primitive_Bladder_Caudal_Urogenital_Sinus_Transition_Zone(_MouseAnatomicalStructureModel):
    """Model mesenchyme of primitive bladder-caudal urogenital sinus transition zone"""

    name: Literal[
        "mesenchyme of primitive bladder-caudal urogenital sinus transition zone"
    ] = "mesenchyme of primitive bladder-caudal urogenital sinus transition zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36098"] = "EMAPA_36098"


class _Urogenital_Sinus_Ridge(_MouseAnatomicalStructureModel):
    """Model urogenital sinus ridge"""

    name: Literal["urogenital sinus ridge"] = "urogenital sinus ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36099"] = "EMAPA_36099"


class _Rest_Of_Caudal_Urogenital_Sinus_Epithelium(_MouseAnatomicalStructureModel):
    """Model rest of caudal urogenital sinus epithelium"""

    name: Literal["rest of caudal urogenital sinus epithelium"] = "rest of caudal urogenital sinus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36100"] = "EMAPA_36100"


class _Common_Nephric_Duct(_MouseAnatomicalStructureModel):
    """Model common nephric duct"""

    name: Literal["common nephric duct"] = "common nephric duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36101"] = "EMAPA_36101"


class _Developing_Vasculature_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model developing vasculature of pelvic urethra"""

    name: Literal["developing vasculature of pelvic urethra"] = "developing vasculature of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36102"] = "EMAPA_36102"


class _Adventitia_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model adventitia of pelvic urethra"""

    name: Literal["adventitia of pelvic urethra"] = "adventitia of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36103"] = "EMAPA_36103"


class _Rest_Of_Epithelium_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model rest of epithelium of pelvic urethra"""

    name: Literal["rest of epithelium of pelvic urethra"] = "rest of epithelium of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36104"] = "EMAPA_36104"


class _Superficial_Cell_Layer_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of pelvic urethra of female"""

    name: Literal[
        "superficial cell layer of pelvic urethra of female"
    ] = "superficial cell layer of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36105"] = "EMAPA_36105"


class _Intermediate_Cell_Layer_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of pelvic urethra of female"""

    name: Literal[
        "intermediate cell layer of pelvic urethra of female"
    ] = "intermediate cell layer of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36106"] = "EMAPA_36106"


class _Basal_Cell_Layer_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model basal cell layer of pelvic urethra of female"""

    name: Literal["basal cell layer of pelvic urethra of female"] = "basal cell layer of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36107"] = "EMAPA_36107"


class _Urogenital_Sinus_Ridge_Of_Female(_MouseAnatomicalStructureModel):
    """Model urogenital sinus ridge of female"""

    name: Literal["urogenital sinus ridge of female"] = "urogenital sinus ridge of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36108"] = "EMAPA_36108"


class _Rest_Of_Epithelium_Of_Dorsal_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model rest of epithelium of dorsal pelvic urethra of female"""

    name: Literal[
        "rest of epithelium of dorsal pelvic urethra of female"
    ] = "rest of epithelium of dorsal pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36109"] = "EMAPA_36109"


class _Lamina_Propria_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model lamina propria of pelvic urethra of female"""

    name: Literal["lamina propria of pelvic urethra of female"] = "lamina propria of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36110"] = "EMAPA_36110"


class _Muscularis_Mucosa_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of pelvic urethra of female"""

    name: Literal["muscularis mucosa of pelvic urethra of female"] = "muscularis mucosa of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36111"] = "EMAPA_36111"


class _Submucosa_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model submucosa of pelvic urethra of female"""

    name: Literal["submucosa of pelvic urethra of female"] = "submucosa of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36112"] = "EMAPA_36112"


class _Anterior_Mesenchymal_Pad_Of_Female(_MouseAnatomicalStructureModel):
    """Model anterior mesenchymal pad of female"""

    name: Literal["anterior mesenchymal pad of female"] = "anterior mesenchymal pad of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36113"] = "EMAPA_36113"


class _Dorsal_Mesenchymal_Pad_Of_Female(_MouseAnatomicalStructureModel):
    """Model dorsal mesenchymal pad of female"""

    name: Literal["dorsal mesenchymal pad of female"] = "dorsal mesenchymal pad of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36114"] = "EMAPA_36114"


class _Ventral_Mesenchymal_Pad_Of_Female(_MouseAnatomicalStructureModel):
    """Model ventral mesenchymal pad of female"""

    name: Literal["ventral mesenchymal pad of female"] = "ventral mesenchymal pad of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36115"] = "EMAPA_36115"


class _Smooth_Muscle_Layer_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model smooth muscle layer of pelvic urethra of female"""

    name: Literal["smooth muscle layer of pelvic urethra of female"] = "smooth muscle layer of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36116"] = "EMAPA_36116"


class _Rhabdosphincter_Of_Female(_MouseAnatomicalStructureModel):
    """Model rhabdosphincter of female"""

    name: Literal["rhabdosphincter of female"] = "rhabdosphincter of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36117"] = "EMAPA_36117"


class _Adventitia_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model adventitia of pelvic urethra of female"""

    name: Literal["adventitia of pelvic urethra of female"] = "adventitia of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36118"] = "EMAPA_36118"


class _Egg_Cylinder(_MouseAnatomicalStructureModel):
    """Model egg cylinder"""

    name: Literal["egg cylinder"] = "egg cylinder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36119"] = "EMAPA_36119"


class _Superficial_Cell_Layer_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of pelvic urethra of male"""

    name: Literal[
        "superficial cell layer of pelvic urethra of male"
    ] = "superficial cell layer of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36120"] = "EMAPA_36120"


class _Intermediate_Cell_Layer_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of pelvic urethra of male"""

    name: Literal[
        "intermediate cell layer of pelvic urethra of male"
    ] = "intermediate cell layer of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36121"] = "EMAPA_36121"


class _Basal_Cell_Layer_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model basal cell layer of pelvic urethra of male"""

    name: Literal["basal cell layer of pelvic urethra of male"] = "basal cell layer of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36122"] = "EMAPA_36122"


class _Urogenital_Sinus_Ridge_Of_Male(_MouseAnatomicalStructureModel):
    """Model urogenital sinus ridge of male"""

    name: Literal["urogenital sinus ridge of male"] = "urogenital sinus ridge of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36123"] = "EMAPA_36123"


class _Rest_Of_Epithelium_Of_Dorsal_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model rest of epithelium of dorsal pelvic urethra of male"""

    name: Literal[
        "rest of epithelium of dorsal pelvic urethra of male"
    ] = "rest of epithelium of dorsal pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36124"] = "EMAPA_36124"


class _Lamina_Propria_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model lamina propria of pelvic urethra of male"""

    name: Literal["lamina propria of pelvic urethra of male"] = "lamina propria of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36125"] = "EMAPA_36125"


class _Muscularis_Mucosa_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model muscularis mucosa of pelvic urethra of male"""

    name: Literal["muscularis mucosa of pelvic urethra of male"] = "muscularis mucosa of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36126"] = "EMAPA_36126"


class _Submucosa_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model submucosa of pelvic urethra of male"""

    name: Literal["submucosa of pelvic urethra of male"] = "submucosa of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36127"] = "EMAPA_36127"


class _Anterior_Mesenchymal_Pad_Of_Male(_MouseAnatomicalStructureModel):
    """Model anterior mesenchymal pad of male"""

    name: Literal["anterior mesenchymal pad of male"] = "anterior mesenchymal pad of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36128"] = "EMAPA_36128"


class _Dorsal_Mesenchymal_Pad_Of_Male(_MouseAnatomicalStructureModel):
    """Model dorsal mesenchymal pad of male"""

    name: Literal["dorsal mesenchymal pad of male"] = "dorsal mesenchymal pad of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36129"] = "EMAPA_36129"


class _Ventral_Mesenchymal_Pad_Of_Male(_MouseAnatomicalStructureModel):
    """Model ventral mesenchymal pad of male"""

    name: Literal["ventral mesenchymal pad of male"] = "ventral mesenchymal pad of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36130"] = "EMAPA_36130"


class _Adventitia_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model adventitia of pelvic urethra of male"""

    name: Literal["adventitia of pelvic urethra of male"] = "adventitia of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36131"] = "EMAPA_36131"


class _Ventral_Epithelial_Bud_Of_Female(_MouseAnatomicalStructureModel):
    """Model ventral epithelial bud of female"""

    name: Literal["ventral epithelial bud of female"] = "ventral epithelial bud of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36132"] = "EMAPA_36132"


class _Urethral_Gland_Of_Pelvic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model urethral gland of pelvic urethra of female"""

    name: Literal["urethral gland of pelvic urethra of female"] = "urethral gland of pelvic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36133"] = "EMAPA_36133"


class _Urethral_Gland_Of_Clitoral_Urethra(_MouseAnatomicalStructureModel):
    """Model urethral gland of clitoral urethra"""

    name: Literal["urethral gland of clitoral urethra"] = "urethral gland of clitoral urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36134"] = "EMAPA_36134"


class _Ventral_Epithelial_Bud_Of_Male(_MouseAnatomicalStructureModel):
    """Model ventral epithelial bud of male"""

    name: Literal["ventral epithelial bud of male"] = "ventral epithelial bud of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36135"] = "EMAPA_36135"


class _Epithelium_Of_Dorsal_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model epithelium of dorsal prostatic urethra"""

    name: Literal["epithelium of dorsal prostatic urethra"] = "epithelium of dorsal prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36136"] = "EMAPA_36136"


class _Verumontanum(_MouseAnatomicalStructureModel):
    """Model verumontanum"""

    name: Literal["verumontanum"] = "verumontanum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36137"] = "EMAPA_36137"


class _Rest_Of_Epithelium_Of_Dorsal_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model rest of epithelium of dorsal prostatic urethra"""

    name: Literal["rest of epithelium of dorsal prostatic urethra"] = "rest of epithelium of dorsal prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36138"] = "EMAPA_36138"


class _Epithelium_Of_Ventral_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model epithelium of ventral prostatic urethra"""

    name: Literal["epithelium of ventral prostatic urethra"] = "epithelium of ventral prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36139"] = "EMAPA_36139"


class _Adventitia_Of_Prostatic_Urethra(_MouseAnatomicalStructureModel):
    """Model adventitia of prostatic urethra"""

    name: Literal["adventitia of prostatic urethra"] = "adventitia of prostatic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36140"] = "EMAPA_36140"


class _Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model prostate bud"""

    name: Literal["prostate bud"] = "prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36141"] = "EMAPA_36141"


class _Anterior_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model anterior prostate bud"""

    name: Literal["anterior prostate bud"] = "anterior prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36142"] = "EMAPA_36142"


class _Dorsal_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model dorsal prostate bud"""

    name: Literal["dorsal prostate bud"] = "dorsal prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36143"] = "EMAPA_36143"


class _Ventral_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model ventral prostate bud"""

    name: Literal["ventral prostate bud"] = "ventral prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36144"] = "EMAPA_36144"


class _Lateral_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model lateral prostate bud"""

    name: Literal["lateral prostate bud"] = "lateral prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36145"] = "EMAPA_36145"


class _Epithelium_Of_Anterior_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model epithelium of anterior prostate bud"""

    name: Literal["epithelium of anterior prostate bud"] = "epithelium of anterior prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36146"] = "EMAPA_36146"


class _Peri_Prostatic_Mesenchyme_Of_Anterior_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model peri-prostatic mesenchyme of anterior prostate bud"""

    name: Literal[
        "peri-prostatic mesenchyme of anterior prostate bud"
    ] = "peri-prostatic mesenchyme of anterior prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36147"] = "EMAPA_36147"


class _Epithelium_Of_Dorsal_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model epithelium of dorsal prostate bud"""

    name: Literal["epithelium of dorsal prostate bud"] = "epithelium of dorsal prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36148"] = "EMAPA_36148"


class _Peri_Prostatic_Mesenchyme_Of_Dorsal_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model peri-prostatic mesenchyme of dorsal prostate bud"""

    name: Literal[
        "peri-prostatic mesenchyme of dorsal prostate bud"
    ] = "peri-prostatic mesenchyme of dorsal prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36149"] = "EMAPA_36149"


class _Epithelium_Of_Ventral_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model epithelium of ventral prostate bud"""

    name: Literal["epithelium of ventral prostate bud"] = "epithelium of ventral prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36150"] = "EMAPA_36150"


class _Peri_Prostatic_Mesenchyme_Of_Ventral_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model peri-prostatic mesenchyme of ventral prostate bud"""

    name: Literal[
        "peri-prostatic mesenchyme of ventral prostate bud"
    ] = "peri-prostatic mesenchyme of ventral prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36151"] = "EMAPA_36151"


class _Epithelium_Of_Lateral_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model epithelium of lateral prostate bud"""

    name: Literal["epithelium of lateral prostate bud"] = "epithelium of lateral prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36152"] = "EMAPA_36152"


class _Peri_Prostatic_Mesenchyme_Of_Lateral_Prostate_Bud(_MouseAnatomicalStructureModel):
    """Model peri-prostatic mesenchyme of lateral prostate bud"""

    name: Literal[
        "peri-prostatic mesenchyme of lateral prostate bud"
    ] = "peri-prostatic mesenchyme of lateral prostate bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36153"] = "EMAPA_36153"


class _Shoulder_Muscle(_MouseAnatomicalStructureModel):
    """Model shoulder muscle"""

    name: Literal["shoulder muscle"] = "shoulder muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36154"] = "EMAPA_36154"


class _Teres_Muscle(_MouseAnatomicalStructureModel):
    """Model teres muscle"""

    name: Literal["teres muscle"] = "teres muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36155"] = "EMAPA_36155"


class _Teres_Minor(_MouseAnatomicalStructureModel):
    """Model teres minor"""

    name: Literal["teres minor"] = "teres minor"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36156"] = "EMAPA_36156"


class _Psoas_Muscle(_MouseAnatomicalStructureModel):
    """Model psoas muscle"""

    name: Literal["psoas muscle"] = "psoas muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36157"] = "EMAPA_36157"


class _Metacarpal_Bone(_MouseAnatomicalStructureModel):
    """Model metacarpal bone"""

    name: Literal["metacarpal bone"] = "metacarpal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36158"] = "EMAPA_36158"


class _Metatarsal_Bone(_MouseAnatomicalStructureModel):
    """Model metatarsal bone"""

    name: Literal["metatarsal bone"] = "metatarsal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36159"] = "EMAPA_36159"


class _Foot_Muscle(_MouseAnatomicalStructureModel):
    """Model foot muscle"""

    name: Literal["foot muscle"] = "foot muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36160"] = "EMAPA_36160"


class _Pars_Acromialis_Of_Deltoid(_MouseAnatomicalStructureModel):
    """Model pars acromialis of deltoid"""

    name: Literal["pars acromialis of deltoid"] = "pars acromialis of deltoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36161"] = "EMAPA_36161"


class _Pars_Clavicularis_Of_Deltoid(_MouseAnatomicalStructureModel):
    """Model pars clavicularis of deltoid"""

    name: Literal["pars clavicularis of deltoid"] = "pars clavicularis of deltoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36162"] = "EMAPA_36162"


class _Pars_Scapularis_Of_Deltoid(_MouseAnatomicalStructureModel):
    """Model pars scapularis of deltoid"""

    name: Literal["pars scapularis of deltoid"] = "pars scapularis of deltoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36163"] = "EMAPA_36163"


class _Proximal_Carpal_Bone(_MouseAnatomicalStructureModel):
    """Model proximal carpal bone"""

    name: Literal["proximal carpal bone"] = "proximal carpal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36164"] = "EMAPA_36164"


class _Pisiform(_MouseAnatomicalStructureModel):
    """Model pisiform"""

    name: Literal["pisiform"] = "pisiform"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36165"] = "EMAPA_36165"


class _Scapholunate(_MouseAnatomicalStructureModel):
    """Model scapholunate"""

    name: Literal["scapholunate"] = "scapholunate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36166"] = "EMAPA_36166"


class _Triquetrum(_MouseAnatomicalStructureModel):
    """Model triquetrum"""

    name: Literal["triquetrum"] = "triquetrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36167"] = "EMAPA_36167"


class _Distal_Carpal_Bone(_MouseAnatomicalStructureModel):
    """Model distal carpal bone"""

    name: Literal["distal carpal bone"] = "distal carpal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36168"] = "EMAPA_36168"


class _Capitate(_MouseAnatomicalStructureModel):
    """Model capitate"""

    name: Literal["capitate"] = "capitate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36169"] = "EMAPA_36169"


class _Central_Carpal_Bone(_MouseAnatomicalStructureModel):
    """Model central carpal bone"""

    name: Literal["central carpal bone"] = "central carpal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36170"] = "EMAPA_36170"


class _Falciform(_MouseAnatomicalStructureModel):
    """Model falciform"""

    name: Literal["falciform"] = "falciform"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36171"] = "EMAPA_36171"


class _Hamate(_MouseAnatomicalStructureModel):
    """Model hamate"""

    name: Literal["hamate"] = "hamate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36172"] = "EMAPA_36172"


class _Trapezium(_MouseAnatomicalStructureModel):
    """Model trapezium"""

    name: Literal["trapezium"] = "trapezium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36173"] = "EMAPA_36173"


class _Trapezoid(_MouseAnatomicalStructureModel):
    """Model trapezoid"""

    name: Literal["trapezoid"] = "trapezoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36174"] = "EMAPA_36174"


class _Cuboid(_MouseAnatomicalStructureModel):
    """Model cuboid"""

    name: Literal["cuboid"] = "cuboid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36175"] = "EMAPA_36175"


class _Medial_Cuneiform(_MouseAnatomicalStructureModel):
    """Model medial cuneiform"""

    name: Literal["medial cuneiform"] = "medial cuneiform"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36176"] = "EMAPA_36176"


class _Intermediate_Cuneiform(_MouseAnatomicalStructureModel):
    """Model intermediate cuneiform"""

    name: Literal["intermediate cuneiform"] = "intermediate cuneiform"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36177"] = "EMAPA_36177"


class _Lateral_Cuneiform(_MouseAnatomicalStructureModel):
    """Model lateral cuneiform"""

    name: Literal["lateral cuneiform"] = "lateral cuneiform"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36178"] = "EMAPA_36178"


class _Tibiale(_MouseAnatomicalStructureModel):
    """Model tibiale"""

    name: Literal["tibiale"] = "tibiale"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36179"] = "EMAPA_36179"


class _Navicular(_MouseAnatomicalStructureModel):
    """Model navicular"""

    name: Literal["navicular"] = "navicular"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36180"] = "EMAPA_36180"


class _Anconeus(_MouseAnatomicalStructureModel):
    """Model anconeus"""

    name: Literal["anconeus"] = "anconeus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36181"] = "EMAPA_36181"


class _Coracobrachialis(_MouseAnatomicalStructureModel):
    """Model coracobrachialis"""

    name: Literal["coracobrachialis"] = "coracobrachialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36182"] = "EMAPA_36182"


class _Tensor_Fasciae_Antebrachii(_MouseAnatomicalStructureModel):
    """Model tensor fasciae antebrachii"""

    name: Literal["tensor fasciae antebrachii"] = "tensor fasciae antebrachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36183"] = "EMAPA_36183"


class _Lateral_Head_Of_Triceps_Brachii(_MouseAnatomicalStructureModel):
    """Model lateral head of triceps brachii"""

    name: Literal["lateral head of triceps brachii"] = "lateral head of triceps brachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36184"] = "EMAPA_36184"


class _Long_Head_Of_Triceps_Brachii(_MouseAnatomicalStructureModel):
    """Model long head of triceps brachii"""

    name: Literal["long head of triceps brachii"] = "long head of triceps brachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36185"] = "EMAPA_36185"


class _Medial_Head_Of_Triceps_Brachii(_MouseAnatomicalStructureModel):
    """Model medial head of triceps brachii"""

    name: Literal["medial head of triceps brachii"] = "medial head of triceps brachii"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36186"] = "EMAPA_36186"


class _Extensor_Carpi_Radialis(_MouseAnatomicalStructureModel):
    """Model extensor carpi radialis"""

    name: Literal["extensor carpi radialis"] = "extensor carpi radialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36187"] = "EMAPA_36187"


class _Extensor_Carpi_Radialis_Brevis(_MouseAnatomicalStructureModel):
    """Model extensor carpi radialis brevis"""

    name: Literal["extensor carpi radialis brevis"] = "extensor carpi radialis brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36188"] = "EMAPA_36188"


class _Extensor_Carpi_Radialis_Longus(_MouseAnatomicalStructureModel):
    """Model extensor carpi radialis longus"""

    name: Literal["extensor carpi radialis longus"] = "extensor carpi radialis longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36189"] = "EMAPA_36189"


class _Extensor_Carpi_Ulnaris(_MouseAnatomicalStructureModel):
    """Model extensor carpi ulnaris"""

    name: Literal["extensor carpi ulnaris"] = "extensor carpi ulnaris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36190"] = "EMAPA_36190"


class _Extensor_Digitorum_Communis(_MouseAnatomicalStructureModel):
    """Model extensor digitorum communis"""

    name: Literal["extensor digitorum communis"] = "extensor digitorum communis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36191"] = "EMAPA_36191"


class _Extensor_Digitorum_Lateralis(_MouseAnatomicalStructureModel):
    """Model extensor digitorum lateralis"""

    name: Literal["extensor digitorum lateralis"] = "extensor digitorum lateralis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36192"] = "EMAPA_36192"


class _Extensor_Indicis_Proprius(_MouseAnatomicalStructureModel):
    """Model extensor indicis proprius"""

    name: Literal["extensor indicis proprius"] = "extensor indicis proprius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36193"] = "EMAPA_36193"


class _Extensor_Pollicis(_MouseAnatomicalStructureModel):
    """Model extensor pollicis"""

    name: Literal["extensor pollicis"] = "extensor pollicis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36194"] = "EMAPA_36194"


class _Extensor_Pollicis_Brevis(_MouseAnatomicalStructureModel):
    """Model extensor pollicis brevis"""

    name: Literal["extensor pollicis brevis"] = "extensor pollicis brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36195"] = "EMAPA_36195"


class _Extensor_Pollicis_Longus(_MouseAnatomicalStructureModel):
    """Model extensor pollicis longus"""

    name: Literal["extensor pollicis longus"] = "extensor pollicis longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36196"] = "EMAPA_36196"


class _Flexor_Carpi_Radialis(_MouseAnatomicalStructureModel):
    """Model flexor carpi radialis"""

    name: Literal["flexor carpi radialis"] = "flexor carpi radialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36197"] = "EMAPA_36197"


class _Flexor_Carpi_Ulnaris(_MouseAnatomicalStructureModel):
    """Model flexor carpi ulnaris"""

    name: Literal["flexor carpi ulnaris"] = "flexor carpi ulnaris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36198"] = "EMAPA_36198"


class _Humeral_Head_Of_Flexor_Digitorum_Profundus(_MouseAnatomicalStructureModel):
    """Model humeral head of flexor digitorum profundus"""

    name: Literal["humeral head of flexor digitorum profundus"] = "humeral head of flexor digitorum profundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36199"] = "EMAPA_36199"


class _Radial_Head_Of_Flexor_Digitorum_Profundus(_MouseAnatomicalStructureModel):
    """Model radial head of flexor digitorum profundus"""

    name: Literal["radial head of flexor digitorum profundus"] = "radial head of flexor digitorum profundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36200"] = "EMAPA_36200"


class _Ulnar_Head_Of_Flexor_Digitorum_Profundus(_MouseAnatomicalStructureModel):
    """Model ulnar head of flexor digitorum profundus"""

    name: Literal["ulnar head of flexor digitorum profundus"] = "ulnar head of flexor digitorum profundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36201"] = "EMAPA_36201"


class _Flexor_Digitorum_Superficialis(_MouseAnatomicalStructureModel):
    """Model flexor digitorum superficialis"""

    name: Literal["flexor digitorum superficialis"] = "flexor digitorum superficialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36202"] = "EMAPA_36202"


class _Flexor_Digitorum_Superficialis_1(_MouseAnatomicalStructureModel):
    """Model flexor digitorum superficialis 1"""

    name: Literal["flexor digitorum superficialis 1"] = "flexor digitorum superficialis 1"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36203"] = "EMAPA_36203"


class _Flexor_Digitorum_Superficialis_2(_MouseAnatomicalStructureModel):
    """Model flexor digitorum superficialis 2"""

    name: Literal["flexor digitorum superficialis 2"] = "flexor digitorum superficialis 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36204"] = "EMAPA_36204"


class _Palmaris_Longus(_MouseAnatomicalStructureModel):
    """Model palmaris longus"""

    name: Literal["palmaris longus"] = "palmaris longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36205"] = "EMAPA_36205"


class _Pronator_Quadratus(_MouseAnatomicalStructureModel):
    """Model pronator quadratus"""

    name: Literal["pronator quadratus"] = "pronator quadratus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36206"] = "EMAPA_36206"


class _Pronator_Teres(_MouseAnatomicalStructureModel):
    """Model pronator teres"""

    name: Literal["pronator teres"] = "pronator teres"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36207"] = "EMAPA_36207"


class _Supinator(_MouseAnatomicalStructureModel):
    """Model supinator"""

    name: Literal["supinator"] = "supinator"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36208"] = "EMAPA_36208"


class _Abductor_Pollicis(_MouseAnatomicalStructureModel):
    """Model abductor pollicis"""

    name: Literal["abductor pollicis"] = "abductor pollicis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36209"] = "EMAPA_36209"


class _Abductor_Pollicis_Longus(_MouseAnatomicalStructureModel):
    """Model abductor pollicis longus"""

    name: Literal["abductor pollicis longus"] = "abductor pollicis longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36210"] = "EMAPA_36210"


class _Abductor_Pollicis_Brevis(_MouseAnatomicalStructureModel):
    """Model abductor pollicis brevis"""

    name: Literal["abductor pollicis brevis"] = "abductor pollicis brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36211"] = "EMAPA_36211"


class _Abductor_Digiti_Quinti_Of_Hand(_MouseAnatomicalStructureModel):
    """Model abductor digiti quinti of hand"""

    name: Literal["abductor digiti quinti of hand"] = "abductor digiti quinti of hand"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36212"] = "EMAPA_36212"


class _Adductor_Pollicis(_MouseAnatomicalStructureModel):
    """Model adductor pollicis"""

    name: Literal["adductor pollicis"] = "adductor pollicis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36213"] = "EMAPA_36213"


class _Flexor_Digiti_Primi_Brevis_Of_Hand(_MouseAnatomicalStructureModel):
    """Model flexor digiti primi brevis of hand"""

    name: Literal["flexor digiti primi brevis of hand"] = "flexor digiti primi brevis of hand"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36214"] = "EMAPA_36214"


class _Flexor_Digiti_Quinti_Brevis(_MouseAnatomicalStructureModel):
    """Model flexor digiti quinti brevis"""

    name: Literal["flexor digiti quinti brevis"] = "flexor digiti quinti brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36215"] = "EMAPA_36215"


class _Interosseus_Muscle_Of_Hand(_MouseAnatomicalStructureModel):
    """Model interosseus muscle of hand"""

    name: Literal["interosseus muscle of hand"] = "interosseus muscle of hand"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36216"] = "EMAPA_36216"


class _Lumbrical_Muscle_Of_Hand(_MouseAnatomicalStructureModel):
    """Model lumbrical muscle of hand"""

    name: Literal["lumbrical muscle of hand"] = "lumbrical muscle of hand"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36217"] = "EMAPA_36217"


class _Opponens_Digiti_Quinti(_MouseAnatomicalStructureModel):
    """Model opponens digiti quinti"""

    name: Literal["opponens digiti quinti"] = "opponens digiti quinti"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36218"] = "EMAPA_36218"


class _Adductor_Brevis(_MouseAnatomicalStructureModel):
    """Model adductor brevis"""

    name: Literal["adductor brevis"] = "adductor brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36219"] = "EMAPA_36219"


class _Adductor_Longus(_MouseAnatomicalStructureModel):
    """Model adductor longus"""

    name: Literal["adductor longus"] = "adductor longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36220"] = "EMAPA_36220"


class _Adductor_Magnus(_MouseAnatomicalStructureModel):
    """Model adductor magnus"""

    name: Literal["adductor magnus"] = "adductor magnus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36221"] = "EMAPA_36221"


class _Accessory_Head_Of_Biceps_Femoris(_MouseAnatomicalStructureModel):
    """Model accessory head of biceps femoris"""

    name: Literal["accessory head of biceps femoris"] = "accessory head of biceps femoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36223"] = "EMAPA_36223"


class _Anterior_Head_Of_Biceps_Femoris(_MouseAnatomicalStructureModel):
    """Model anterior head of biceps femoris"""

    name: Literal["anterior head of biceps femoris"] = "anterior head of biceps femoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36224"] = "EMAPA_36224"


class _Posterior_Head_Of_Biceps_Femoris(_MouseAnatomicalStructureModel):
    """Model posterior head of biceps femoris"""

    name: Literal["posterior head of biceps femoris"] = "posterior head of biceps femoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36225"] = "EMAPA_36225"


class _Caudofemoralis(_MouseAnatomicalStructureModel):
    """Model caudofemoralis"""

    name: Literal["caudofemoralis"] = "caudofemoralis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36226"] = "EMAPA_36226"


class _Gemellus_Muscle(_MouseAnatomicalStructureModel):
    """Model gemellus muscle"""

    name: Literal["gemellus muscle"] = "gemellus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36227"] = "EMAPA_36227"


class _Gemellus_Inferior(_MouseAnatomicalStructureModel):
    """Model gemellus inferior"""

    name: Literal["gemellus inferior"] = "gemellus inferior"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36228"] = "EMAPA_36228"


class _Gemellus_Superior(_MouseAnatomicalStructureModel):
    """Model gemellus superior"""

    name: Literal["gemellus superior"] = "gemellus superior"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36229"] = "EMAPA_36229"


class _Gluteus_Minimus(_MouseAnatomicalStructureModel):
    """Model gluteus minimus"""

    name: Literal["gluteus minimus"] = "gluteus minimus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36230"] = "EMAPA_36230"


class _Gracilis_Muscle(_MouseAnatomicalStructureModel):
    """Model gracilis muscle"""

    name: Literal["gracilis muscle"] = "gracilis muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36231"] = "EMAPA_36231"


class _Gracilis_Anticus(_MouseAnatomicalStructureModel):
    """Model gracilis anticus"""

    name: Literal["gracilis anticus"] = "gracilis anticus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36232"] = "EMAPA_36232"


class _Gracilis_Posticus(_MouseAnatomicalStructureModel):
    """Model gracilis posticus"""

    name: Literal["gracilis posticus"] = "gracilis posticus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36233"] = "EMAPA_36233"


class _Obturator_Muscle(_MouseAnatomicalStructureModel):
    """Model obturator muscle"""

    name: Literal["obturator muscle"] = "obturator muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36235"] = "EMAPA_36235"


class _Obturator_Externus(_MouseAnatomicalStructureModel):
    """Model obturator externus"""

    name: Literal["obturator externus"] = "obturator externus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36236"] = "EMAPA_36236"


class _Obturator_Internus(_MouseAnatomicalStructureModel):
    """Model obturator internus"""

    name: Literal["obturator internus"] = "obturator internus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36237"] = "EMAPA_36237"


class _Pectineus(_MouseAnatomicalStructureModel):
    """Model pectineus"""

    name: Literal["pectineus"] = "pectineus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36238"] = "EMAPA_36238"


class _Piriformis(_MouseAnatomicalStructureModel):
    """Model piriformis"""

    name: Literal["piriformis"] = "piriformis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36239"] = "EMAPA_36239"


class _Popliteus(_MouseAnatomicalStructureModel):
    """Model popliteus"""

    name: Literal["popliteus"] = "popliteus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36240"] = "EMAPA_36240"


class _Quadratus_Femoris(_MouseAnatomicalStructureModel):
    """Model quadratus femoris"""

    name: Literal["quadratus femoris"] = "quadratus femoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36241"] = "EMAPA_36241"


class _Semimembranosus(_MouseAnatomicalStructureModel):
    """Model semimembranosus"""

    name: Literal["semimembranosus"] = "semimembranosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36242"] = "EMAPA_36242"


class _Vastus_Intermedius(_MouseAnatomicalStructureModel):
    """Model vastus intermedius"""

    name: Literal["vastus intermedius"] = "vastus intermedius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36243"] = "EMAPA_36243"


class _Vastus_Lateralis(_MouseAnatomicalStructureModel):
    """Model vastus lateralis"""

    name: Literal["vastus lateralis"] = "vastus lateralis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36244"] = "EMAPA_36244"


class _Vastus_Medialis(_MouseAnatomicalStructureModel):
    """Model vastus medialis"""

    name: Literal["vastus medialis"] = "vastus medialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36245"] = "EMAPA_36245"


class _Extensor_Hallucis_Longus(_MouseAnatomicalStructureModel):
    """Model extensor hallucis longus"""

    name: Literal["extensor hallucis longus"] = "extensor hallucis longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36246"] = "EMAPA_36246"


class _Flexor_Digitorum_Brevis(_MouseAnatomicalStructureModel):
    """Model flexor digitorum brevis"""

    name: Literal["flexor digitorum brevis"] = "flexor digitorum brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36247"] = "EMAPA_36247"


class _Flexor_Digitorum_Longus(_MouseAnatomicalStructureModel):
    """Model flexor digitorum longus"""

    name: Literal["flexor digitorum longus"] = "flexor digitorum longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36248"] = "EMAPA_36248"


class _Lateral_Head_Of_Gastrocnemius(_MouseAnatomicalStructureModel):
    """Model lateral head of gastrocnemius"""

    name: Literal["lateral head of gastrocnemius"] = "lateral head of gastrocnemius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36249"] = "EMAPA_36249"


class _Medial_Head_Of_Gastrocnemius(_MouseAnatomicalStructureModel):
    """Model medial head of gastrocnemius"""

    name: Literal["medial head of gastrocnemius"] = "medial head of gastrocnemius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36250"] = "EMAPA_36250"


class _Peroneus_Muscle(_MouseAnatomicalStructureModel):
    """Model peroneus muscle"""

    name: Literal["peroneus muscle"] = "peroneus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36251"] = "EMAPA_36251"


class _Peroneus_Brevis(_MouseAnatomicalStructureModel):
    """Model peroneus brevis"""

    name: Literal["peroneus brevis"] = "peroneus brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36252"] = "EMAPA_36252"


class _Peroneus_Longus(_MouseAnatomicalStructureModel):
    """Model peroneus longus"""

    name: Literal["peroneus longus"] = "peroneus longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36253"] = "EMAPA_36253"


class _Plantaris(_MouseAnatomicalStructureModel):
    """Model plantaris"""

    name: Literal["plantaris"] = "plantaris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36254"] = "EMAPA_36254"


class _Tibialis_Posterior(_MouseAnatomicalStructureModel):
    """Model tibialis posterior"""

    name: Literal["tibialis posterior"] = "tibialis posterior"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36255"] = "EMAPA_36255"


class _Abductor_Digiti_Quinti_Of_Foot(_MouseAnatomicalStructureModel):
    """Model abductor digiti quinti of foot"""

    name: Literal["abductor digiti quinti of foot"] = "abductor digiti quinti of foot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36256"] = "EMAPA_36256"


class _Adductor_Indicis(_MouseAnatomicalStructureModel):
    """Model adductor indicis"""

    name: Literal["adductor indicis"] = "adductor indicis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36257"] = "EMAPA_36257"


class _Extensor_Digitorum_Brevis(_MouseAnatomicalStructureModel):
    """Model extensor digitorum brevis"""

    name: Literal["extensor digitorum brevis"] = "extensor digitorum brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36258"] = "EMAPA_36258"


class _Flexor_Digiti_Primi_Brevis_Of_Foot(_MouseAnatomicalStructureModel):
    """Model flexor digiti primi brevis of foot"""

    name: Literal["flexor digiti primi brevis of foot"] = "flexor digiti primi brevis of foot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36259"] = "EMAPA_36259"


class _Peroneus_Digiti_Quarti(_MouseAnatomicalStructureModel):
    """Model peroneus digiti quarti"""

    name: Literal["peroneus digiti quarti"] = "peroneus digiti quarti"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36260"] = "EMAPA_36260"


class _Peroneus_Digiti_Quinti(_MouseAnatomicalStructureModel):
    """Model peroneus digiti quinti"""

    name: Literal["peroneus digiti quinti"] = "peroneus digiti quinti"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36261"] = "EMAPA_36261"


class _Interosseus_Muscle_Of_Foot(_MouseAnatomicalStructureModel):
    """Model interosseus muscle of foot"""

    name: Literal["interosseus muscle of foot"] = "interosseus muscle of foot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36262"] = "EMAPA_36262"


class _Lumbrical_Muscle_Of_Foot(_MouseAnatomicalStructureModel):
    """Model lumbrical muscle of foot"""

    name: Literal["lumbrical muscle of foot"] = "lumbrical muscle of foot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36263"] = "EMAPA_36263"


class _Quadratus_Plantae(_MouseAnatomicalStructureModel):
    """Model quadratus plantae"""

    name: Literal["quadratus plantae"] = "quadratus plantae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36264"] = "EMAPA_36264"


class _Tensor_Aponeurosis_Plantaris(_MouseAnatomicalStructureModel):
    """Model tensor aponeurosis plantaris"""

    name: Literal["tensor aponeurosis plantaris"] = "tensor aponeurosis plantaris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36265"] = "EMAPA_36265"


class _Rectus_Femoris(_MouseAnatomicalStructureModel):
    """Model rectus femoris"""

    name: Literal["rectus femoris"] = "rectus femoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36266"] = "EMAPA_36266"


class _Triceps_Surae_Muscle(_MouseAnatomicalStructureModel):
    """Model triceps surae muscle"""

    name: Literal["triceps surae muscle"] = "triceps surae muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36267"] = "EMAPA_36267"


class _Median_Sulcus(_MouseAnatomicalStructureModel):
    """Model median sulcus"""

    name: Literal["median sulcus"] = "median sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36268"] = "EMAPA_36268"


class _Serratus_Dorsalis(_MouseAnatomicalStructureModel):
    """Model serratus dorsalis"""

    name: Literal["serratus dorsalis"] = "serratus dorsalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36269"] = "EMAPA_36269"


class _Medullary_Velum(_MouseAnatomicalStructureModel):
    """Model medullary velum"""

    name: Literal["medullary velum"] = "medullary velum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36270"] = "EMAPA_36270"


class _Vertebral_Vein(_MouseAnatomicalStructureModel):
    """Model vertebral vein"""

    name: Literal["vertebral vein"] = "vertebral vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36271"] = "EMAPA_36271"


class _Foramen_Transversarium(_MouseAnatomicalStructureModel):
    """Model foramen transversarium"""

    name: Literal["foramen transversarium"] = "foramen transversarium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36272"] = "EMAPA_36272"


class _Uterus_Lumen(_MouseAnatomicalStructureModel):
    """Model uterus lumen"""

    name: Literal["uterus lumen"] = "uterus lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36273"] = "EMAPA_36273"


class _Otic_Ganglion(_MouseAnatomicalStructureModel):
    """Model otic ganglion"""

    name: Literal["otic ganglion"] = "otic ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36274"] = "EMAPA_36274"


class _Sphenopalatine_Ganglion(_MouseAnatomicalStructureModel):
    """Model sphenopalatine ganglion"""

    name: Literal["sphenopalatine ganglion"] = "sphenopalatine ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36275"] = "EMAPA_36275"


class _Submandibular_Ganglion(_MouseAnatomicalStructureModel):
    """Model submandibular ganglion"""

    name: Literal["submandibular ganglion"] = "submandibular ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36276"] = "EMAPA_36276"


class _Right_Lung_Accessory_Lobe_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung accessory lobe vascular element"""

    name: Literal["right lung accessory lobe vascular element"] = "right lung accessory lobe vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36277"] = "EMAPA_36277"


class _Right_Lung_Caudal_Lobe_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung caudal lobe vascular element"""

    name: Literal["right lung caudal lobe vascular element"] = "right lung caudal lobe vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36278"] = "EMAPA_36278"


class _Right_Lung_Cranial_Lobe_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung cranial lobe vascular element"""

    name: Literal["right lung cranial lobe vascular element"] = "right lung cranial lobe vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36279"] = "EMAPA_36279"


class _Right_Lung_Middle_Lobe_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model right lung middle lobe vascular element"""

    name: Literal["right lung middle lobe vascular element"] = "right lung middle lobe vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36280"] = "EMAPA_36280"


class _Lung_Lobe(_MouseAnatomicalStructureModel):
    """Model lung lobe"""

    name: Literal["lung lobe"] = "lung lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36281"] = "EMAPA_36281"


class _Terminal_Bronchiole(_MouseAnatomicalStructureModel):
    """Model terminal bronchiole"""

    name: Literal["terminal bronchiole"] = "terminal bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36282"] = "EMAPA_36282"


class _Terminal_Bronchiole_Epithelium(_MouseAnatomicalStructureModel):
    """Model terminal bronchiole epithelium"""

    name: Literal["terminal bronchiole epithelium"] = "terminal bronchiole epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36283"] = "EMAPA_36283"


class _Bronchial_Vein(_MouseAnatomicalStructureModel):
    """Model bronchial vein"""

    name: Literal["bronchial vein"] = "bronchial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36284"] = "EMAPA_36284"


class _Artery_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model artery smooth muscle"""

    name: Literal["artery smooth muscle"] = "artery smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36285"] = "EMAPA_36285"


class _Arteriole_Endothelium(_MouseAnatomicalStructureModel):
    """Model arteriole endothelium"""

    name: Literal["arteriole endothelium"] = "arteriole endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36286"] = "EMAPA_36286"


class _Arteriole_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model arteriole smooth muscle"""

    name: Literal["arteriole smooth muscle"] = "arteriole smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36287"] = "EMAPA_36287"


class _Vein_Endothelium(_MouseAnatomicalStructureModel):
    """Model vein endothelium"""

    name: Literal["vein endothelium"] = "vein endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36288"] = "EMAPA_36288"


class _Vein_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model vein smooth muscle"""

    name: Literal["vein smooth muscle"] = "vein smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36289"] = "EMAPA_36289"


class _Venule_Endothelium(_MouseAnatomicalStructureModel):
    """Model venule endothelium"""

    name: Literal["venule endothelium"] = "venule endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36290"] = "EMAPA_36290"


class _Capillary_Bed(_MouseAnatomicalStructureModel):
    """Model capillary bed"""

    name: Literal["capillary bed"] = "capillary bed"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36291"] = "EMAPA_36291"


class _Capillary_Endothelium(_MouseAnatomicalStructureModel):
    """Model capillary endothelium"""

    name: Literal["capillary endothelium"] = "capillary endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36292"] = "EMAPA_36292"


class _Artery_Tunica_Intima(_MouseAnatomicalStructureModel):
    """Model artery tunica intima"""

    name: Literal["artery tunica intima"] = "artery tunica intima"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36293"] = "EMAPA_36293"


class _Artery_Tunica_Media(_MouseAnatomicalStructureModel):
    """Model artery tunica media"""

    name: Literal["artery tunica media"] = "artery tunica media"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36294"] = "EMAPA_36294"


class _Artery_Tunica_Adventitia(_MouseAnatomicalStructureModel):
    """Model artery tunica adventitia"""

    name: Literal["artery tunica adventitia"] = "artery tunica adventitia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36295"] = "EMAPA_36295"


class _Blood_Vessel_Layer(_MouseAnatomicalStructureModel):
    """Model blood vessel layer"""

    name: Literal["blood vessel layer"] = "blood vessel layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36296"] = "EMAPA_36296"


class _Tunica_Intima(_MouseAnatomicalStructureModel):
    """Model tunica intima"""

    name: Literal["tunica intima"] = "tunica intima"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36297"] = "EMAPA_36297"


class _Tunica_Media(_MouseAnatomicalStructureModel):
    """Model tunica media"""

    name: Literal["tunica media"] = "tunica media"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36298"] = "EMAPA_36298"


class _Tunica_Adventitia(_MouseAnatomicalStructureModel):
    """Model tunica adventitia"""

    name: Literal["tunica adventitia"] = "tunica adventitia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36299"] = "EMAPA_36299"


class _Blood_Vessel_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model blood vessel elastic tissue"""

    name: Literal["blood vessel elastic tissue"] = "blood vessel elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36300"] = "EMAPA_36300"


class _Internal_Elastic_Lamina(_MouseAnatomicalStructureModel):
    """Model internal elastic lamina"""

    name: Literal["internal elastic lamina"] = "internal elastic lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36301"] = "EMAPA_36301"


class _External_Elastic_Lamina(_MouseAnatomicalStructureModel):
    """Model external elastic lamina"""

    name: Literal["external elastic lamina"] = "external elastic lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36302"] = "EMAPA_36302"


class _Artery_Internal_Elastic_Lamina(_MouseAnatomicalStructureModel):
    """Model artery internal elastic lamina"""

    name: Literal["artery internal elastic lamina"] = "artery internal elastic lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36303"] = "EMAPA_36303"


class _Artery_External_Elastic_Lamina(_MouseAnatomicalStructureModel):
    """Model artery external elastic lamina"""

    name: Literal["artery external elastic lamina"] = "artery external elastic lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36304"] = "EMAPA_36304"


class _Arteriole_Tunica_Intima(_MouseAnatomicalStructureModel):
    """Model arteriole tunica intima"""

    name: Literal["arteriole tunica intima"] = "arteriole tunica intima"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36305"] = "EMAPA_36305"


class _Arteriole_Tunica_Media(_MouseAnatomicalStructureModel):
    """Model arteriole tunica media"""

    name: Literal["arteriole tunica media"] = "arteriole tunica media"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36306"] = "EMAPA_36306"


class _Arteriole_Tunica_Adventitia(_MouseAnatomicalStructureModel):
    """Model arteriole tunica adventitia"""

    name: Literal["arteriole tunica adventitia"] = "arteriole tunica adventitia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36307"] = "EMAPA_36307"


class _Vein_Tunica_Intima(_MouseAnatomicalStructureModel):
    """Model vein tunica intima"""

    name: Literal["vein tunica intima"] = "vein tunica intima"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36308"] = "EMAPA_36308"


class _Vein_Tunica_Media(_MouseAnatomicalStructureModel):
    """Model vein tunica media"""

    name: Literal["vein tunica media"] = "vein tunica media"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36309"] = "EMAPA_36309"


class _Vein_Tunica_Adventitia(_MouseAnatomicalStructureModel):
    """Model vein tunica adventitia"""

    name: Literal["vein tunica adventitia"] = "vein tunica adventitia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36310"] = "EMAPA_36310"


class _Lymphatic_Vessel_Tunica_Intima(_MouseAnatomicalStructureModel):
    """Model lymphatic vessel tunica intima"""

    name: Literal["lymphatic vessel tunica intima"] = "lymphatic vessel tunica intima"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36311"] = "EMAPA_36311"


class _Lymphatic_Vessel_Tunica_Media(_MouseAnatomicalStructureModel):
    """Model lymphatic vessel tunica media"""

    name: Literal["lymphatic vessel tunica media"] = "lymphatic vessel tunica media"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36312"] = "EMAPA_36312"


class _Lymphatic_Vessel_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model lymphatic vessel smooth muscle"""

    name: Literal["lymphatic vessel smooth muscle"] = "lymphatic vessel smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36313"] = "EMAPA_36313"


class _Lymphatic_Vessel_Tunica_Adventitia(_MouseAnatomicalStructureModel):
    """Model lymphatic vessel tunica adventitia"""

    name: Literal["lymphatic vessel tunica adventitia"] = "lymphatic vessel tunica adventitia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36314"] = "EMAPA_36314"


class _Surface_Ectoderm_Of_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model surface ectoderm of genital tubercle"""

    name: Literal["surface ectoderm of genital tubercle"] = "surface ectoderm of genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36315"] = "EMAPA_36315"


class _Palatine_Vasculature(_MouseAnatomicalStructureModel):
    """Model palatine vasculature"""

    name: Literal["palatine vasculature"] = "palatine vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36316"] = "EMAPA_36316"


class _Reichert_S_Cartilage_Pre_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Reichert's cartilage pre-cartilage condensation"""

    name: Literal["Reichert's cartilage pre-cartilage condensation"] = "Reichert's cartilage pre-cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36317"] = "EMAPA_36317"


class _Reichert_S_Cartilage_Condensation(_MouseAnatomicalStructureModel):
    """Model Reichert's cartilage condensation"""

    name: Literal["Reichert's cartilage condensation"] = "Reichert's cartilage condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36318"] = "EMAPA_36318"


class _Reichert_S_Cartilage(_MouseAnatomicalStructureModel):
    """Model Reichert's cartilage"""

    name: Literal["Reichert's cartilage"] = "Reichert's cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36319"] = "EMAPA_36319"


class _Styloid_Process_Of_Temporal_Bone(_MouseAnatomicalStructureModel):
    """Model styloid process of temporal bone"""

    name: Literal["styloid process of temporal bone"] = "styloid process of temporal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36320"] = "EMAPA_36320"


class _Hyoid_Body_Upper_Part(_MouseAnatomicalStructureModel):
    """Model hyoid body upper part"""

    name: Literal["hyoid body upper part"] = "hyoid body upper part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36321"] = "EMAPA_36321"


class _Chordae_Tendinae(_MouseAnatomicalStructureModel):
    """Model chordae tendinae"""

    name: Literal["chordae tendinae"] = "chordae tendinae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36322"] = "EMAPA_36322"


class _Hepatic_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model hepatic venous plexus"""

    name: Literal["hepatic venous plexus"] = "hepatic venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36323"] = "EMAPA_36323"


class _Lingual_Artery(_MouseAnatomicalStructureModel):
    """Model lingual artery"""

    name: Literal["lingual artery"] = "lingual artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36324"] = "EMAPA_36324"


class _Thymic_Vein(_MouseAnatomicalStructureModel):
    """Model thymic vein"""

    name: Literal["thymic vein"] = "thymic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36325"] = "EMAPA_36325"


class _Liver_Lobar_Interzone(_MouseAnatomicalStructureModel):
    """Model liver lobar interzone"""

    name: Literal["liver lobar interzone"] = "liver lobar interzone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36326"] = "EMAPA_36326"


class _Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model venous plexus"""

    name: Literal["venous plexus"] = "venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36327"] = "EMAPA_36327"


class _Vertebral_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model vertebral venous plexus"""

    name: Literal["vertebral venous plexus"] = "vertebral venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36328"] = "EMAPA_36328"


class _External_Vertebral_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model external vertebral venous plexus"""

    name: Literal["external vertebral venous plexus"] = "external vertebral venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36329"] = "EMAPA_36329"


class _Internal_Vertebral_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model internal vertebral venous plexus"""

    name: Literal["internal vertebral venous plexus"] = "internal vertebral venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36330"] = "EMAPA_36330"


class _Tailgut(_MouseAnatomicalStructureModel):
    """Model tailgut"""

    name: Literal["tailgut"] = "tailgut"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36331"] = "EMAPA_36331"


class _Bladder_Urethra_Transition_Zone(_MouseAnatomicalStructureModel):
    """Model bladder-urethra transition zone"""

    name: Literal["bladder-urethra transition zone"] = "bladder-urethra transition zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36332"] = "EMAPA_36332"


class _Epithelium_Of_Bladder_Urethra_Transition_Zone(_MouseAnatomicalStructureModel):
    """Model epithelium of bladder-urethra transition zone"""

    name: Literal["epithelium of bladder-urethra transition zone"] = "epithelium of bladder-urethra transition zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36333"] = "EMAPA_36333"


class _Mesenchyme_Of_Bladder_Urethra_Transition_Zone(_MouseAnatomicalStructureModel):
    """Model mesenchyme of bladder-urethra transition zone"""

    name: Literal["mesenchyme of bladder-urethra transition zone"] = "mesenchyme of bladder-urethra transition zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36334"] = "EMAPA_36334"


class _Remnant_Of_Mesonephric_Tubule_Of_Male(_MouseAnatomicalStructureModel):
    """Model remnant of mesonephric tubule of male"""

    name: Literal["remnant of mesonephric tubule of male"] = "remnant of mesonephric tubule of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36335"] = "EMAPA_36335"


class _Forelimb_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb interphalangeal joint"""

    name: Literal["forelimb interphalangeal joint"] = "forelimb interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36336"] = "EMAPA_36336"


class _Hindlimb_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb interphalangeal joint"""

    name: Literal["hindlimb interphalangeal joint"] = "hindlimb interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36337"] = "EMAPA_36337"


class _Metatarsal_Phalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model metatarsal-phalangeal joint"""

    name: Literal["metatarsal-phalangeal joint"] = "metatarsal-phalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36338"] = "EMAPA_36338"


class _Bronchiole_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model bronchiole smooth muscle"""

    name: Literal["bronchiole smooth muscle"] = "bronchiole smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36339"] = "EMAPA_36339"


class _Hair_Follicle_Of_Male_Prepuce(_MouseAnatomicalStructureModel):
    """Model hair follicle of male prepuce"""

    name: Literal["hair follicle of male prepuce"] = "hair follicle of male prepuce"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36340"] = "EMAPA_36340"


class _Lamina_Propria_Of_Male_Prepuce(_MouseAnatomicalStructureModel):
    """Model lamina propria of male prepuce"""

    name: Literal["lamina propria of male prepuce"] = "lamina propria of male prepuce"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36341"] = "EMAPA_36341"


class _Preputial_Space_Of_Male(_MouseAnatomicalStructureModel):
    """Model preputial space of male"""

    name: Literal["preputial space of male"] = "preputial space of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36342"] = "EMAPA_36342"


class _Nerve_Of_Urothelium_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of urothelium of bladder"""

    name: Literal["nerve of urothelium of bladder"] = "nerve of urothelium of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36343"] = "EMAPA_36343"


class _Nerve_Of_Lamina_Propria_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of lamina propria of bladder"""

    name: Literal["nerve of lamina propria of bladder"] = "nerve of lamina propria of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36344"] = "EMAPA_36344"


class _Nerve_Of_Detrusor_Muscle_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of detrusor muscle of bladder"""

    name: Literal["nerve of detrusor muscle of bladder"] = "nerve of detrusor muscle of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36345"] = "EMAPA_36345"


class _Nerve_Of_Outer_Layer_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of outer layer of bladder"""

    name: Literal["nerve of outer layer of bladder"] = "nerve of outer layer of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36346"] = "EMAPA_36346"


class _Nerve_Of_Urothelium_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of urothelium of bladder fundus"""

    name: Literal["nerve of urothelium of bladder fundus"] = "nerve of urothelium of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36347"] = "EMAPA_36347"


class _Nerve_Of_Urothelium_Of_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of urothelium of bladder neck"""

    name: Literal["nerve of urothelium of bladder neck"] = "nerve of urothelium of bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36348"] = "EMAPA_36348"


class _Nerve_Of_Urothelium_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model nerve of urothelium of bladder trigone"""

    name: Literal["nerve of urothelium of bladder trigone"] = "nerve of urothelium of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36349"] = "EMAPA_36349"


class _Nerve_Of_Urothelium_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of urothelium of ventral bladder neck"""

    name: Literal["nerve of urothelium of ventral bladder neck"] = "nerve of urothelium of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36350"] = "EMAPA_36350"


class _Nerve_Of_Lamina_Propria_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of lamina propria of bladder fundus"""

    name: Literal["nerve of lamina propria of bladder fundus"] = "nerve of lamina propria of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36351"] = "EMAPA_36351"


class _Nerve_Of_Lamina_Propria_Of_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of lamina propria of bladder neck"""

    name: Literal["nerve of lamina propria of bladder neck"] = "nerve of lamina propria of bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36352"] = "EMAPA_36352"


class _Nerve_Of_Blood_Vessel_Of_Lamina_Propria_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of lamina propria of bladder fundus"""

    name: Literal[
        "nerve of blood vessel of lamina propria of bladder fundus"
    ] = "nerve of blood vessel of lamina propria of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36353"] = "EMAPA_36353"


class _Nerve_Of_Blood_Vessel_Of_Lamina_Propria_Of_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of lamina propria of bladder neck"""

    name: Literal[
        "nerve of blood vessel of lamina propria of bladder neck"
    ] = "nerve of blood vessel of lamina propria of bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36354"] = "EMAPA_36354"


class _Nerve_Of_Suburothelial_Lamina_Propria_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of suburothelial lamina propria of bladder fundus"""

    name: Literal[
        "nerve of suburothelial lamina propria of bladder fundus"
    ] = "nerve of suburothelial lamina propria of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36355"] = "EMAPA_36355"


class _Nerve_Of_Outer_Lamina_Propria_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of outer lamina propria of bladder fundus"""

    name: Literal["nerve of outer lamina propria of bladder fundus"] = "nerve of outer lamina propria of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36356"] = "EMAPA_36356"


class _Nerve_Of_Lamina_Propria_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model nerve of lamina propria of bladder trigone"""

    name: Literal["nerve of lamina propria of bladder trigone"] = "nerve of lamina propria of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36357"] = "EMAPA_36357"


class _Nerve_Of_Lamina_Propria_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of lamina propria of ventral bladder neck"""

    name: Literal["nerve of lamina propria of ventral bladder neck"] = "nerve of lamina propria of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36358"] = "EMAPA_36358"


class _Nerve_Of_Blood_Vessel_Of_Suburothelial_Lamina_Propria_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of suburothelial lamina propria of bladder fundus"""

    name: Literal[
        "nerve of blood vessel of suburothelial lamina propria of bladder fundus"
    ] = "nerve of blood vessel of suburothelial lamina propria of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36359"] = "EMAPA_36359"


class _Nerve_Of_Blood_Vessel_Of_Outer_Lamina_Propria_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of outer lamina propria of bladder fundus"""

    name: Literal[
        "nerve of blood vessel of outer lamina propria of bladder fundus"
    ] = "nerve of blood vessel of outer lamina propria of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36360"] = "EMAPA_36360"


class _Nerve_Of_Blood_Vessel_Of_Lamina_Propria_Of_Trigone(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of lamina propria of trigone"""

    name: Literal[
        "nerve of blood vessel of lamina propria of trigone"
    ] = "nerve of blood vessel of lamina propria of trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36361"] = "EMAPA_36361"


class _Nerve_Of_Blood_Vessel_Of_Lamina_Propria_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of lamina propria of ventral bladder neck"""

    name: Literal[
        "nerve of blood vessel of lamina propria of ventral bladder neck"
    ] = "nerve of blood vessel of lamina propria of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36362"] = "EMAPA_36362"


class _Nerve_Of_Nonvascular_Tissue_Of_Detrusor_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of nonvascular tissue of detrusor of bladder"""

    name: Literal[
        "nerve of nonvascular tissue of detrusor of bladder"
    ] = "nerve of nonvascular tissue of detrusor of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36363"] = "EMAPA_36363"


class _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of detrusor of bladder"""

    name: Literal["nerve of blood vessel of detrusor of bladder"] = "nerve of blood vessel of detrusor of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36364"] = "EMAPA_36364"


class _Nerve_Of_Detrusor_Muscle_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of detrusor muscle of bladder fundus"""

    name: Literal["nerve of detrusor muscle of bladder fundus"] = "nerve of detrusor muscle of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36365"] = "EMAPA_36365"


class _Nerve_Of_Detrusor_Muscle_Of_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of detrusor muscle of bladder neck"""

    name: Literal["nerve of detrusor muscle of bladder neck"] = "nerve of detrusor muscle of bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36366"] = "EMAPA_36366"


class _Nerve_Of_Detrusor_Muscle_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model nerve of detrusor muscle of bladder trigone"""

    name: Literal["nerve of detrusor muscle of bladder trigone"] = "nerve of detrusor muscle of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36367"] = "EMAPA_36367"


class _Nerve_Of_Detrusor_Muscle_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of detrusor muscle of ventral bladder neck"""

    name: Literal[
        "nerve of detrusor muscle of ventral bladder neck"
    ] = "nerve of detrusor muscle of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36368"] = "EMAPA_36368"


class _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of detrusor of bladder fundus"""

    name: Literal[
        "nerve of blood vessel of detrusor of bladder fundus"
    ] = "nerve of blood vessel of detrusor of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36369"] = "EMAPA_36369"


class _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of detrusor of bladder neck"""

    name: Literal[
        "nerve of blood vessel of detrusor of bladder neck"
    ] = "nerve of blood vessel of detrusor of bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36370"] = "EMAPA_36370"


class _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Trigone(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of detrusor of trigone"""

    name: Literal["nerve of blood vessel of detrusor of trigone"] = "nerve of blood vessel of detrusor of trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36371"] = "EMAPA_36371"


class _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of detrusor of ventral bladder neck"""

    name: Literal[
        "nerve of blood vessel of detrusor of ventral bladder neck"
    ] = "nerve of blood vessel of detrusor of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36372"] = "EMAPA_36372"


class _Nerve_Of_Nonvascular_Tissue_Of_Outer_Layer_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of nonvascular tissue of outer layer of bladder"""

    name: Literal[
        "nerve of nonvascular tissue of outer layer of bladder"
    ] = "nerve of nonvascular tissue of outer layer of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36373"] = "EMAPA_36373"


class _Nerve_Of_Blood_Vessel_Of_Outer_Layer_Of_Bladder(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of outer layer of bladder"""

    name: Literal["nerve of blood vessel of outer layer of bladder"] = "nerve of blood vessel of outer layer of bladder"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36374"] = "EMAPA_36374"


class _Nerve_Of_Serosa_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of serosa of bladder fundus"""

    name: Literal["nerve of serosa of bladder fundus"] = "nerve of serosa of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36375"] = "EMAPA_36375"


class _Nerve_Of_Adventitia_Of_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of adventitia of bladder neck"""

    name: Literal["nerve of adventitia of bladder neck"] = "nerve of adventitia of bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36376"] = "EMAPA_36376"


class _Nerve_Of_Adventitia_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model nerve of adventitia of bladder trigone"""

    name: Literal["nerve of adventitia of bladder trigone"] = "nerve of adventitia of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36377"] = "EMAPA_36377"


class _Nerve_Of_Adventitia_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of adventitia of ventral bladder neck"""

    name: Literal["nerve of adventitia of ventral bladder neck"] = "nerve of adventitia of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36378"] = "EMAPA_36378"


class _Nerve_Of_Blood_Vessel_Of_Serosa_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of serosa of bladder fundus"""

    name: Literal[
        "nerve of blood vessel of serosa of bladder fundus"
    ] = "nerve of blood vessel of serosa of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36379"] = "EMAPA_36379"


class _Nerve_Of_Blood_Vessel_Of_Adventitia_Of_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of adventitia of bladder neck"""

    name: Literal[
        "nerve of blood vessel of adventitia of bladder neck"
    ] = "nerve of blood vessel of adventitia of bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36380"] = "EMAPA_36380"


class _Nerve_Of_Blood_Vessel_Of_Adventitia_Of_Trigone(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of adventitia of trigone"""

    name: Literal["nerve of blood vessel of adventitia of trigone"] = "nerve of blood vessel of adventitia of trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36381"] = "EMAPA_36381"


class _Nerve_Of_Blood_Vessel_Of_Adventitia_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of blood vessel of adventitia of ventral bladder neck"""

    name: Literal[
        "nerve of blood vessel of adventitia of ventral bladder neck"
    ] = "nerve of blood vessel of adventitia of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36382"] = "EMAPA_36382"


class _Duodenum_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model duodenum mesenchyme"""

    name: Literal["duodenum mesenchyme"] = "duodenum mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36383"] = "EMAPA_36383"


class _Genital_Tubercle_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model genital tubercle mesenchyme"""

    name: Literal["genital tubercle mesenchyme"] = "genital tubercle mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36384"] = "EMAPA_36384"


class _Small_Intestine_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model small intestine mesenchyme"""

    name: Literal["small intestine mesenchyme"] = "small intestine mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36385"] = "EMAPA_36385"


class _Genital_Tubercle_Epithelium(_MouseAnatomicalStructureModel):
    """Model genital tubercle epithelium"""

    name: Literal["genital tubercle epithelium"] = "genital tubercle epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36386"] = "EMAPA_36386"


class _Digit_Dermis(_MouseAnatomicalStructureModel):
    """Model digit dermis"""

    name: Literal["digit dermis"] = "digit dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36387"] = "EMAPA_36387"


class _Digit_Epidermis(_MouseAnatomicalStructureModel):
    """Model digit epidermis"""

    name: Literal["digit epidermis"] = "digit epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36388"] = "EMAPA_36388"


class _Tail_Dermatome(_MouseAnatomicalStructureModel):
    """Model tail dermatome"""

    name: Literal["tail dermatome"] = "tail dermatome"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36389"] = "EMAPA_36389"


class _Striated_Muscle_Tissue(_MouseAnatomicalStructureModel):
    """Model striated muscle tissue"""

    name: Literal["striated muscle tissue"] = "striated muscle tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36390"] = "EMAPA_36390"


class _Sigmoid_Colon(_MouseAnatomicalStructureModel):
    """Model sigmoid colon"""

    name: Literal["sigmoid colon"] = "sigmoid colon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36391"] = "EMAPA_36391"


class _Back_Skin(_MouseAnatomicalStructureModel):
    """Model back skin"""

    name: Literal["back skin"] = "back skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36392"] = "EMAPA_36392"


class _Nerve_Of_Bladder_Fundus(_MouseAnatomicalStructureModel):
    """Model nerve of bladder fundus"""

    name: Literal["nerve of bladder fundus"] = "nerve of bladder fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36393"] = "EMAPA_36393"


class _Nerve_Of_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of bladder neck"""

    name: Literal["nerve of bladder neck"] = "nerve of bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36394"] = "EMAPA_36394"


class _Nerve_Of_Bladder_Trigone(_MouseAnatomicalStructureModel):
    """Model nerve of bladder trigone"""

    name: Literal["nerve of bladder trigone"] = "nerve of bladder trigone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36395"] = "EMAPA_36395"


class _Nerve_Of_Ventral_Bladder_Neck(_MouseAnatomicalStructureModel):
    """Model nerve of ventral bladder neck"""

    name: Literal["nerve of ventral bladder neck"] = "nerve of ventral bladder neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36396"] = "EMAPA_36396"


class _Glandular_Ridge(_MouseAnatomicalStructureModel):
    """Model glandular ridge"""

    name: Literal["glandular ridge"] = "glandular ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36397"] = "EMAPA_36397"


class _Male_Urogenital_Mating_Protuberance(_MouseAnatomicalStructureModel):
    """Model male urogenital mating protuberance"""

    name: Literal["male urogenital mating protuberance"] = "male urogenital mating protuberance"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36398"] = "EMAPA_36398"


class _Bone_Of_Os_Penis(_MouseAnatomicalStructureModel):
    """Model bone of os penis"""

    name: Literal["bone of os penis"] = "bone of os penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36399"] = "EMAPA_36399"


class _Hyaline_Cartilage_Of_Os_Penis(_MouseAnatomicalStructureModel):
    """Model hyaline cartilage of os penis"""

    name: Literal["hyaline cartilage of os penis"] = "hyaline cartilage of os penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36400"] = "EMAPA_36400"


class _Male_Urogenital_Mating_Protuberance_Cartilage(_MouseAnatomicalStructureModel):
    """Model male urogenital mating protuberance cartilage"""

    name: Literal["male urogenital mating protuberance cartilage"] = "male urogenital mating protuberance cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36401"] = "EMAPA_36401"


class _Male_Urogenital_Mating_Protuberance_Corpus_Cavernosum(_MouseAnatomicalStructureModel):
    """Model male urogenital mating protuberance corpus cavernosum"""

    name: Literal[
        "male urogenital mating protuberance corpus cavernosum"
    ] = "male urogenital mating protuberance corpus cavernosum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36402"] = "EMAPA_36402"


class _Male_Urogenital_Mating_Protuberance_Surface_Epithelium(_MouseAnatomicalStructureModel):
    """Model male urogenital mating protuberance surface epithelium"""

    name: Literal[
        "male urogenital mating protuberance surface epithelium"
    ] = "male urogenital mating protuberance surface epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36403"] = "EMAPA_36403"


class _Male_Urogenital_Mating_Protuberance_Ridge_Groove(_MouseAnatomicalStructureModel):
    """Model male urogenital mating protuberance ridge groove"""

    name: Literal[
        "male urogenital mating protuberance ridge groove"
    ] = "male urogenital mating protuberance ridge groove"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36404"] = "EMAPA_36404"


class _Male_Urogenital_Mating_Protuberance_Skin(_MouseAnatomicalStructureModel):
    """Model male urogenital mating protuberance skin"""

    name: Literal["male urogenital mating protuberance skin"] = "male urogenital mating protuberance skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36405"] = "EMAPA_36405"


class _Corpus_Cavernosum_Glandis(_MouseAnatomicalStructureModel):
    """Model corpus cavernosum glandis"""

    name: Literal["corpus cavernosum glandis"] = "corpus cavernosum glandis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36406"] = "EMAPA_36406"


class _Corpus_Cavernosum_Urethra(_MouseAnatomicalStructureModel):
    """Model corpus cavernosum urethra"""

    name: Literal["corpus cavernosum urethra"] = "corpus cavernosum urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36407"] = "EMAPA_36407"


class _Female_Prepuce_Hair_Follicle(_MouseAnatomicalStructureModel):
    """Model female prepuce hair follicle"""

    name: Literal["female prepuce hair follicle"] = "female prepuce hair follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36409"] = "EMAPA_36409"


class _Female_Prepuce_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model female prepuce lamina propria"""

    name: Literal["female prepuce lamina propria"] = "female prepuce lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36410"] = "EMAPA_36410"


class _Scrotum_Skin(_MouseAnatomicalStructureModel):
    """Model scrotum skin"""

    name: Literal["scrotum skin"] = "scrotum skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36411"] = "EMAPA_36411"


class _Lamina_Propria_Of_Scrotum(_MouseAnatomicalStructureModel):
    """Model lamina propria of scrotum"""

    name: Literal["lamina propria of scrotum"] = "lamina propria of scrotum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36412"] = "EMAPA_36412"


class _Developing_Vasculature_Of_Scrotal_Swelling(_MouseAnatomicalStructureModel):
    """Model developing vasculature of scrotal swelling"""

    name: Literal["developing vasculature of scrotal swelling"] = "developing vasculature of scrotal swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36413"] = "EMAPA_36413"


class _Septum_Of_Scrotal_Fold(_MouseAnatomicalStructureModel):
    """Model septum of scrotal fold"""

    name: Literal["septum of scrotal fold"] = "septum of scrotal fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36414"] = "EMAPA_36414"


class _Developing_Vasculature_Of_Scrotal_Fold(_MouseAnatomicalStructureModel):
    """Model developing vasculature of scrotal fold"""

    name: Literal["developing vasculature of scrotal fold"] = "developing vasculature of scrotal fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36415"] = "EMAPA_36415"


class _Developing_Vasculature_Of_Labial_Fold(_MouseAnatomicalStructureModel):
    """Model developing vasculature of labial fold"""

    name: Literal["developing vasculature of labial fold"] = "developing vasculature of labial fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36416"] = "EMAPA_36416"


class _Developing_Vasculature_Of_Labial_Swelling(_MouseAnatomicalStructureModel):
    """Model developing vasculature of labial swelling"""

    name: Literal["developing vasculature of labial swelling"] = "developing vasculature of labial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36417"] = "EMAPA_36417"


class _Lamina_Propria_Of_Seminal_Vesicle(_MouseAnatomicalStructureModel):
    """Model lamina propria of seminal vesicle"""

    name: Literal["lamina propria of seminal vesicle"] = "lamina propria of seminal vesicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36418"] = "EMAPA_36418"


class _Adventitia_Of_Ejaculatory_Duct(_MouseAnatomicalStructureModel):
    """Model adventitia of ejaculatory duct"""

    name: Literal["adventitia of ejaculatory duct"] = "adventitia of ejaculatory duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36419"] = "EMAPA_36419"


class _Lamina_Propria_Of_Ductus_Deferens(_MouseAnatomicalStructureModel):
    """Model lamina propria of ductus deferens"""

    name: Literal["lamina propria of ductus deferens"] = "lamina propria of ductus deferens"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36420"] = "EMAPA_36420"


class _Urethral_Seam(_MouseAnatomicalStructureModel):
    """Model urethral seam"""

    name: Literal["urethral seam"] = "urethral seam"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36421"] = "EMAPA_36421"


class _Migrating_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model migrating neural crest"""

    name: Literal["migrating neural crest"] = "migrating neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36422"] = "EMAPA_36422"


class _Urethral_Gland_Of_Pelvic_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model urethral gland of pelvic urethra of male"""

    name: Literal["urethral gland of pelvic urethra of male"] = "urethral gland of pelvic urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36423"] = "EMAPA_36423"


class _Urethral_Gland_Of_Penile_Urethra(_MouseAnatomicalStructureModel):
    """Model urethral gland of penile urethra"""

    name: Literal["urethral gland of penile urethra"] = "urethral gland of penile urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36424"] = "EMAPA_36424"


class _Male_Urethral_Gland_Bud(_MouseAnatomicalStructureModel):
    """Model male urethral gland bud"""

    name: Literal["male urethral gland bud"] = "male urethral gland bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36425"] = "EMAPA_36425"


class _Anterior_Male_Urethral_Gland_Bud(_MouseAnatomicalStructureModel):
    """Model anterior male urethral gland bud"""

    name: Literal["anterior male urethral gland bud"] = "anterior male urethral gland bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36426"] = "EMAPA_36426"


class _Posterior_Male_Urethral_Gland_Bud(_MouseAnatomicalStructureModel):
    """Model posterior male urethral gland bud"""

    name: Literal["posterior male urethral gland bud"] = "posterior male urethral gland bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36427"] = "EMAPA_36427"


class _Female_Accessory_Gland(_MouseAnatomicalStructureModel):
    """Model female accessory gland"""

    name: Literal["female accessory gland"] = "female accessory gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36428"] = "EMAPA_36428"


class _Bulbourethral_Gland_Of_Female(_MouseAnatomicalStructureModel):
    """Model bulbourethral gland of female"""

    name: Literal["bulbourethral gland of female"] = "bulbourethral gland of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36429"] = "EMAPA_36429"


class _Epithelium_Of_Bulbourethral_Gland_Of_Female(_MouseAnatomicalStructureModel):
    """Model epithelium of bulbourethral gland of female"""

    name: Literal["epithelium of bulbourethral gland of female"] = "epithelium of bulbourethral gland of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36430"] = "EMAPA_36430"


class _Lamina_Propria_Of_Bulbourethral_Gland_Of_Female(_MouseAnatomicalStructureModel):
    """Model lamina propria of bulbourethral gland of female"""

    name: Literal["lamina propria of bulbourethral gland of female"] = "lamina propria of bulbourethral gland of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36431"] = "EMAPA_36431"


class _Vasculature_Of_Bulbourethral_Gland_Of_Female(_MouseAnatomicalStructureModel):
    """Model vasculature of bulbourethral gland of female"""

    name: Literal["vasculature of bulbourethral gland of female"] = "vasculature of bulbourethral gland of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36432"] = "EMAPA_36432"


class _Phallic_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model phallic urethra of female"""

    name: Literal["phallic urethra of female"] = "phallic urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36433"] = "EMAPA_36433"


class _Urethral_Meatus_Of_Penile_Urethra(_MouseAnatomicalStructureModel):
    """Model urethral meatus of penile urethra"""

    name: Literal["urethral meatus of penile urethra"] = "urethral meatus of penile urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36434"] = "EMAPA_36434"


class _Urogenital_Membrane_Of_Female(_MouseAnatomicalStructureModel):
    """Model urogenital membrane of female"""

    name: Literal["urogenital membrane of female"] = "urogenital membrane of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36435"] = "EMAPA_36435"


class _Urogenital_Membrane_Of_Male(_MouseAnatomicalStructureModel):
    """Model urogenital membrane of male"""

    name: Literal["urogenital membrane of male"] = "urogenital membrane of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36436"] = "EMAPA_36436"


class _Mesenchyme_Of_Metanephros(_MouseAnatomicalStructureModel):
    """Model mesenchyme of metanephros"""

    name: Literal["mesenchyme of metanephros"] = "mesenchyme of metanephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36437"] = "EMAPA_36437"


class _Heart_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model heart mesenchyme"""

    name: Literal["heart mesenchyme"] = "heart mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36438"] = "EMAPA_36438"


class _Predentin(_MouseAnatomicalStructureModel):
    """Model predentin"""

    name: Literal["predentin"] = "predentin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36439"] = "EMAPA_36439"


class _Tooth_Basement_Membrane(_MouseAnatomicalStructureModel):
    """Model tooth basement membrane"""

    name: Literal["tooth basement membrane"] = "tooth basement membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36440"] = "EMAPA_36440"


class _Mesenchyme_Of_Glans_Of_Female_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model mesenchyme of glans of female genital tubercle"""

    name: Literal["mesenchyme of glans of female genital tubercle"] = "mesenchyme of glans of female genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36441"] = "EMAPA_36441"


class _Urethral_Plate_Epithelium_Of_Urogenital_Membrane_Of_Female(_MouseAnatomicalStructureModel):
    """Model urethral plate epithelium of urogenital membrane of female"""

    name: Literal[
        "urethral plate epithelium of urogenital membrane of female"
    ] = "urethral plate epithelium of urogenital membrane of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36442"] = "EMAPA_36442"


class _Skin_Of_Urogenital_Membrane_Of_Female(_MouseAnatomicalStructureModel):
    """Model skin of urogenital membrane of female"""

    name: Literal["skin of urogenital membrane of female"] = "skin of urogenital membrane of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36443"] = "EMAPA_36443"


class _Urethral_Plate_Epithelium_Of_Urogenital_Membrane_Of_Male(_MouseAnatomicalStructureModel):
    """Model urethral plate epithelium of urogenital membrane of male"""

    name: Literal[
        "urethral plate epithelium of urogenital membrane of male"
    ] = "urethral plate epithelium of urogenital membrane of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36444"] = "EMAPA_36444"


class _Skin_Of_Urogenital_Membrane_Of_Male(_MouseAnatomicalStructureModel):
    """Model skin of urogenital membrane of male"""

    name: Literal["skin of urogenital membrane of male"] = "skin of urogenital membrane of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36445"] = "EMAPA_36445"


class _Visual_Cortex(_MouseAnatomicalStructureModel):
    """Model visual cortex"""

    name: Literal["visual cortex"] = "visual cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36446"] = "EMAPA_36446"


class _Prelimbic_Area(_MouseAnatomicalStructureModel):
    """Model prelimbic area"""

    name: Literal["prelimbic area"] = "prelimbic area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36447"] = "EMAPA_36447"


class _Ca3_Pyramidal_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model CA3 pyramidal cell layer"""

    name: Literal["CA3 pyramidal cell layer"] = "CA3 pyramidal cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36448"] = "EMAPA_36448"


class _Forebrain_Midbrain_Boundary_Region(_MouseAnatomicalStructureModel):
    """Model forebrain-midbrain boundary region"""

    name: Literal["forebrain-midbrain boundary region"] = "forebrain-midbrain boundary region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36449"] = "EMAPA_36449"


class _Subcommissural_Organ_Primordium(_MouseAnatomicalStructureModel):
    """Model subcommissural organ primordium"""

    name: Literal["subcommissural organ primordium"] = "subcommissural organ primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36450"] = "EMAPA_36450"


class _Urethral_Tube_Epithelium_Of_Clitoral_Urethra(_MouseAnatomicalStructureModel):
    """Model urethral tube epithelium of clitoral urethra"""

    name: Literal["urethral tube epithelium of clitoral urethra"] = "urethral tube epithelium of clitoral urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36451"] = "EMAPA_36451"


class _Proximal_Urethral_Meatus_Of_Clitoral_Urethra(_MouseAnatomicalStructureModel):
    """Model proximal urethral meatus of clitoral urethra"""

    name: Literal["proximal urethral meatus of clitoral urethra"] = "proximal urethral meatus of clitoral urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36452"] = "EMAPA_36452"


class _Urethral_Meatus_Of_Clitoral_Urethra(_MouseAnatomicalStructureModel):
    """Model urethral meatus of clitoral urethra"""

    name: Literal["urethral meatus of clitoral urethra"] = "urethral meatus of clitoral urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36453"] = "EMAPA_36453"


class _Urethral_Tube_Epithelium_Of_Penile_Urethra(_MouseAnatomicalStructureModel):
    """Model urethral tube epithelium of penile urethra"""

    name: Literal["urethral tube epithelium of penile urethra"] = "urethral tube epithelium of penile urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36454"] = "EMAPA_36454"


class _Gland_Of_Vaginal_Epithelium(_MouseAnatomicalStructureModel):
    """Model gland of vaginal epithelium"""

    name: Literal["gland of vaginal epithelium"] = "gland of vaginal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36455"] = "EMAPA_36455"


class _Rest_Of_Epithelium_Of_Vagina(_MouseAnatomicalStructureModel):
    """Model rest of epithelium of vagina"""

    name: Literal["rest of epithelium of vagina"] = "rest of epithelium of vagina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36456"] = "EMAPA_36456"


class _Hindlimb_Nail(_MouseAnatomicalStructureModel):
    """Model hindlimb nail"""

    name: Literal["hindlimb nail"] = "hindlimb nail"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36457"] = "EMAPA_36457"


class _Myometrium_Inner_Circular_Smooth_Muscle_Layer(_MouseAnatomicalStructureModel):
    """Model myometrium inner circular smooth muscle layer"""

    name: Literal["myometrium inner circular smooth muscle layer"] = "myometrium inner circular smooth muscle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36458"] = "EMAPA_36458"


class _Myometrium_Outer_Longitudinal_Smooth_Muscle_Layer(_MouseAnatomicalStructureModel):
    """Model myometrium outer longitudinal smooth muscle layer"""

    name: Literal[
        "myometrium outer longitudinal smooth muscle layer"
    ] = "myometrium outer longitudinal smooth muscle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36459"] = "EMAPA_36459"


class _Great_Vessel_Of_Heart(_MouseAnatomicalStructureModel):
    """Model great vessel of heart"""

    name: Literal["great vessel of heart"] = "great vessel of heart"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36460"] = "EMAPA_36460"


class _Aortic_Sac(_MouseAnatomicalStructureModel):
    """Model aortic sac"""

    name: Literal["aortic sac"] = "aortic sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36461"] = "EMAPA_36461"


class _Outflow_Tract_Distal_Part(_MouseAnatomicalStructureModel):
    """Model outflow tract distal part"""

    name: Literal["outflow tract distal part"] = "outflow tract distal part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36462"] = "EMAPA_36462"


class _Anterior_Amniotic_Fold(_MouseAnatomicalStructureModel):
    """Model anterior amniotic fold"""

    name: Literal["anterior amniotic fold"] = "anterior amniotic fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36463"] = "EMAPA_36463"


class _Posterior_Amniotic_Fold(_MouseAnatomicalStructureModel):
    """Model posterior amniotic fold"""

    name: Literal["posterior amniotic fold"] = "posterior amniotic fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36464"] = "EMAPA_36464"


class _Perioptic_Vascular_Plexus(_MouseAnatomicalStructureModel):
    """Model perioptic vascular plexus"""

    name: Literal["perioptic vascular plexus"] = "perioptic vascular plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36465"] = "EMAPA_36465"


class _Cerebral_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model cerebral venous plexus"""

    name: Literal["cerebral venous plexus"] = "cerebral venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36466"] = "EMAPA_36466"


class _Anterior_Cerebral_Vein(_MouseAnatomicalStructureModel):
    """Model anterior cerebral vein"""

    name: Literal["anterior cerebral vein"] = "anterior cerebral vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36467"] = "EMAPA_36467"


class _Paracardiac_Ganglion(_MouseAnatomicalStructureModel):
    """Model paracardiac ganglion"""

    name: Literal["paracardiac ganglion"] = "paracardiac ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36468"] = "EMAPA_36468"


class _Dentate_Gyrus_Primordium(_MouseAnatomicalStructureModel):
    """Model dentate gyrus primordium"""

    name: Literal["dentate gyrus primordium"] = "dentate gyrus primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36469"] = "EMAPA_36469"


class _Prospective_Hippocampal_Fissure(_MouseAnatomicalStructureModel):
    """Model prospective hippocampal fissure"""

    name: Literal["prospective hippocampal fissure"] = "prospective hippocampal fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36470"] = "EMAPA_36470"


class _Hippocampal_Fissure(_MouseAnatomicalStructureModel):
    """Model hippocampal fissure"""

    name: Literal["hippocampal fissure"] = "hippocampal fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36471"] = "EMAPA_36471"


class _Macula_Of_Vestibular_Component(_MouseAnatomicalStructureModel):
    """Model macula of vestibular component"""

    name: Literal["macula of vestibular component"] = "macula of vestibular component"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36472"] = "EMAPA_36472"


class _Early_Conceptus(_MouseAnatomicalStructureModel):
    """Model early conceptus"""

    name: Literal["early conceptus"] = "early conceptus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36473"] = "EMAPA_36473"


class _Ovary_Follicle_Cell(_MouseAnatomicalStructureModel):
    """Model ovary follicle cell"""

    name: Literal["ovary follicle cell"] = "ovary follicle cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36474"] = "EMAPA_36474"


class _Mesenchyme_Of_Preputial_Swelling(_MouseAnatomicalStructureModel):
    """Model mesenchyme of preputial swelling"""

    name: Literal["mesenchyme of preputial swelling"] = "mesenchyme of preputial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36475"] = "EMAPA_36475"


class _Skin_Of_Preputial_Swelling(_MouseAnatomicalStructureModel):
    """Model skin of preputial swelling"""

    name: Literal["skin of preputial swelling"] = "skin of preputial swelling"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36476"] = "EMAPA_36476"


class _Vibrissa_Inner_Root_Sheath(_MouseAnatomicalStructureModel):
    """Model vibrissa inner root sheath"""

    name: Literal["vibrissa inner root sheath"] = "vibrissa inner root sheath"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36477"] = "EMAPA_36477"


class _Vibrissa_Outer_Root_Sheath(_MouseAnatomicalStructureModel):
    """Model vibrissa outer root sheath"""

    name: Literal["vibrissa outer root sheath"] = "vibrissa outer root sheath"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36478"] = "EMAPA_36478"


class _Hair_Germ(_MouseAnatomicalStructureModel):
    """Model hair germ"""

    name: Literal["hair germ"] = "hair germ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36479"] = "EMAPA_36479"


class _Ca2_Pyramidal_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model CA2 pyramidal cell layer"""

    name: Literal["CA2 pyramidal cell layer"] = "CA2 pyramidal cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36480"] = "EMAPA_36480"


class _Hair_Epidermal_Placode(_MouseAnatomicalStructureModel):
    """Model hair epidermal placode"""

    name: Literal["hair epidermal placode"] = "hair epidermal placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36481"] = "EMAPA_36481"


class _Vibrissa_Root_Sheath_Matrix(_MouseAnatomicalStructureModel):
    """Model vibrissa root sheath matrix"""

    name: Literal["vibrissa root sheath matrix"] = "vibrissa root sheath matrix"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36482"] = "EMAPA_36482"


class _Vibrissa_Dermal_Papilla(_MouseAnatomicalStructureModel):
    """Model vibrissa dermal papilla"""

    name: Literal["vibrissa dermal papilla"] = "vibrissa dermal papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36483"] = "EMAPA_36483"


class _Hair_Follicle_Dermal_Papilla(_MouseAnatomicalStructureModel):
    """Model hair follicle dermal papilla"""

    name: Literal["hair follicle dermal papilla"] = "hair follicle dermal papilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36484"] = "EMAPA_36484"


class _Pelage_Hair(_MouseAnatomicalStructureModel):
    """Model pelage hair"""

    name: Literal["pelage hair"] = "pelage hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36485"] = "EMAPA_36485"


class _Bulbus_Cordis_Endocardial_Tube(_MouseAnatomicalStructureModel):
    """Model bulbus cordis endocardial tube"""

    name: Literal["bulbus cordis endocardial tube"] = "bulbus cordis endocardial tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36486"] = "EMAPA_36486"


class _Bulbus_Cordis_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model bulbus cordis endocardial lining"""

    name: Literal["bulbus cordis endocardial lining"] = "bulbus cordis endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36487"] = "EMAPA_36487"


class _Bulbus_Cordis_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model bulbus cordis cardiac muscle"""

    name: Literal["bulbus cordis cardiac muscle"] = "bulbus cordis cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36488"] = "EMAPA_36488"


class _Bulbus_Cordis_Cardiac_Jelly(_MouseAnatomicalStructureModel):
    """Model bulbus cordis cardiac jelly"""

    name: Literal["bulbus cordis cardiac jelly"] = "bulbus cordis cardiac jelly"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36489"] = "EMAPA_36489"


class _Costo_Chondral_Joint(_MouseAnatomicalStructureModel):
    """Model costo-chondral joint"""

    name: Literal["costo-chondral joint"] = "costo-chondral joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36490"] = "EMAPA_36490"


class _Ventral_Ectodermal_Ridge(_MouseAnatomicalStructureModel):
    """Model ventral ectodermal ridge"""

    name: Literal["ventral ectodermal ridge"] = "ventral ectodermal ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36491"] = "EMAPA_36491"


class _Intersomitic_Artery(_MouseAnatomicalStructureModel):
    """Model intersomitic artery"""

    name: Literal["intersomitic artery"] = "intersomitic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36492"] = "EMAPA_36492"


class _Umbilical_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model umbilical blood vessel"""

    name: Literal["umbilical blood vessel"] = "umbilical blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36493"] = "EMAPA_36493"


class _Vitelline_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model vitelline blood vessel"""

    name: Literal["vitelline blood vessel"] = "vitelline blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36494"] = "EMAPA_36494"


class _Perirenal_Fat(_MouseAnatomicalStructureModel):
    """Model perirenal fat"""

    name: Literal["perirenal fat"] = "perirenal fat"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36495"] = "EMAPA_36495"


class _Large_Intestine_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model large intestine mesenchyme"""

    name: Literal["large intestine mesenchyme"] = "large intestine mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36496"] = "EMAPA_36496"


class _Thoracic_Cavity(_MouseAnatomicalStructureModel):
    """Model thoracic cavity"""

    name: Literal["thoracic cavity"] = "thoracic cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36497"] = "EMAPA_36497"


class _Hair_Shaft(_MouseAnatomicalStructureModel):
    """Model hair shaft"""

    name: Literal["hair shaft"] = "hair shaft"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36498"] = "EMAPA_36498"


class _Abdominal_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model abdominal fat pad"""

    name: Literal["abdominal fat pad"] = "abdominal fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36499"] = "EMAPA_36499"


class _Leg_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model leg blood vessel"""

    name: Literal["leg blood vessel"] = "leg blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36500"] = "EMAPA_36500"


class _Limb_Joint(_MouseAnatomicalStructureModel):
    """Model limb joint"""

    name: Literal["limb joint"] = "limb joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36501"] = "EMAPA_36501"


class _Tail_Skin(_MouseAnatomicalStructureModel):
    """Model tail skin"""

    name: Literal["tail skin"] = "tail skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36502"] = "EMAPA_36502"


class _Arterial_System_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model arterial system smooth muscle"""

    name: Literal["arterial system smooth muscle"] = "arterial system smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36503"] = "EMAPA_36503"


class _Thyroid_Gland_Follicle(_MouseAnatomicalStructureModel):
    """Model thyroid gland follicle"""

    name: Literal["thyroid gland follicle"] = "thyroid gland follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36504"] = "EMAPA_36504"


class _Abdominal_Cavity(_MouseAnatomicalStructureModel):
    """Model abdominal cavity"""

    name: Literal["abdominal cavity"] = "abdominal cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36505"] = "EMAPA_36505"


class _Peyer_S_Patch_Epithelium(_MouseAnatomicalStructureModel):
    """Model Peyer's patch epithelium"""

    name: Literal["Peyer's patch epithelium"] = "Peyer's patch epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36506"] = "EMAPA_36506"


class _Abdominal_Mammary_Gland(_MouseAnatomicalStructureModel):
    """Model abdominal mammary gland"""

    name: Literal["abdominal mammary gland"] = "abdominal mammary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36507"] = "EMAPA_36507"


class _Nipple(_MouseAnatomicalStructureModel):
    """Model nipple"""

    name: Literal["nipple"] = "nipple"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36508"] = "EMAPA_36508"


class _Dermis_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model dermis connective tissue"""

    name: Literal["dermis connective tissue"] = "dermis connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36509"] = "EMAPA_36509"


class _Substantia_Gelatinosa(_MouseAnatomicalStructureModel):
    """Model substantia gelatinosa"""

    name: Literal["substantia gelatinosa"] = "substantia gelatinosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36510"] = "EMAPA_36510"


class _Common_Peroneal_Nerve(_MouseAnatomicalStructureModel):
    """Model common peroneal nerve"""

    name: Literal["common peroneal nerve"] = "common peroneal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36511"] = "EMAPA_36511"


class _Tibial_Nerve(_MouseAnatomicalStructureModel):
    """Model tibial nerve"""

    name: Literal["tibial nerve"] = "tibial nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36512"] = "EMAPA_36512"


class _Auricular_Nerve(_MouseAnatomicalStructureModel):
    """Model auricular nerve"""

    name: Literal["auricular nerve"] = "auricular nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36513"] = "EMAPA_36513"


class _Harderian_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model Harderian gland epithelium"""

    name: Literal["Harderian gland epithelium"] = "Harderian gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36514"] = "EMAPA_36514"


class _Lacrimal_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model lacrimal gland epithelium"""

    name: Literal["lacrimal gland epithelium"] = "lacrimal gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36515"] = "EMAPA_36515"


class _Macula_Of_Retina(_MouseAnatomicalStructureModel):
    """Model macula of retina"""

    name: Literal["macula of retina"] = "macula of retina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36516"] = "EMAPA_36516"


class _Retina_Limiting_Lamina(_MouseAnatomicalStructureModel):
    """Model retina limiting lamina"""

    name: Literal["retina limiting lamina"] = "retina limiting lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36517"] = "EMAPA_36517"


class _Retina_External_Limiting_Lamina(_MouseAnatomicalStructureModel):
    """Model retina external limiting lamina"""

    name: Literal["retina external limiting lamina"] = "retina external limiting lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36518"] = "EMAPA_36518"


class _Retina_Internal_Limiting_Lamina(_MouseAnatomicalStructureModel):
    """Model retina internal limiting lamina"""

    name: Literal["retina internal limiting lamina"] = "retina internal limiting lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36519"] = "EMAPA_36519"


class _Retina_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model retina blood vessel"""

    name: Literal["retina blood vessel"] = "retina blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36520"] = "EMAPA_36520"


class _Squamosal_Bone(_MouseAnatomicalStructureModel):
    """Model squamosal bone"""

    name: Literal["squamosal bone"] = "squamosal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36521"] = "EMAPA_36521"


class _Brunner_S_Gland(_MouseAnatomicalStructureModel):
    """Model Brunner's gland"""

    name: Literal["Brunner's gland"] = "Brunner's gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36522"] = "EMAPA_36522"


class _Esophagus_Skeletal_Muscle(_MouseAnatomicalStructureModel):
    """Model esophagus skeletal muscle"""

    name: Literal["esophagus skeletal muscle"] = "esophagus skeletal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36523"] = "EMAPA_36523"


class _Renal_Tubule_Epithelium(_MouseAnatomicalStructureModel):
    """Model renal tubule epithelium"""

    name: Literal["renal tubule epithelium"] = "renal tubule epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36524"] = "EMAPA_36524"


class _Epididymal_Duct(_MouseAnatomicalStructureModel):
    """Model epididymal duct"""

    name: Literal["epididymal duct"] = "epididymal duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36525"] = "EMAPA_36525"


class _Xiphoid_Cartilage(_MouseAnatomicalStructureModel):
    """Model xiphoid cartilage"""

    name: Literal["xiphoid cartilage"] = "xiphoid cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36526"] = "EMAPA_36526"


class _Auchene_Hair(_MouseAnatomicalStructureModel):
    """Model auchene hair"""

    name: Literal["auchene hair"] = "auchene hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36527"] = "EMAPA_36527"


class _Guard_Hair(_MouseAnatomicalStructureModel):
    """Model guard hair"""

    name: Literal["guard hair"] = "guard hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36528"] = "EMAPA_36528"


class _Pancreatico_Duodenal_Artery(_MouseAnatomicalStructureModel):
    """Model pancreatico-duodenal artery"""

    name: Literal["pancreatico-duodenal artery"] = "pancreatico-duodenal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36529"] = "EMAPA_36529"


class _Tibial_Artery(_MouseAnatomicalStructureModel):
    """Model tibial artery"""

    name: Literal["tibial artery"] = "tibial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36530"] = "EMAPA_36530"


class _Left_Coronary_Artery(_MouseAnatomicalStructureModel):
    """Model left coronary artery"""

    name: Literal["left coronary artery"] = "left coronary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36531"] = "EMAPA_36531"


class _Right_Coronary_Artery(_MouseAnatomicalStructureModel):
    """Model right coronary artery"""

    name: Literal["right coronary artery"] = "right coronary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36532"] = "EMAPA_36532"


class _Septal_Coronary_Artery(_MouseAnatomicalStructureModel):
    """Model septal coronary artery"""

    name: Literal["septal coronary artery"] = "septal coronary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36533"] = "EMAPA_36533"


class _Bile_Canaliculus(_MouseAnatomicalStructureModel):
    """Model bile canaliculus"""

    name: Literal["bile canaliculus"] = "bile canaliculus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36534"] = "EMAPA_36534"


class _Exocrine_Gland_Fluid_Or_Secretion(_MouseAnatomicalStructureModel):
    """Model exocrine gland fluid or secretion"""

    name: Literal["exocrine gland fluid or secretion"] = "exocrine gland fluid or secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36535"] = "EMAPA_36535"


class _Saliva(_MouseAnatomicalStructureModel):
    """Model saliva"""

    name: Literal["saliva"] = "saliva"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36536"] = "EMAPA_36536"


class _Tear(_MouseAnatomicalStructureModel):
    """Model tear"""

    name: Literal["tear"] = "tear"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36537"] = "EMAPA_36537"


class _Mammary_Gland_Fluid_Or_Secretion(_MouseAnatomicalStructureModel):
    """Model mammary gland fluid or secretion"""

    name: Literal["mammary gland fluid or secretion"] = "mammary gland fluid or secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36538"] = "EMAPA_36538"


class _Colostrom(_MouseAnatomicalStructureModel):
    """Model colostrom"""

    name: Literal["colostrom"] = "colostrom"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36539"] = "EMAPA_36539"


class _Mammary_Gland_Milk(_MouseAnatomicalStructureModel):
    """Model mammary gland milk"""

    name: Literal["mammary gland milk"] = "mammary gland milk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36540"] = "EMAPA_36540"


class _Male_Reproductive_System_Fluid_Or_Secretion(_MouseAnatomicalStructureModel):
    """Model male reproductive system fluid or secretion"""

    name: Literal["male reproductive system fluid or secretion"] = "male reproductive system fluid or secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36541"] = "EMAPA_36541"


class _Semen(_MouseAnatomicalStructureModel):
    """Model semen"""

    name: Literal["semen"] = "semen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36542"] = "EMAPA_36542"


class _Seminal_Fluid(_MouseAnatomicalStructureModel):
    """Model seminal fluid"""

    name: Literal["seminal fluid"] = "seminal fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36543"] = "EMAPA_36543"


class _Bulbourethral_Gland_Secretion(_MouseAnatomicalStructureModel):
    """Model bulbourethral gland secretion"""

    name: Literal["bulbourethral gland secretion"] = "bulbourethral gland secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36544"] = "EMAPA_36544"


class _Prostate_Gland_Secretion(_MouseAnatomicalStructureModel):
    """Model prostate gland secretion"""

    name: Literal["prostate gland secretion"] = "prostate gland secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36545"] = "EMAPA_36545"


class _Seminal_Vesicle_Gland_Secretion(_MouseAnatomicalStructureModel):
    """Model seminal vesicle gland secretion"""

    name: Literal["seminal vesicle gland secretion"] = "seminal vesicle gland secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36546"] = "EMAPA_36546"


class _Otolymph(_MouseAnatomicalStructureModel):
    """Model otolymph"""

    name: Literal["otolymph"] = "otolymph"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36547"] = "EMAPA_36547"


class _Endolymph(_MouseAnatomicalStructureModel):
    """Model endolymph"""

    name: Literal["endolymph"] = "endolymph"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36548"] = "EMAPA_36548"


class _Perilymph(_MouseAnatomicalStructureModel):
    """Model perilymph"""

    name: Literal["perilymph"] = "perilymph"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36549"] = "EMAPA_36549"


class _Respiratory_System_Fluid_Or_Secretion(_MouseAnatomicalStructureModel):
    """Model respiratory system fluid or secretion"""

    name: Literal["respiratory system fluid or secretion"] = "respiratory system fluid or secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36550"] = "EMAPA_36550"


class _Lung_Surfactant(_MouseAnatomicalStructureModel):
    """Model lung surfactant"""

    name: Literal["lung surfactant"] = "lung surfactant"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36551"] = "EMAPA_36551"


class _Nasal_Mucus(_MouseAnatomicalStructureModel):
    """Model nasal mucus"""

    name: Literal["nasal mucus"] = "nasal mucus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36552"] = "EMAPA_36552"


class _Sputum(_MouseAnatomicalStructureModel):
    """Model sputum"""

    name: Literal["sputum"] = "sputum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36553"] = "EMAPA_36553"


class _Urine(_MouseAnatomicalStructureModel):
    """Model urine"""

    name: Literal["urine"] = "urine"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36554"] = "EMAPA_36554"


class _Inguinal_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model inguinal fat pad"""

    name: Literal["inguinal fat pad"] = "inguinal fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36555"] = "EMAPA_36555"


class _Corpora_Quadrigemina(_MouseAnatomicalStructureModel):
    """Model corpora quadrigemina"""

    name: Literal["corpora quadrigemina"] = "corpora quadrigemina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36556"] = "EMAPA_36556"


class _Pre_Botzinger_Complex(_MouseAnatomicalStructureModel):
    """Model pre-botzinger complex"""

    name: Literal["pre-botzinger complex"] = "pre-botzinger complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36557"] = "EMAPA_36557"


class _Peritubular_Capillary(_MouseAnatomicalStructureModel):
    """Model peritubular capillary"""

    name: Literal["peritubular capillary"] = "peritubular capillary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36558"] = "EMAPA_36558"


class _Inner_Renal_Medulla_Vasa_Recta(_MouseAnatomicalStructureModel):
    """Model inner renal medulla vasa recta"""

    name: Literal["inner renal medulla vasa recta"] = "inner renal medulla vasa recta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36559"] = "EMAPA_36559"


class _Outer_Renal_Medulla_Vasa_Recta(_MouseAnatomicalStructureModel):
    """Model outer renal medulla vasa recta"""

    name: Literal["outer renal medulla vasa recta"] = "outer renal medulla vasa recta"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36560"] = "EMAPA_36560"


class _Mesangium(_MouseAnatomicalStructureModel):
    """Model mesangium"""

    name: Literal["mesangium"] = "mesangium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36561"] = "EMAPA_36561"


class _Glomerular_Mesangium(_MouseAnatomicalStructureModel):
    """Model glomerular mesangium"""

    name: Literal["glomerular mesangium"] = "glomerular mesangium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36562"] = "EMAPA_36562"


class _Parotid_Duct(_MouseAnatomicalStructureModel):
    """Model parotid duct"""

    name: Literal["parotid duct"] = "parotid duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36563"] = "EMAPA_36563"


class _Sublingual_Duct(_MouseAnatomicalStructureModel):
    """Model sublingual duct"""

    name: Literal["sublingual duct"] = "sublingual duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36564"] = "EMAPA_36564"


class _Spinal_Cord_Intermediolateral_Nucleus(_MouseAnatomicalStructureModel):
    """Model spinal cord intermediolateral nucleus"""

    name: Literal["spinal cord intermediolateral nucleus"] = "spinal cord intermediolateral nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36565"] = "EMAPA_36565"


class _Mammary_Gland_Alveolus(_MouseAnatomicalStructureModel):
    """Model mammary gland alveolus"""

    name: Literal["mammary gland alveolus"] = "mammary gland alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36566"] = "EMAPA_36566"


class _Alisphenoid_Bone(_MouseAnatomicalStructureModel):
    """Model alisphenoid bone"""

    name: Literal["alisphenoid bone"] = "alisphenoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36567"] = "EMAPA_36567"


class _Prostate_Duct(_MouseAnatomicalStructureModel):
    """Model prostate duct"""

    name: Literal["prostate duct"] = "prostate duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36568"] = "EMAPA_36568"


class _Cochlear_Labyrinth(_MouseAnatomicalStructureModel):
    """Model cochlear labyrinth"""

    name: Literal["cochlear labyrinth"] = "cochlear labyrinth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36569"] = "EMAPA_36569"


class _Zygomatic_Arch(_MouseAnatomicalStructureModel):
    """Model zygomatic arch"""

    name: Literal["zygomatic arch"] = "zygomatic arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36570"] = "EMAPA_36570"


class _Temporal_Bone_Round_Window(_MouseAnatomicalStructureModel):
    """Model temporal bone round window"""

    name: Literal["temporal bone round window"] = "temporal bone round window"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36571"] = "EMAPA_36571"


class _Mandible_Condylar_Process(_MouseAnatomicalStructureModel):
    """Model mandible condylar process"""

    name: Literal["mandible condylar process"] = "mandible condylar process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36572"] = "EMAPA_36572"


class _Trabeculae_Carneae_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model trabeculae carneae cardiac muscle"""

    name: Literal["trabeculae carneae cardiac muscle"] = "trabeculae carneae cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36573"] = "EMAPA_36573"


class _Trachea_Gland(_MouseAnatomicalStructureModel):
    """Model trachea gland"""

    name: Literal["trachea gland"] = "trachea gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36574"] = "EMAPA_36574"


class _Dorsal_Striatum(_MouseAnatomicalStructureModel):
    """Model dorsal striatum"""

    name: Literal["dorsal striatum"] = "dorsal striatum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36575"] = "EMAPA_36575"


class _Ventral_Striatum(_MouseAnatomicalStructureModel):
    """Model ventral striatum"""

    name: Literal["ventral striatum"] = "ventral striatum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36576"] = "EMAPA_36576"


class _Exorbital_Lacrimal_Gland(_MouseAnatomicalStructureModel):
    """Model exorbital lacrimal gland"""

    name: Literal["exorbital lacrimal gland"] = "exorbital lacrimal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36577"] = "EMAPA_36577"


class _Intraorbital_Lacrimal_Gland(_MouseAnatomicalStructureModel):
    """Model intraorbital lacrimal gland"""

    name: Literal["intraorbital lacrimal gland"] = "intraorbital lacrimal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36578"] = "EMAPA_36578"


class _Carpal_Tarsal_Bone(_MouseAnatomicalStructureModel):
    """Model carpal/tarsal bone"""

    name: Literal["carpal/tarsal bone"] = "carpal/tarsal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36579"] = "EMAPA_36579"


class _Bony_Labyrinth(_MouseAnatomicalStructureModel):
    """Model bony labyrinth"""

    name: Literal["bony labyrinth"] = "bony labyrinth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36580"] = "EMAPA_36580"


class _Cartilaginous_Joint(_MouseAnatomicalStructureModel):
    """Model cartilaginous joint"""

    name: Literal["cartilaginous joint"] = "cartilaginous joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36581"] = "EMAPA_36581"


class _Pilosebaceous_Gland(_MouseAnatomicalStructureModel):
    """Model pilosebaceous gland"""

    name: Literal["pilosebaceous gland"] = "pilosebaceous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36582"] = "EMAPA_36582"


class _Trunk_Bone(_MouseAnatomicalStructureModel):
    """Model trunk bone"""

    name: Literal["trunk bone"] = "trunk bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36583"] = "EMAPA_36583"


class _Accessory_Olfactory_Bulb_Anlage(_MouseAnatomicalStructureModel):
    """Model accessory olfactory bulb anlage"""

    name: Literal["accessory olfactory bulb anlage"] = "accessory olfactory bulb anlage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36584"] = "EMAPA_36584"


class _Accessory_Olfactory_Bulb_Anlage_Mitral_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model accessory olfactory bulb anlage mitral cell layer"""

    name: Literal[
        "accessory olfactory bulb anlage mitral cell layer"
    ] = "accessory olfactory bulb anlage mitral cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36585"] = "EMAPA_36585"


class _Main_Olfactory_Bulb_Ventricular_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb ventricular layer"""

    name: Literal["main olfactory bulb ventricular layer"] = "main olfactory bulb ventricular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36586"] = "EMAPA_36586"


class _Main_Olfactory_Bulb_Prospective_Glomerular_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb prospective glomerular layer"""

    name: Literal[
        "main olfactory bulb prospective glomerular layer"
    ] = "main olfactory bulb prospective glomerular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36587"] = "EMAPA_36587"


class _Vertebral_Body(_MouseAnatomicalStructureModel):
    """Model vertebral body"""

    name: Literal["vertebral body"] = "vertebral body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36588"] = "EMAPA_36588"


class _Left_Kidney(_MouseAnatomicalStructureModel):
    """Model left kidney"""

    name: Literal["left kidney"] = "left kidney"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36589"] = "EMAPA_36589"


class _Right_Kidney(_MouseAnatomicalStructureModel):
    """Model right kidney"""

    name: Literal["right kidney"] = "right kidney"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36590"] = "EMAPA_36590"


class _Alimentary_System_Mucosa(_MouseAnatomicalStructureModel):
    """Model alimentary system mucosa"""

    name: Literal["alimentary system mucosa"] = "alimentary system mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36591"] = "EMAPA_36591"


class _Alimentary_System_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model alimentary system lamina propria"""

    name: Literal["alimentary system lamina propria"] = "alimentary system lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36592"] = "EMAPA_36592"


class _Stomach_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model stomach lamina propria"""

    name: Literal["stomach lamina propria"] = "stomach lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36593"] = "EMAPA_36593"


class _Eye_Anterior_Segment(_MouseAnatomicalStructureModel):
    """Model eye anterior segment"""

    name: Literal["eye anterior segment"] = "eye anterior segment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36594"] = "EMAPA_36594"


class _Eye_Posterior_Segment(_MouseAnatomicalStructureModel):
    """Model eye posterior segment"""

    name: Literal["eye posterior segment"] = "eye posterior segment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36595"] = "EMAPA_36595"


class _Sensory_Ganglion(_MouseAnatomicalStructureModel):
    """Model sensory ganglion"""

    name: Literal["sensory ganglion"] = "sensory ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36596"] = "EMAPA_36596"


class _Baroreceptor(_MouseAnatomicalStructureModel):
    """Model baroreceptor"""

    name: Literal["baroreceptor"] = "baroreceptor"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36597"] = "EMAPA_36597"


class _Limb_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model limb blood vessel"""

    name: Literal["limb blood vessel"] = "limb blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36598"] = "EMAPA_36598"


class _Main_Olfactory_Bulb_Prospective_Granule_Cell_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb prospective granule cell layer"""

    name: Literal[
        "main olfactory bulb prospective granule cell layer"
    ] = "main olfactory bulb prospective granule cell layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36599"] = "EMAPA_36599"


class _Corticospinal_Tract(_MouseAnatomicalStructureModel):
    """Model corticospinal tract"""

    name: Literal["corticospinal tract"] = "corticospinal tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36600"] = "EMAPA_36600"


class _Cerebellum_Purkinje_Cell_Cluster(_MouseAnatomicalStructureModel):
    """Model cerebellum Purkinje cell cluster"""

    name: Literal["cerebellum Purkinje cell cluster"] = "cerebellum Purkinje cell cluster"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36601"] = "EMAPA_36601"


class _Hypothalamus_Subventricular_Zone(_MouseAnatomicalStructureModel):
    """Model hypothalamus subventricular zone"""

    name: Literal["hypothalamus subventricular zone"] = "hypothalamus subventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36602"] = "EMAPA_36602"


class _Thalamus_Subventricular_Zone(_MouseAnatomicalStructureModel):
    """Model thalamus subventricular zone"""

    name: Literal["thalamus subventricular zone"] = "thalamus subventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36603"] = "EMAPA_36603"


class _Zona_Limitans_Intrathalamica(_MouseAnatomicalStructureModel):
    """Model zona limitans intrathalamica"""

    name: Literal["zona limitans intrathalamica"] = "zona limitans intrathalamica"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36604"] = "EMAPA_36604"


class _Nerve_Fiber_Tract(_MouseAnatomicalStructureModel):
    """Model nerve fiber tract"""

    name: Literal["nerve fiber tract"] = "nerve fiber tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36605"] = "EMAPA_36605"


class _Fasciculus_Retroflexus(_MouseAnatomicalStructureModel):
    """Model fasciculus retroflexus"""

    name: Literal["fasciculus retroflexus"] = "fasciculus retroflexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36606"] = "EMAPA_36606"


class _Stria_Medullaris(_MouseAnatomicalStructureModel):
    """Model stria medullaris"""

    name: Literal["stria medullaris"] = "stria medullaris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36607"] = "EMAPA_36607"


class _Choroid_Plexus_Epithelium(_MouseAnatomicalStructureModel):
    """Model choroid plexus epithelium"""

    name: Literal["choroid plexus epithelium"] = "choroid plexus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36608"] = "EMAPA_36608"


class _Choroid_Plexus_Stroma(_MouseAnatomicalStructureModel):
    """Model choroid plexus stroma"""

    name: Literal["choroid plexus stroma"] = "choroid plexus stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36609"] = "EMAPA_36609"


class _Head_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model head blood vessel"""

    name: Literal["head blood vessel"] = "head blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36610"] = "EMAPA_36610"


class _Cornea_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model cornea blood vessel"""

    name: Literal["cornea blood vessel"] = "cornea blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36611"] = "EMAPA_36611"


class _Spiral_Artery(_MouseAnatomicalStructureModel):
    """Model spiral artery"""

    name: Literal["spiral artery"] = "spiral artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36612"] = "EMAPA_36612"


class _Venous_System_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model venous system smooth muscle"""

    name: Literal["venous system smooth muscle"] = "venous system smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36613"] = "EMAPA_36613"


class _Vertebral_Neural_Arch(_MouseAnatomicalStructureModel):
    """Model vertebral neural arch"""

    name: Literal["vertebral neural arch"] = "vertebral neural arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36614"] = "EMAPA_36614"


class _Intramembranous_Bone(_MouseAnatomicalStructureModel):
    """Model intramembranous bone"""

    name: Literal["intramembranous bone"] = "intramembranous bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36615"] = "EMAPA_36615"


class _Presphenoid_Bone(_MouseAnatomicalStructureModel):
    """Model presphenoid bone"""

    name: Literal["presphenoid bone"] = "presphenoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36616"] = "EMAPA_36616"


class _Pterygoid_Bone(_MouseAnatomicalStructureModel):
    """Model pterygoid bone"""

    name: Literal["pterygoid bone"] = "pterygoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36617"] = "EMAPA_36617"


class _Supraoccipital_Bone(_MouseAnatomicalStructureModel):
    """Model supraoccipital bone"""

    name: Literal["supraoccipital bone"] = "supraoccipital bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36618"] = "EMAPA_36618"


class _Palatine_Bone(_MouseAnatomicalStructureModel):
    """Model palatine bone"""

    name: Literal["palatine bone"] = "palatine bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36619"] = "EMAPA_36619"


class _Sesamoid_Bone(_MouseAnatomicalStructureModel):
    """Model sesamoid bone"""

    name: Literal["sesamoid bone"] = "sesamoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36620"] = "EMAPA_36620"


class _Ulnar_Sesamoid_Bone(_MouseAnatomicalStructureModel):
    """Model ulnar sesamoid bone"""

    name: Literal["ulnar sesamoid bone"] = "ulnar sesamoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36621"] = "EMAPA_36621"


class _Nucleus_Prepositus(_MouseAnatomicalStructureModel):
    """Model nucleus prepositus"""

    name: Literal["nucleus prepositus"] = "nucleus prepositus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36622"] = "EMAPA_36622"


class _Lower_Back(_MouseAnatomicalStructureModel):
    """Model lower back"""

    name: Literal["lower back"] = "lower back"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36623"] = "EMAPA_36623"


class _Lower_Back_Nerve(_MouseAnatomicalStructureModel):
    """Model lower back nerve"""

    name: Literal["lower back nerve"] = "lower back nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36624"] = "EMAPA_36624"


class _Saphenous_Nerve(_MouseAnatomicalStructureModel):
    """Model saphenous nerve"""

    name: Literal["saphenous nerve"] = "saphenous nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36625"] = "EMAPA_36625"


class _Geniohyoid(_MouseAnatomicalStructureModel):
    """Model geniohyoid"""

    name: Literal["geniohyoid"] = "geniohyoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36626"] = "EMAPA_36626"


class _Levator_Auris_Longus(_MouseAnatomicalStructureModel):
    """Model levator auris longus"""

    name: Literal["levator auris longus"] = "levator auris longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36627"] = "EMAPA_36627"


class _Perineum(_MouseAnatomicalStructureModel):
    """Model perineum"""

    name: Literal["perineum"] = "perineum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36628"] = "EMAPA_36628"


class _Perineal_Muscle(_MouseAnatomicalStructureModel):
    """Model perineal muscle"""

    name: Literal["perineal muscle"] = "perineal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36629"] = "EMAPA_36629"


class _Smooth_Muscle_Of_Urethra(_MouseAnatomicalStructureModel):
    """Model smooth muscle of urethra"""

    name: Literal["smooth muscle of urethra"] = "smooth muscle of urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36630"] = "EMAPA_36630"


class _Pudendum_Of_Female(_MouseAnatomicalStructureModel):
    """Model pudendum of female"""

    name: Literal["pudendum of female"] = "pudendum of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36631"] = "EMAPA_36631"


class _Corpus_Cavernosum_Of_Penis(_MouseAnatomicalStructureModel):
    """Model corpus cavernosum of penis"""

    name: Literal["corpus cavernosum of penis"] = "corpus cavernosum of penis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36632"] = "EMAPA_36632"


class _Thoracic_Mammary_Gland(_MouseAnatomicalStructureModel):
    """Model thoracic mammary gland"""

    name: Literal["thoracic mammary gland"] = "thoracic mammary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36633"] = "EMAPA_36633"


class _Mammary_Gland_Lobule(_MouseAnatomicalStructureModel):
    """Model mammary gland lobule"""

    name: Literal["mammary gland lobule"] = "mammary gland lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36634"] = "EMAPA_36634"


class _Left_Lung_Respiratory_Bronchiole(_MouseAnatomicalStructureModel):
    """Model left lung respiratory bronchiole"""

    name: Literal["left lung respiratory bronchiole"] = "left lung respiratory bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36635"] = "EMAPA_36635"


class _Left_Lung_Terminal_Bronchiole(_MouseAnatomicalStructureModel):
    """Model left lung terminal bronchiole"""

    name: Literal["left lung terminal bronchiole"] = "left lung terminal bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36636"] = "EMAPA_36636"


class _Right_Lung_Respiratory_Bronchiole(_MouseAnatomicalStructureModel):
    """Model right lung respiratory bronchiole"""

    name: Literal["right lung respiratory bronchiole"] = "right lung respiratory bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36637"] = "EMAPA_36637"


class _Right_Lung_Terminal_Bronchiole(_MouseAnatomicalStructureModel):
    """Model right lung terminal bronchiole"""

    name: Literal["right lung terminal bronchiole"] = "right lung terminal bronchiole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36638"] = "EMAPA_36638"


class _Awl_Hair(_MouseAnatomicalStructureModel):
    """Model awl hair"""

    name: Literal["awl hair"] = "awl hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36639"] = "EMAPA_36639"


class _Zigzag_Hair(_MouseAnatomicalStructureModel):
    """Model zigzag hair"""

    name: Literal["zigzag hair"] = "zigzag hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36640"] = "EMAPA_36640"


class _Renal_Lymphatic(_MouseAnatomicalStructureModel):
    """Model renal lymphatic"""

    name: Literal["renal lymphatic"] = "renal lymphatic"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36641"] = "EMAPA_36641"


class _Pontine_Reticular_Nucleus(_MouseAnatomicalStructureModel):
    """Model pontine reticular nucleus"""

    name: Literal["pontine reticular nucleus"] = "pontine reticular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36642"] = "EMAPA_36642"


class _Lateral_Vestibular_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral vestibular nucleus"""

    name: Literal["lateral vestibular nucleus"] = "lateral vestibular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36643"] = "EMAPA_36643"


class _Cardiac_Ganglion(_MouseAnatomicalStructureModel):
    """Model cardiac ganglion"""

    name: Literal["cardiac ganglion"] = "cardiac ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36644"] = "EMAPA_36644"


class _Cardiac_Fibrous_Skeleton(_MouseAnatomicalStructureModel):
    """Model cardiac fibrous skeleton"""

    name: Literal["cardiac fibrous skeleton"] = "cardiac fibrous skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36645"] = "EMAPA_36645"


class _Cardiac_Interstitium(_MouseAnatomicalStructureModel):
    """Model cardiac interstitium"""

    name: Literal["cardiac interstitium"] = "cardiac interstitium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36646"] = "EMAPA_36646"


class _Prosomere_1(_MouseAnatomicalStructureModel):
    """Model prosomere 1"""

    name: Literal["prosomere 1"] = "prosomere 1"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36647"] = "EMAPA_36647"


class _Prosomere_2(_MouseAnatomicalStructureModel):
    """Model prosomere 2"""

    name: Literal["prosomere 2"] = "prosomere 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36648"] = "EMAPA_36648"


class _Prosomere_3(_MouseAnatomicalStructureModel):
    """Model prosomere 3"""

    name: Literal["prosomere 3"] = "prosomere 3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36649"] = "EMAPA_36649"


class _Spleen_Marginal_Zone(_MouseAnatomicalStructureModel):
    """Model spleen marginal zone"""

    name: Literal["spleen marginal zone"] = "spleen marginal zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36650"] = "EMAPA_36650"


class _Eyelid_Muscle(_MouseAnatomicalStructureModel):
    """Model eyelid muscle"""

    name: Literal["eyelid muscle"] = "eyelid muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36651"] = "EMAPA_36651"


class _Levator_Palpebrae_Superioris(_MouseAnatomicalStructureModel):
    """Model levator palpebrae superioris"""

    name: Literal["levator palpebrae superioris"] = "levator palpebrae superioris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36652"] = "EMAPA_36652"


class _Primordial_Germ_Cell_Of_Extraembryonic_Mesoderm(_MouseAnatomicalStructureModel):
    """Model primordial germ cell of extraembryonic mesoderm"""

    name: Literal["primordial germ cell of extraembryonic mesoderm"] = "primordial germ cell of extraembryonic mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36653"] = "EMAPA_36653"


class _Ventral_Lateral_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model ventral lateral thalamic nucleus"""

    name: Literal["ventral lateral thalamic nucleus"] = "ventral lateral thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36654"] = "EMAPA_36654"


class _Preoptic_Area(_MouseAnatomicalStructureModel):
    """Model preoptic area"""

    name: Literal["preoptic area"] = "preoptic area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36655"] = "EMAPA_36655"


class _Lateral_Preoptic_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral preoptic nucleus"""

    name: Literal["lateral preoptic nucleus"] = "lateral preoptic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36656"] = "EMAPA_36656"


class _Face_Skin(_MouseAnatomicalStructureModel):
    """Model face skin"""

    name: Literal["face skin"] = "face skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36657"] = "EMAPA_36657"


class _Head_Skin(_MouseAnatomicalStructureModel):
    """Model head skin"""

    name: Literal["head skin"] = "head skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36658"] = "EMAPA_36658"


class _Basal_Magnocellular_Complex(_MouseAnatomicalStructureModel):
    """Model basal magnocellular complex"""

    name: Literal["basal magnocellular complex"] = "basal magnocellular complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36659"] = "EMAPA_36659"


class _Anterior_Entopeduncular_Area(_MouseAnatomicalStructureModel):
    """Model anterior entopeduncular area"""

    name: Literal["anterior entopeduncular area"] = "anterior entopeduncular area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36660"] = "EMAPA_36660"


class _Vomeronasal_Branch_Of_Olfactory_I_Nerve(_MouseAnatomicalStructureModel):
    """Model vomeronasal branch of olfactory I nerve"""

    name: Literal["vomeronasal branch of olfactory I nerve"] = "vomeronasal branch of olfactory I nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36661"] = "EMAPA_36661"


class _Vomeronasal_Organ_Sensory_Epithelium(_MouseAnatomicalStructureModel):
    """Model vomeronasal organ sensory epithelium"""

    name: Literal["vomeronasal organ sensory epithelium"] = "vomeronasal organ sensory epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36662"] = "EMAPA_36662"


class _Vomeronasal_Organ_Non_Sensory_Epithelium(_MouseAnatomicalStructureModel):
    """Model vomeronasal organ non-sensory epithelium"""

    name: Literal["vomeronasal organ non-sensory epithelium"] = "vomeronasal organ non-sensory epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36663"] = "EMAPA_36663"


class _Vomeronasal_Organ_Vascular_Pump_Anlage(_MouseAnatomicalStructureModel):
    """Model vomeronasal organ vascular pump anlage"""

    name: Literal["vomeronasal organ vascular pump anlage"] = "vomeronasal organ vascular pump anlage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36664"] = "EMAPA_36664"


class _Vomeronasal_Organ_Vascular_Pump(_MouseAnatomicalStructureModel):
    """Model vomeronasal organ vascular pump"""

    name: Literal["vomeronasal organ vascular pump"] = "vomeronasal organ vascular pump"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36665"] = "EMAPA_36665"


class _Vomeronasal_Organ_Glandular_Tissue(_MouseAnatomicalStructureModel):
    """Model vomeronasal organ glandular tissue"""

    name: Literal["vomeronasal organ glandular tissue"] = "vomeronasal organ glandular tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36666"] = "EMAPA_36666"


class _Rib_Cage(_MouseAnatomicalStructureModel):
    """Model rib cage"""

    name: Literal["rib cage"] = "rib cage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36667"] = "EMAPA_36667"


class _Gonadal_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model gonadal fat pad"""

    name: Literal["gonadal fat pad"] = "gonadal fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36668"] = "EMAPA_36668"


class _Mesenteric_Adipose_Tissue(_MouseAnatomicalStructureModel):
    """Model mesenteric adipose tissue"""

    name: Literal["mesenteric adipose tissue"] = "mesenteric adipose tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36669"] = "EMAPA_36669"


class _Lower_Urinary_Tract(_MouseAnatomicalStructureModel):
    """Model lower urinary tract"""

    name: Literal["lower urinary tract"] = "lower urinary tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36670"] = "EMAPA_36670"


class _Follicle_Cell_Of_Antral_Follicle(_MouseAnatomicalStructureModel):
    """Model follicle cell of antral follicle"""

    name: Literal["follicle cell of antral follicle"] = "follicle cell of antral follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36671"] = "EMAPA_36671"


class _Rhombic_Lip(_MouseAnatomicalStructureModel):
    """Model rhombic lip"""

    name: Literal["rhombic lip"] = "rhombic lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36672"] = "EMAPA_36672"


class _Upper_Rhombic_Lip(_MouseAnatomicalStructureModel):
    """Model upper rhombic lip"""

    name: Literal["upper rhombic lip"] = "upper rhombic lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36673"] = "EMAPA_36673"


class _Lower_Rhombic_Lip(_MouseAnatomicalStructureModel):
    """Model lower rhombic lip"""

    name: Literal["lower rhombic lip"] = "lower rhombic lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36674"] = "EMAPA_36674"


class _Prosomere(_MouseAnatomicalStructureModel):
    """Model prosomere"""

    name: Literal["prosomere"] = "prosomere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36675"] = "EMAPA_36675"


class _Cervical_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model cervical dorsal root ganglion"""

    name: Literal["cervical dorsal root ganglion"] = "cervical dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36676"] = "EMAPA_36676"


class _Thoracic_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model thoracic dorsal root ganglion"""

    name: Literal["thoracic dorsal root ganglion"] = "thoracic dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36677"] = "EMAPA_36677"


class _Lumbar_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model lumbar dorsal root ganglion"""

    name: Literal["lumbar dorsal root ganglion"] = "lumbar dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36678"] = "EMAPA_36678"


class _Sacral_Dorsal_Root_Ganglion(_MouseAnatomicalStructureModel):
    """Model sacral dorsal root ganglion"""

    name: Literal["sacral dorsal root ganglion"] = "sacral dorsal root ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36679"] = "EMAPA_36679"


class _Proamniotic_Canal(_MouseAnatomicalStructureModel):
    """Model proamniotic canal"""

    name: Literal["proamniotic canal"] = "proamniotic canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36680"] = "EMAPA_36680"


class _Acromio_Clavicular_Joint(_MouseAnatomicalStructureModel):
    """Model acromio-clavicular joint"""

    name: Literal["acromio-clavicular joint"] = "acromio-clavicular joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36681"] = "EMAPA_36681"


class _Sterno_Costal_Joint(_MouseAnatomicalStructureModel):
    """Model sterno-costal joint"""

    name: Literal["sterno-costal joint"] = "sterno-costal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36682"] = "EMAPA_36682"


class _Mesencephalic_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model mesencephalic venous plexus"""

    name: Literal["mesencephalic venous plexus"] = "mesencephalic venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36683"] = "EMAPA_36683"


class _Pterygoid_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model pterygoid venous plexus"""

    name: Literal["pterygoid venous plexus"] = "pterygoid venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36684"] = "EMAPA_36684"


class _Brachial_Artery(_MouseAnatomicalStructureModel):
    """Model brachial artery"""

    name: Literal["brachial artery"] = "brachial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36685"] = "EMAPA_36685"


class _Inferior_Alveolar_Artery(_MouseAnatomicalStructureModel):
    """Model inferior alveolar artery"""

    name: Literal["inferior alveolar artery"] = "inferior alveolar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36686"] = "EMAPA_36686"


class _Lateral_Caudal_Artery(_MouseAnatomicalStructureModel):
    """Model lateral caudal artery"""

    name: Literal["lateral caudal artery"] = "lateral caudal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36687"] = "EMAPA_36687"


class _Superior_Vesical_Artery(_MouseAnatomicalStructureModel):
    """Model superior vesical artery"""

    name: Literal["superior vesical artery"] = "superior vesical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36688"] = "EMAPA_36688"


class _Adrenal_Vein(_MouseAnatomicalStructureModel):
    """Model adrenal vein"""

    name: Literal["adrenal vein"] = "adrenal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36689"] = "EMAPA_36689"


class _Occipital_Vein(_MouseAnatomicalStructureModel):
    """Model occipital vein"""

    name: Literal["occipital vein"] = "occipital vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36690"] = "EMAPA_36690"


class _Superior_Anastomotic_Vein(_MouseAnatomicalStructureModel):
    """Model superior anastomotic vein"""

    name: Literal["superior anastomotic vein"] = "superior anastomotic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36691"] = "EMAPA_36691"


class _Multifidus(_MouseAnatomicalStructureModel):
    """Model multifidus"""

    name: Literal["multifidus"] = "multifidus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36692"] = "EMAPA_36692"


class _Pharyngeal_Raphe(_MouseAnatomicalStructureModel):
    """Model pharyngeal raphe"""

    name: Literal["pharyngeal raphe"] = "pharyngeal raphe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36693"] = "EMAPA_36693"


class _Quadriceps_Tendon(_MouseAnatomicalStructureModel):
    """Model quadriceps tendon"""

    name: Literal["quadriceps tendon"] = "quadriceps tendon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36694"] = "EMAPA_36694"


class _Intestine_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model intestine lamina propria"""

    name: Literal["intestine lamina propria"] = "intestine lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36695"] = "EMAPA_36695"


class _Large_Intestine_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model large intestine lamina propria"""

    name: Literal["large intestine lamina propria"] = "large intestine lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36696"] = "EMAPA_36696"


class _Olfactory_Migratory_Mass(_MouseAnatomicalStructureModel):
    """Model olfactory migratory mass"""

    name: Literal["olfactory migratory mass"] = "olfactory migratory mass"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36697"] = "EMAPA_36697"


class _Nerve_To_Soleus(_MouseAnatomicalStructureModel):
    """Model nerve to soleus"""

    name: Literal["nerve to soleus"] = "nerve to soleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36698"] = "EMAPA_36698"


class _Primordial_Germ_Cell(_MouseAnatomicalStructureModel):
    """Model primordial germ cell"""

    name: Literal["primordial germ cell"] = "primordial germ cell"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36699"] = "EMAPA_36699"


class _Synovial_Joint(_MouseAnatomicalStructureModel):
    """Model synovial joint"""

    name: Literal["synovial joint"] = "synovial joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36700"] = "EMAPA_36700"


class _Primordial_Germ_Cell_Of_Base_Of_Allantois(_MouseAnatomicalStructureModel):
    """Model primordial germ cell of base of allantois"""

    name: Literal["primordial germ cell of base of allantois"] = "primordial germ cell of base of allantois"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36701"] = "EMAPA_36701"


class _Primitive_Hindgut(_MouseAnatomicalStructureModel):
    """Model primitive hindgut"""

    name: Literal["primitive hindgut"] = "primitive hindgut"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36702"] = "EMAPA_36702"


class _Primordial_Germ_Cell_Of_Dorsal_Mesentery(_MouseAnatomicalStructureModel):
    """Model primordial germ cell of dorsal mesentery"""

    name: Literal["primordial germ cell of dorsal mesentery"] = "primordial germ cell of dorsal mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36703"] = "EMAPA_36703"


class _Mystacial_Pad(_MouseAnatomicalStructureModel):
    """Model mystacial pad"""

    name: Literal["mystacial pad"] = "mystacial pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36704"] = "EMAPA_36704"


class _Head_Surface_Ectoderm(_MouseAnatomicalStructureModel):
    """Model head surface ectoderm"""

    name: Literal["head surface ectoderm"] = "head surface ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36705"] = "EMAPA_36705"


class _Trunk_Surface_Ectoderm(_MouseAnatomicalStructureModel):
    """Model trunk surface ectoderm"""

    name: Literal["trunk surface ectoderm"] = "trunk surface ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36706"] = "EMAPA_36706"


class _Heart_Valve_Primordium(_MouseAnatomicalStructureModel):
    """Model heart valve primordium"""

    name: Literal["heart valve primordium"] = "heart valve primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36707"] = "EMAPA_36707"


class _Atrioventricular_Valve_Primordium(_MouseAnatomicalStructureModel):
    """Model atrioventricular valve primordium"""

    name: Literal["atrioventricular valve primordium"] = "atrioventricular valve primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36708"] = "EMAPA_36708"


class _Semilunar_Valve_Primordium(_MouseAnatomicalStructureModel):
    """Model semilunar valve primordium"""

    name: Literal["semilunar valve primordium"] = "semilunar valve primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36709"] = "EMAPA_36709"


class _Outflow_Tract_Endocardial_Cushion(_MouseAnatomicalStructureModel):
    """Model outflow tract endocardial cushion"""

    name: Literal["outflow tract endocardial cushion"] = "outflow tract endocardial cushion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36710"] = "EMAPA_36710"


class _Primitive_Meninges(_MouseAnatomicalStructureModel):
    """Model primitive meninges"""

    name: Literal["primitive meninges"] = "primitive meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36711"] = "EMAPA_36711"


class _Leptomeninges(_MouseAnatomicalStructureModel):
    """Model leptomeninges"""

    name: Literal["leptomeninges"] = "leptomeninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36712"] = "EMAPA_36712"


class _Metencephalon_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon marginal layer"""

    name: Literal["metencephalon marginal layer"] = "metencephalon marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36713"] = "EMAPA_36713"


class _Myelencephalon_Marginal_Layer(_MouseAnatomicalStructureModel):
    """Model myelencephalon marginal layer"""

    name: Literal["myelencephalon marginal layer"] = "myelencephalon marginal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36714"] = "EMAPA_36714"


class _Metencephalon_Mantle_Layer(_MouseAnatomicalStructureModel):
    """Model metencephalon mantle layer"""

    name: Literal["metencephalon mantle layer"] = "metencephalon mantle layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36715"] = "EMAPA_36715"


class _Telencephalon_Subventricular_Zone(_MouseAnatomicalStructureModel):
    """Model telencephalon subventricular zone"""

    name: Literal["telencephalon subventricular zone"] = "telencephalon subventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36716"] = "EMAPA_36716"


class _Diencephalon_Subventricular_Zone(_MouseAnatomicalStructureModel):
    """Model diencephalon subventricular zone"""

    name: Literal["diencephalon subventricular zone"] = "diencephalon subventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36717"] = "EMAPA_36717"


class _Spinal_Nerve_Dorsal_Root(_MouseAnatomicalStructureModel):
    """Model spinal nerve dorsal root"""

    name: Literal["spinal nerve dorsal root"] = "spinal nerve dorsal root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36718"] = "EMAPA_36718"


class _Spinal_Cord_Mixed_Spinal_Nerve(_MouseAnatomicalStructureModel):
    """Model spinal cord mixed spinal nerve"""

    name: Literal["spinal cord mixed spinal nerve"] = "spinal cord mixed spinal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36719"] = "EMAPA_36719"


class _Spinal_Nerve_Ventral_Root(_MouseAnatomicalStructureModel):
    """Model spinal nerve ventral root"""

    name: Literal["spinal nerve ventral root"] = "spinal nerve ventral root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36720"] = "EMAPA_36720"


class _Trabecular_Myocardium(_MouseAnatomicalStructureModel):
    """Model trabecular myocardium"""

    name: Literal["trabecular myocardium"] = "trabecular myocardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36721"] = "EMAPA_36721"


class _Compact_Myocardium(_MouseAnatomicalStructureModel):
    """Model compact myocardium"""

    name: Literal["compact myocardium"] = "compact myocardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36722"] = "EMAPA_36722"


class _Heart_Papillary_Muscle(_MouseAnatomicalStructureModel):
    """Model heart papillary muscle"""

    name: Literal["heart papillary muscle"] = "heart papillary muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36723"] = "EMAPA_36723"


class _Atrioventricular_Canal_Endocardial_Lining(_MouseAnatomicalStructureModel):
    """Model atrioventricular canal endocardial lining"""

    name: Literal["atrioventricular canal endocardial lining"] = "atrioventricular canal endocardial lining"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36724"] = "EMAPA_36724"


class _Superior_Atrioventricular_Endocardial_Cushion(_MouseAnatomicalStructureModel):
    """Model superior atrioventricular endocardial cushion"""

    name: Literal["superior atrioventricular endocardial cushion"] = "superior atrioventricular endocardial cushion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36725"] = "EMAPA_36725"


class _Inferior_Atrioventricular_Endocardial_Cushion(_MouseAnatomicalStructureModel):
    """Model inferior atrioventricular endocardial cushion"""

    name: Literal["inferior atrioventricular endocardial cushion"] = "inferior atrioventricular endocardial cushion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36726"] = "EMAPA_36726"


class _Heart_Endothelium(_MouseAnatomicalStructureModel):
    """Model heart endothelium"""

    name: Literal["heart endothelium"] = "heart endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36727"] = "EMAPA_36727"


class _Outflow_Tract_Endothelium(_MouseAnatomicalStructureModel):
    """Model outflow tract endothelium"""

    name: Literal["outflow tract endothelium"] = "outflow tract endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36728"] = "EMAPA_36728"


class _Vasculature(_MouseAnatomicalStructureModel):
    """Model vasculature"""

    name: Literal["vasculature"] = "vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36729"] = "EMAPA_36729"


class _Secondary_Heart_Field(_MouseAnatomicalStructureModel):
    """Model secondary heart field"""

    name: Literal["secondary heart field"] = "secondary heart field"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36730"] = "EMAPA_36730"


class _Somatosensory_Cortex(_MouseAnatomicalStructureModel):
    """Model somatosensory cortex"""

    name: Literal["somatosensory cortex"] = "somatosensory cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36731"] = "EMAPA_36731"


class _Prefrontal_Cortex(_MouseAnatomicalStructureModel):
    """Model prefrontal cortex"""

    name: Literal["prefrontal cortex"] = "prefrontal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36732"] = "EMAPA_36732"


class _Orbitofrontal_Cortex(_MouseAnatomicalStructureModel):
    """Model orbitofrontal cortex"""

    name: Literal["orbitofrontal cortex"] = "orbitofrontal cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36733"] = "EMAPA_36733"


class _Ca1_Stratum_Radiatum(_MouseAnatomicalStructureModel):
    """Model CA1 stratum radiatum"""

    name: Literal["CA1 stratum radiatum"] = "CA1 stratum radiatum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36734"] = "EMAPA_36734"


class _Conjunctiva_Epithelium(_MouseAnatomicalStructureModel):
    """Model conjunctiva epithelium"""

    name: Literal["conjunctiva epithelium"] = "conjunctiva epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36735"] = "EMAPA_36735"


class _Fast_Muscle_Tissue(_MouseAnatomicalStructureModel):
    """Model fast muscle tissue"""

    name: Literal["fast muscle tissue"] = "fast muscle tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36736"] = "EMAPA_36736"


class _Slow_Muscle_Tissue(_MouseAnatomicalStructureModel):
    """Model slow muscle tissue"""

    name: Literal["slow muscle tissue"] = "slow muscle tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36737"] = "EMAPA_36737"


class _Jaw_Primordium_Epithelium(_MouseAnatomicalStructureModel):
    """Model jaw primordium epithelium"""

    name: Literal["jaw primordium epithelium"] = "jaw primordium epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36738"] = "EMAPA_36738"


class _Dental_Placode(_MouseAnatomicalStructureModel):
    """Model dental placode"""

    name: Literal["dental placode"] = "dental placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36739"] = "EMAPA_36739"


class _Tooth_Bud(_MouseAnatomicalStructureModel):
    """Model tooth bud"""

    name: Literal["tooth bud"] = "tooth bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36740"] = "EMAPA_36740"


class _Cap_Stage_Tooth(_MouseAnatomicalStructureModel):
    """Model cap stage tooth"""

    name: Literal["cap stage tooth"] = "cap stage tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36741"] = "EMAPA_36741"


class _Bell_Stage_Tooth(_MouseAnatomicalStructureModel):
    """Model bell stage tooth"""

    name: Literal["bell stage tooth"] = "bell stage tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36742"] = "EMAPA_36742"


class _Early_Bell_Stage_Tooth(_MouseAnatomicalStructureModel):
    """Model early bell stage tooth"""

    name: Literal["early bell stage tooth"] = "early bell stage tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36743"] = "EMAPA_36743"


class _Mid_Bell_Stage_Tooth(_MouseAnatomicalStructureModel):
    """Model mid bell stage tooth"""

    name: Literal["mid bell stage tooth"] = "mid bell stage tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36744"] = "EMAPA_36744"


class _Late_Bell_Stage_Tooth(_MouseAnatomicalStructureModel):
    """Model late bell stage tooth"""

    name: Literal["late bell stage tooth"] = "late bell stage tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36745"] = "EMAPA_36745"


class _Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model lamina propria"""

    name: Literal["lamina propria"] = "lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36746"] = "EMAPA_36746"


class _Iridocorneal_Angle(_MouseAnatomicalStructureModel):
    """Model iridocorneal angle"""

    name: Literal["iridocorneal angle"] = "iridocorneal angle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36747"] = "EMAPA_36747"


class _Eye_Trabecular_Meshwork(_MouseAnatomicalStructureModel):
    """Model eye trabecular meshwork"""

    name: Literal["eye trabecular meshwork"] = "eye trabecular meshwork"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36748"] = "EMAPA_36748"


class _Pre_Placodal_Region(_MouseAnatomicalStructureModel):
    """Model pre-placodal region"""

    name: Literal["pre-placodal region"] = "pre-placodal region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36749"] = "EMAPA_36749"


class _Ectodermal_Placode(_MouseAnatomicalStructureModel):
    """Model ectodermal placode"""

    name: Literal["ectodermal placode"] = "ectodermal placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36750"] = "EMAPA_36750"


class _Cranial_Placode(_MouseAnatomicalStructureModel):
    """Model cranial placode"""

    name: Literal["cranial placode"] = "cranial placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36751"] = "EMAPA_36751"


class _Optic_Placode(_MouseAnatomicalStructureModel):
    """Model optic placode"""

    name: Literal["optic placode"] = "optic placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36752"] = "EMAPA_36752"


class _Adenohypophyseal_Placode(_MouseAnatomicalStructureModel):
    """Model adenohypophyseal placode"""

    name: Literal["adenohypophyseal placode"] = "adenohypophyseal placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36753"] = "EMAPA_36753"


class _Neurogenic_Placode(_MouseAnatomicalStructureModel):
    """Model neurogenic placode"""

    name: Literal["neurogenic placode"] = "neurogenic placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36754"] = "EMAPA_36754"


class _Trigeminal_Placode(_MouseAnatomicalStructureModel):
    """Model trigeminal placode"""

    name: Literal["trigeminal placode"] = "trigeminal placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36755"] = "EMAPA_36755"


class _Epibranchial_Placode(_MouseAnatomicalStructureModel):
    """Model epibranchial placode"""

    name: Literal["epibranchial placode"] = "epibranchial placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36756"] = "EMAPA_36756"


class _Geniculate_Placode(_MouseAnatomicalStructureModel):
    """Model geniculate placode"""

    name: Literal["geniculate placode"] = "geniculate placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36757"] = "EMAPA_36757"


class _Petrosal_Placode(_MouseAnatomicalStructureModel):
    """Model petrosal placode"""

    name: Literal["petrosal placode"] = "petrosal placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36758"] = "EMAPA_36758"


class _Nodose_Placode(_MouseAnatomicalStructureModel):
    """Model nodose placode"""

    name: Literal["nodose placode"] = "nodose placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36759"] = "EMAPA_36759"


class _Non_Neurogenic_Placode(_MouseAnatomicalStructureModel):
    """Model non-neurogenic placode"""

    name: Literal["non-neurogenic placode"] = "non-neurogenic placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36760"] = "EMAPA_36760"


class _Tongue_Papillary_Placode(_MouseAnatomicalStructureModel):
    """Model tongue papillary placode"""

    name: Literal["tongue papillary placode"] = "tongue papillary placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36761"] = "EMAPA_36761"


class _Integumental_System_Placode(_MouseAnatomicalStructureModel):
    """Model integumental system placode"""

    name: Literal["integumental system placode"] = "integumental system placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36762"] = "EMAPA_36762"


class _Vibrissa_Placode(_MouseAnatomicalStructureModel):
    """Model vibrissa placode"""

    name: Literal["vibrissa placode"] = "vibrissa placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36763"] = "EMAPA_36763"


class _Otic_Pre_Placode(_MouseAnatomicalStructureModel):
    """Model otic pre-placode"""

    name: Literal["otic pre-placode"] = "otic pre-placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36764"] = "EMAPA_36764"


class _Anterior_Pituitary_Pre_Placode(_MouseAnatomicalStructureModel):
    """Model anterior pituitary pre-placode"""

    name: Literal["anterior pituitary pre-placode"] = "anterior pituitary pre-placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36765"] = "EMAPA_36765"


class _Lens_Pre_Placode(_MouseAnatomicalStructureModel):
    """Model lens pre-placode"""

    name: Literal["lens pre-placode"] = "lens pre-placode"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36766"] = "EMAPA_36766"


class _Extrahepatic_Bile_Duct(_MouseAnatomicalStructureModel):
    """Model extrahepatic bile duct"""

    name: Literal["extrahepatic bile duct"] = "extrahepatic bile duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36767"] = "EMAPA_36767"


class _Intrahepatic_Bile_Duct(_MouseAnatomicalStructureModel):
    """Model intrahepatic bile duct"""

    name: Literal["intrahepatic bile duct"] = "intrahepatic bile duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36768"] = "EMAPA_36768"


class _Ventral_Cochlear_Nucleus(_MouseAnatomicalStructureModel):
    """Model ventral cochlear nucleus"""

    name: Literal["ventral cochlear nucleus"] = "ventral cochlear nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36769"] = "EMAPA_36769"


class _Stomach_Muscularis_Externa(_MouseAnatomicalStructureModel):
    """Model stomach muscularis externa"""

    name: Literal["stomach muscularis externa"] = "stomach muscularis externa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36770"] = "EMAPA_36770"


class _Amniotic_Fluid(_MouseAnatomicalStructureModel):
    """Model amniotic fluid"""

    name: Literal["amniotic fluid"] = "amniotic fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36771"] = "EMAPA_36771"


class _Retrosplenial_Cortex(_MouseAnatomicalStructureModel):
    """Model retrosplenial cortex"""

    name: Literal["retrosplenial cortex"] = "retrosplenial cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36772"] = "EMAPA_36772"


class _Atrioventricular_Canal_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model atrioventricular canal cardiac muscle"""

    name: Literal["atrioventricular canal cardiac muscle"] = "atrioventricular canal cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36773"] = "EMAPA_36773"


class _Hypothalamus_Periventricular_Region(_MouseAnatomicalStructureModel):
    """Model hypothalamus periventricular region"""

    name: Literal["hypothalamus periventricular region"] = "hypothalamus periventricular region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36774"] = "EMAPA_36774"


class _Hypothalamus_Subparaventricular_Zone(_MouseAnatomicalStructureModel):
    """Model hypothalamus subparaventricular zone"""

    name: Literal["hypothalamus subparaventricular zone"] = "hypothalamus subparaventricular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36775"] = "EMAPA_36775"


class _Brain_Roof_Plate(_MouseAnatomicalStructureModel):
    """Model brain roof plate"""

    name: Literal["brain roof plate"] = "brain roof plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36776"] = "EMAPA_36776"


class _Cerebellum_Gray_Matter(_MouseAnatomicalStructureModel):
    """Model cerebellum gray matter"""

    name: Literal["cerebellum gray matter"] = "cerebellum gray matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36777"] = "EMAPA_36777"


class _Mammillary_Area(_MouseAnatomicalStructureModel):
    """Model mammillary area"""

    name: Literal["mammillary area"] = "mammillary area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36778"] = "EMAPA_36778"


class _Cuneate_Fasciculus(_MouseAnatomicalStructureModel):
    """Model cuneate fasciculus"""

    name: Literal["cuneate fasciculus"] = "cuneate fasciculus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36779"] = "EMAPA_36779"


class _Gracile_Fasciculus(_MouseAnatomicalStructureModel):
    """Model gracile fasciculus"""

    name: Literal["gracile fasciculus"] = "gracile fasciculus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36780"] = "EMAPA_36780"


class _Spinal_Cord_Lamina(_MouseAnatomicalStructureModel):
    """Model spinal cord lamina"""

    name: Literal["spinal cord lamina"] = "spinal cord lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36781"] = "EMAPA_36781"


class _Abdomen_Organ(_MouseAnatomicalStructureModel):
    """Model abdomen organ"""

    name: Literal["abdomen organ"] = "abdomen organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36782"] = "EMAPA_36782"


class _Adrenal_Gland_Capsule(_MouseAnatomicalStructureModel):
    """Model adrenal gland capsule"""

    name: Literal["adrenal gland capsule"] = "adrenal gland capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36783"] = "EMAPA_36783"


class _Adrenal_Gland_X_Zone(_MouseAnatomicalStructureModel):
    """Model adrenal gland X zone"""

    name: Literal["adrenal gland X zone"] = "adrenal gland X zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36784"] = "EMAPA_36784"


class _Afferent_Lymphatic_Vessel(_MouseAnatomicalStructureModel):
    """Model afferent lymphatic vessel"""

    name: Literal["afferent lymphatic vessel"] = "afferent lymphatic vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36785"] = "EMAPA_36785"


class _Efferent_Lymphatic_Vessel(_MouseAnatomicalStructureModel):
    """Model efferent lymphatic vessel"""

    name: Literal["efferent lymphatic vessel"] = "efferent lymphatic vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36786"] = "EMAPA_36786"


class _Anterior_Buccal_Gland(_MouseAnatomicalStructureModel):
    """Model anterior buccal gland"""

    name: Literal["anterior buccal gland"] = "anterior buccal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36787"] = "EMAPA_36787"


class _Anterior_Lingual_Gland(_MouseAnatomicalStructureModel):
    """Model anterior lingual gland"""

    name: Literal["anterior lingual gland"] = "anterior lingual gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36788"] = "EMAPA_36788"


class _Major_Salivary_Gland(_MouseAnatomicalStructureModel):
    """Model major salivary gland"""

    name: Literal["major salivary gland"] = "major salivary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36789"] = "EMAPA_36789"


class _Cornea_Anterior_Limiting_Lamina(_MouseAnatomicalStructureModel):
    """Model cornea anterior limiting lamina"""

    name: Literal["cornea anterior limiting lamina"] = "cornea anterior limiting lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36790"] = "EMAPA_36790"


class _Anus(_MouseAnatomicalStructureModel):
    """Model anus"""

    name: Literal["anus"] = "anus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36791"] = "EMAPA_36791"


class _Aorta_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model aorta elastic tissue"""

    name: Literal["aorta elastic tissue"] = "aorta elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36792"] = "EMAPA_36792"


class _Heart_Apex(_MouseAnatomicalStructureModel):
    """Model heart apex"""

    name: Literal["heart apex"] = "heart apex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36793"] = "EMAPA_36793"


class _Areola(_MouseAnatomicalStructureModel):
    """Model areola"""

    name: Literal["areola"] = "areola"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36794"] = "EMAPA_36794"


class _Cervical_Mammary_Gland(_MouseAnatomicalStructureModel):
    """Model cervical mammary gland"""

    name: Literal["cervical mammary gland"] = "cervical mammary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36795"] = "EMAPA_36795"


class _Inguinal_Mammary_Gland(_MouseAnatomicalStructureModel):
    """Model inguinal mammary gland"""

    name: Literal["inguinal mammary gland"] = "inguinal mammary gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36796"] = "EMAPA_36796"


class _Axillary_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model axillary lymph node"""

    name: Literal["axillary lymph node"] = "axillary lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36797"] = "EMAPA_36797"


class _Auricular_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model auricular lymph node"""

    name: Literal["auricular lymph node"] = "auricular lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36798"] = "EMAPA_36798"


class _Brachial_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model brachial lymph node"""

    name: Literal["brachial lymph node"] = "brachial lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36799"] = "EMAPA_36799"


class _Bronchial_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model bronchial lymph node"""

    name: Literal["bronchial lymph node"] = "bronchial lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36800"] = "EMAPA_36800"


class _Celiac_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model celiac lymph node"""

    name: Literal["celiac lymph node"] = "celiac lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36801"] = "EMAPA_36801"


class _Cervical_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model cervical lymph node"""

    name: Literal["cervical lymph node"] = "cervical lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36802"] = "EMAPA_36802"


class _Gastric_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model gastric lymph node"""

    name: Literal["gastric lymph node"] = "gastric lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36803"] = "EMAPA_36803"


class _Hepatic_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model hepatic lymph node"""

    name: Literal["hepatic lymph node"] = "hepatic lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36804"] = "EMAPA_36804"


class _Ileocolic_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model ileocolic lymph node"""

    name: Literal["ileocolic lymph node"] = "ileocolic lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36805"] = "EMAPA_36805"


class _Iliac_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model iliac lymph node"""

    name: Literal["iliac lymph node"] = "iliac lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36806"] = "EMAPA_36806"


class _Lumbar_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model lumbar lymph node"""

    name: Literal["lumbar lymph node"] = "lumbar lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36807"] = "EMAPA_36807"


class _Mandibular_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model mandibular lymph node"""

    name: Literal["mandibular lymph node"] = "mandibular lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36808"] = "EMAPA_36808"


class _Pancreatic_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model pancreatic lymph node"""

    name: Literal["pancreatic lymph node"] = "pancreatic lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36809"] = "EMAPA_36809"


class _Paraaortic_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model paraaortic lymph node"""

    name: Literal["paraaortic lymph node"] = "paraaortic lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36810"] = "EMAPA_36810"


class _Parotid_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model parotid lymph node"""

    name: Literal["parotid lymph node"] = "parotid lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36811"] = "EMAPA_36811"


class _Popliteal_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model popliteal lymph node"""

    name: Literal["popliteal lymph node"] = "popliteal lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36812"] = "EMAPA_36812"


class _Renal_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model renal lymph node"""

    name: Literal["renal lymph node"] = "renal lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36813"] = "EMAPA_36813"


class _Sacral_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model sacral lymph node"""

    name: Literal["sacral lymph node"] = "sacral lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36814"] = "EMAPA_36814"


class _Sciatic_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model sciatic lymph node"""

    name: Literal["sciatic lymph node"] = "sciatic lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36815"] = "EMAPA_36815"


class _Splenic_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model splenic lymph node"""

    name: Literal["splenic lymph node"] = "splenic lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36816"] = "EMAPA_36816"


class _Subcutaneous_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model subcutaneous lymph node"""

    name: Literal["subcutaneous lymph node"] = "subcutaneous lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36817"] = "EMAPA_36817"


class _Submandibular_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model submandibular lymph node"""

    name: Literal["submandibular lymph node"] = "submandibular lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36818"] = "EMAPA_36818"


class _Thymic_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model thymic lymph node"""

    name: Literal["thymic lymph node"] = "thymic lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36819"] = "EMAPA_36819"


class _Tracheobronchial_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model tracheobronchial lymph node"""

    name: Literal["tracheobronchial lymph node"] = "tracheobronchial lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36820"] = "EMAPA_36820"


class _Lymph_Node_Trabeculum(_MouseAnatomicalStructureModel):
    """Model lymph node trabeculum"""

    name: Literal["lymph node trabeculum"] = "lymph node trabeculum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36821"] = "EMAPA_36821"


class _Lymph_Node_B_Cell_Domain(_MouseAnatomicalStructureModel):
    """Model lymph node B cell domain"""

    name: Literal["lymph node B cell domain"] = "lymph node B cell domain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36822"] = "EMAPA_36822"


class _Lymphoid_Tissue(_MouseAnatomicalStructureModel):
    """Model lymphoid tissue"""

    name: Literal["lymphoid tissue"] = "lymphoid tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36823"] = "EMAPA_36823"


class _Bronchus_Associated_Lymphoid_Tissue(_MouseAnatomicalStructureModel):
    """Model bronchus-associated lymphoid tissue"""

    name: Literal["bronchus-associated lymphoid tissue"] = "bronchus-associated lymphoid tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36824"] = "EMAPA_36824"


class _Gut_Associated_Lymphoid_Tissue(_MouseAnatomicalStructureModel):
    """Model gut-associated lymphoid tissue"""

    name: Literal["gut-associated lymphoid tissue"] = "gut-associated lymphoid tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36825"] = "EMAPA_36825"


class _Mucosa_Associated_Lymphoid_Tissue(_MouseAnatomicalStructureModel):
    """Model mucosa-associated lymphoid tissue"""

    name: Literal["mucosa-associated lymphoid tissue"] = "mucosa-associated lymphoid tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36826"] = "EMAPA_36826"


class _Nasal_Associated_Lymphoid_Tissue(_MouseAnatomicalStructureModel):
    """Model nasal-associated lymphoid tissue"""

    name: Literal["nasal-associated lymphoid tissue"] = "nasal-associated lymphoid tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36827"] = "EMAPA_36827"


class _Oropharyngeal_Lymphoid_Tissue(_MouseAnatomicalStructureModel):
    """Model oropharyngeal lymphoid tissue"""

    name: Literal["oropharyngeal lymphoid tissue"] = "oropharyngeal lymphoid tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36828"] = "EMAPA_36828"


class _Basicranium(_MouseAnatomicalStructureModel):
    """Model basicranium"""

    name: Literal["basicranium"] = "basicranium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36829"] = "EMAPA_36829"


class _Alimentary_System_Fluid_Or_Secretion(_MouseAnatomicalStructureModel):
    """Model alimentary system fluid or secretion"""

    name: Literal["alimentary system fluid or secretion"] = "alimentary system fluid or secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36830"] = "EMAPA_36830"


class _Esophagus_Secretion(_MouseAnatomicalStructureModel):
    """Model esophagus secretion"""

    name: Literal["esophagus secretion"] = "esophagus secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36831"] = "EMAPA_36831"


class _Stomach_Secretion(_MouseAnatomicalStructureModel):
    """Model stomach secretion"""

    name: Literal["stomach secretion"] = "stomach secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36832"] = "EMAPA_36832"


class _Intestine_Secretion(_MouseAnatomicalStructureModel):
    """Model intestine secretion"""

    name: Literal["intestine secretion"] = "intestine secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36833"] = "EMAPA_36833"


class _Pancreas_Secretion(_MouseAnatomicalStructureModel):
    """Model pancreas secretion"""

    name: Literal["pancreas secretion"] = "pancreas secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36834"] = "EMAPA_36834"


class _Endocrine_Pancreas_Secretion(_MouseAnatomicalStructureModel):
    """Model endocrine pancreas secretion"""

    name: Literal["endocrine pancreas secretion"] = "endocrine pancreas secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36835"] = "EMAPA_36835"


class _Exocrine_Pancreas_Secretion(_MouseAnatomicalStructureModel):
    """Model exocrine pancreas secretion"""

    name: Literal["exocrine pancreas secretion"] = "exocrine pancreas secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36836"] = "EMAPA_36836"


class _Bile(_MouseAnatomicalStructureModel):
    """Model bile"""

    name: Literal["bile"] = "bile"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36837"] = "EMAPA_36837"


class _Bile_Duct_Epithelium(_MouseAnatomicalStructureModel):
    """Model bile duct epithelium"""

    name: Literal["bile duct epithelium"] = "bile duct epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36838"] = "EMAPA_36838"


class _Extrahepatic_Bile_Duct_Epithelium(_MouseAnatomicalStructureModel):
    """Model extrahepatic bile duct epithelium"""

    name: Literal["extrahepatic bile duct epithelium"] = "extrahepatic bile duct epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36839"] = "EMAPA_36839"


class _Intrahepatic_Bile_Duct_Epithelium(_MouseAnatomicalStructureModel):
    """Model intrahepatic bile duct epithelium"""

    name: Literal["intrahepatic bile duct epithelium"] = "intrahepatic bile duct epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36840"] = "EMAPA_36840"


class _Interlobular_Bile_Duct(_MouseAnatomicalStructureModel):
    """Model interlobular bile duct"""

    name: Literal["interlobular bile duct"] = "interlobular bile duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36841"] = "EMAPA_36841"


class _Intralobular_Bile_Duct(_MouseAnatomicalStructureModel):
    """Model intralobular bile duct"""

    name: Literal["intralobular bile duct"] = "intralobular bile duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36842"] = "EMAPA_36842"


class _Bone_Marrow_Cavity(_MouseAnatomicalStructureModel):
    """Model bone marrow cavity"""

    name: Literal["bone marrow cavity"] = "bone marrow cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36843"] = "EMAPA_36843"


class _Cerebellum_Anterior_Vermis(_MouseAnatomicalStructureModel):
    """Model cerebellum anterior vermis"""

    name: Literal["cerebellum anterior vermis"] = "cerebellum anterior vermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36844"] = "EMAPA_36844"


class _Cerebellum_Posterior_Vermis(_MouseAnatomicalStructureModel):
    """Model cerebellum posterior vermis"""

    name: Literal["cerebellum posterior vermis"] = "cerebellum posterior vermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36845"] = "EMAPA_36845"


class _Cerebellum_Lobule(_MouseAnatomicalStructureModel):
    """Model cerebellum lobule"""

    name: Literal["cerebellum lobule"] = "cerebellum lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36846"] = "EMAPA_36846"


class _Cerebellum_Hemisphere_Lobule(_MouseAnatomicalStructureModel):
    """Model cerebellum hemisphere lobule"""

    name: Literal["cerebellum hemisphere lobule"] = "cerebellum hemisphere lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36847"] = "EMAPA_36847"


class _Flocculonodular_Lobe(_MouseAnatomicalStructureModel):
    """Model flocculonodular lobe"""

    name: Literal["flocculonodular lobe"] = "flocculonodular lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36848"] = "EMAPA_36848"


class _Cerebrospinal_Fluid(_MouseAnatomicalStructureModel):
    """Model cerebrospinal fluid"""

    name: Literal["cerebrospinal fluid"] = "cerebrospinal fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36849"] = "EMAPA_36849"


class _Cerumen(_MouseAnatomicalStructureModel):
    """Model cerumen"""

    name: Literal["cerumen"] = "cerumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36850"] = "EMAPA_36850"


class _Feces(_MouseAnatomicalStructureModel):
    """Model feces"""

    name: Literal["feces"] = "feces"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36851"] = "EMAPA_36851"


class _Female_Reproductive_System_Fluid_Or_Secretion(_MouseAnatomicalStructureModel):
    """Model female reproductive system fluid or secretion"""

    name: Literal["female reproductive system fluid or secretion"] = "female reproductive system fluid or secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36852"] = "EMAPA_36852"


class _Ovary_Follicle_Fluid(_MouseAnatomicalStructureModel):
    """Model ovary follicle fluid"""

    name: Literal["ovary follicle fluid"] = "ovary follicle fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36853"] = "EMAPA_36853"


class _Lymph(_MouseAnatomicalStructureModel):
    """Model lymph"""

    name: Literal["lymph"] = "lymph"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36854"] = "EMAPA_36854"


class _Ocular_Refractive_Media(_MouseAnatomicalStructureModel):
    """Model ocular refractive media"""

    name: Literal["ocular refractive media"] = "ocular refractive media"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36855"] = "EMAPA_36855"


class _Pericardial_Fluid(_MouseAnatomicalStructureModel):
    """Model pericardial fluid"""

    name: Literal["pericardial fluid"] = "pericardial fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36856"] = "EMAPA_36856"


class _Pleural_Fluid(_MouseAnatomicalStructureModel):
    """Model pleural fluid"""

    name: Literal["pleural fluid"] = "pleural fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36857"] = "EMAPA_36857"


class _Skin_Fluid_Or_Secretion(_MouseAnatomicalStructureModel):
    """Model skin fluid or secretion"""

    name: Literal["skin fluid or secretion"] = "skin fluid or secretion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36858"] = "EMAPA_36858"


class _Sebum(_MouseAnatomicalStructureModel):
    """Model sebum"""

    name: Literal["sebum"] = "sebum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36859"] = "EMAPA_36859"


class _Sweat(_MouseAnatomicalStructureModel):
    """Model sweat"""

    name: Literal["sweat"] = "sweat"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36860"] = "EMAPA_36860"


class _Synovial_Fluid(_MouseAnatomicalStructureModel):
    """Model synovial fluid"""

    name: Literal["synovial fluid"] = "synovial fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36861"] = "EMAPA_36861"


class _C1_Vertebra_Ventral_Tubercle(_MouseAnatomicalStructureModel):
    """Model C1 vertebra ventral tubercle"""

    name: Literal["C1 vertebra ventral tubercle"] = "C1 vertebra ventral tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36862"] = "EMAPA_36862"


class _Cervix_Uteri_Squamous_Epithelium(_MouseAnatomicalStructureModel):
    """Model cervix uteri squamous epithelium"""

    name: Literal["cervix uteri squamous epithelium"] = "cervix uteri squamous epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36863"] = "EMAPA_36863"


class _Thoracic_Body_Wall(_MouseAnatomicalStructureModel):
    """Model thoracic body wall"""

    name: Literal["thoracic body wall"] = "thoracic body wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36864"] = "EMAPA_36864"


class _Ciliated_Columnar_Oviduct_Epithelium(_MouseAnatomicalStructureModel):
    """Model ciliated columnar oviduct epithelium"""

    name: Literal["ciliated columnar oviduct epithelium"] = "ciliated columnar oviduct epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36865"] = "EMAPA_36865"


class _Cuboidal_Oviduct_Epithelium(_MouseAnatomicalStructureModel):
    """Model cuboidal oviduct epithelium"""

    name: Literal["cuboidal oviduct epithelium"] = "cuboidal oviduct epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36866"] = "EMAPA_36866"


class _Craniocervical_Region(_MouseAnatomicalStructureModel):
    """Model craniocervical region"""

    name: Literal["craniocervical region"] = "craniocervical region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36867"] = "EMAPA_36867"


class _Crista_Ampullaris_Neuroepithelium(_MouseAnatomicalStructureModel):
    """Model crista ampullaris neuroepithelium"""

    name: Literal["crista ampullaris neuroepithelium"] = "crista ampullaris neuroepithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36868"] = "EMAPA_36868"


class _Dentate_Nucleus(_MouseAnatomicalStructureModel):
    """Model dentate nucleus"""

    name: Literal["dentate nucleus"] = "dentate nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36869"] = "EMAPA_36869"


class _Fastigial_Nucleus(_MouseAnatomicalStructureModel):
    """Model fastigial nucleus"""

    name: Literal["fastigial nucleus"] = "fastigial nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36870"] = "EMAPA_36870"


class _Dermis_Adipose_Tissue(_MouseAnatomicalStructureModel):
    """Model dermis adipose tissue"""

    name: Literal["dermis adipose tissue"] = "dermis adipose tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36871"] = "EMAPA_36871"


class _Holocrine_Gland(_MouseAnatomicalStructureModel):
    """Model holocrine gland"""

    name: Literal["holocrine gland"] = "holocrine gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36872"] = "EMAPA_36872"


class _Merocrine_Gland(_MouseAnatomicalStructureModel):
    """Model merocrine gland"""

    name: Literal["merocrine gland"] = "merocrine gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36873"] = "EMAPA_36873"


class _Eccrine_Sweat_Gland(_MouseAnatomicalStructureModel):
    """Model eccrine sweat gland"""

    name: Literal["eccrine sweat gland"] = "eccrine sweat gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36874"] = "EMAPA_36874"


class _Elastic_Cartilage(_MouseAnatomicalStructureModel):
    """Model elastic cartilage"""

    name: Literal["elastic cartilage"] = "elastic cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36875"] = "EMAPA_36875"


class _Ethmoid_Sinus(_MouseAnatomicalStructureModel):
    """Model ethmoid sinus"""

    name: Literal["ethmoid sinus"] = "ethmoid sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36876"] = "EMAPA_36876"


class _Frontal_Sinus(_MouseAnatomicalStructureModel):
    """Model frontal sinus"""

    name: Literal["frontal sinus"] = "frontal sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36877"] = "EMAPA_36877"


class _Maxillary_Sinus(_MouseAnatomicalStructureModel):
    """Model maxillary sinus"""

    name: Literal["maxillary sinus"] = "maxillary sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36878"] = "EMAPA_36878"


class _Sphenoid_Sinus(_MouseAnatomicalStructureModel):
    """Model sphenoid sinus"""

    name: Literal["sphenoid sinus"] = "sphenoid sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36879"] = "EMAPA_36879"


class _Eyelash(_MouseAnatomicalStructureModel):
    """Model eyelash"""

    name: Literal["eyelash"] = "eyelash"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36880"] = "EMAPA_36880"


class _Fibrocartilage(_MouseAnatomicalStructureModel):
    """Model fibrocartilage"""

    name: Literal["fibrocartilage"] = "fibrocartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36881"] = "EMAPA_36881"


class _Fontanel(_MouseAnatomicalStructureModel):
    """Model fontanel"""

    name: Literal["fontanel"] = "fontanel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36882"] = "EMAPA_36882"


class _Glomerular_Capillary_Endothelium(_MouseAnatomicalStructureModel):
    """Model glomerular capillary endothelium"""

    name: Literal["glomerular capillary endothelium"] = "glomerular capillary endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36883"] = "EMAPA_36883"


class _Glottis(_MouseAnatomicalStructureModel):
    """Model glottis"""

    name: Literal["glottis"] = "glottis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36884"] = "EMAPA_36884"


class _Gustatory_System(_MouseAnatomicalStructureModel):
    """Model gustatory system"""

    name: Literal["gustatory system"] = "gustatory system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36885"] = "EMAPA_36885"


class _Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model elastic tissue"""

    name: Literal["elastic tissue"] = "elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36886"] = "EMAPA_36886"


class _Cardiovascular_System_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model cardiovascular system elastic tissue"""

    name: Literal["cardiovascular system elastic tissue"] = "cardiovascular system elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36887"] = "EMAPA_36887"


class _Heart_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model heart elastic tissue"""

    name: Literal["heart elastic tissue"] = "heart elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36888"] = "EMAPA_36888"


class _Respiratory_System_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model respiratory system elastic tissue"""

    name: Literal["respiratory system elastic tissue"] = "respiratory system elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36889"] = "EMAPA_36889"


class _Bronchus_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model bronchus elastic tissue"""

    name: Literal["bronchus elastic tissue"] = "bronchus elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36890"] = "EMAPA_36890"


class _Lung_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model lung elastic tissue"""

    name: Literal["lung elastic tissue"] = "lung elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36891"] = "EMAPA_36891"


class _Trachea_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model trachea elastic tissue"""

    name: Literal["trachea elastic tissue"] = "trachea elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36892"] = "EMAPA_36892"


class _Heart_Ventricle_Wall(_MouseAnatomicalStructureModel):
    """Model heart ventricle wall"""

    name: Literal["heart ventricle wall"] = "heart ventricle wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36893"] = "EMAPA_36893"


class _Helix(_MouseAnatomicalStructureModel):
    """Model helix"""

    name: Literal["helix"] = "helix"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36894"] = "EMAPA_36894"


class _Hepatic_Portal_Vein(_MouseAnatomicalStructureModel):
    """Model hepatic portal vein"""

    name: Literal["hepatic portal vein"] = "hepatic portal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36895"] = "EMAPA_36895"


class _Immune_System(_MouseAnatomicalStructureModel):
    """Model immune system"""

    name: Literal["immune system"] = "immune system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36896"] = "EMAPA_36896"


class _Inferior_Cerebellar_Peduncle(_MouseAnatomicalStructureModel):
    """Model inferior cerebellar peduncle"""

    name: Literal["inferior cerebellar peduncle"] = "inferior cerebellar peduncle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36897"] = "EMAPA_36897"


class _Middle_Cerebellar_Peduncle(_MouseAnatomicalStructureModel):
    """Model middle cerebellar peduncle"""

    name: Literal["middle cerebellar peduncle"] = "middle cerebellar peduncle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36898"] = "EMAPA_36898"


class _Superior_Cerebellar_Peduncle(_MouseAnatomicalStructureModel):
    """Model superior cerebellar peduncle"""

    name: Literal["superior cerebellar peduncle"] = "superior cerebellar peduncle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36899"] = "EMAPA_36899"


class _Hair_Follicle_Infundibulum(_MouseAnatomicalStructureModel):
    """Model hair follicle infundibulum"""

    name: Literal["hair follicle infundibulum"] = "hair follicle infundibulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36900"] = "EMAPA_36900"


class _Axillary_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model axillary fat pad"""

    name: Literal["axillary fat pad"] = "axillary fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36901"] = "EMAPA_36901"


class _Interscapular_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model interscapular fat pad"""

    name: Literal["interscapular fat pad"] = "interscapular fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36902"] = "EMAPA_36902"


class _Mediastinal_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model mediastinal fat pad"""

    name: Literal["mediastinal fat pad"] = "mediastinal fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36903"] = "EMAPA_36903"


class _Omental_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model omental fat pad"""

    name: Literal["omental fat pad"] = "omental fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36904"] = "EMAPA_36904"


class _Pancreatic_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model pancreatic fat pad"""

    name: Literal["pancreatic fat pad"] = "pancreatic fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36905"] = "EMAPA_36905"


class _Parametrial_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model parametrial fat pad"""

    name: Literal["parametrial fat pad"] = "parametrial fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36906"] = "EMAPA_36906"


class _Periovarian_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model periovarian fat pad"""

    name: Literal["periovarian fat pad"] = "periovarian fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36907"] = "EMAPA_36907"


class _Renal_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model renal fat pad"""

    name: Literal["renal fat pad"] = "renal fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36908"] = "EMAPA_36908"


class _Retroperitoneal_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model retroperitoneal fat pad"""

    name: Literal["retroperitoneal fat pad"] = "retroperitoneal fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36909"] = "EMAPA_36909"


class _Joint_Of_Rib(_MouseAnatomicalStructureModel):
    """Model joint of  rib"""

    name: Literal["joint of  rib"] = "joint of  rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36910"] = "EMAPA_36910"


class _Interchondral_Joint(_MouseAnatomicalStructureModel):
    """Model interchondral joint"""

    name: Literal["interchondral joint"] = "interchondral joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36911"] = "EMAPA_36911"


class _Joint_Of_Vertebral_Arch(_MouseAnatomicalStructureModel):
    """Model joint of vertebral arch"""

    name: Literal["joint of vertebral arch"] = "joint of vertebral arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36912"] = "EMAPA_36912"


class _Intervertebral_Joint(_MouseAnatomicalStructureModel):
    """Model intervertebral joint"""

    name: Literal["intervertebral joint"] = "intervertebral joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36913"] = "EMAPA_36913"


class _Joint_Of_Girdle(_MouseAnatomicalStructureModel):
    """Model joint of girdle"""

    name: Literal["joint of girdle"] = "joint of girdle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36914"] = "EMAPA_36914"


class _Renal_Pyramid(_MouseAnatomicalStructureModel):
    """Model renal pyramid"""

    name: Literal["renal pyramid"] = "renal pyramid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36915"] = "EMAPA_36915"


class _Labium_Majorum(_MouseAnatomicalStructureModel):
    """Model labium majorum"""

    name: Literal["labium majorum"] = "labium majorum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36916"] = "EMAPA_36916"


class _Labium_Minorum(_MouseAnatomicalStructureModel):
    """Model labium minorum"""

    name: Literal["labium minorum"] = "labium minorum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36917"] = "EMAPA_36917"


class _Lacrimal_Bone(_MouseAnatomicalStructureModel):
    """Model lacrimal bone"""

    name: Literal["lacrimal bone"] = "lacrimal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36918"] = "EMAPA_36918"


class _Lacrimal_Sac(_MouseAnatomicalStructureModel):
    """Model lacrimal sac"""

    name: Literal["lacrimal sac"] = "lacrimal sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36919"] = "EMAPA_36919"


class _Oculomotor_Muscle(_MouseAnatomicalStructureModel):
    """Model oculomotor muscle"""

    name: Literal["oculomotor muscle"] = "oculomotor muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36920"] = "EMAPA_36920"


class _Rectus_Extraocular_Muscle(_MouseAnatomicalStructureModel):
    """Model rectus extraocular muscle"""

    name: Literal["rectus extraocular muscle"] = "rectus extraocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36921"] = "EMAPA_36921"


class _Inferior_Rectus_Extraocular_Muscle(_MouseAnatomicalStructureModel):
    """Model inferior rectus extraocular muscle"""

    name: Literal["inferior rectus extraocular muscle"] = "inferior rectus extraocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36922"] = "EMAPA_36922"


class _Lateral_Rectus_Extraocular_Muscle(_MouseAnatomicalStructureModel):
    """Model lateral rectus extraocular muscle"""

    name: Literal["lateral rectus extraocular muscle"] = "lateral rectus extraocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36923"] = "EMAPA_36923"


class _Medial_Rectus_Extraocular_Muscle(_MouseAnatomicalStructureModel):
    """Model medial rectus extraocular muscle"""

    name: Literal["medial rectus extraocular muscle"] = "medial rectus extraocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36924"] = "EMAPA_36924"


class _Superior_Rectus_Extraocular_Muscle(_MouseAnatomicalStructureModel):
    """Model superior rectus extraocular muscle"""

    name: Literal["superior rectus extraocular muscle"] = "superior rectus extraocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36925"] = "EMAPA_36925"


class _Oblique_Extraocular_Muscle(_MouseAnatomicalStructureModel):
    """Model oblique extraocular muscle"""

    name: Literal["oblique extraocular muscle"] = "oblique extraocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36926"] = "EMAPA_36926"


class _Inferior_Oblique_Extraocular_Muscle(_MouseAnatomicalStructureModel):
    """Model inferior oblique extraocular muscle"""

    name: Literal["inferior oblique extraocular muscle"] = "inferior oblique extraocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36927"] = "EMAPA_36927"


class _Superior_Oblique_Extraocular_Muscle(_MouseAnatomicalStructureModel):
    """Model superior oblique extraocular muscle"""

    name: Literal["superior oblique extraocular muscle"] = "superior oblique extraocular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36928"] = "EMAPA_36928"


class _Lingual_Tonsil(_MouseAnatomicalStructureModel):
    """Model lingual tonsil"""

    name: Literal["lingual tonsil"] = "lingual tonsil"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36929"] = "EMAPA_36929"


class _Pharyngeal_Tonsil(_MouseAnatomicalStructureModel):
    """Model pharyngeal tonsil"""

    name: Literal["pharyngeal tonsil"] = "pharyngeal tonsil"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36930"] = "EMAPA_36930"


class _Tonsil_Capsule(_MouseAnatomicalStructureModel):
    """Model tonsil capsule"""

    name: Literal["tonsil capsule"] = "tonsil capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36931"] = "EMAPA_36931"


class _Tonsil_Crypt(_MouseAnatomicalStructureModel):
    """Model tonsil crypt"""

    name: Literal["tonsil crypt"] = "tonsil crypt"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36932"] = "EMAPA_36932"


class _Liver_Perisinusoidal_Space(_MouseAnatomicalStructureModel):
    """Model liver perisinusoidal space"""

    name: Literal["liver perisinusoidal space"] = "liver perisinusoidal space"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36933"] = "EMAPA_36933"


class _Pinna_Lobule(_MouseAnatomicalStructureModel):
    """Model pinna lobule"""

    name: Literal["pinna lobule"] = "pinna lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36934"] = "EMAPA_36934"


class _Membranous_Urethra_Of_Male(_MouseAnatomicalStructureModel):
    """Model membranous urethra of male"""

    name: Literal["membranous urethra of male"] = "membranous urethra of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36935"] = "EMAPA_36935"


class _Male_Reproductive_Gland_Or_Organ(_MouseAnatomicalStructureModel):
    """Model male reproductive gland or organ"""

    name: Literal["male reproductive gland or organ"] = "male reproductive gland or organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36936"] = "EMAPA_36936"


class _Malleus_Manubrium(_MouseAnatomicalStructureModel):
    """Model malleus manubrium"""

    name: Literal["malleus manubrium"] = "malleus manubrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36937"] = "EMAPA_36937"


class _Malleus_Processus_Brevis(_MouseAnatomicalStructureModel):
    """Model malleus processus brevis"""

    name: Literal["malleus processus brevis"] = "malleus processus brevis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36938"] = "EMAPA_36938"


class _Malleus_Head(_MouseAnatomicalStructureModel):
    """Model malleus head"""

    name: Literal["malleus head"] = "malleus head"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36939"] = "EMAPA_36939"


class _Malleus_Neck(_MouseAnatomicalStructureModel):
    """Model malleus neck"""

    name: Literal["malleus neck"] = "malleus neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36940"] = "EMAPA_36940"


class _Mandible_Angular_Process(_MouseAnatomicalStructureModel):
    """Model mandible angular process"""

    name: Literal["mandible angular process"] = "mandible angular process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36941"] = "EMAPA_36941"


class _Mandible_Head(_MouseAnatomicalStructureModel):
    """Model mandible head"""

    name: Literal["mandible head"] = "mandible head"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36942"] = "EMAPA_36942"


class _Mandible_Neck(_MouseAnatomicalStructureModel):
    """Model mandible neck"""

    name: Literal["mandible neck"] = "mandible neck"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36943"] = "EMAPA_36943"


class _Mandible_Coronoid_Process(_MouseAnatomicalStructureModel):
    """Model mandible coronoid process"""

    name: Literal["mandible coronoid process"] = "mandible coronoid process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36944"] = "EMAPA_36944"


class _Mandible_Temporal_Crest(_MouseAnatomicalStructureModel):
    """Model mandible temporal crest"""

    name: Literal["mandible temporal crest"] = "mandible temporal crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36945"] = "EMAPA_36945"


class _Mandible_Symphysis(_MouseAnatomicalStructureModel):
    """Model mandible symphysis"""

    name: Literal["mandible symphysis"] = "mandible symphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36946"] = "EMAPA_36946"


class _Mandible_Petrous_Part(_MouseAnatomicalStructureModel):
    """Model mandible petrous part"""

    name: Literal["mandible petrous part"] = "mandible petrous part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36947"] = "EMAPA_36947"


class _Mandible_Squamous_Part(_MouseAnatomicalStructureModel):
    """Model mandible squamous part"""

    name: Literal["mandible squamous part"] = "mandible squamous part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36948"] = "EMAPA_36948"


class _Mandible_Alveolar_Process(_MouseAnatomicalStructureModel):
    """Model mandible alveolar process"""

    name: Literal["mandible alveolar process"] = "mandible alveolar process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36949"] = "EMAPA_36949"


class _Maxilla_Alveolar_Process(_MouseAnatomicalStructureModel):
    """Model maxilla alveolar process"""

    name: Literal["maxilla alveolar process"] = "maxilla alveolar process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36950"] = "EMAPA_36950"


class _Masticatory_Muscle(_MouseAnatomicalStructureModel):
    """Model masticatory muscle"""

    name: Literal["masticatory muscle"] = "masticatory muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36951"] = "EMAPA_36951"


class _Metapodial_Pad(_MouseAnatomicalStructureModel):
    """Model metapodial pad"""

    name: Literal["metapodial pad"] = "metapodial pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36952"] = "EMAPA_36952"


class _Nasal_Bridge(_MouseAnatomicalStructureModel):
    """Model nasal bridge"""

    name: Literal["nasal bridge"] = "nasal bridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36953"] = "EMAPA_36953"


class _Neuroendocrine_Gland(_MouseAnatomicalStructureModel):
    """Model neuroendocrine gland"""

    name: Literal["neuroendocrine gland"] = "neuroendocrine gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36954"] = "EMAPA_36954"


class _Orbit_Of_Skull(_MouseAnatomicalStructureModel):
    """Model orbit of skull"""

    name: Literal["orbit of skull"] = "orbit of skull"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36955"] = "EMAPA_36955"


class _Osseus_Labyrinth_Vestibule(_MouseAnatomicalStructureModel):
    """Model osseus labyrinth vestibule"""

    name: Literal["osseus labyrinth vestibule"] = "osseus labyrinth vestibule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36956"] = "EMAPA_36956"


class _Vestibular_Aqueduct(_MouseAnatomicalStructureModel):
    """Model vestibular aqueduct"""

    name: Literal["vestibular aqueduct"] = "vestibular aqueduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36957"] = "EMAPA_36957"


class _Osseus_Semicircular_Canal(_MouseAnatomicalStructureModel):
    """Model osseus semicircular canal"""

    name: Literal["osseus semicircular canal"] = "osseus semicircular canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36958"] = "EMAPA_36958"


class _Membranous_Labyrinth(_MouseAnatomicalStructureModel):
    """Model membranous labyrinth"""

    name: Literal["membranous labyrinth"] = "membranous labyrinth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36959"] = "EMAPA_36959"


class _Vestibular_Labyrinth(_MouseAnatomicalStructureModel):
    """Model vestibular labyrinth"""

    name: Literal["vestibular labyrinth"] = "vestibular labyrinth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36960"] = "EMAPA_36960"


class _Otolithic_Membrane(_MouseAnatomicalStructureModel):
    """Model otolithic membrane"""

    name: Literal["otolithic membrane"] = "otolithic membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36961"] = "EMAPA_36961"


class _Otolith_Organ(_MouseAnatomicalStructureModel):
    """Model otolith organ"""

    name: Literal["otolith organ"] = "otolith organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36962"] = "EMAPA_36962"


class _Bulbar_Conjunctiva(_MouseAnatomicalStructureModel):
    """Model bulbar conjunctiva"""

    name: Literal["bulbar conjunctiva"] = "bulbar conjunctiva"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36963"] = "EMAPA_36963"


class _Palpebral_Conjunctiva(_MouseAnatomicalStructureModel):
    """Model palpebral conjunctiva"""

    name: Literal["palpebral conjunctiva"] = "palpebral conjunctiva"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36964"] = "EMAPA_36964"


class _Palpebral_Fissure(_MouseAnatomicalStructureModel):
    """Model palpebral fissure"""

    name: Literal["palpebral fissure"] = "palpebral fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36965"] = "EMAPA_36965"


class _Heart_Ventricle_Papillary_Muscle(_MouseAnatomicalStructureModel):
    """Model heart ventricle papillary muscle"""

    name: Literal["heart ventricle papillary muscle"] = "heart ventricle papillary muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36966"] = "EMAPA_36966"


class _Vertebral_Pedicle(_MouseAnatomicalStructureModel):
    """Model vertebral pedicle"""

    name: Literal["vertebral pedicle"] = "vertebral pedicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36967"] = "EMAPA_36967"


class _Pelvic_Ligament(_MouseAnatomicalStructureModel):
    """Model pelvic ligament"""

    name: Literal["pelvic ligament"] = "pelvic ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36968"] = "EMAPA_36968"


class _Periorbital_Region(_MouseAnatomicalStructureModel):
    """Model periorbital region"""

    name: Literal["periorbital region"] = "periorbital region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36969"] = "EMAPA_36969"


class _Peyer_S_Patch_Follicle(_MouseAnatomicalStructureModel):
    """Model Peyer's patch follicle"""

    name: Literal["Peyer's patch follicle"] = "Peyer's patch follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36970"] = "EMAPA_36970"


class _Placenta_Metrial_Gland(_MouseAnatomicalStructureModel):
    """Model placenta metrial gland"""

    name: Literal["placenta metrial gland"] = "placenta metrial gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36971"] = "EMAPA_36971"


class _Pontine_Raphe_Nucleus(_MouseAnatomicalStructureModel):
    """Model pontine raphe nucleus"""

    name: Literal["pontine raphe nucleus"] = "pontine raphe nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36972"] = "EMAPA_36972"


class _Portal_Lobule(_MouseAnatomicalStructureModel):
    """Model portal lobule"""

    name: Literal["portal lobule"] = "portal lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36973"] = "EMAPA_36973"


class _Portal_Triad(_MouseAnatomicalStructureModel):
    """Model portal triad"""

    name: Literal["portal triad"] = "portal triad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36974"] = "EMAPA_36974"


class _Eye_Posterior_Chamber(_MouseAnatomicalStructureModel):
    """Model eye posterior chamber"""

    name: Literal["eye posterior chamber"] = "eye posterior chamber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36975"] = "EMAPA_36975"


class _Pupillary_Membrane(_MouseAnatomicalStructureModel):
    """Model pupillary membrane"""

    name: Literal["pupillary membrane"] = "pupillary membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36976"] = "EMAPA_36976"


class _Pupil(_MouseAnatomicalStructureModel):
    """Model pupil"""

    name: Literal["pupil"] = "pupil"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36977"] = "EMAPA_36977"


class _Paravertebral_Ganglion(_MouseAnatomicalStructureModel):
    """Model paravertebral ganglion"""

    name: Literal["paravertebral ganglion"] = "paravertebral ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36978"] = "EMAPA_36978"


class _Prevertebral_Ganglion(_MouseAnatomicalStructureModel):
    """Model prevertebral ganglion"""

    name: Literal["prevertebral ganglion"] = "prevertebral ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36979"] = "EMAPA_36979"


class _Mesenteric_Ganglion(_MouseAnatomicalStructureModel):
    """Model mesenteric ganglion"""

    name: Literal["mesenteric ganglion"] = "mesenteric ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36980"] = "EMAPA_36980"


class _Inferior_Mesenteric_Ganglion(_MouseAnatomicalStructureModel):
    """Model inferior mesenteric ganglion"""

    name: Literal["inferior mesenteric ganglion"] = "inferior mesenteric ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36981"] = "EMAPA_36981"


class _Superior_Mesenteric_Ganglion(_MouseAnatomicalStructureModel):
    """Model superior mesenteric ganglion"""

    name: Literal["superior mesenteric ganglion"] = "superior mesenteric ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36982"] = "EMAPA_36982"


class _Retrotrapezoid_Nucleus(_MouseAnatomicalStructureModel):
    """Model retrotrapezoid nucleus"""

    name: Literal["retrotrapezoid nucleus"] = "retrotrapezoid nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36983"] = "EMAPA_36983"


class _Septum_Pellucidum(_MouseAnatomicalStructureModel):
    """Model septum pellucidum"""

    name: Literal["septum pellucidum"] = "septum pellucidum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36984"] = "EMAPA_36984"


class _Reproductive_System_Gland(_MouseAnatomicalStructureModel):
    """Model reproductive system gland"""

    name: Literal["reproductive system gland"] = "reproductive system gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36985"] = "EMAPA_36985"


class _Shoulder_Bone(_MouseAnatomicalStructureModel):
    """Model shoulder bone"""

    name: Literal["shoulder bone"] = "shoulder bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36986"] = "EMAPA_36986"


class _Somatic_Nervous_System(_MouseAnatomicalStructureModel):
    """Model somatic nervous system"""

    name: Literal["somatic nervous system"] = "somatic nervous system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36987"] = "EMAPA_36987"


class _Sphenoid_Bone_Pterygoid_Process(_MouseAnatomicalStructureModel):
    """Model sphenoid bone pterygoid process"""

    name: Literal["sphenoid bone pterygoid process"] = "sphenoid bone pterygoid process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36988"] = "EMAPA_36988"


class _Spinal_Cord_Dorsal_Column(_MouseAnatomicalStructureModel):
    """Model spinal cord dorsal column"""

    name: Literal["spinal cord dorsal column"] = "spinal cord dorsal column"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36989"] = "EMAPA_36989"


class _Spinal_Cord_Lateral_Column(_MouseAnatomicalStructureModel):
    """Model spinal cord lateral column"""

    name: Literal["spinal cord lateral column"] = "spinal cord lateral column"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36990"] = "EMAPA_36990"


class _Spinal_Cord_Lateral_Motor_Column(_MouseAnatomicalStructureModel):
    """Model spinal cord lateral motor column"""

    name: Literal["spinal cord lateral motor column"] = "spinal cord lateral motor column"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36991"] = "EMAPA_36991"


class _Spinal_Cord_Medial_Motor_Column(_MouseAnatomicalStructureModel):
    """Model spinal cord medial motor column"""

    name: Literal["spinal cord medial motor column"] = "spinal cord medial motor column"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36992"] = "EMAPA_36992"


class _Spinal_Cord_Motor_Column(_MouseAnatomicalStructureModel):
    """Model spinal cord motor column"""

    name: Literal["spinal cord motor column"] = "spinal cord motor column"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36993"] = "EMAPA_36993"


class _Spinal_Cord_Ventral_Column(_MouseAnatomicalStructureModel):
    """Model spinal cord ventral column"""

    name: Literal["spinal cord ventral column"] = "spinal cord ventral column"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36994"] = "EMAPA_36994"


class _Spiral_Modiolar_Artery(_MouseAnatomicalStructureModel):
    """Model spiral modiolar artery"""

    name: Literal["spiral modiolar artery"] = "spiral modiolar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36995"] = "EMAPA_36995"


class _Spleen_Central_Arteriole(_MouseAnatomicalStructureModel):
    """Model spleen central arteriole"""

    name: Literal["spleen central arteriole"] = "spleen central arteriole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36996"] = "EMAPA_36996"


class _Spleen_Marginal_Sinus(_MouseAnatomicalStructureModel):
    """Model spleen marginal sinus"""

    name: Literal["spleen marginal sinus"] = "spleen marginal sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36997"] = "EMAPA_36997"


class _Spleen_Trabecular_Artery(_MouseAnatomicalStructureModel):
    """Model spleen trabecular artery"""

    name: Literal["spleen trabecular artery"] = "spleen trabecular artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36998"] = "EMAPA_36998"


class _Spleen_Trabecular_Vein(_MouseAnatomicalStructureModel):
    """Model spleen trabecular vein"""

    name: Literal["spleen trabecular vein"] = "spleen trabecular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_36999"] = "EMAPA_36999"


class _Stapes_Base(_MouseAnatomicalStructureModel):
    """Model stapes base"""

    name: Literal["stapes base"] = "stapes base"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37000"] = "EMAPA_37000"


class _Stomach_Smooth_Muscle_Circular_Layer(_MouseAnatomicalStructureModel):
    """Model stomach smooth muscle circular layer"""

    name: Literal["stomach smooth muscle circular layer"] = "stomach smooth muscle circular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37001"] = "EMAPA_37001"


class _Duvet_Hair(_MouseAnatomicalStructureModel):
    """Model duvet hair"""

    name: Literal["duvet hair"] = "duvet hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37002"] = "EMAPA_37002"


class _Nonskeletal_Ligament(_MouseAnatomicalStructureModel):
    """Model nonskeletal ligament"""

    name: Literal["nonskeletal ligament"] = "nonskeletal ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37003"] = "EMAPA_37003"


class _Skeletal_Ligament(_MouseAnatomicalStructureModel):
    """Model skeletal ligament"""

    name: Literal["skeletal ligament"] = "skeletal ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37004"] = "EMAPA_37004"


class _Stylohyoid_Ligament(_MouseAnatomicalStructureModel):
    """Model stylohyoid ligament"""

    name: Literal["stylohyoid ligament"] = "stylohyoid ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37005"] = "EMAPA_37005"


class _Sublingual_Ganglion(_MouseAnatomicalStructureModel):
    """Model sublingual ganglion"""

    name: Literal["sublingual ganglion"] = "sublingual ganglion"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37006"] = "EMAPA_37006"


class _Sulcus_Ampullaris(_MouseAnatomicalStructureModel):
    """Model sulcus ampullaris"""

    name: Literal["sulcus ampullaris"] = "sulcus ampullaris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37007"] = "EMAPA_37007"


class _Vestibular_Ganglion_Superior_Part(_MouseAnatomicalStructureModel):
    """Model vestibular ganglion superior part"""

    name: Literal["vestibular ganglion superior part"] = "vestibular ganglion superior part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37008"] = "EMAPA_37008"


class _Vestibular_Ganglion_Inferior_Part(_MouseAnatomicalStructureModel):
    """Model vestibular ganglion inferior part"""

    name: Literal["vestibular ganglion inferior part"] = "vestibular ganglion inferior part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37009"] = "EMAPA_37009"


class _Eyelid_Tarsus(_MouseAnatomicalStructureModel):
    """Model eyelid tarsus"""

    name: Literal["eyelid tarsus"] = "eyelid tarsus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37010"] = "EMAPA_37010"


class _Meibomian_Gland(_MouseAnatomicalStructureModel):
    """Model meibomian gland"""

    name: Literal["meibomian gland"] = "meibomian gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37011"] = "EMAPA_37011"


class _Ovary_Theca_Externa(_MouseAnatomicalStructureModel):
    """Model ovary theca externa"""

    name: Literal["ovary theca externa"] = "ovary theca externa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37012"] = "EMAPA_37012"


class _Ovary_Theca_Interna(_MouseAnatomicalStructureModel):
    """Model ovary theca interna"""

    name: Literal["ovary theca interna"] = "ovary theca interna"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37013"] = "EMAPA_37013"


class _Thymus_Lobule(_MouseAnatomicalStructureModel):
    """Model thymus lobule"""

    name: Literal["thymus lobule"] = "thymus lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37014"] = "EMAPA_37014"


class _Thymus_Subcapsular_Epithelium(_MouseAnatomicalStructureModel):
    """Model thymus subcapsular epithelium"""

    name: Literal["thymus subcapsular epithelium"] = "thymus subcapsular epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37015"] = "EMAPA_37015"


class _Thymus_Trabecula(_MouseAnatomicalStructureModel):
    """Model thymus trabecula"""

    name: Literal["thymus trabecula"] = "thymus trabecula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37016"] = "EMAPA_37016"


class _Tongue_Squamous_Epitthelium(_MouseAnatomicalStructureModel):
    """Model tongue squamous epitthelium"""

    name: Literal["tongue squamous epitthelium"] = "tongue squamous epitthelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37017"] = "EMAPA_37017"


class _Tongue_Keratinized_Epithelium(_MouseAnatomicalStructureModel):
    """Model tongue keratinized epithelium"""

    name: Literal["tongue keratinized epithelium"] = "tongue keratinized epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37018"] = "EMAPA_37018"


class _Tongue_Taste_Bud(_MouseAnatomicalStructureModel):
    """Model tongue taste bud"""

    name: Literal["tongue taste bud"] = "tongue taste bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37019"] = "EMAPA_37019"


class _Tooth_Cavity(_MouseAnatomicalStructureModel):
    """Model tooth cavity"""

    name: Literal["tooth cavity"] = "tooth cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37020"] = "EMAPA_37020"


class _Vertebra_Transverse_Process(_MouseAnatomicalStructureModel):
    """Model vertebra transverse process"""

    name: Literal["vertebra transverse process"] = "vertebra transverse process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37021"] = "EMAPA_37021"


class _Trochanter_Of_Femur(_MouseAnatomicalStructureModel):
    """Model trochanter of femur"""

    name: Literal["trochanter of femur"] = "trochanter of femur"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37023"] = "EMAPA_37023"


class _Uterine_Artery(_MouseAnatomicalStructureModel):
    """Model uterine artery"""

    name: Literal["uterine artery"] = "uterine artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37024"] = "EMAPA_37024"


class _Venous_Sinus(_MouseAnatomicalStructureModel):
    """Model venous sinus"""

    name: Literal["venous sinus"] = "venous sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37025"] = "EMAPA_37025"


class _Vertebra_Lamina(_MouseAnatomicalStructureModel):
    """Model vertebra lamina"""

    name: Literal["vertebra lamina"] = "vertebra lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37026"] = "EMAPA_37026"


class _Vitreous_Body(_MouseAnatomicalStructureModel):
    """Model vitreous body"""

    name: Literal["vitreous body"] = "vitreous body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37027"] = "EMAPA_37027"


class _Vomer_Bone(_MouseAnatomicalStructureModel):
    """Model vomer bone"""

    name: Literal["vomer bone"] = "vomer bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37028"] = "EMAPA_37028"


class _4Th_Ventricle_Aperture(_MouseAnatomicalStructureModel):
    """Model 4th ventricle aperture"""

    name: Literal["4th ventricle aperture"] = "4th ventricle aperture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37029"] = "EMAPA_37029"


class _4Th_Ventricle_Lateral_Aperture(_MouseAnatomicalStructureModel):
    """Model 4th ventricle lateral aperture"""

    name: Literal["4th ventricle lateral aperture"] = "4th ventricle lateral aperture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37030"] = "EMAPA_37030"


class _4Th_Ventricle_Median_Aperture(_MouseAnatomicalStructureModel):
    """Model 4th ventricle median aperture"""

    name: Literal["4th ventricle median aperture"] = "4th ventricle median aperture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37031"] = "EMAPA_37031"


class _Limb_Segment(_MouseAnatomicalStructureModel):
    """Model limb segment"""

    name: Literal["limb segment"] = "limb segment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37032"] = "EMAPA_37032"


class _Stylopod(_MouseAnatomicalStructureModel):
    """Model stylopod"""

    name: Literal["stylopod"] = "stylopod"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37033"] = "EMAPA_37033"


class _Zeugopod(_MouseAnatomicalStructureModel):
    """Model zeugopod"""

    name: Literal["zeugopod"] = "zeugopod"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37034"] = "EMAPA_37034"


class _Hypopharynx(_MouseAnatomicalStructureModel):
    """Model hypopharynx"""

    name: Literal["hypopharynx"] = "hypopharynx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37035"] = "EMAPA_37035"


class _Ovarian_Bursa(_MouseAnatomicalStructureModel):
    """Model ovarian bursa"""

    name: Literal["ovarian bursa"] = "ovarian bursa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37036"] = "EMAPA_37036"


class _Pancreas_Vasculature(_MouseAnatomicalStructureModel):
    """Model pancreas vasculature"""

    name: Literal["pancreas vasculature"] = "pancreas vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37037"] = "EMAPA_37037"


class _4Th_Ventricle_Choroid_Plexus_Epithelium(_MouseAnatomicalStructureModel):
    """Model 4th ventricle choroid plexus epithelium"""

    name: Literal["4th ventricle choroid plexus epithelium"] = "4th ventricle choroid plexus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37038"] = "EMAPA_37038"


class _4Th_Ventricle_Choroid_Plexus_Stroma(_MouseAnatomicalStructureModel):
    """Model 4th ventricle choroid plexus stroma"""

    name: Literal["4th ventricle choroid plexus stroma"] = "4th ventricle choroid plexus stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37039"] = "EMAPA_37039"


class _Lateral_Ventricle_Choroid_Plexus_Epithelium(_MouseAnatomicalStructureModel):
    """Model lateral ventricle choroid plexus epithelium"""

    name: Literal["lateral ventricle choroid plexus epithelium"] = "lateral ventricle choroid plexus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37040"] = "EMAPA_37040"


class _Lateral_Ventricle_Choroid_Plexus_Stroma(_MouseAnatomicalStructureModel):
    """Model lateral ventricle choroid plexus stroma"""

    name: Literal["lateral ventricle choroid plexus stroma"] = "lateral ventricle choroid plexus stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37041"] = "EMAPA_37041"


class _Abdomen_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model abdomen blood vessel"""

    name: Literal["abdomen blood vessel"] = "abdomen blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37042"] = "EMAPA_37042"


class _Abdomen_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model abdomen connective tissue"""

    name: Literal["abdomen connective tissue"] = "abdomen connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37043"] = "EMAPA_37043"


class _Abdomen_Nerve(_MouseAnatomicalStructureModel):
    """Model abdomen nerve"""

    name: Literal["abdomen nerve"] = "abdomen nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37044"] = "EMAPA_37044"


class _Abdomen_Skin(_MouseAnatomicalStructureModel):
    """Model abdomen skin"""

    name: Literal["abdomen skin"] = "abdomen skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37045"] = "EMAPA_37045"


class _Tail_Dermis(_MouseAnatomicalStructureModel):
    """Model tail dermis"""

    name: Literal["tail dermis"] = "tail dermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37046"] = "EMAPA_37046"


class _Tail_Epidermis(_MouseAnatomicalStructureModel):
    """Model tail epidermis"""

    name: Literal["tail epidermis"] = "tail epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37047"] = "EMAPA_37047"


class _Spinal_Cord_Region(_MouseAnatomicalStructureModel):
    """Model spinal cord region"""

    name: Literal["spinal cord region"] = "spinal cord region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37048"] = "EMAPA_37048"


class _Spinal_Cord_Cervical_Region(_MouseAnatomicalStructureModel):
    """Model spinal cord cervical region"""

    name: Literal["spinal cord cervical region"] = "spinal cord cervical region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37049"] = "EMAPA_37049"


class _Spinal_Cord_Thoracic_Region(_MouseAnatomicalStructureModel):
    """Model spinal cord thoracic region"""

    name: Literal["spinal cord thoracic region"] = "spinal cord thoracic region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37050"] = "EMAPA_37050"


class _Spinal_Cord_Lumbar_Region(_MouseAnatomicalStructureModel):
    """Model spinal cord lumbar region"""

    name: Literal["spinal cord lumbar region"] = "spinal cord lumbar region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37051"] = "EMAPA_37051"


class _Spinal_Cord_Sacral_Region(_MouseAnatomicalStructureModel):
    """Model spinal cord sacral region"""

    name: Literal["spinal cord sacral region"] = "spinal cord sacral region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37052"] = "EMAPA_37052"


class _Spinal_Cord_Coccygeal_Region(_MouseAnatomicalStructureModel):
    """Model spinal cord coccygeal region"""

    name: Literal["spinal cord coccygeal region"] = "spinal cord coccygeal region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37053"] = "EMAPA_37053"


class _Unsegmented_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model unsegmented mesenchyme"""

    name: Literal["unsegmented mesenchyme"] = "unsegmented mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37054"] = "EMAPA_37054"


class _3Rd_Ventricle_Choroid_Plexus_Epitheilum(_MouseAnatomicalStructureModel):
    """Model 3rd ventricle choroid plexus epitheilum"""

    name: Literal["3rd ventricle choroid plexus epitheilum"] = "3rd ventricle choroid plexus epitheilum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37055"] = "EMAPA_37055"


class _3Rd_Ventricle_Choroid_Plexus_Stroma(_MouseAnatomicalStructureModel):
    """Model 3rd ventricle choroid plexus stroma"""

    name: Literal["3rd ventricle choroid plexus stroma"] = "3rd ventricle choroid plexus stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37056"] = "EMAPA_37056"


class _Abdominal_Segment_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model abdominal segment blood vessel"""

    name: Literal["abdominal segment blood vessel"] = "abdominal segment blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37057"] = "EMAPA_37057"


class _Abdominal_Segment_Bone(_MouseAnatomicalStructureModel):
    """Model abdominal segment bone"""

    name: Literal["abdominal segment bone"] = "abdominal segment bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37058"] = "EMAPA_37058"


class _Abdominal_Segment_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model abdominal segment connective tissue"""

    name: Literal["abdominal segment connective tissue"] = "abdominal segment connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37059"] = "EMAPA_37059"


class _Abdominal_Segment_Muscle(_MouseAnatomicalStructureModel):
    """Model abdominal segment muscle"""

    name: Literal["abdominal segment muscle"] = "abdominal segment muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37060"] = "EMAPA_37060"


class _Abdominal_Segment_Nerve(_MouseAnatomicalStructureModel):
    """Model abdominal segment nerve"""

    name: Literal["abdominal segment nerve"] = "abdominal segment nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37061"] = "EMAPA_37061"


class _Abdominal_Segment_Organ(_MouseAnatomicalStructureModel):
    """Model abdominal segment organ"""

    name: Literal["abdominal segment organ"] = "abdominal segment organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37062"] = "EMAPA_37062"


class _Abdominal_Segment_Skin(_MouseAnatomicalStructureModel):
    """Model abdominal segment skin"""

    name: Literal["abdominal segment skin"] = "abdominal segment skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37063"] = "EMAPA_37063"


class _Abdominal_Wall(_MouseAnatomicalStructureModel):
    """Model abdominal wall"""

    name: Literal["abdominal wall"] = "abdominal wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37064"] = "EMAPA_37064"


class _Accessory_Hepatic_Vein(_MouseAnatomicalStructureModel):
    """Model accessory hepatic vein"""

    name: Literal["accessory hepatic vein"] = "accessory hepatic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37065"] = "EMAPA_37065"


class _Cranial_Nerve_Nucleus(_MouseAnatomicalStructureModel):
    """Model cranial nerve nucleus"""

    name: Literal["cranial nerve nucleus"] = "cranial nerve nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37066"] = "EMAPA_37066"


class _Accessory_Xi_Nerve_Nucleus(_MouseAnatomicalStructureModel):
    """Model accessory XI nerve nucleus"""

    name: Literal["accessory XI nerve nucleus"] = "accessory XI nerve nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37067"] = "EMAPA_37067"


class _Alimentary_System_Mesentery(_MouseAnatomicalStructureModel):
    """Model alimentary system mesentery"""

    name: Literal["alimentary system mesentery"] = "alimentary system mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37068"] = "EMAPA_37068"


class _Alveolar_Artery(_MouseAnatomicalStructureModel):
    """Model alveolar artery"""

    name: Literal["alveolar artery"] = "alveolar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37069"] = "EMAPA_37069"


class _Anterior_Inferior_Cerebellar_Artery(_MouseAnatomicalStructureModel):
    """Model anterior inferior cerebellar artery"""

    name: Literal["anterior inferior cerebellar artery"] = "anterior inferior cerebellar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37070"] = "EMAPA_37070"


class _Anterior_Tibial_Artery(_MouseAnatomicalStructureModel):
    """Model anterior tibial artery"""

    name: Literal["anterior tibial artery"] = "anterior tibial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37071"] = "EMAPA_37071"


class _Auricular_Artery(_MouseAnatomicalStructureModel):
    """Model auricular artery"""

    name: Literal["auricular artery"] = "auricular artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37072"] = "EMAPA_37072"


class _Buccal_Artery(_MouseAnatomicalStructureModel):
    """Model buccal artery"""

    name: Literal["buccal artery"] = "buccal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37073"] = "EMAPA_37073"


class _Cerebellar_Artery(_MouseAnatomicalStructureModel):
    """Model cerebellar artery"""

    name: Literal["cerebellar artery"] = "cerebellar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37074"] = "EMAPA_37074"


class _Cervical_Artery(_MouseAnatomicalStructureModel):
    """Model cervical artery"""

    name: Literal["cervical artery"] = "cervical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37075"] = "EMAPA_37075"


class _Digital_Artery(_MouseAnatomicalStructureModel):
    """Model digital artery"""

    name: Literal["digital artery"] = "digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37076"] = "EMAPA_37076"


class _Dorsal_Artery_Of_Foot(_MouseAnatomicalStructureModel):
    """Model dorsal artery of foot"""

    name: Literal["dorsal artery of foot"] = "dorsal artery of foot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37077"] = "EMAPA_37077"


class _Dorsal_Intercostal_Artery(_MouseAnatomicalStructureModel):
    """Model dorsal intercostal artery"""

    name: Literal["dorsal intercostal artery"] = "dorsal intercostal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37078"] = "EMAPA_37078"


class _Dorsal_Metacarpal_Artery(_MouseAnatomicalStructureModel):
    """Model dorsal metacarpal artery"""

    name: Literal["dorsal metacarpal artery"] = "dorsal metacarpal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37079"] = "EMAPA_37079"


class _Dorsal_Penis_Artery(_MouseAnatomicalStructureModel):
    """Model dorsal penis artery"""

    name: Literal["dorsal penis artery"] = "dorsal penis artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37080"] = "EMAPA_37080"


class _Ethmoidal_Artery(_MouseAnatomicalStructureModel):
    """Model ethmoidal artery"""

    name: Literal["ethmoidal artery"] = "ethmoidal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37081"] = "EMAPA_37081"


class _Ileocolic_Artery(_MouseAnatomicalStructureModel):
    """Model ileocolic artery"""

    name: Literal["ileocolic artery"] = "ileocolic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37082"] = "EMAPA_37082"


class _Iliac_Circumflex_Artery(_MouseAnatomicalStructureModel):
    """Model iliac circumflex artery"""

    name: Literal["iliac circumflex artery"] = "iliac circumflex artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37084"] = "EMAPA_37084"


class _Ilio_Lumbar_Artery(_MouseAnatomicalStructureModel):
    """Model ilio-lumbar artery"""

    name: Literal["ilio-lumbar artery"] = "ilio-lumbar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37085"] = "EMAPA_37085"


class _Inferior_Pancreatico_Duodenal_Artery(_MouseAnatomicalStructureModel):
    """Model inferior pancreatico-duodenal artery"""

    name: Literal["inferior pancreatico-duodenal artery"] = "inferior pancreatico-duodenal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37086"] = "EMAPA_37086"


class _Inferior_Rectal_Artery(_MouseAnatomicalStructureModel):
    """Model inferior rectal artery"""

    name: Literal["inferior rectal artery"] = "inferior rectal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37087"] = "EMAPA_37087"


class _Inferior_Suprarenal_Artery(_MouseAnatomicalStructureModel):
    """Model inferior suprarenal artery"""

    name: Literal["inferior suprarenal artery"] = "inferior suprarenal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37088"] = "EMAPA_37088"


class _Inferior_Vesical_Artery(_MouseAnatomicalStructureModel):
    """Model inferior vesical artery"""

    name: Literal["inferior vesical artery"] = "inferior vesical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37089"] = "EMAPA_37089"


class _Infraorbital_Artery(_MouseAnatomicalStructureModel):
    """Model infraorbital artery"""

    name: Literal["infraorbital artery"] = "infraorbital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37090"] = "EMAPA_37090"


class _Intralobar_Artery(_MouseAnatomicalStructureModel):
    """Model intralobar artery"""

    name: Literal["intralobar artery"] = "intralobar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37091"] = "EMAPA_37091"


class _Labial_Artery(_MouseAnatomicalStructureModel):
    """Model labial artery"""

    name: Literal["labial artery"] = "labial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37092"] = "EMAPA_37092"


class _Labyrinthine_Artery(_MouseAnatomicalStructureModel):
    """Model labyrinthine artery"""

    name: Literal["labyrinthine artery"] = "labyrinthine artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37093"] = "EMAPA_37093"


class _Lacrimal_Artery(_MouseAnatomicalStructureModel):
    """Model lacrimal artery"""

    name: Literal["lacrimal artery"] = "lacrimal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37094"] = "EMAPA_37094"


class _Lateral_Thoracic_Artery(_MouseAnatomicalStructureModel):
    """Model lateral thoracic artery"""

    name: Literal["lateral thoracic artery"] = "lateral thoracic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37095"] = "EMAPA_37095"


class _Left_Hepatic_Artery(_MouseAnatomicalStructureModel):
    """Model left hepatic artery"""

    name: Literal["left hepatic artery"] = "left hepatic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37096"] = "EMAPA_37096"


class _Left_Pulmonary_Artery(_MouseAnatomicalStructureModel):
    """Model left pulmonary artery"""

    name: Literal["left pulmonary artery"] = "left pulmonary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37097"] = "EMAPA_37097"


class _Left_Renal_Artery(_MouseAnatomicalStructureModel):
    """Model left renal artery"""

    name: Literal["left renal artery"] = "left renal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37098"] = "EMAPA_37098"


class _Left_Spermatic_Artery(_MouseAnatomicalStructureModel):
    """Model left spermatic artery"""

    name: Literal["left spermatic artery"] = "left spermatic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37099"] = "EMAPA_37099"


class _Left_Subclavian_Artery(_MouseAnatomicalStructureModel):
    """Model left subclavian artery"""

    name: Literal["left subclavian artery"] = "left subclavian artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37100"] = "EMAPA_37100"


class _Medial_Plantar_Artery(_MouseAnatomicalStructureModel):
    """Model medial plantar artery"""

    name: Literal["medial plantar artery"] = "medial plantar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37101"] = "EMAPA_37101"


class _Medial_Tarsal_Artery(_MouseAnatomicalStructureModel):
    """Model medial tarsal artery"""

    name: Literal["medial tarsal artery"] = "medial tarsal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37102"] = "EMAPA_37102"


class _Median_Artery(_MouseAnatomicalStructureModel):
    """Model median artery"""

    name: Literal["median artery"] = "median artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37103"] = "EMAPA_37103"


class _Meningeal_Artery(_MouseAnatomicalStructureModel):
    """Model meningeal artery"""

    name: Literal["meningeal artery"] = "meningeal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37104"] = "EMAPA_37104"


class _Mental_Artery(_MouseAnatomicalStructureModel):
    """Model mental artery"""

    name: Literal["mental artery"] = "mental artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37105"] = "EMAPA_37105"


class _Middle_Colic_Artery(_MouseAnatomicalStructureModel):
    """Model middle colic artery"""

    name: Literal["middle colic artery"] = "middle colic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37106"] = "EMAPA_37106"


class _Perineal_Artery(_MouseAnatomicalStructureModel):
    """Model perineal artery"""

    name: Literal["perineal artery"] = "perineal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37107"] = "EMAPA_37107"


class _Phrenic_Artery(_MouseAnatomicalStructureModel):
    """Model phrenic artery"""

    name: Literal["phrenic artery"] = "phrenic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37108"] = "EMAPA_37108"


class _Popliteal_Artery(_MouseAnatomicalStructureModel):
    """Model popliteal artery"""

    name: Literal["popliteal artery"] = "popliteal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37109"] = "EMAPA_37109"


class _Posterior_Tibial_Artery(_MouseAnatomicalStructureModel):
    """Model posterior tibial artery"""

    name: Literal["posterior tibial artery"] = "posterior tibial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37110"] = "EMAPA_37110"


class _Pudendal_Artery(_MouseAnatomicalStructureModel):
    """Model pudendal artery"""

    name: Literal["pudendal artery"] = "pudendal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37111"] = "EMAPA_37111"


class _Radial_Artery(_MouseAnatomicalStructureModel):
    """Model radial artery"""

    name: Literal["radial artery"] = "radial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37112"] = "EMAPA_37112"


class _Retinal_Artery(_MouseAnatomicalStructureModel):
    """Model retinal artery"""

    name: Literal["retinal artery"] = "retinal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37113"] = "EMAPA_37113"


class _Spermatic_Artery(_MouseAnatomicalStructureModel):
    """Model spermatic artery"""

    name: Literal["spermatic artery"] = "spermatic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37114"] = "EMAPA_37114"


class _Sublingual_Artery(_MouseAnatomicalStructureModel):
    """Model sublingual artery"""

    name: Literal["sublingual artery"] = "sublingual artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37115"] = "EMAPA_37115"


class _Subscapular_Artery(_MouseAnatomicalStructureModel):
    """Model subscapular artery"""

    name: Literal["subscapular artery"] = "subscapular artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37116"] = "EMAPA_37116"


class _Superficial_Cervical_Artery(_MouseAnatomicalStructureModel):
    """Model superficial cervical artery"""

    name: Literal["superficial cervical artery"] = "superficial cervical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37117"] = "EMAPA_37117"


class _Superior_Temporal_Artery(_MouseAnatomicalStructureModel):
    """Model superior temporal artery"""

    name: Literal["superior temporal artery"] = "superior temporal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37118"] = "EMAPA_37118"


class _Superior_External_Pudendal_Artery(_MouseAnatomicalStructureModel):
    """Model superior external pudendal artery"""

    name: Literal["superior external pudendal artery"] = "superior external pudendal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37119"] = "EMAPA_37119"


class _Superior_Gluteal_Artery(_MouseAnatomicalStructureModel):
    """Model superior gluteal artery"""

    name: Literal["superior gluteal artery"] = "superior gluteal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37120"] = "EMAPA_37120"


class _Superior_Pancreatico_Duodenal_Artery(_MouseAnatomicalStructureModel):
    """Model superior pancreatico-duodenal artery"""

    name: Literal["superior pancreatico-duodenal artery"] = "superior pancreatico-duodenal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37121"] = "EMAPA_37121"


class _Superior_Suprarenal_Artery(_MouseAnatomicalStructureModel):
    """Model superior suprarenal artery"""

    name: Literal["superior suprarenal artery"] = "superior suprarenal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37122"] = "EMAPA_37122"


class _Suprarenal_Artery(_MouseAnatomicalStructureModel):
    """Model suprarenal artery"""

    name: Literal["suprarenal artery"] = "suprarenal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37124"] = "EMAPA_37124"


class _Sural_Artery(_MouseAnatomicalStructureModel):
    """Model sural artery"""

    name: Literal["sural artery"] = "sural artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37125"] = "EMAPA_37125"


class _Systemic_Artery(_MouseAnatomicalStructureModel):
    """Model systemic artery"""

    name: Literal["systemic artery"] = "systemic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37126"] = "EMAPA_37126"


class _Temporal_Artery(_MouseAnatomicalStructureModel):
    """Model temporal artery"""

    name: Literal["temporal artery"] = "temporal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37127"] = "EMAPA_37127"


class _Thoraco_Acromial_Artery(_MouseAnatomicalStructureModel):
    """Model thoraco-acromial artery"""

    name: Literal["thoraco-acromial artery"] = "thoraco-acromial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37128"] = "EMAPA_37128"


class _Thoracodorsal_Artery(_MouseAnatomicalStructureModel):
    """Model thoracodorsal artery"""

    name: Literal["thoracodorsal artery"] = "thoracodorsal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37129"] = "EMAPA_37129"


class _Transverse_Facial_Artery(_MouseAnatomicalStructureModel):
    """Model transverse facial artery"""

    name: Literal["transverse facial artery"] = "transverse facial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37130"] = "EMAPA_37130"


class _Vesical_Artery(_MouseAnatomicalStructureModel):
    """Model vesical artery"""

    name: Literal["vesical artery"] = "vesical artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37131"] = "EMAPA_37131"


class _Anterior_Auricular_Vein(_MouseAnatomicalStructureModel):
    """Model anterior auricular vein"""

    name: Literal["anterior auricular vein"] = "anterior auricular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37132"] = "EMAPA_37132"


class _Anterior_Facial_Vein(_MouseAnatomicalStructureModel):
    """Model anterior facial vein"""

    name: Literal["anterior facial vein"] = "anterior facial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37133"] = "EMAPA_37133"


class _Anterior_Jugular_Vein(_MouseAnatomicalStructureModel):
    """Model anterior jugular vein"""

    name: Literal["anterior jugular vein"] = "anterior jugular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37134"] = "EMAPA_37134"


class _Anterior_Tibial_Vein(_MouseAnatomicalStructureModel):
    """Model anterior tibial vein"""

    name: Literal["anterior tibial vein"] = "anterior tibial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37135"] = "EMAPA_37135"


class _Auricular_Vein(_MouseAnatomicalStructureModel):
    """Model auricular vein"""

    name: Literal["auricular vein"] = "auricular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37136"] = "EMAPA_37136"


class _Cardiac_Vein(_MouseAnatomicalStructureModel):
    """Model cardiac vein"""

    name: Literal["cardiac vein"] = "cardiac vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37137"] = "EMAPA_37137"


class _Caudal_Auricular_Vein(_MouseAnatomicalStructureModel):
    """Model caudal auricular vein"""

    name: Literal["caudal auricular vein"] = "caudal auricular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37138"] = "EMAPA_37138"


class _Cerebellar_Vein(_MouseAnatomicalStructureModel):
    """Model cerebellar vein"""

    name: Literal["cerebellar vein"] = "cerebellar vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37139"] = "EMAPA_37139"


class _Cerebral_Vein(_MouseAnatomicalStructureModel):
    """Model cerebral vein"""

    name: Literal["cerebral vein"] = "cerebral vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37140"] = "EMAPA_37140"


class _Digital_Vein(_MouseAnatomicalStructureModel):
    """Model digital vein"""

    name: Literal["digital vein"] = "digital vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37141"] = "EMAPA_37141"


class _Dorsal_Cerebral_Vein(_MouseAnatomicalStructureModel):
    """Model dorsal cerebral vein"""

    name: Literal["dorsal cerebral vein"] = "dorsal cerebral vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37142"] = "EMAPA_37142"


class _Dorsal_Metatarsal_Vein(_MouseAnatomicalStructureModel):
    """Model dorsal metatarsal vein"""

    name: Literal["dorsal metatarsal vein"] = "dorsal metatarsal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37143"] = "EMAPA_37143"


class _External_Iliac_Vein(_MouseAnatomicalStructureModel):
    """Model external iliac vein"""

    name: Literal["external iliac vein"] = "external iliac vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37144"] = "EMAPA_37144"


class _External_Thoracic_Vein(_MouseAnatomicalStructureModel):
    """Model external thoracic vein"""

    name: Literal["external thoracic vein"] = "external thoracic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37145"] = "EMAPA_37145"


class _Gastric_Vein(_MouseAnatomicalStructureModel):
    """Model gastric vein"""

    name: Literal["gastric vein"] = "gastric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37146"] = "EMAPA_37146"


class _Great_Saphenous_Vein(_MouseAnatomicalStructureModel):
    """Model great saphenous vein"""

    name: Literal["great saphenous vein"] = "great saphenous vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37147"] = "EMAPA_37147"


class _Hypogastric_Vein(_MouseAnatomicalStructureModel):
    """Model hypogastric vein"""

    name: Literal["hypogastric vein"] = "hypogastric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37148"] = "EMAPA_37148"


class _Ileal_Vein(_MouseAnatomicalStructureModel):
    """Model ileal vein"""

    name: Literal["ileal vein"] = "ileal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37149"] = "EMAPA_37149"


class _Ileocolic_Vein(_MouseAnatomicalStructureModel):
    """Model ileocolic vein"""

    name: Literal["ileocolic vein"] = "ileocolic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37150"] = "EMAPA_37150"


class _Iliac_Vein(_MouseAnatomicalStructureModel):
    """Model iliac vein"""

    name: Literal["iliac vein"] = "iliac vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37151"] = "EMAPA_37151"


class _Ilio_Lumbar_Vein(_MouseAnatomicalStructureModel):
    """Model ilio-lumbar vein"""

    name: Literal["ilio-lumbar vein"] = "ilio-lumbar vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37152"] = "EMAPA_37152"


class _Inferior_Cerebellar_Vein(_MouseAnatomicalStructureModel):
    """Model inferior cerebellar vein"""

    name: Literal["inferior cerebellar vein"] = "inferior cerebellar vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37153"] = "EMAPA_37153"


class _Inferior_Cerebral_Vein(_MouseAnatomicalStructureModel):
    """Model inferior cerebral vein"""

    name: Literal["inferior cerebral vein"] = "inferior cerebral vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37154"] = "EMAPA_37154"


class _Inferior_External_Pudendal_Vein(_MouseAnatomicalStructureModel):
    """Model inferior external pudendal vein"""

    name: Literal["inferior external pudendal vein"] = "inferior external pudendal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37155"] = "EMAPA_37155"


class _Inferior_Palpebral_Vein(_MouseAnatomicalStructureModel):
    """Model inferior palpebral vein"""

    name: Literal["inferior palpebral vein"] = "inferior palpebral vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37156"] = "EMAPA_37156"


class _Inferior_Phrenic_Vein(_MouseAnatomicalStructureModel):
    """Model inferior phrenic vein"""

    name: Literal["inferior phrenic vein"] = "inferior phrenic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37157"] = "EMAPA_37157"


class _Inferior_Vesical_Vein(_MouseAnatomicalStructureModel):
    """Model inferior vesical vein"""

    name: Literal["inferior vesical vein"] = "inferior vesical vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37158"] = "EMAPA_37158"


class _Internal_Mammary_Vein(_MouseAnatomicalStructureModel):
    """Model internal mammary vein"""

    name: Literal["internal mammary vein"] = "internal mammary vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37159"] = "EMAPA_37159"


class _Jejunal_Vein(_MouseAnatomicalStructureModel):
    """Model jejunal vein"""

    name: Literal["jejunal vein"] = "jejunal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37160"] = "EMAPA_37160"


class _Lateral_Marginal_Vein(_MouseAnatomicalStructureModel):
    """Model lateral marginal vein"""

    name: Literal["lateral marginal vein"] = "lateral marginal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37161"] = "EMAPA_37161"


class _Lateral_Saphenous_Vein(_MouseAnatomicalStructureModel):
    """Model lateral saphenous vein"""

    name: Literal["lateral saphenous vein"] = "lateral saphenous vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37162"] = "EMAPA_37162"


class _Lateral_Thoracic_Vein(_MouseAnatomicalStructureModel):
    """Model lateral thoracic vein"""

    name: Literal["lateral thoracic vein"] = "lateral thoracic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37163"] = "EMAPA_37163"


class _Left_Hepatic_Vein(_MouseAnatomicalStructureModel):
    """Model left hepatic vein"""

    name: Literal["left hepatic vein"] = "left hepatic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37164"] = "EMAPA_37164"


class _Left_Pulmonary_Vein(_MouseAnatomicalStructureModel):
    """Model left pulmonary vein"""

    name: Literal["left pulmonary vein"] = "left pulmonary vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37165"] = "EMAPA_37165"


class _Left_Renal_Vein(_MouseAnatomicalStructureModel):
    """Model left renal vein"""

    name: Literal["left renal vein"] = "left renal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37166"] = "EMAPA_37166"


class _Left_Testicular_Vein(_MouseAnatomicalStructureModel):
    """Model left testicular vein"""

    name: Literal["left testicular vein"] = "left testicular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37167"] = "EMAPA_37167"


class _Masseteric_Vein(_MouseAnatomicalStructureModel):
    """Model masseteric vein"""

    name: Literal["masseteric vein"] = "masseteric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37168"] = "EMAPA_37168"


class _Maxillary_Vein(_MouseAnatomicalStructureModel):
    """Model maxillary vein"""

    name: Literal["maxillary vein"] = "maxillary vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37169"] = "EMAPA_37169"


class _Medial_Marginal_Vein(_MouseAnatomicalStructureModel):
    """Model medial marginal vein"""

    name: Literal["medial marginal vein"] = "medial marginal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37170"] = "EMAPA_37170"


class _Medial_Plantar_Vein(_MouseAnatomicalStructureModel):
    """Model medial plantar vein"""

    name: Literal["medial plantar vein"] = "medial plantar vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37171"] = "EMAPA_37171"


class _Medial_Saphenous_Vein(_MouseAnatomicalStructureModel):
    """Model medial saphenous vein"""

    name: Literal["medial saphenous vein"] = "medial saphenous vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37172"] = "EMAPA_37172"


class _Median_Cubital_Vein(_MouseAnatomicalStructureModel):
    """Model median cubital vein"""

    name: Literal["median cubital vein"] = "median cubital vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37173"] = "EMAPA_37173"


class _Middle_Colic_Vein(_MouseAnatomicalStructureModel):
    """Model middle colic vein"""

    name: Literal["middle colic vein"] = "middle colic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37174"] = "EMAPA_37174"


class _Middle_Hepatic_Vein(_MouseAnatomicalStructureModel):
    """Model middle hepatic vein"""

    name: Literal["middle hepatic vein"] = "middle hepatic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37175"] = "EMAPA_37175"


class _Middle_Temporal_Vein(_MouseAnatomicalStructureModel):
    """Model middle temporal vein"""

    name: Literal["middle temporal vein"] = "middle temporal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37176"] = "EMAPA_37176"


class _Pancreatico_Duodenal_Vein(_MouseAnatomicalStructureModel):
    """Model pancreatico-duodenal vein"""

    name: Literal["pancreatico-duodenal vein"] = "pancreatico-duodenal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37177"] = "EMAPA_37177"


class _Pericardiacophrenic_Vein(_MouseAnatomicalStructureModel):
    """Model pericardiacophrenic vein"""

    name: Literal["pericardiacophrenic vein"] = "pericardiacophrenic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37178"] = "EMAPA_37178"


class _Perineal_Vein(_MouseAnatomicalStructureModel):
    """Model perineal vein"""

    name: Literal["perineal vein"] = "perineal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37179"] = "EMAPA_37179"


class _Phrenic_Vein(_MouseAnatomicalStructureModel):
    """Model phrenic vein"""

    name: Literal["phrenic vein"] = "phrenic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37180"] = "EMAPA_37180"


class _Popliteal_Vein(_MouseAnatomicalStructureModel):
    """Model popliteal vein"""

    name: Literal["popliteal vein"] = "popliteal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37181"] = "EMAPA_37181"


class _Posterior_Facial_Vein(_MouseAnatomicalStructureModel):
    """Model posterior facial vein"""

    name: Literal["posterior facial vein"] = "posterior facial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37182"] = "EMAPA_37182"


class _Posterior_Tibial_Vein(_MouseAnatomicalStructureModel):
    """Model posterior tibial vein"""

    name: Literal["posterior tibial vein"] = "posterior tibial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37183"] = "EMAPA_37183"


class _Pudendal_Vein(_MouseAnatomicalStructureModel):
    """Model pudendal vein"""

    name: Literal["pudendal vein"] = "pudendal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37184"] = "EMAPA_37184"


class _Retinal_Vein(_MouseAnatomicalStructureModel):
    """Model retinal vein"""

    name: Literal["retinal vein"] = "retinal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37185"] = "EMAPA_37185"


class _Saphenous_Vein(_MouseAnatomicalStructureModel):
    """Model saphenous vein"""

    name: Literal["saphenous vein"] = "saphenous vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37186"] = "EMAPA_37186"


class _Small_Saphenous_Vein(_MouseAnatomicalStructureModel):
    """Model small saphenous vein"""

    name: Literal["small saphenous vein"] = "small saphenous vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37187"] = "EMAPA_37187"


class _Submental_Vein(_MouseAnatomicalStructureModel):
    """Model submental vein"""

    name: Literal["submental vein"] = "submental vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37188"] = "EMAPA_37188"


class _Subcostal_Vein(_MouseAnatomicalStructureModel):
    """Model subcostal vein"""

    name: Literal["subcostal vein"] = "subcostal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37189"] = "EMAPA_37189"


class _Subscapular_Vein(_MouseAnatomicalStructureModel):
    """Model subscapular vein"""

    name: Literal["subscapular vein"] = "subscapular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37190"] = "EMAPA_37190"


class _Superior_Cerebellar_Vein(_MouseAnatomicalStructureModel):
    """Model superior cerebellar vein"""

    name: Literal["superior cerebellar vein"] = "superior cerebellar vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37191"] = "EMAPA_37191"


class _Superior_External_Pudendal_Vein(_MouseAnatomicalStructureModel):
    """Model superior external pudendal vein"""

    name: Literal["superior external pudendal vein"] = "superior external pudendal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37192"] = "EMAPA_37192"


class _Superior_Intercostal_Vein(_MouseAnatomicalStructureModel):
    """Model superior intercostal vein"""

    name: Literal["superior intercostal vein"] = "superior intercostal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37193"] = "EMAPA_37193"


class _Superior_Pancreatico_Duodenal_Vein(_MouseAnatomicalStructureModel):
    """Model superior pancreatico-duodenal vein"""

    name: Literal["superior pancreatico-duodenal vein"] = "superior pancreatico-duodenal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37194"] = "EMAPA_37194"


class _Supraorbital_Vein(_MouseAnatomicalStructureModel):
    """Model supraorbital vein"""

    name: Literal["supraorbital vein"] = "supraorbital vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37195"] = "EMAPA_37195"


class _Temporal_Vein(_MouseAnatomicalStructureModel):
    """Model temporal vein"""

    name: Literal["temporal vein"] = "temporal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37196"] = "EMAPA_37196"


class _Thoracic_Vein(_MouseAnatomicalStructureModel):
    """Model thoracic vein"""

    name: Literal["thoracic vein"] = "thoracic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37197"] = "EMAPA_37197"


class _Thoracodorsal_Vein(_MouseAnatomicalStructureModel):
    """Model thoracodorsal vein"""

    name: Literal["thoracodorsal vein"] = "thoracodorsal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37198"] = "EMAPA_37198"


class _Tibial_Vein(_MouseAnatomicalStructureModel):
    """Model tibial vein"""

    name: Literal["tibial vein"] = "tibial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37199"] = "EMAPA_37199"


class _Transverse_Facial_Vein(_MouseAnatomicalStructureModel):
    """Model transverse facial vein"""

    name: Literal["transverse facial vein"] = "transverse facial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37200"] = "EMAPA_37200"


class _Vein_Of_Clitoris(_MouseAnatomicalStructureModel):
    """Model vein of clitoris"""

    name: Literal["vein of clitoris"] = "vein of clitoris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37201"] = "EMAPA_37201"


class _Vein_Of_Lower_Lip(_MouseAnatomicalStructureModel):
    """Model vein of lower lip"""

    name: Literal["vein of lower lip"] = "vein of lower lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37202"] = "EMAPA_37202"


class _Vein_Of_Trabecular_Bone(_MouseAnatomicalStructureModel):
    """Model vein of trabecular bone"""

    name: Literal["vein of trabecular bone"] = "vein of trabecular bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37203"] = "EMAPA_37203"


class _Vein_Of_Upper_Lip(_MouseAnatomicalStructureModel):
    """Model vein of upper lip"""

    name: Literal["vein of upper lip"] = "vein of upper lip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37204"] = "EMAPA_37204"


class _Vesical_Vein(_MouseAnatomicalStructureModel):
    """Model vesical vein"""

    name: Literal["vesical vein"] = "vesical vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37205"] = "EMAPA_37205"


class _Common_Hepatic_Artery(_MouseAnatomicalStructureModel):
    """Model common hepatic artery"""

    name: Literal["common hepatic artery"] = "common hepatic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37206"] = "EMAPA_37206"


class _Common_Palmar_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model common palmar digital artery"""

    name: Literal["common palmar digital artery"] = "common palmar digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37207"] = "EMAPA_37207"


class _Common_Plantar_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model common plantar digital artery"""

    name: Literal["common plantar digital artery"] = "common plantar digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37208"] = "EMAPA_37208"


class _Forelimb_Common_Dorsal_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model forelimb common dorsal digital artery"""

    name: Literal["forelimb common dorsal digital artery"] = "forelimb common dorsal digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37209"] = "EMAPA_37209"


class _Forelimb_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model forelimb digital artery"""

    name: Literal["forelimb digital artery"] = "forelimb digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37210"] = "EMAPA_37210"


class _Forelimb_Proper_Dorsal_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model forelimb proper dorsal digital artery"""

    name: Literal["forelimb proper dorsal digital artery"] = "forelimb proper dorsal digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37211"] = "EMAPA_37211"


class _Hindlimb_Common_Dorsal_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model hindlimb common dorsal digital artery"""

    name: Literal["hindlimb common dorsal digital artery"] = "hindlimb common dorsal digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37212"] = "EMAPA_37212"


class _Hindlimb_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model hindlimb digital artery"""

    name: Literal["hindlimb digital artery"] = "hindlimb digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37213"] = "EMAPA_37213"


class _Hindlimb_Proper_Dorsal_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model hindlimb proper dorsal digital artery"""

    name: Literal["hindlimb proper dorsal digital artery"] = "hindlimb proper dorsal digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37214"] = "EMAPA_37214"


class _Profunda_Brachii_Artery(_MouseAnatomicalStructureModel):
    """Model profunda brachii artery"""

    name: Literal["profunda brachii artery"] = "profunda brachii artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37215"] = "EMAPA_37215"


class _Profunda_Femoris_Artery(_MouseAnatomicalStructureModel):
    """Model profunda femoris artery"""

    name: Literal["profunda femoris artery"] = "profunda femoris artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37216"] = "EMAPA_37216"


class _Proper_Hepatic_Artery(_MouseAnatomicalStructureModel):
    """Model proper hepatic artery"""

    name: Literal["proper hepatic artery"] = "proper hepatic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37217"] = "EMAPA_37217"


class _Proper_Palmar_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model proper palmar digital artery"""

    name: Literal["proper palmar digital artery"] = "proper palmar digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37218"] = "EMAPA_37218"


class _Proper_Plantar_Digital_Artery(_MouseAnatomicalStructureModel):
    """Model proper plantar digital artery"""

    name: Literal["proper plantar digital artery"] = "proper plantar digital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37219"] = "EMAPA_37219"


class _Saphenous_Artery(_MouseAnatomicalStructureModel):
    """Model saphenous artery"""

    name: Literal["saphenous artery"] = "saphenous artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37220"] = "EMAPA_37220"


class _Common_Plantar_Vein(_MouseAnatomicalStructureModel):
    """Model common plantar vein"""

    name: Literal["common plantar vein"] = "common plantar vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37221"] = "EMAPA_37221"


class _Common_Palmar_Digital_Vein(_MouseAnatomicalStructureModel):
    """Model common palmar digital vein"""

    name: Literal["common palmar digital vein"] = "common palmar digital vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37222"] = "EMAPA_37222"


class _Forelimb_Digital_Vein(_MouseAnatomicalStructureModel):
    """Model forelimb digital vein"""

    name: Literal["forelimb digital vein"] = "forelimb digital vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37223"] = "EMAPA_37223"


class _Hindlimb_Digital_Vein(_MouseAnatomicalStructureModel):
    """Model hindlimb digital vein"""

    name: Literal["hindlimb digital vein"] = "hindlimb digital vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37224"] = "EMAPA_37224"


class _Great_Vein_Of_Heart(_MouseAnatomicalStructureModel):
    """Model great vein of heart"""

    name: Literal["great vein of heart"] = "great vein of heart"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37225"] = "EMAPA_37225"


class _Lienal_Vein(_MouseAnatomicalStructureModel):
    """Model lienal vein"""

    name: Literal["lienal vein"] = "lienal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37226"] = "EMAPA_37226"


class _Naso_Frontal_Vein(_MouseAnatomicalStructureModel):
    """Model naso-frontal vein"""

    name: Literal["naso-frontal vein"] = "naso-frontal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37227"] = "EMAPA_37227"


class _Paraumbilical_Vein(_MouseAnatomicalStructureModel):
    """Model paraumbilical vein"""

    name: Literal["paraumbilical vein"] = "paraumbilical vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37228"] = "EMAPA_37228"


class _Proper_Palmar_Vein(_MouseAnatomicalStructureModel):
    """Model proper palmar vein"""

    name: Literal["proper palmar vein"] = "proper palmar vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37229"] = "EMAPA_37229"


class _Proper_Plantar_Vein(_MouseAnatomicalStructureModel):
    """Model proper plantar vein"""

    name: Literal["proper plantar vein"] = "proper plantar vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37230"] = "EMAPA_37230"


class _Sural_Vein(_MouseAnatomicalStructureModel):
    """Model sural vein"""

    name: Literal["sural vein"] = "sural vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37231"] = "EMAPA_37231"


class _Chest(_MouseAnatomicalStructureModel):
    """Model chest"""

    name: Literal["chest"] = "chest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37232"] = "EMAPA_37232"


class _Chest_Wall(_MouseAnatomicalStructureModel):
    """Model chest wall"""

    name: Literal["chest wall"] = "chest wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37233"] = "EMAPA_37233"


class _Upper_Back(_MouseAnatomicalStructureModel):
    """Model upper back"""

    name: Literal["upper back"] = "upper back"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37234"] = "EMAPA_37234"


class _Pelvic_Cavity(_MouseAnatomicalStructureModel):
    """Model pelvic cavity"""

    name: Literal["pelvic cavity"] = "pelvic cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37235"] = "EMAPA_37235"


class _Neck_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model neck blood vessel"""

    name: Literal["neck blood vessel"] = "neck blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37236"] = "EMAPA_37236"


class _Trunk_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model trunk blood vessel"""

    name: Literal["trunk blood vessel"] = "trunk blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37237"] = "EMAPA_37237"


class _Thoracic_Segment_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model thoracic segment blood vessel"""

    name: Literal["thoracic segment blood vessel"] = "thoracic segment blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37238"] = "EMAPA_37238"


class _Chest_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model chest blood vessel"""

    name: Literal["chest blood vessel"] = "chest blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37239"] = "EMAPA_37239"


class _Thoracic_Cavity_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model thoracic cavity blood vessel"""

    name: Literal["thoracic cavity blood vessel"] = "thoracic cavity blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37240"] = "EMAPA_37240"


class _Thoracic_Cavity_Artery(_MouseAnatomicalStructureModel):
    """Model thoracic cavity artery"""

    name: Literal["thoracic cavity artery"] = "thoracic cavity artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37241"] = "EMAPA_37241"


class _Thoracic_Cavity_Vein(_MouseAnatomicalStructureModel):
    """Model thoracic cavity vein"""

    name: Literal["thoracic cavity vein"] = "thoracic cavity vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37242"] = "EMAPA_37242"


class _Back_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model back blood vessel"""

    name: Literal["back blood vessel"] = "back blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37243"] = "EMAPA_37243"


class _Pelvis_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model pelvis blood vessel"""

    name: Literal["pelvis blood vessel"] = "pelvis blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37244"] = "EMAPA_37244"


class _Craniocervical_Region_Bone(_MouseAnatomicalStructureModel):
    """Model craniocervical region bone"""

    name: Literal["craniocervical region bone"] = "craniocervical region bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37245"] = "EMAPA_37245"


class _Neck_Bone(_MouseAnatomicalStructureModel):
    """Model neck bone"""

    name: Literal["neck bone"] = "neck bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37246"] = "EMAPA_37246"


class _Thoracic_Segment_Bone(_MouseAnatomicalStructureModel):
    """Model thoracic segment bone"""

    name: Literal["thoracic segment bone"] = "thoracic segment bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37247"] = "EMAPA_37247"


class _Back_Bone(_MouseAnatomicalStructureModel):
    """Model back bone"""

    name: Literal["back bone"] = "back bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37248"] = "EMAPA_37248"


class _Pelvis_Bone(_MouseAnatomicalStructureModel):
    """Model pelvis bone"""

    name: Literal["pelvis bone"] = "pelvis bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37249"] = "EMAPA_37249"


class _Neck_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model neck connective tissue"""

    name: Literal["neck connective tissue"] = "neck connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37250"] = "EMAPA_37250"


class _Neck_Cartilage(_MouseAnatomicalStructureModel):
    """Model neck cartilage"""

    name: Literal["neck cartilage"] = "neck cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37251"] = "EMAPA_37251"


class _Trunk_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model trunk connective tissue"""

    name: Literal["trunk connective tissue"] = "trunk connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37252"] = "EMAPA_37252"


class _Thoracic_Segment_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model thoracic segment connective tissue"""

    name: Literal["thoracic segment connective tissue"] = "thoracic segment connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37253"] = "EMAPA_37253"


class _Chest_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model chest connective tissue"""

    name: Literal["chest connective tissue"] = "chest connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37254"] = "EMAPA_37254"


class _Thoracic_Cavity_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model thoracic cavity connective tissue"""

    name: Literal["thoracic cavity connective tissue"] = "thoracic cavity connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37255"] = "EMAPA_37255"


class _Back_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model back connective tissue"""

    name: Literal["back connective tissue"] = "back connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37256"] = "EMAPA_37256"


class _Pelvis_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model pelvis connective tissue"""

    name: Literal["pelvis connective tissue"] = "pelvis connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37257"] = "EMAPA_37257"


class _Axial_Mesoderm(_MouseAnatomicalStructureModel):
    """Model axial mesoderm"""

    name: Literal["axial mesoderm"] = "axial mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37258"] = "EMAPA_37258"


class _Craniocervical_Region_Muscle(_MouseAnatomicalStructureModel):
    """Model craniocervical region muscle"""

    name: Literal["craniocervical region muscle"] = "craniocervical region muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37259"] = "EMAPA_37259"


class _Thoracic_Segment_Muscle(_MouseAnatomicalStructureModel):
    """Model thoracic segment muscle"""

    name: Literal["thoracic segment muscle"] = "thoracic segment muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37260"] = "EMAPA_37260"


class _Upper_Back_Muscle(_MouseAnatomicalStructureModel):
    """Model upper back muscle"""

    name: Literal["upper back muscle"] = "upper back muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37261"] = "EMAPA_37261"


class _Lower_Back_Muscle(_MouseAnatomicalStructureModel):
    """Model lower back muscle"""

    name: Literal["lower back muscle"] = "lower back muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37262"] = "EMAPA_37262"


class _Neck_Nerve(_MouseAnatomicalStructureModel):
    """Model neck nerve"""

    name: Literal["neck nerve"] = "neck nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37263"] = "EMAPA_37263"


class _Trunk_Nerve(_MouseAnatomicalStructureModel):
    """Model trunk nerve"""

    name: Literal["trunk nerve"] = "trunk nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37264"] = "EMAPA_37264"


class _Thoracic_Segment_Nerve(_MouseAnatomicalStructureModel):
    """Model thoracic segment nerve"""

    name: Literal["thoracic segment nerve"] = "thoracic segment nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37265"] = "EMAPA_37265"


class _Chest_Nerve(_MouseAnatomicalStructureModel):
    """Model chest nerve"""

    name: Literal["chest nerve"] = "chest nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37266"] = "EMAPA_37266"


class _Thoracic_Cavity_Nerve(_MouseAnatomicalStructureModel):
    """Model thoracic cavity nerve"""

    name: Literal["thoracic cavity nerve"] = "thoracic cavity nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37267"] = "EMAPA_37267"


class _Back_Nerve(_MouseAnatomicalStructureModel):
    """Model back nerve"""

    name: Literal["back nerve"] = "back nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37268"] = "EMAPA_37268"


class _Pelvis_Nerve(_MouseAnatomicalStructureModel):
    """Model pelvis nerve"""

    name: Literal["pelvis nerve"] = "pelvis nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37269"] = "EMAPA_37269"


class _Trunk_Organ(_MouseAnatomicalStructureModel):
    """Model trunk organ"""

    name: Literal["trunk organ"] = "trunk organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37270"] = "EMAPA_37270"


class _Thoracic_Segment_Organ(_MouseAnatomicalStructureModel):
    """Model thoracic segment organ"""

    name: Literal["thoracic segment organ"] = "thoracic segment organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37271"] = "EMAPA_37271"


class _Chest_Organ(_MouseAnatomicalStructureModel):
    """Model chest organ"""

    name: Literal["chest organ"] = "chest organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37272"] = "EMAPA_37272"


class _Thoracic_Cavity_Organ(_MouseAnatomicalStructureModel):
    """Model thoracic cavity organ"""

    name: Literal["thoracic cavity organ"] = "thoracic cavity organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37273"] = "EMAPA_37273"


class _Back_Organ(_MouseAnatomicalStructureModel):
    """Model back organ"""

    name: Literal["back organ"] = "back organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37274"] = "EMAPA_37274"


class _Pelvis_Organ(_MouseAnatomicalStructureModel):
    """Model pelvis organ"""

    name: Literal["pelvis organ"] = "pelvis organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37275"] = "EMAPA_37275"


class _Craniocervical_Region_Skin(_MouseAnatomicalStructureModel):
    """Model craniocervical region skin"""

    name: Literal["craniocervical region skin"] = "craniocervical region skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37276"] = "EMAPA_37276"


class _Neck_Skin(_MouseAnatomicalStructureModel):
    """Model neck skin"""

    name: Literal["neck skin"] = "neck skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37277"] = "EMAPA_37277"


class _Trunk_Skin(_MouseAnatomicalStructureModel):
    """Model trunk skin"""

    name: Literal["trunk skin"] = "trunk skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37278"] = "EMAPA_37278"


class _Chest_Skin(_MouseAnatomicalStructureModel):
    """Model chest skin"""

    name: Literal["chest skin"] = "chest skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37279"] = "EMAPA_37279"


class _Upper_Back_Skin(_MouseAnatomicalStructureModel):
    """Model upper back skin"""

    name: Literal["upper back skin"] = "upper back skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37280"] = "EMAPA_37280"


class _Lower_Back_Skin(_MouseAnatomicalStructureModel):
    """Model lower back skin"""

    name: Literal["lower back skin"] = "lower back skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37281"] = "EMAPA_37281"


class _Pelvis_Skin(_MouseAnatomicalStructureModel):
    """Model pelvis skin"""

    name: Literal["pelvis skin"] = "pelvis skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37282"] = "EMAPA_37282"


class _Appendage(_MouseAnatomicalStructureModel):
    """Model appendage"""

    name: Literal["appendage"] = "appendage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37283"] = "EMAPA_37283"


class _Metacarpal_Metatarsal_Bone(_MouseAnatomicalStructureModel):
    """Model metacarpal/metatarsal bone"""

    name: Literal["metacarpal/metatarsal bone"] = "metacarpal/metatarsal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37284"] = "EMAPA_37284"


class _Limb_Digit_1(_MouseAnatomicalStructureModel):
    """Model limb digit 1"""

    name: Literal["limb digit 1"] = "limb digit 1"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37285"] = "EMAPA_37285"


class _Limb_Digit_2(_MouseAnatomicalStructureModel):
    """Model limb digit 2"""

    name: Literal["limb digit 2"] = "limb digit 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37286"] = "EMAPA_37286"


class _Limb_Digit_3(_MouseAnatomicalStructureModel):
    """Model limb digit 3"""

    name: Literal["limb digit 3"] = "limb digit 3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37287"] = "EMAPA_37287"


class _Limb_Digit_4(_MouseAnatomicalStructureModel):
    """Model limb digit 4"""

    name: Literal["limb digit 4"] = "limb digit 4"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37288"] = "EMAPA_37288"


class _Limb_Digit_5(_MouseAnatomicalStructureModel):
    """Model limb digit 5"""

    name: Literal["limb digit 5"] = "limb digit 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37289"] = "EMAPA_37289"


class _Digit_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model digit connective tissue"""

    name: Literal["digit connective tissue"] = "digit connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37290"] = "EMAPA_37290"


class _Limb_Nerve(_MouseAnatomicalStructureModel):
    """Model limb nerve"""

    name: Literal["limb nerve"] = "limb nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37291"] = "EMAPA_37291"


class _Forelimb_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model forelimb blood vessel"""

    name: Literal["forelimb blood vessel"] = "forelimb blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37292"] = "EMAPA_37292"


class _Arm_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model arm blood vessel"""

    name: Literal["arm blood vessel"] = "arm blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37293"] = "EMAPA_37293"


class _Upper_Arm_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model upper arm blood vessel"""

    name: Literal["upper arm blood vessel"] = "upper arm blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37294"] = "EMAPA_37294"


class _Forearm_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model forearm blood vessel"""

    name: Literal["forearm blood vessel"] = "forearm blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37295"] = "EMAPA_37295"


class _Hand_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model hand blood vessel"""

    name: Literal["hand blood vessel"] = "hand blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37296"] = "EMAPA_37296"


class _Forelimb_Digit_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model forelimb digit blood vessel"""

    name: Literal["forelimb digit blood vessel"] = "forelimb digit blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37297"] = "EMAPA_37297"


class _Hindlimb_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model hindlimb blood vessel"""

    name: Literal["hindlimb blood vessel"] = "hindlimb blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37298"] = "EMAPA_37298"


class _Upper_Leg_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model upper leg blood vessel"""

    name: Literal["upper leg blood vessel"] = "upper leg blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37299"] = "EMAPA_37299"


class _Lower_Leg_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model lower leg blood vessel"""

    name: Literal["lower leg blood vessel"] = "lower leg blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37300"] = "EMAPA_37300"


class _Foot_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model foot blood vessel"""

    name: Literal["foot blood vessel"] = "foot blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37301"] = "EMAPA_37301"


class _Hindlimb_Digit_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model hindlimb digit blood vessel"""

    name: Literal["hindlimb digit blood vessel"] = "hindlimb digit blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37302"] = "EMAPA_37302"


class _Arm_Bone(_MouseAnatomicalStructureModel):
    """Model arm bone"""

    name: Literal["arm bone"] = "arm bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37303"] = "EMAPA_37303"


class _Leg_Bone(_MouseAnatomicalStructureModel):
    """Model leg bone"""

    name: Literal["leg bone"] = "leg bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37304"] = "EMAPA_37304"


class _Forelimb_Digit_Bone(_MouseAnatomicalStructureModel):
    """Model forelimb digit bone"""

    name: Literal["forelimb digit bone"] = "forelimb digit bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37305"] = "EMAPA_37305"


class _Forelimb_Middle_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb middle phalanx"""

    name: Literal["forelimb middle phalanx"] = "forelimb middle phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37306"] = "EMAPA_37306"


class _Forelimb_Proximal_Phalanx(_MouseAnatomicalStructureModel):
    """Model forelimb proximal phalanx"""

    name: Literal["forelimb proximal phalanx"] = "forelimb proximal phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37307"] = "EMAPA_37307"


class _Hip_Bone(_MouseAnatomicalStructureModel):
    """Model hip bone"""

    name: Literal["hip bone"] = "hip bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37308"] = "EMAPA_37308"


class _Hindlimb_Digit_Bone(_MouseAnatomicalStructureModel):
    """Model hindlimb digit bone"""

    name: Literal["hindlimb digit bone"] = "hindlimb digit bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37309"] = "EMAPA_37309"


class _Hindlimb_Distal_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb distal phalanx"""

    name: Literal["hindlimb distal phalanx"] = "hindlimb distal phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37310"] = "EMAPA_37310"


class _Hindlimb_Middle_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb middle phalanx"""

    name: Literal["hindlimb middle phalanx"] = "hindlimb middle phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37311"] = "EMAPA_37311"


class _Hindlimb_Proximal_Phalanx(_MouseAnatomicalStructureModel):
    """Model hindlimb proximal phalanx"""

    name: Literal["hindlimb proximal phalanx"] = "hindlimb proximal phalanx"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37312"] = "EMAPA_37312"


class _Limb_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model limb connective tissue"""

    name: Literal["limb connective tissue"] = "limb connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37313"] = "EMAPA_37313"


class _Forelimb_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model forelimb connective tissue"""

    name: Literal["forelimb connective tissue"] = "forelimb connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37314"] = "EMAPA_37314"


class _Shoulder_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model shoulder connective tissue"""

    name: Literal["shoulder connective tissue"] = "shoulder connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37315"] = "EMAPA_37315"


class _Arm_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model arm connective tissue"""

    name: Literal["arm connective tissue"] = "arm connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37316"] = "EMAPA_37316"


class _Upper_Arm_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model upper arm connective tissue"""

    name: Literal["upper arm connective tissue"] = "upper arm connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37317"] = "EMAPA_37317"


class _Elbow_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model elbow connective tissue"""

    name: Literal["elbow connective tissue"] = "elbow connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37318"] = "EMAPA_37318"


class _Forearm_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model forearm connective tissue"""

    name: Literal["forearm connective tissue"] = "forearm connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37319"] = "EMAPA_37319"


class _Wrist_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model wrist connective tissue"""

    name: Literal["wrist connective tissue"] = "wrist connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37320"] = "EMAPA_37320"


class _Forelimb_Digit_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model forelimb digit connective tissue"""

    name: Literal["forelimb digit connective tissue"] = "forelimb digit connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37321"] = "EMAPA_37321"


class _Hindlimb_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model hindlimb connective tissue"""

    name: Literal["hindlimb connective tissue"] = "hindlimb connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37322"] = "EMAPA_37322"


class _Hip_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model hip connective tissue"""

    name: Literal["hip connective tissue"] = "hip connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37323"] = "EMAPA_37323"


class _Leg_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model leg connective tissue"""

    name: Literal["leg connective tissue"] = "leg connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37324"] = "EMAPA_37324"


class _Upper_Leg_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model upper leg connective tissue"""

    name: Literal["upper leg connective tissue"] = "upper leg connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37325"] = "EMAPA_37325"


class _Knee_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model knee connective tissue"""

    name: Literal["knee connective tissue"] = "knee connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37326"] = "EMAPA_37326"


class _Lower_Leg_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model lower leg connective tissue"""

    name: Literal["lower leg connective tissue"] = "lower leg connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37327"] = "EMAPA_37327"


class _Ankle_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model ankle connective tissue"""

    name: Literal["ankle connective tissue"] = "ankle connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37328"] = "EMAPA_37328"


class _Foot_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model foot connective tissue"""

    name: Literal["foot connective tissue"] = "foot connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37329"] = "EMAPA_37329"


class _Hindlimb_Digit_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model hindlimb digit connective tissue"""

    name: Literal["hindlimb digit connective tissue"] = "hindlimb digit connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37330"] = "EMAPA_37330"


class _Forelimb_Digit_Muscle(_MouseAnatomicalStructureModel):
    """Model forelimb digit muscle"""

    name: Literal["forelimb digit muscle"] = "forelimb digit muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37331"] = "EMAPA_37331"


class _Hip_Muscle(_MouseAnatomicalStructureModel):
    """Model hip muscle"""

    name: Literal["hip muscle"] = "hip muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37332"] = "EMAPA_37332"


class _Hindlimb_Digit_Muscle(_MouseAnatomicalStructureModel):
    """Model hindlimb digit muscle"""

    name: Literal["hindlimb digit muscle"] = "hindlimb digit muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37333"] = "EMAPA_37333"


class _Forelimb_Nerve(_MouseAnatomicalStructureModel):
    """Model forelimb nerve"""

    name: Literal["forelimb nerve"] = "forelimb nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37334"] = "EMAPA_37334"


class _Shoulder_Nerve(_MouseAnatomicalStructureModel):
    """Model shoulder nerve"""

    name: Literal["shoulder nerve"] = "shoulder nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37335"] = "EMAPA_37335"


class _Arm_Nerve(_MouseAnatomicalStructureModel):
    """Model arm nerve"""

    name: Literal["arm nerve"] = "arm nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37336"] = "EMAPA_37336"


class _Upper_Arm_Nerve(_MouseAnatomicalStructureModel):
    """Model upper arm nerve"""

    name: Literal["upper arm nerve"] = "upper arm nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37337"] = "EMAPA_37337"


class _Forearm_Nerve(_MouseAnatomicalStructureModel):
    """Model forearm nerve"""

    name: Literal["forearm nerve"] = "forearm nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37338"] = "EMAPA_37338"


class _Wrist_Nerve(_MouseAnatomicalStructureModel):
    """Model wrist nerve"""

    name: Literal["wrist nerve"] = "wrist nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37339"] = "EMAPA_37339"


class _Hand_Nerve(_MouseAnatomicalStructureModel):
    """Model hand nerve"""

    name: Literal["hand nerve"] = "hand nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37340"] = "EMAPA_37340"


class _Forelimb_Digit_Nerve(_MouseAnatomicalStructureModel):
    """Model forelimb digit nerve"""

    name: Literal["forelimb digit nerve"] = "forelimb digit nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37341"] = "EMAPA_37341"


class _Hindlimb_Nerve(_MouseAnatomicalStructureModel):
    """Model hindlimb nerve"""

    name: Literal["hindlimb nerve"] = "hindlimb nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37342"] = "EMAPA_37342"


class _Leg_Nerve(_MouseAnatomicalStructureModel):
    """Model leg nerve"""

    name: Literal["leg nerve"] = "leg nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37343"] = "EMAPA_37343"


class _Upper_Leg_Nerve(_MouseAnatomicalStructureModel):
    """Model upper leg nerve"""

    name: Literal["upper leg nerve"] = "upper leg nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37344"] = "EMAPA_37344"


class _Lower_Leg_Nerve(_MouseAnatomicalStructureModel):
    """Model lower leg nerve"""

    name: Literal["lower leg nerve"] = "lower leg nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37345"] = "EMAPA_37345"


class _Ankle_Nerve(_MouseAnatomicalStructureModel):
    """Model ankle nerve"""

    name: Literal["ankle nerve"] = "ankle nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37346"] = "EMAPA_37346"


class _Foot_Nerve(_MouseAnatomicalStructureModel):
    """Model foot nerve"""

    name: Literal["foot nerve"] = "foot nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37347"] = "EMAPA_37347"


class _Hindlimb_Digit_Nerve(_MouseAnatomicalStructureModel):
    """Model hindlimb digit nerve"""

    name: Literal["hindlimb digit nerve"] = "hindlimb digit nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37348"] = "EMAPA_37348"


class _Axilla_Skin(_MouseAnatomicalStructureModel):
    """Model axilla skin"""

    name: Literal["axilla skin"] = "axilla skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37349"] = "EMAPA_37349"


class _Arm_Skin(_MouseAnatomicalStructureModel):
    """Model arm skin"""

    name: Literal["arm skin"] = "arm skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37350"] = "EMAPA_37350"


class _Wrist_Skin(_MouseAnatomicalStructureModel):
    """Model wrist skin"""

    name: Literal["wrist skin"] = "wrist skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37351"] = "EMAPA_37351"


class _Leg_Skin(_MouseAnatomicalStructureModel):
    """Model leg skin"""

    name: Literal["leg skin"] = "leg skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37352"] = "EMAPA_37352"


class _Ankle_Skin(_MouseAnatomicalStructureModel):
    """Model ankle skin"""

    name: Literal["ankle skin"] = "ankle skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37353"] = "EMAPA_37353"


class _Heel_Skin(_MouseAnatomicalStructureModel):
    """Model heel skin"""

    name: Literal["heel skin"] = "heel skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37354"] = "EMAPA_37354"


class _Metapodial_Pad_Epidermis(_MouseAnatomicalStructureModel):
    """Model metapodial pad epidermis"""

    name: Literal["metapodial pad epidermis"] = "metapodial pad epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37355"] = "EMAPA_37355"


class _Left_Adrenal_Gland(_MouseAnatomicalStructureModel):
    """Model left adrenal gland"""

    name: Literal["left adrenal gland"] = "left adrenal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37356"] = "EMAPA_37356"


class _Right_Adrenal_Gland(_MouseAnatomicalStructureModel):
    """Model right adrenal gland"""

    name: Literal["right adrenal gland"] = "right adrenal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37357"] = "EMAPA_37357"


class _Left_Branch_Of_Atrioventricular_Bundle(_MouseAnatomicalStructureModel):
    """Model left branch of atrioventricular bundle"""

    name: Literal["left branch of atrioventricular bundle"] = "left branch of atrioventricular bundle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37358"] = "EMAPA_37358"


class _Right_Branch_Of_Atrioventricular_Bundle(_MouseAnatomicalStructureModel):
    """Model right branch of atrioventricular bundle"""

    name: Literal["right branch of atrioventricular bundle"] = "right branch of atrioventricular bundle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37359"] = "EMAPA_37359"


class _Left_Outer_Ear(_MouseAnatomicalStructureModel):
    """Model left outer ear"""

    name: Literal["left outer ear"] = "left outer ear"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37360"] = "EMAPA_37360"


class _Right_Outer_Ear(_MouseAnatomicalStructureModel):
    """Model right outer ear"""

    name: Literal["right outer ear"] = "right outer ear"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37361"] = "EMAPA_37361"


class _Left_Eye(_MouseAnatomicalStructureModel):
    """Model left eye"""

    name: Literal["left eye"] = "left eye"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37362"] = "EMAPA_37362"


class _Right_Eye(_MouseAnatomicalStructureModel):
    """Model right eye"""

    name: Literal["right eye"] = "right eye"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37363"] = "EMAPA_37363"


class _Left_Main_Bronchus(_MouseAnatomicalStructureModel):
    """Model left main bronchus"""

    name: Literal["left main bronchus"] = "left main bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37364"] = "EMAPA_37364"


class _Right_Main_Bronchus(_MouseAnatomicalStructureModel):
    """Model right main bronchus"""

    name: Literal["right main bronchus"] = "right main bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37365"] = "EMAPA_37365"


class _Left_Ovary(_MouseAnatomicalStructureModel):
    """Model left ovary"""

    name: Literal["left ovary"] = "left ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37366"] = "EMAPA_37366"


class _Right_Ovary(_MouseAnatomicalStructureModel):
    """Model right ovary"""

    name: Literal["right ovary"] = "right ovary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37367"] = "EMAPA_37367"


class _Left_Oviduct(_MouseAnatomicalStructureModel):
    """Model left oviduct"""

    name: Literal["left oviduct"] = "left oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37368"] = "EMAPA_37368"


class _Right_Oviduct(_MouseAnatomicalStructureModel):
    """Model right oviduct"""

    name: Literal["right oviduct"] = "right oviduct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37369"] = "EMAPA_37369"


class _Left_Testis(_MouseAnatomicalStructureModel):
    """Model left testis"""

    name: Literal["left testis"] = "left testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37370"] = "EMAPA_37370"


class _Right_Testis(_MouseAnatomicalStructureModel):
    """Model right testis"""

    name: Literal["right testis"] = "right testis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37371"] = "EMAPA_37371"


class _Left_Ureter(_MouseAnatomicalStructureModel):
    """Model left ureter"""

    name: Literal["left ureter"] = "left ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37372"] = "EMAPA_37372"


class _Right_Ureter(_MouseAnatomicalStructureModel):
    """Model right ureter"""

    name: Literal["right ureter"] = "right ureter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37373"] = "EMAPA_37373"


class _Left_Uterine_Horn(_MouseAnatomicalStructureModel):
    """Model left uterine horn"""

    name: Literal["left uterine horn"] = "left uterine horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37374"] = "EMAPA_37374"


class _Right_Uterine_Horn(_MouseAnatomicalStructureModel):
    """Model right uterine horn"""

    name: Literal["right uterine horn"] = "right uterine horn"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37375"] = "EMAPA_37375"


class _Right_Hepatic_Artery(_MouseAnatomicalStructureModel):
    """Model right hepatic artery"""

    name: Literal["right hepatic artery"] = "right hepatic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37376"] = "EMAPA_37376"


class _Right_Hepatic_Vein(_MouseAnatomicalStructureModel):
    """Model right hepatic vein"""

    name: Literal["right hepatic vein"] = "right hepatic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37377"] = "EMAPA_37377"


class _Right_Pulmonary_Artery(_MouseAnatomicalStructureModel):
    """Model right pulmonary artery"""

    name: Literal["right pulmonary artery"] = "right pulmonary artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37378"] = "EMAPA_37378"


class _Right_Pulmonary_Vein(_MouseAnatomicalStructureModel):
    """Model right pulmonary vein"""

    name: Literal["right pulmonary vein"] = "right pulmonary vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37379"] = "EMAPA_37379"


class _Right_Renal_Artery(_MouseAnatomicalStructureModel):
    """Model right renal artery"""

    name: Literal["right renal artery"] = "right renal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37380"] = "EMAPA_37380"


class _Right_Renal_Vein(_MouseAnatomicalStructureModel):
    """Model right renal vein"""

    name: Literal["right renal vein"] = "right renal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37381"] = "EMAPA_37381"


class _Right_Spermatic_Artery(_MouseAnatomicalStructureModel):
    """Model right spermatic artery"""

    name: Literal["right spermatic artery"] = "right spermatic artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37382"] = "EMAPA_37382"


class _Right_Testicular_Vein(_MouseAnatomicalStructureModel):
    """Model right testicular vein"""

    name: Literal["right testicular vein"] = "right testicular vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37383"] = "EMAPA_37383"


class _Right_Subclavian_Artery(_MouseAnatomicalStructureModel):
    """Model right subclavian artery"""

    name: Literal["right subclavian artery"] = "right subclavian artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37384"] = "EMAPA_37384"


class _Pampiniform_Plexus(_MouseAnatomicalStructureModel):
    """Model pampiniform plexus"""

    name: Literal["pampiniform plexus"] = "pampiniform plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37385"] = "EMAPA_37385"


class _Auricular_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model auricular blood vessel"""

    name: Literal["auricular blood vessel"] = "auricular blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37386"] = "EMAPA_37386"


class _Iris_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model iris blood vessel"""

    name: Literal["iris blood vessel"] = "iris blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37387"] = "EMAPA_37387"


class _Eyelid_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model eyelid blood vessel"""

    name: Literal["eyelid blood vessel"] = "eyelid blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37388"] = "EMAPA_37388"


class _Intersomitic_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model intersomitic blood vessel"""

    name: Literal["intersomitic blood vessel"] = "intersomitic blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37389"] = "EMAPA_37389"


class _Alveolar_Atrium(_MouseAnatomicalStructureModel):
    """Model alveolar atrium"""

    name: Literal["alveolar atrium"] = "alveolar atrium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37390"] = "EMAPA_37390"


class _Alveolar_Pore(_MouseAnatomicalStructureModel):
    """Model alveolar pore"""

    name: Literal["alveolar pore"] = "alveolar pore"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37391"] = "EMAPA_37391"


class _Anal_Fold(_MouseAnatomicalStructureModel):
    """Model anal fold"""

    name: Literal["anal fold"] = "anal fold"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37392"] = "EMAPA_37392"


class _Anal_Region_Skeletal_Muscle(_MouseAnatomicalStructureModel):
    """Model anal region skeletal muscle"""

    name: Literal["anal region skeletal muscle"] = "anal region skeletal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37393"] = "EMAPA_37393"


class _Anal_Region_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model anal region smooth muscle"""

    name: Literal["anal region smooth muscle"] = "anal region smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37394"] = "EMAPA_37394"


class _Anal_Sac(_MouseAnatomicalStructureModel):
    """Model anal sac"""

    name: Literal["anal sac"] = "anal sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37395"] = "EMAPA_37395"


class _Anococcygeus(_MouseAnatomicalStructureModel):
    """Model anococcygeus"""

    name: Literal["anococcygeus"] = "anococcygeus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37396"] = "EMAPA_37396"


class _Ansiform_Lobule(_MouseAnatomicalStructureModel):
    """Model ansiform lobule"""

    name: Literal["ansiform lobule"] = "ansiform lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37397"] = "EMAPA_37397"


class _Ansiform_Lobule_Crus_I(_MouseAnatomicalStructureModel):
    """Model ansiform lobule crus I"""

    name: Literal["ansiform lobule crus I"] = "ansiform lobule crus I"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37398"] = "EMAPA_37398"


class _Ansiform_Lobule_Crus_Ii(_MouseAnatomicalStructureModel):
    """Model ansiform lobule crus II"""

    name: Literal["ansiform lobule crus II"] = "ansiform lobule crus II"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37399"] = "EMAPA_37399"


class _Copula_Pyramidis(_MouseAnatomicalStructureModel):
    """Model copula pyramidis"""

    name: Literal["copula pyramidis"] = "copula pyramidis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37400"] = "EMAPA_37400"


class _Lobule_Simplex(_MouseAnatomicalStructureModel):
    """Model lobule simplex"""

    name: Literal["lobule simplex"] = "lobule simplex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37401"] = "EMAPA_37401"


class _Paraflocculus(_MouseAnatomicalStructureModel):
    """Model paraflocculus"""

    name: Literal["paraflocculus"] = "paraflocculus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37402"] = "EMAPA_37402"


class _Paramedian_Lobule(_MouseAnatomicalStructureModel):
    """Model paramedian lobule"""

    name: Literal["paramedian lobule"] = "paramedian lobule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37403"] = "EMAPA_37403"


class _Anterior_Commissure_Anterior_Part(_MouseAnatomicalStructureModel):
    """Model anterior commissure anterior part"""

    name: Literal["anterior commissure anterior part"] = "anterior commissure anterior part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37404"] = "EMAPA_37404"


class _Anterior_Digastric_Muscle(_MouseAnatomicalStructureModel):
    """Model anterior digastric muscle"""

    name: Literal["anterior digastric muscle"] = "anterior digastric muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37405"] = "EMAPA_37405"


class _Posterior_Digastric_Muscle(_MouseAnatomicalStructureModel):
    """Model posterior digastric muscle"""

    name: Literal["posterior digastric muscle"] = "posterior digastric muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37406"] = "EMAPA_37406"


class _Bed_Nucleus_Of_Stria_Terminalis_Anterior_Part(_MouseAnatomicalStructureModel):
    """Model bed nucleus of stria terminalis anterior part"""

    name: Literal["bed nucleus of stria terminalis anterior part"] = "bed nucleus of stria terminalis anterior part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37407"] = "EMAPA_37407"


class _Bed_Nucleus_Of_Stria_Terminalis_Posterior_Part(_MouseAnatomicalStructureModel):
    """Model bed nucleus of stria terminalis posterior part"""

    name: Literal["bed nucleus of stria terminalis posterior part"] = "bed nucleus of stria terminalis posterior part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37408"] = "EMAPA_37408"


class _Anterior_Hypothalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model anterior hypothalamic nucleus"""

    name: Literal["anterior hypothalamic nucleus"] = "anterior hypothalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37409"] = "EMAPA_37409"


class _Anterior_Commissure_Posterior_Part(_MouseAnatomicalStructureModel):
    """Model anterior commissure posterior part"""

    name: Literal["anterior commissure posterior part"] = "anterior commissure posterior part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37410"] = "EMAPA_37410"


class _Anterior_Semicircular_Duct(_MouseAnatomicalStructureModel):
    """Model anterior semicircular duct"""

    name: Literal["anterior semicircular duct"] = "anterior semicircular duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37411"] = "EMAPA_37411"


class _Lateral_Semicircular_Duct(_MouseAnatomicalStructureModel):
    """Model lateral semicircular duct"""

    name: Literal["lateral semicircular duct"] = "lateral semicircular duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37412"] = "EMAPA_37412"


class _Posterior_Semicircular_Duct(_MouseAnatomicalStructureModel):
    """Model posterior semicircular duct"""

    name: Literal["posterior semicircular duct"] = "posterior semicircular duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37413"] = "EMAPA_37413"


class _Cornea_Anterior_Stroma(_MouseAnatomicalStructureModel):
    """Model cornea anterior stroma"""

    name: Literal["cornea anterior stroma"] = "cornea anterior stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37414"] = "EMAPA_37414"


class _Cornea_Posterior_Stroma(_MouseAnatomicalStructureModel):
    """Model cornea posterior stroma"""

    name: Literal["cornea posterior stroma"] = "cornea posterior stroma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37415"] = "EMAPA_37415"


class _Anterior_Tegmental_Nucleus(_MouseAnatomicalStructureModel):
    """Model anterior tegmental nucleus"""

    name: Literal["anterior tegmental nucleus"] = "anterior tegmental nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37416"] = "EMAPA_37416"


class _Anterior_Uvea(_MouseAnatomicalStructureModel):
    """Model anterior uvea"""

    name: Literal["anterior uvea"] = "anterior uvea"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37417"] = "EMAPA_37417"


class _Aortic_Valve_Anulus(_MouseAnatomicalStructureModel):
    """Model aortic valve anulus"""

    name: Literal["aortic valve anulus"] = "aortic valve anulus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37418"] = "EMAPA_37418"


class _Mitral_Valve_Anulus(_MouseAnatomicalStructureModel):
    """Model mitral valve anulus"""

    name: Literal["mitral valve anulus"] = "mitral valve anulus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37419"] = "EMAPA_37419"


class _Pulmonary_Valve_Anulus(_MouseAnatomicalStructureModel):
    """Model pulmonary valve anulus"""

    name: Literal["pulmonary valve anulus"] = "pulmonary valve anulus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37420"] = "EMAPA_37420"


class _Tricuspid_Valve_Anulus(_MouseAnatomicalStructureModel):
    """Model tricuspid valve anulus"""

    name: Literal["tricuspid valve anulus"] = "tricuspid valve anulus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37421"] = "EMAPA_37421"


class _Heart_Anulus_Fibrosus(_MouseAnatomicalStructureModel):
    """Model heart anulus fibrosus"""

    name: Literal["heart anulus fibrosus"] = "heart anulus fibrosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37422"] = "EMAPA_37422"


class _Apex_Of_Arytenoid(_MouseAnatomicalStructureModel):
    """Model apex of arytenoid"""

    name: Literal["apex of arytenoid"] = "apex of arytenoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37423"] = "EMAPA_37423"


class _Base_Of_Arytenoid(_MouseAnatomicalStructureModel):
    """Model base of arytenoid"""

    name: Literal["base of arytenoid"] = "base of arytenoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37424"] = "EMAPA_37424"


class _Apex_Of_Heart_Ventricle(_MouseAnatomicalStructureModel):
    """Model apex of heart ventricle"""

    name: Literal["apex of heart ventricle"] = "apex of heart ventricle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37425"] = "EMAPA_37425"


class _Apocrine_Sweat_Gland(_MouseAnatomicalStructureModel):
    """Model apocrine sweat gland"""

    name: Literal["apocrine sweat gland"] = "apocrine sweat gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37426"] = "EMAPA_37426"


class _Aqueous_Drainage_System(_MouseAnatomicalStructureModel):
    """Model aqueous drainage system"""

    name: Literal["aqueous drainage system"] = "aqueous drainage system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37427"] = "EMAPA_37427"


class _Aqueous_Vein(_MouseAnatomicalStructureModel):
    """Model aqueous vein"""

    name: Literal["aqueous vein"] = "aqueous vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37428"] = "EMAPA_37428"


class _Inferior_Labial_Artery(_MouseAnatomicalStructureModel):
    """Model inferior labial artery"""

    name: Literal["inferior labial artery"] = "inferior labial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37429"] = "EMAPA_37429"


class _Superior_Labial_Artery(_MouseAnatomicalStructureModel):
    """Model superior labial artery"""

    name: Literal["superior labial artery"] = "superior labial artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37430"] = "EMAPA_37430"


class _Atrioventricular_Septal_Complex(_MouseAnatomicalStructureModel):
    """Model atrioventricular septal complex"""

    name: Literal["atrioventricular septal complex"] = "atrioventricular septal complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37431"] = "EMAPA_37431"


class _Atrial_Trabecula(_MouseAnatomicalStructureModel):
    """Model atrial trabecula"""

    name: Literal["atrial trabecula"] = "atrial trabecula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37432"] = "EMAPA_37432"


class _Auditory_Bulla(_MouseAnatomicalStructureModel):
    """Model auditory bulla"""

    name: Literal["auditory bulla"] = "auditory bulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37433"] = "EMAPA_37433"


class _Auricular_Ligament(_MouseAnatomicalStructureModel):
    """Model auricular ligament"""

    name: Literal["auricular ligament"] = "auricular ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37434"] = "EMAPA_37434"


class _Bachmann_S_Bundle(_MouseAnatomicalStructureModel):
    """Model Bachmann's bundle"""

    name: Literal["Bachmann's bundle"] = "Bachmann's bundle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37435"] = "EMAPA_37435"


class _Barrington_S_Nucleus(_MouseAnatomicalStructureModel):
    """Model Barrington's nucleus"""

    name: Literal["Barrington's nucleus"] = "Barrington's nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37436"] = "EMAPA_37436"


class _Tongue_Anterior_Part(_MouseAnatomicalStructureModel):
    """Model tongue anterior part"""

    name: Literal["tongue anterior part"] = "tongue anterior part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37437"] = "EMAPA_37437"


class _Tongue_Posterior_Part(_MouseAnatomicalStructureModel):
    """Model tongue posterior part"""

    name: Literal["tongue posterior part"] = "tongue posterior part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37438"] = "EMAPA_37438"


class _Basilic_Vein(_MouseAnatomicalStructureModel):
    """Model basilic vein"""

    name: Literal["basilic vein"] = "basilic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37439"] = "EMAPA_37439"


class _Biliary_Ductule(_MouseAnatomicalStructureModel):
    """Model biliary ductule"""

    name: Literal["biliary ductule"] = "biliary ductule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37440"] = "EMAPA_37440"


class _Body_Fluid(_MouseAnatomicalStructureModel):
    """Model body fluid"""

    name: Literal["body fluid"] = "body fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37441"] = "EMAPA_37441"


class _Body_Cavity(_MouseAnatomicalStructureModel):
    """Model body cavity"""

    name: Literal["body cavity"] = "body cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37442"] = "EMAPA_37442"


class _Body_Of_Sternum(_MouseAnatomicalStructureModel):
    """Model body of sternum"""

    name: Literal["body of sternum"] = "body of sternum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37443"] = "EMAPA_37443"


class _Hard_Palate_Bony_Part(_MouseAnatomicalStructureModel):
    """Model hard palate bony part"""

    name: Literal["hard palate bony part"] = "hard palate bony part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37444"] = "EMAPA_37444"


class _Brachial_Vein(_MouseAnatomicalStructureModel):
    """Model brachial vein"""

    name: Literal["brachial vein"] = "brachial vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37445"] = "EMAPA_37445"


class _Brain_Commissure(_MouseAnatomicalStructureModel):
    """Model brain commissure"""

    name: Literal["brain commissure"] = "brain commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37446"] = "EMAPA_37446"


class _Brain_Ventricle_And_Choroid_Plexus(_MouseAnatomicalStructureModel):
    """Model brain ventricle and choroid plexus"""

    name: Literal["brain ventricle and choroid plexus"] = "brain ventricle and choroid plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37447"] = "EMAPA_37447"


class _Bronchoalveolar_Duct_Junction(_MouseAnatomicalStructureModel):
    """Model bronchoalveolar duct junction"""

    name: Literal["bronchoalveolar duct junction"] = "bronchoalveolar duct junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37448"] = "EMAPA_37448"


class _Bronchus_Submucosa(_MouseAnatomicalStructureModel):
    """Model bronchus submucosa"""

    name: Literal["bronchus submucosa"] = "bronchus submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37449"] = "EMAPA_37449"


class _Bruch_S_Membrane(_MouseAnatomicalStructureModel):
    """Model Bruch's membrane"""

    name: Literal["Bruch's membrane"] = "Bruch's membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37450"] = "EMAPA_37450"


class _Cheek(_MouseAnatomicalStructureModel):
    """Model cheek"""

    name: Literal["cheek"] = "cheek"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37451"] = "EMAPA_37451"


class _Buccal_Pouch(_MouseAnatomicalStructureModel):
    """Model buccal pouch"""

    name: Literal["buccal pouch"] = "buccal pouch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37452"] = "EMAPA_37452"


class _Buccinator(_MouseAnatomicalStructureModel):
    """Model buccinator"""

    name: Literal["buccinator"] = "buccinator"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37453"] = "EMAPA_37453"


class _Bulbospongiosus(_MouseAnatomicalStructureModel):
    """Model bulbospongiosus"""

    name: Literal["bulbospongiosus"] = "bulbospongiosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37454"] = "EMAPA_37454"


class _Ischiocavernosus(_MouseAnatomicalStructureModel):
    """Model ischiocavernosus"""

    name: Literal["ischiocavernosus"] = "ischiocavernosus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37455"] = "EMAPA_37455"


class _Canal_Of_Schlemm(_MouseAnatomicalStructureModel):
    """Model canal of Schlemm"""

    name: Literal["canal of Schlemm"] = "canal of Schlemm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37456"] = "EMAPA_37456"


class _Canthus(_MouseAnatomicalStructureModel):
    """Model canthus"""

    name: Literal["canthus"] = "canthus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37457"] = "EMAPA_37457"


class _Outer_Canthus(_MouseAnatomicalStructureModel):
    """Model outer canthus"""

    name: Literal["outer canthus"] = "outer canthus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37458"] = "EMAPA_37458"


class _Cardiac_Region_Gastric_Gland(_MouseAnatomicalStructureModel):
    """Model cardiac region gastric gland"""

    name: Literal["cardiac region gastric gland"] = "cardiac region gastric gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37459"] = "EMAPA_37459"


class _Cardiac_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model cardiac nerve plexus"""

    name: Literal["cardiac nerve plexus"] = "cardiac nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37460"] = "EMAPA_37460"


class _Celiac_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model celiac nerve plexus"""

    name: Literal["celiac nerve plexus"] = "celiac nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37461"] = "EMAPA_37461"


class _Pulmonary_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model pulmonary nerve plexus"""

    name: Literal["pulmonary nerve plexus"] = "pulmonary nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37462"] = "EMAPA_37462"


class _Cartilaginous_Joint_Suture(_MouseAnatomicalStructureModel):
    """Model cartilaginous joint suture"""

    name: Literal["cartilaginous joint suture"] = "cartilaginous joint suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37463"] = "EMAPA_37463"


class _Gomphosis(_MouseAnatomicalStructureModel):
    """Model gomphosis"""

    name: Literal["gomphosis"] = "gomphosis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37464"] = "EMAPA_37464"


class _Syndesmosis(_MouseAnatomicalStructureModel):
    """Model syndesmosis"""

    name: Literal["syndesmosis"] = "syndesmosis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37465"] = "EMAPA_37465"


class _Bony_Otic_Capsule(_MouseAnatomicalStructureModel):
    """Model bony otic capsule"""

    name: Literal["bony otic capsule"] = "bony otic capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37466"] = "EMAPA_37466"


class _Cartilaginous_Otic_Capsule(_MouseAnatomicalStructureModel):
    """Model cartilaginous otic capsule"""

    name: Literal["cartilaginous otic capsule"] = "cartilaginous otic capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37467"] = "EMAPA_37467"


class _Cauda_Equina(_MouseAnatomicalStructureModel):
    """Model cauda equina"""

    name: Literal["cauda equina"] = "cauda equina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37468"] = "EMAPA_37468"


class _Caudal_Ganglionic_Eminence(_MouseAnatomicalStructureModel):
    """Model caudal ganglionic eminence"""

    name: Literal["caudal ganglionic eminence"] = "caudal ganglionic eminence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37469"] = "EMAPA_37469"


class _Lateral_Ganglionic_Eminence(_MouseAnatomicalStructureModel):
    """Model lateral ganglionic eminence"""

    name: Literal["lateral ganglionic eminence"] = "lateral ganglionic eminence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37470"] = "EMAPA_37470"


class _Medial_Ganglionic_Eminence(_MouseAnatomicalStructureModel):
    """Model medial ganglionic eminence"""

    name: Literal["medial ganglionic eminence"] = "medial ganglionic eminence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37471"] = "EMAPA_37471"


class _Caudal_Humeral_Circumflex_Vein(_MouseAnatomicalStructureModel):
    """Model caudal humeral circumflex vein"""

    name: Literal["caudal humeral circumflex vein"] = "caudal humeral circumflex vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37472"] = "EMAPA_37472"


class _Cellular_Cartilage(_MouseAnatomicalStructureModel):
    """Model cellular cartilage"""

    name: Literal["cellular cartilage"] = "cellular cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37473"] = "EMAPA_37473"


class _Muscle_Organ(_MouseAnatomicalStructureModel):
    """Model muscle organ"""

    name: Literal["muscle organ"] = "muscle organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37474"] = "EMAPA_37474"


class _Myocardium_Layer(_MouseAnatomicalStructureModel):
    """Model myocardium layer"""

    name: Literal["myocardium layer"] = "myocardium layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37475"] = "EMAPA_37475"


class _Synovium(_MouseAnatomicalStructureModel):
    """Model synovium"""

    name: Literal["synovium"] = "synovium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37476"] = "EMAPA_37476"


class _Cerebral_Hemisphere_Gray_Matter(_MouseAnatomicalStructureModel):
    """Model cerebral hemisphere gray matter"""

    name: Literal["cerebral hemisphere gray matter"] = "cerebral hemisphere gray matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37477"] = "EMAPA_37477"


class _Choledochoduodenal_Junction(_MouseAnatomicalStructureModel):
    """Model choledochoduodenal junction"""

    name: Literal["choledochoduodenal junction"] = "choledochoduodenal junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37478"] = "EMAPA_37478"


class _Enteric_Nerve(_MouseAnatomicalStructureModel):
    """Model enteric nerve"""

    name: Literal["enteric nerve"] = "enteric nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37479"] = "EMAPA_37479"


class _Cholinergic_Enteric_Nerve(_MouseAnatomicalStructureModel):
    """Model cholinergic enteric nerve"""

    name: Literal["cholinergic enteric nerve"] = "cholinergic enteric nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37480"] = "EMAPA_37480"


class _Pelvis_Muscle(_MouseAnatomicalStructureModel):
    """Model pelvis muscle"""

    name: Literal["pelvis muscle"] = "pelvis muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37481"] = "EMAPA_37481"


class _Coccygeus(_MouseAnatomicalStructureModel):
    """Model coccygeus"""

    name: Literal["coccygeus"] = "coccygeus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37482"] = "EMAPA_37482"


class _Constrictor_Vulvae(_MouseAnatomicalStructureModel):
    """Model constrictor vulvae"""

    name: Literal["constrictor vulvae"] = "constrictor vulvae"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37483"] = "EMAPA_37483"


class _Corniculate_Cartilage(_MouseAnatomicalStructureModel):
    """Model corniculate cartilage"""

    name: Literal["corniculate cartilage"] = "corniculate cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37484"] = "EMAPA_37484"


class _Kidney_Outer_Cortex(_MouseAnatomicalStructureModel):
    """Model kidney outer cortex"""

    name: Literal["kidney outer cortex"] = "kidney outer cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37485"] = "EMAPA_37485"


class _Kidney_Cortical_Arch(_MouseAnatomicalStructureModel):
    """Model kidney cortical arch"""

    name: Literal["kidney cortical arch"] = "kidney cortical arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37486"] = "EMAPA_37486"


class _Kidney_Column(_MouseAnatomicalStructureModel):
    """Model kidney column"""

    name: Literal["kidney column"] = "kidney column"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37487"] = "EMAPA_37487"


class _Kidney_Cortex_Peritubular_Capillary(_MouseAnatomicalStructureModel):
    """Model kidney cortex peritubular capillary"""

    name: Literal["kidney cortex peritubular capillary"] = "kidney cortex peritubular capillary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37488"] = "EMAPA_37488"


class _Renal_Straight_Tubule(_MouseAnatomicalStructureModel):
    """Model renal straight tubule"""

    name: Literal["renal straight tubule"] = "renal straight tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37489"] = "EMAPA_37489"


class _Renal_Tubule_Basement_Membrane(_MouseAnatomicalStructureModel):
    """Model renal tubule basement membrane"""

    name: Literal["renal tubule basement membrane"] = "renal tubule basement membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37490"] = "EMAPA_37490"


class _Costal_Arch(_MouseAnatomicalStructureModel):
    """Model costal arch"""

    name: Literal["costal arch"] = "costal arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37491"] = "EMAPA_37491"


class _Distal_Rib(_MouseAnatomicalStructureModel):
    """Model distal rib"""

    name: Literal["distal rib"] = "distal rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37492"] = "EMAPA_37492"


class _False_Rib(_MouseAnatomicalStructureModel):
    """Model false rib"""

    name: Literal["false rib"] = "false rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37493"] = "EMAPA_37493"


class _Floating_Rib(_MouseAnatomicalStructureModel):
    """Model floating rib"""

    name: Literal["floating rib"] = "floating rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37494"] = "EMAPA_37494"


class _Proximal_Rib(_MouseAnatomicalStructureModel):
    """Model proximal rib"""

    name: Literal["proximal rib"] = "proximal rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37495"] = "EMAPA_37495"


class _Costo_Cervical_Trunk(_MouseAnatomicalStructureModel):
    """Model costo-cervical trunk"""

    name: Literal["costo-cervical trunk"] = "costo-cervical trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37496"] = "EMAPA_37496"


class _Cranial_Cavity(_MouseAnatomicalStructureModel):
    """Model cranial cavity"""

    name: Literal["cranial cavity"] = "cranial cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37497"] = "EMAPA_37497"


class _Cricoarytenoid_Muscle(_MouseAnatomicalStructureModel):
    """Model cricoarytenoid muscle"""

    name: Literal["cricoarytenoid muscle"] = "cricoarytenoid muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37498"] = "EMAPA_37498"


class _Crus_Cerebri(_MouseAnatomicalStructureModel):
    """Model crus cerebri"""

    name: Literal["crus cerebri"] = "crus cerebri"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37499"] = "EMAPA_37499"


class _Cutaneous_Muscle(_MouseAnatomicalStructureModel):
    """Model cutaneous muscle"""

    name: Literal["cutaneous muscle"] = "cutaneous muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37500"] = "EMAPA_37500"


class _Cutaneous_Trunci_Muscle(_MouseAnatomicalStructureModel):
    """Model cutaneous trunci muscle"""

    name: Literal["cutaneous trunci muscle"] = "cutaneous trunci muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37501"] = "EMAPA_37501"


class _Levator_Nasolabialis(_MouseAnatomicalStructureModel):
    """Model levator nasolabialis"""

    name: Literal["levator nasolabialis"] = "levator nasolabialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37502"] = "EMAPA_37502"


class _Levator_Labii_Superioris(_MouseAnatomicalStructureModel):
    """Model levator labii superioris"""

    name: Literal["levator labii superioris"] = "levator labii superioris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37503"] = "EMAPA_37503"


class _Integument(_MouseAnatomicalStructureModel):
    """Model integument"""

    name: Literal["integument"] = "integument"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37504"] = "EMAPA_37504"


class _Hypodermis(_MouseAnatomicalStructureModel):
    """Model hypodermis"""

    name: Literal["hypodermis"] = "hypodermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37505"] = "EMAPA_37505"


class _Cutaneous_Vein(_MouseAnatomicalStructureModel):
    """Model cutaneous vein"""

    name: Literal["cutaneous vein"] = "cutaneous vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37506"] = "EMAPA_37506"


class _Eponychium(_MouseAnatomicalStructureModel):
    """Model eponychium"""

    name: Literal["eponychium"] = "eponychium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37507"] = "EMAPA_37507"


class _Hyponychium(_MouseAnatomicalStructureModel):
    """Model hyponychium"""

    name: Literal["hyponychium"] = "hyponychium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37508"] = "EMAPA_37508"


class _Proximal_Nail_Bed(_MouseAnatomicalStructureModel):
    """Model proximal nail bed"""

    name: Literal["proximal nail bed"] = "proximal nail bed"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37509"] = "EMAPA_37509"


class _Deep_Cervical_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model deep cervical lymph node"""

    name: Literal["deep cervical lymph node"] = "deep cervical lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37510"] = "EMAPA_37510"


class _Deep_Iliac_Circumflex_Vein(_MouseAnatomicalStructureModel):
    """Model deep iliac circumflex vein"""

    name: Literal["deep iliac circumflex vein"] = "deep iliac circumflex vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37511"] = "EMAPA_37511"


class _Deep_Temporal_Vein(_MouseAnatomicalStructureModel):
    """Model deep temporal vein"""

    name: Literal["deep temporal vein"] = "deep temporal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37512"] = "EMAPA_37512"


class _Deferent_Duct_Artery(_MouseAnatomicalStructureModel):
    """Model deferent duct artery"""

    name: Literal["deferent duct artery"] = "deferent duct artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37513"] = "EMAPA_37513"


class _Deferent_Duct_Vein(_MouseAnatomicalStructureModel):
    """Model deferent duct vein"""

    name: Literal["deferent duct vein"] = "deferent duct vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37514"] = "EMAPA_37514"


class _Dentate_Gyrus_Pyramidal_Layer(_MouseAnatomicalStructureModel):
    """Model dentate gyrus pyramidal layer"""

    name: Literal["dentate gyrus pyramidal layer"] = "dentate gyrus pyramidal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37515"] = "EMAPA_37515"


class _Depressor_Labii_Inferioris(_MouseAnatomicalStructureModel):
    """Model depressor labii inferioris"""

    name: Literal["depressor labii inferioris"] = "depressor labii inferioris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37516"] = "EMAPA_37516"


class _Dorsal_Foot_Interosseus_Muscle(_MouseAnatomicalStructureModel):
    """Model dorsal foot interosseus muscle"""

    name: Literal["dorsal foot interosseus muscle"] = "dorsal foot interosseus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37517"] = "EMAPA_37517"


class _Plantar_Foot_Interosseus_Muscle(_MouseAnatomicalStructureModel):
    """Model plantar foot interosseus muscle"""

    name: Literal["plantar foot interosseus muscle"] = "plantar foot interosseus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37518"] = "EMAPA_37518"


class _Dorsal_Hand_Interosseus_Muscle(_MouseAnatomicalStructureModel):
    """Model dorsal hand interosseus muscle"""

    name: Literal["dorsal hand interosseus muscle"] = "dorsal hand interosseus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37519"] = "EMAPA_37519"


class _Palmar_Hand_Interosseus_Muscle(_MouseAnatomicalStructureModel):
    """Model palmar hand interosseus muscle"""

    name: Literal["palmar hand interosseus muscle"] = "palmar hand interosseus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37520"] = "EMAPA_37520"


class _Dorsal_Venous_Arch(_MouseAnatomicalStructureModel):
    """Model dorsal venous arch"""

    name: Literal["dorsal venous arch"] = "dorsal venous arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37521"] = "EMAPA_37521"


class _Epiglottic_Cartilage(_MouseAnatomicalStructureModel):
    """Model epiglottic cartilage"""

    name: Literal["epiglottic cartilage"] = "epiglottic cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37522"] = "EMAPA_37522"


class _Esophagus_Smooth_Muscle_Circular_Layer(_MouseAnatomicalStructureModel):
    """Model esophagus smooth muscle circular layer"""

    name: Literal["esophagus smooth muscle circular layer"] = "esophagus smooth muscle circular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37523"] = "EMAPA_37523"


class _Esophagus_Smooth_Muscle_Longitudinal_Layer(_MouseAnatomicalStructureModel):
    """Model esophagus smooth muscle longitudinal layer"""

    name: Literal["esophagus smooth muscle longitudinal layer"] = "esophagus smooth muscle longitudinal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37524"] = "EMAPA_37524"


class _External_Auditory_Meatus_Cartilaginous_Part(_MouseAnatomicalStructureModel):
    """Model external auditory meatus cartilaginous part"""

    name: Literal["external auditory meatus cartilaginous part"] = "external auditory meatus cartilaginous part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37525"] = "EMAPA_37525"


class _External_Auditory_Meatus_Osseus_Part(_MouseAnatomicalStructureModel):
    """Model external auditory meatus osseus part"""

    name: Literal["external auditory meatus osseus part"] = "external auditory meatus osseus part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37526"] = "EMAPA_37526"


class _Extrinsic_Auricular_Muscle(_MouseAnatomicalStructureModel):
    """Model extrinsic auricular muscle"""

    name: Literal["extrinsic auricular muscle"] = "extrinsic auricular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37527"] = "EMAPA_37527"


class _Intrinsic_Auricular_Muscle(_MouseAnatomicalStructureModel):
    """Model intrinsic auricular muscle"""

    name: Literal["intrinsic auricular muscle"] = "intrinsic auricular muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37528"] = "EMAPA_37528"


class _Eye_Chamber(_MouseAnatomicalStructureModel):
    """Model eye chamber"""

    name: Literal["eye chamber"] = "eye chamber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37529"] = "EMAPA_37529"


class _Eye_Skin_Gland(_MouseAnatomicalStructureModel):
    """Model eye skin gland"""

    name: Literal["eye skin gland"] = "eye skin gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37530"] = "EMAPA_37530"


class _Eye_Sebaceous_Gland(_MouseAnatomicalStructureModel):
    """Model eye sebaceous gland"""

    name: Literal["eye sebaceous gland"] = "eye sebaceous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37531"] = "EMAPA_37531"


class _Eyelid_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model eyelid connective tissue"""

    name: Literal["eyelid connective tissue"] = "eyelid connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37532"] = "EMAPA_37532"


class _Eyelid_Subcutaneous_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model eyelid subcutaneous connective tissue"""

    name: Literal["eyelid subcutaneous connective tissue"] = "eyelid subcutaneous connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37533"] = "EMAPA_37533"


class _Eyelid_Submuscular_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model eyelid submuscular connective tissue"""

    name: Literal["eyelid submuscular connective tissue"] = "eyelid submuscular connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37534"] = "EMAPA_37534"


class _Eyelid_Nerve(_MouseAnatomicalStructureModel):
    """Model eyelid nerve"""

    name: Literal["eyelid nerve"] = "eyelid nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37535"] = "EMAPA_37535"


class _Eyelid_Skin(_MouseAnatomicalStructureModel):
    """Model eyelid skin"""

    name: Literal["eyelid skin"] = "eyelid skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37536"] = "EMAPA_37536"


class _Membranous_Urethra_Of_Female(_MouseAnatomicalStructureModel):
    """Model membranous urethra of female"""

    name: Literal["membranous urethra of female"] = "membranous urethra of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37537"] = "EMAPA_37537"


class _Femur_Diaphysis(_MouseAnatomicalStructureModel):
    """Model femur diaphysis"""

    name: Literal["femur diaphysis"] = "femur diaphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37538"] = "EMAPA_37538"


class _Femur_Epiphysis(_MouseAnatomicalStructureModel):
    """Model femur epiphysis"""

    name: Literal["femur epiphysis"] = "femur epiphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37539"] = "EMAPA_37539"


class _Femur_Metaphysis(_MouseAnatomicalStructureModel):
    """Model femur metaphysis"""

    name: Literal["femur metaphysis"] = "femur metaphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37540"] = "EMAPA_37540"


class _Head_Of_Femur(_MouseAnatomicalStructureModel):
    """Model head of femur"""

    name: Literal["head of femur"] = "head of femur"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37541"] = "EMAPA_37541"


class _Membranous_Urethra(_MouseAnatomicalStructureModel):
    """Model membranous urethra"""

    name: Literal["membranous urethra"] = "membranous urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37542"] = "EMAPA_37542"


class _Forebrain_Meninges(_MouseAnatomicalStructureModel):
    """Model forebrain meninges"""

    name: Literal["forebrain meninges"] = "forebrain meninges"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37543"] = "EMAPA_37543"


class _Forebrain_Arachnoid_Mater(_MouseAnatomicalStructureModel):
    """Model forebrain arachnoid mater"""

    name: Literal["forebrain arachnoid mater"] = "forebrain arachnoid mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37544"] = "EMAPA_37544"


class _Forebrain_Dura_Mater(_MouseAnatomicalStructureModel):
    """Model forebrain dura mater"""

    name: Literal["forebrain dura mater"] = "forebrain dura mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37545"] = "EMAPA_37545"


class _Forebrain_Pia_Mater(_MouseAnatomicalStructureModel):
    """Model forebrain pia mater"""

    name: Literal["forebrain pia mater"] = "forebrain pia mater"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37546"] = "EMAPA_37546"


class _Lower_Respiratory_Tract_Cartilage(_MouseAnatomicalStructureModel):
    """Model lower respiratory tract cartilage"""

    name: Literal["lower respiratory tract cartilage"] = "lower respiratory tract cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37547"] = "EMAPA_37547"


class _Lower_Respiratory_Tract_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model lower respiratory tract connective tissue"""

    name: Literal["lower respiratory tract connective tissue"] = "lower respiratory tract connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37548"] = "EMAPA_37548"


class _Lower_Respiratory_Tract_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower respiratory tract epithelium"""

    name: Literal["lower respiratory tract epithelium"] = "lower respiratory tract epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37549"] = "EMAPA_37549"


class _Main_Bronchus_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model main bronchus connective tissue"""

    name: Literal["main bronchus connective tissue"] = "main bronchus connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37550"] = "EMAPA_37550"


class _Main_Bronchus_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model main bronchus smooth muscle"""

    name: Literal["main bronchus smooth muscle"] = "main bronchus smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37551"] = "EMAPA_37551"


class _Trachea_Basement_Membrane(_MouseAnatomicalStructureModel):
    """Model trachea basement membrane"""

    name: Literal["trachea basement membrane"] = "trachea basement membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37552"] = "EMAPA_37552"


class _Trachea_Basal_Lamina(_MouseAnatomicalStructureModel):
    """Model trachea basal lamina"""

    name: Literal["trachea basal lamina"] = "trachea basal lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37553"] = "EMAPA_37553"


class _Trachea_Reticular_Lamina(_MouseAnatomicalStructureModel):
    """Model trachea reticular lamina"""

    name: Literal["trachea reticular lamina"] = "trachea reticular lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37554"] = "EMAPA_37554"


class _Tracheal_Bifurcation(_MouseAnatomicalStructureModel):
    """Model tracheal bifurcation"""

    name: Literal["tracheal bifurcation"] = "tracheal bifurcation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37555"] = "EMAPA_37555"


class _Large_Intestine_Muscularis_Mucosa(_MouseAnatomicalStructureModel):
    """Model large intestine muscularis mucosa"""

    name: Literal["large intestine muscularis mucosa"] = "large intestine muscularis mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37556"] = "EMAPA_37556"


class _Large_Intestine_Serosa(_MouseAnatomicalStructureModel):
    """Model large intestine serosa"""

    name: Literal["large intestine serosa"] = "large intestine serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37557"] = "EMAPA_37557"


class _Large_Intestine_Smooth_Muscle_Circular_Layer(_MouseAnatomicalStructureModel):
    """Model large intestine smooth muscle circular layer"""

    name: Literal["large intestine smooth muscle circular layer"] = "large intestine smooth muscle circular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37558"] = "EMAPA_37558"


class _Large_Intestine_Smooth_Muscle_Longitudinal_Layer(_MouseAnatomicalStructureModel):
    """Model large intestine smooth muscle longitudinal layer"""

    name: Literal[
        "large intestine smooth muscle longitudinal layer"
    ] = "large intestine smooth muscle longitudinal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37559"] = "EMAPA_37559"


class _Large_Intestine_Submucosa(_MouseAnatomicalStructureModel):
    """Model large intestine submucosa"""

    name: Literal["large intestine submucosa"] = "large intestine submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37560"] = "EMAPA_37560"


class _Small_Intestine_Serosa(_MouseAnatomicalStructureModel):
    """Model small intestine serosa"""

    name: Literal["small intestine serosa"] = "small intestine serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37561"] = "EMAPA_37561"


class _Small_Intestine_Smooth_Muscle_Circular_Layer(_MouseAnatomicalStructureModel):
    """Model small intestine smooth muscle circular layer"""

    name: Literal["small intestine smooth muscle circular layer"] = "small intestine smooth muscle circular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37562"] = "EMAPA_37562"


class _Small_Intestine_Smooth_Muscle_Longitudinal_Layer(_MouseAnatomicalStructureModel):
    """Model small intestine smooth muscle longitudinal layer"""

    name: Literal[
        "small intestine smooth muscle longitudinal layer"
    ] = "small intestine smooth muscle longitudinal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37563"] = "EMAPA_37563"


class _Small_Intestine_Submucosa(_MouseAnatomicalStructureModel):
    """Model small intestine submucosa"""

    name: Literal["small intestine submucosa"] = "small intestine submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37564"] = "EMAPA_37564"


class _Respiratory_System_Arterial_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model respiratory system arterial blood vessel"""

    name: Literal["respiratory system arterial blood vessel"] = "respiratory system arterial blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37565"] = "EMAPA_37565"


class _Respiratory_System_Arterial_Endothelium(_MouseAnatomicalStructureModel):
    """Model respiratory system arterial endothelium"""

    name: Literal["respiratory system arterial endothelium"] = "respiratory system arterial endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37566"] = "EMAPA_37566"


class _Respiratory_System_Arterial_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model respiratory system arterial smooth muscle"""

    name: Literal["respiratory system arterial smooth muscle"] = "respiratory system arterial smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37567"] = "EMAPA_37567"


class _Respiratory_System_Arteriole(_MouseAnatomicalStructureModel):
    """Model respiratory system arteriole"""

    name: Literal["respiratory system arteriole"] = "respiratory system arteriole"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37568"] = "EMAPA_37568"


class _Respiratory_System_Artery(_MouseAnatomicalStructureModel):
    """Model respiratory system artery"""

    name: Literal["respiratory system artery"] = "respiratory system artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37569"] = "EMAPA_37569"


class _Respiratory_System_Basement_Membrane(_MouseAnatomicalStructureModel):
    """Model respiratory system basement membrane"""

    name: Literal["respiratory system basement membrane"] = "respiratory system basement membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37570"] = "EMAPA_37570"


class _Respiratory_System_Basal_Lamina(_MouseAnatomicalStructureModel):
    """Model respiratory system basal lamina"""

    name: Literal["respiratory system basal lamina"] = "respiratory system basal lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37571"] = "EMAPA_37571"


class _Respiratory_System_Reticular_Lamina(_MouseAnatomicalStructureModel):
    """Model respiratory system reticular lamina"""

    name: Literal["respiratory system reticular lamina"] = "respiratory system reticular lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37572"] = "EMAPA_37572"


class _Respiratory_System_Blood_Vessel_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model respiratory system blood vessel smooth muscle"""

    name: Literal["respiratory system blood vessel smooth muscle"] = "respiratory system blood vessel smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37573"] = "EMAPA_37573"


class _Respiratory_System_Capillary(_MouseAnatomicalStructureModel):
    """Model respiratory system capillary"""

    name: Literal["respiratory system capillary"] = "respiratory system capillary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37574"] = "EMAPA_37574"


class _Respiratory_System_Capillary_Endothelium(_MouseAnatomicalStructureModel):
    """Model respiratory system capillary endothelium"""

    name: Literal["respiratory system capillary endothelium"] = "respiratory system capillary endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37575"] = "EMAPA_37575"


class _Respiratory_System_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model respiratory system lamina propria"""

    name: Literal["respiratory system lamina propria"] = "respiratory system lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37576"] = "EMAPA_37576"


class _Respiratory_System_Mucosa(_MouseAnatomicalStructureModel):
    """Model respiratory system mucosa"""

    name: Literal["respiratory system mucosa"] = "respiratory system mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37577"] = "EMAPA_37577"


class _Respiratory_System_Submucosa(_MouseAnatomicalStructureModel):
    """Model respiratory system submucosa"""

    name: Literal["respiratory system submucosa"] = "respiratory system submucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37578"] = "EMAPA_37578"


class _Respiratory_System_Lymphatic_Vessel(_MouseAnatomicalStructureModel):
    """Model respiratory system lymphatic vessel"""

    name: Literal["respiratory system lymphatic vessel"] = "respiratory system lymphatic vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37580"] = "EMAPA_37580"


class _Respiratory_System_Lymphatic_Vessel_Endothelium(_MouseAnatomicalStructureModel):
    """Model respiratory system lymphatic vessel endothelium"""

    name: Literal["respiratory system lymphatic vessel endothelium"] = "respiratory system lymphatic vessel endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37581"] = "EMAPA_37581"


class _Respiratory_System_Lymphatic_Vessel_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model respiratory system lymphatic vessel smooth muscle"""

    name: Literal[
        "respiratory system lymphatic vessel smooth muscle"
    ] = "respiratory system lymphatic vessel smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37582"] = "EMAPA_37582"


class _Respiratory_System_Skeletal_Muscle(_MouseAnatomicalStructureModel):
    """Model respiratory system skeletal muscle"""

    name: Literal["respiratory system skeletal muscle"] = "respiratory system skeletal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37583"] = "EMAPA_37583"


class _Respiratory_System_Venous_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model respiratory system venous blood vessel"""

    name: Literal["respiratory system venous blood vessel"] = "respiratory system venous blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37584"] = "EMAPA_37584"


class _Respiratory_System_Venous_Endothelium(_MouseAnatomicalStructureModel):
    """Model respiratory system venous endothelium"""

    name: Literal["respiratory system venous endothelium"] = "respiratory system venous endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37585"] = "EMAPA_37585"


class _Respiratory_System_Venous_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model respiratory system venous smooth muscle"""

    name: Literal["respiratory system venous smooth muscle"] = "respiratory system venous smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37586"] = "EMAPA_37586"


class _Respiratory_System_Venule(_MouseAnatomicalStructureModel):
    """Model respiratory system venule"""

    name: Literal["respiratory system venule"] = "respiratory system venule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37587"] = "EMAPA_37587"


class _Flexor_Hallucis_Longus(_MouseAnatomicalStructureModel):
    """Model flexor hallucis longus"""

    name: Literal["flexor hallucis longus"] = "flexor hallucis longus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37588"] = "EMAPA_37588"


class _Fovea_Centralis(_MouseAnatomicalStructureModel):
    """Model fovea centralis"""

    name: Literal["fovea centralis"] = "fovea centralis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37589"] = "EMAPA_37589"


class _Frontal_Artery(_MouseAnatomicalStructureModel):
    """Model frontal artery"""

    name: Literal["frontal artery"] = "frontal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37590"] = "EMAPA_37590"


class _Fusiform_Nucleus(_MouseAnatomicalStructureModel):
    """Model fusiform nucleus"""

    name: Literal["fusiform nucleus"] = "fusiform nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37591"] = "EMAPA_37591"


class _Alimentary_System_Serosa(_MouseAnatomicalStructureModel):
    """Model alimentary system serosa"""

    name: Literal["alimentary system serosa"] = "alimentary system serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37592"] = "EMAPA_37592"


class _Gracile_Nucleus(_MouseAnatomicalStructureModel):
    """Model gracile nucleus"""

    name: Literal["gracile nucleus"] = "gracile nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37593"] = "EMAPA_37593"


class _Greater_Trochanter(_MouseAnatomicalStructureModel):
    """Model greater trochanter"""

    name: Literal["greater trochanter"] = "greater trochanter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37594"] = "EMAPA_37594"


class _Lesser_Trochanter(_MouseAnatomicalStructureModel):
    """Model lesser trochanter"""

    name: Literal["lesser trochanter"] = "lesser trochanter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37595"] = "EMAPA_37595"


class _Gray_Matter(_MouseAnatomicalStructureModel):
    """Model gray matter"""

    name: Literal["gray matter"] = "gray matter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37596"] = "EMAPA_37596"


class _Heart_And_Pericardium(_MouseAnatomicalStructureModel):
    """Model heart and pericardium"""

    name: Literal["heart and pericardium"] = "heart and pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37597"] = "EMAPA_37597"


class _Hepatic_Duct_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model hepatic duct smooth muscle"""

    name: Literal["hepatic duct smooth muscle"] = "hepatic duct smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37598"] = "EMAPA_37598"


class _Hilar_Part_Of_Hepatic_Duct(_MouseAnatomicalStructureModel):
    """Model hilar part of hepatic duct"""

    name: Literal["hilar part of hepatic duct"] = "hilar part of hepatic duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37599"] = "EMAPA_37599"


class _Hyoid_Apparatus(_MouseAnatomicalStructureModel):
    """Model hyoid apparatus"""

    name: Literal["hyoid apparatus"] = "hyoid apparatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37600"] = "EMAPA_37600"


class _Ileocecal_Junction(_MouseAnatomicalStructureModel):
    """Model ileocecal junction"""

    name: Literal["ileocecal junction"] = "ileocecal junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37601"] = "EMAPA_37601"


class _Iliac_Crest(_MouseAnatomicalStructureModel):
    """Model iliac crest"""

    name: Literal["iliac crest"] = "iliac crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37602"] = "EMAPA_37602"


class _Iliocostalis(_MouseAnatomicalStructureModel):
    """Model iliocostalis"""

    name: Literal["iliocostalis"] = "iliocostalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37603"] = "EMAPA_37603"


class _Iliocostalis_Thoracis(_MouseAnatomicalStructureModel):
    """Model iliocostalis thoracis"""

    name: Literal["iliocostalis thoracis"] = "iliocostalis thoracis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37604"] = "EMAPA_37604"


class _Iliothoracic(_MouseAnatomicalStructureModel):
    """Model iliothoracic"""

    name: Literal["iliothoracic"] = "iliothoracic"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37605"] = "EMAPA_37605"


class _Inferior_Eyelid_Tarsus(_MouseAnatomicalStructureModel):
    """Model inferior eyelid tarsus"""

    name: Literal["inferior eyelid tarsus"] = "inferior eyelid tarsus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37606"] = "EMAPA_37606"


class _Superior_Eyelid_Tarsus(_MouseAnatomicalStructureModel):
    """Model superior eyelid tarsus"""

    name: Literal["superior eyelid tarsus"] = "superior eyelid tarsus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37607"] = "EMAPA_37607"


class _Medial_Palpebral_Ligament(_MouseAnatomicalStructureModel):
    """Model medial palpebral ligament"""

    name: Literal["medial palpebral ligament"] = "medial palpebral ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37608"] = "EMAPA_37608"


class _Orbital_Septum(_MouseAnatomicalStructureModel):
    """Model orbital septum"""

    name: Literal["orbital septum"] = "orbital septum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37609"] = "EMAPA_37609"


class _Inferior_Olivary_Commissure(_MouseAnatomicalStructureModel):
    """Model inferior olivary commissure"""

    name: Literal["inferior olivary commissure"] = "inferior olivary commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37610"] = "EMAPA_37610"


class _Inferior_Olive_Beta_Subnucleus(_MouseAnatomicalStructureModel):
    """Model inferior olive beta subnucleus"""

    name: Literal["inferior olive beta subnucleus"] = "inferior olive beta subnucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37611"] = "EMAPA_37611"


class _Inferior_Olive_Dorsal_Accessory_Nucleus(_MouseAnatomicalStructureModel):
    """Model inferior olive dorsal accessory nucleus"""

    name: Literal["inferior olive dorsal accessory nucleus"] = "inferior olive dorsal accessory nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37612"] = "EMAPA_37612"


class _Inferior_Olive_Medial_Accessory_Nucleus(_MouseAnatomicalStructureModel):
    """Model inferior olive medial accessory nucleus"""

    name: Literal["inferior olive medial accessory nucleus"] = "inferior olive medial accessory nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37613"] = "EMAPA_37613"


class _Inferior_Olive_Medial_Nucleus(_MouseAnatomicalStructureModel):
    """Model inferior olive medial nucleus"""

    name: Literal["inferior olive medial nucleus"] = "inferior olive medial nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37614"] = "EMAPA_37614"


class _Inferior_Olive_Principal_Nucleus(_MouseAnatomicalStructureModel):
    """Model inferior olive principal nucleus"""

    name: Literal["inferior olive principal nucleus"] = "inferior olive principal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37615"] = "EMAPA_37615"


class _Inferior_Pancreatico_Duodenal_Vein(_MouseAnatomicalStructureModel):
    """Model inferior pancreatico-duodenal vein"""

    name: Literal["inferior pancreatico-duodenal vein"] = "inferior pancreatico-duodenal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37616"] = "EMAPA_37616"


class _Sympathetic_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model sympathetic nerve plexus"""

    name: Literal["sympathetic nerve plexus"] = "sympathetic nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37617"] = "EMAPA_37617"


class _Internal_Carotid_Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model internal carotid nerve plexus"""

    name: Literal["internal carotid nerve plexus"] = "internal carotid nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37618"] = "EMAPA_37618"


class _Intestine_Serosa(_MouseAnatomicalStructureModel):
    """Model intestine serosa"""

    name: Literal["intestine serosa"] = "intestine serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37619"] = "EMAPA_37619"


class _Joint_Articular_Surface(_MouseAnatomicalStructureModel):
    """Model joint articular surface"""

    name: Literal["joint articular surface"] = "joint articular surface"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37620"] = "EMAPA_37620"


class _Joint_Fibrous_Capsule(_MouseAnatomicalStructureModel):
    """Model joint fibrous capsule"""

    name: Literal["joint fibrous capsule"] = "joint fibrous capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37621"] = "EMAPA_37621"


class _Joint_Of_Vertebral_Body(_MouseAnatomicalStructureModel):
    """Model joint of vertebral body"""

    name: Literal["joint of vertebral body"] = "joint of vertebral body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37622"] = "EMAPA_37622"


class _Juxtamedullary_Cortex(_MouseAnatomicalStructureModel):
    """Model juxtamedullary cortex"""

    name: Literal["juxtamedullary cortex"] = "juxtamedullary cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37623"] = "EMAPA_37623"


class _Lacrimal_Canaliculus(_MouseAnatomicalStructureModel):
    """Model lacrimal canaliculus"""

    name: Literal["lacrimal canaliculus"] = "lacrimal canaliculus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37624"] = "EMAPA_37624"


class _Lamellar_Bone(_MouseAnatomicalStructureModel):
    """Model lamellar bone"""

    name: Literal["lamellar bone"] = "lamellar bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37625"] = "EMAPA_37625"


class _Larynx_Ligament(_MouseAnatomicalStructureModel):
    """Model larynx ligament"""

    name: Literal["larynx ligament"] = "larynx ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37626"] = "EMAPA_37626"


class _Laryngeal_Extrinsic_Ligament(_MouseAnatomicalStructureModel):
    """Model laryngeal extrinsic ligament"""

    name: Literal["laryngeal extrinsic ligament"] = "laryngeal extrinsic ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37627"] = "EMAPA_37627"


class _Laryngeal_Intrinsic_Ligament(_MouseAnatomicalStructureModel):
    """Model laryngeal intrinsic ligament"""

    name: Literal["laryngeal intrinsic ligament"] = "laryngeal intrinsic ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37628"] = "EMAPA_37628"


class _Laryngeal_Extrinsic_Muscle(_MouseAnatomicalStructureModel):
    """Model laryngeal extrinsic muscle"""

    name: Literal["laryngeal extrinsic muscle"] = "laryngeal extrinsic muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37629"] = "EMAPA_37629"


class _Laryngeal_Intrinsic_Muscle(_MouseAnatomicalStructureModel):
    """Model laryngeal intrinsic muscle"""

    name: Literal["laryngeal intrinsic muscle"] = "laryngeal intrinsic muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37630"] = "EMAPA_37630"


class _Larynx_Mucous_Gland(_MouseAnatomicalStructureModel):
    """Model larynx mucous gland"""

    name: Literal["larynx mucous gland"] = "larynx mucous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37631"] = "EMAPA_37631"


class _Spinal_Cord_Basal_Nucleus(_MouseAnatomicalStructureModel):
    """Model spinal cord basal nucleus"""

    name: Literal["spinal cord basal nucleus"] = "spinal cord basal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37632"] = "EMAPA_37632"


class _Lateral_Cervical_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral cervical nucleus"""

    name: Literal["lateral cervical nucleus"] = "lateral cervical nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37633"] = "EMAPA_37633"


class _Lateral_Spinal_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral spinal nucleus"""

    name: Literal["lateral spinal nucleus"] = "lateral spinal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37634"] = "EMAPA_37634"


class _Spinal_Cord_Dorsal_Nucleus(_MouseAnatomicalStructureModel):
    """Model spinal cord dorsal nucleus"""

    name: Literal["spinal cord dorsal nucleus"] = "spinal cord dorsal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37635"] = "EMAPA_37635"


class _Lateral_Dorsal_Digital_Artery_For_Digit_5(_MouseAnatomicalStructureModel):
    """Model lateral dorsal digital artery for digit 5"""

    name: Literal["lateral dorsal digital artery for digit 5"] = "lateral dorsal digital artery for digit 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37636"] = "EMAPA_37636"


class _Median_Dorsal_Digital_Artery_For_Digit_1(_MouseAnatomicalStructureModel):
    """Model median dorsal digital artery for digit 1"""

    name: Literal["median dorsal digital artery for digit 1"] = "median dorsal digital artery for digit 1"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37637"] = "EMAPA_37637"


class _Lateral_Globus_Pallidus(_MouseAnatomicalStructureModel):
    """Model lateral globus pallidus"""

    name: Literal["lateral globus pallidus"] = "lateral globus pallidus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37638"] = "EMAPA_37638"


class _Medial_Globus_Pallidus(_MouseAnatomicalStructureModel):
    """Model medial globus pallidus"""

    name: Literal["medial globus pallidus"] = "medial globus pallidus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37639"] = "EMAPA_37639"


class _Limiting_Ridge_Of_Stomach(_MouseAnatomicalStructureModel):
    """Model limiting ridge of stomach"""

    name: Literal["limiting ridge of stomach"] = "limiting ridge of stomach"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37640"] = "EMAPA_37640"


class _Lingual_Gland_Duct(_MouseAnatomicalStructureModel):
    """Model lingual gland duct"""

    name: Literal["lingual gland duct"] = "lingual gland duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37641"] = "EMAPA_37641"


class _Lip_Skeletal_Muscle(_MouseAnatomicalStructureModel):
    """Model lip skeletal muscle"""

    name: Literal["lip skeletal muscle"] = "lip skeletal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37642"] = "EMAPA_37642"


class _Lip_Skin(_MouseAnatomicalStructureModel):
    """Model lip skin"""

    name: Literal["lip skin"] = "lip skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37643"] = "EMAPA_37643"


class _Liver_Left_Lateral_Lobe(_MouseAnatomicalStructureModel):
    """Model liver left lateral lobe"""

    name: Literal["liver left lateral lobe"] = "liver left lateral lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37644"] = "EMAPA_37644"


class _Liver_Left_Medial_Lobe(_MouseAnatomicalStructureModel):
    """Model liver left medial lobe"""

    name: Literal["liver left medial lobe"] = "liver left medial lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37645"] = "EMAPA_37645"


class _Liver_Papillary_Process(_MouseAnatomicalStructureModel):
    """Model liver papillary process"""

    name: Literal["liver papillary process"] = "liver papillary process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37646"] = "EMAPA_37646"


class _Lobar_Bronchus_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model lobar bronchus connective tissue"""

    name: Literal["lobar bronchus connective tissue"] = "lobar bronchus connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37647"] = "EMAPA_37647"


class _Longissimus_Muscle(_MouseAnatomicalStructureModel):
    """Model longissimus muscle"""

    name: Literal["longissimus muscle"] = "longissimus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37648"] = "EMAPA_37648"


class _Longissimus_Atlantis(_MouseAnatomicalStructureModel):
    """Model longissimus atlantis"""

    name: Literal["longissimus atlantis"] = "longissimus atlantis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37649"] = "EMAPA_37649"


class _Longissimus_Capitis(_MouseAnatomicalStructureModel):
    """Model longissimus capitis"""

    name: Literal["longissimus capitis"] = "longissimus capitis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37650"] = "EMAPA_37650"


class _Longissimus_Cervicis(_MouseAnatomicalStructureModel):
    """Model longissimus cervicis"""

    name: Literal["longissimus cervicis"] = "longissimus cervicis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37651"] = "EMAPA_37651"


class _Longissimus_Lumborum(_MouseAnatomicalStructureModel):
    """Model longissimus lumborum"""

    name: Literal["longissimus lumborum"] = "longissimus lumborum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37652"] = "EMAPA_37652"


class _Longissimus_Thoracis(_MouseAnatomicalStructureModel):
    """Model longissimus thoracis"""

    name: Literal["longissimus thoracis"] = "longissimus thoracis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37653"] = "EMAPA_37653"


class _Longus_Colli(_MouseAnatomicalStructureModel):
    """Model longus colli"""

    name: Literal["longus colli"] = "longus colli"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37654"] = "EMAPA_37654"


class _Lumbar_Sympathetic_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model lumbar sympathetic nerve trunk"""

    name: Literal["lumbar sympathetic nerve trunk"] = "lumbar sympathetic nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37655"] = "EMAPA_37655"


class _Pelvic_Sympathetic_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model pelvic sympathetic nerve trunk"""

    name: Literal["pelvic sympathetic nerve trunk"] = "pelvic sympathetic nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37656"] = "EMAPA_37656"


class _Thoracic_Sympathetic_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model thoracic sympathetic nerve trunk"""

    name: Literal["thoracic sympathetic nerve trunk"] = "thoracic sympathetic nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37657"] = "EMAPA_37657"


class _Lumbosacrocaudalis(_MouseAnatomicalStructureModel):
    """Model lumbosacrocaudalis"""

    name: Literal["lumbosacrocaudalis"] = "lumbosacrocaudalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37658"] = "EMAPA_37658"


class _Lunate(_MouseAnatomicalStructureModel):
    """Model lunate"""

    name: Literal["lunate"] = "lunate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37659"] = "EMAPA_37659"


class _Scaphoid(_MouseAnatomicalStructureModel):
    """Model scaphoid"""

    name: Literal["scaphoid"] = "scaphoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37660"] = "EMAPA_37660"


class _Lymph_Node_Follicular_Mantle(_MouseAnatomicalStructureModel):
    """Model lymph node follicular mantle"""

    name: Literal["lymph node follicular mantle"] = "lymph node follicular mantle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37661"] = "EMAPA_37661"


class _Lymph_Node_Subcortical_Sinus(_MouseAnatomicalStructureModel):
    """Model lymph node subcortical sinus"""

    name: Literal["lymph node subcortical sinus"] = "lymph node subcortical sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37662"] = "EMAPA_37662"


class _Lymph_Node_T_Cell_Domain(_MouseAnatomicalStructureModel):
    """Model lymph node T cell domain"""

    name: Literal["lymph node T cell domain"] = "lymph node T cell domain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37663"] = "EMAPA_37663"


class _Lymphoid_System(_MouseAnatomicalStructureModel):
    """Model lymphoid system"""

    name: Literal["lymphoid system"] = "lymphoid system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37664"] = "EMAPA_37664"


class _Lymph_Organ(_MouseAnatomicalStructureModel):
    """Model lymph organ"""

    name: Literal["lymph organ"] = "lymph organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37665"] = "EMAPA_37665"


class _Magnocellular_Nucleus(_MouseAnatomicalStructureModel):
    """Model magnocellular nucleus"""

    name: Literal["magnocellular nucleus"] = "magnocellular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37666"] = "EMAPA_37666"


class _Oval_Nucleus(_MouseAnatomicalStructureModel):
    """Model oval nucleus"""

    name: Literal["oval nucleus"] = "oval nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37667"] = "EMAPA_37667"


class _Mammary_Sebaceous_Gland(_MouseAnatomicalStructureModel):
    """Model mammary sebaceous gland"""

    name: Literal["mammary sebaceous gland"] = "mammary sebaceous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37668"] = "EMAPA_37668"


class _Mammary_Gland_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model mammary gland smooth muscle"""

    name: Literal["mammary gland smooth muscle"] = "mammary gland smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37669"] = "EMAPA_37669"


class _Medial_Femoral_Circumflex_Artery(_MouseAnatomicalStructureModel):
    """Model medial femoral circumflex artery"""

    name: Literal["medial femoral circumflex artery"] = "medial femoral circumflex artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37670"] = "EMAPA_37670"


class _Obturator_Artery(_MouseAnatomicalStructureModel):
    """Model obturator artery"""

    name: Literal["obturator artery"] = "obturator artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37671"] = "EMAPA_37671"


class _Occipital_Artery(_MouseAnatomicalStructureModel):
    """Model occipital artery"""

    name: Literal["occipital artery"] = "occipital artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37672"] = "EMAPA_37672"


class _Ocular_Angle_Artery(_MouseAnatomicalStructureModel):
    """Model ocular angle artery"""

    name: Literal["ocular angle artery"] = "ocular angle artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37673"] = "EMAPA_37673"


class _Peroneal_Artery(_MouseAnatomicalStructureModel):
    """Model peroneal artery"""

    name: Literal["peroneal artery"] = "peroneal artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37674"] = "EMAPA_37674"


class _Ulnar_Artery(_MouseAnatomicalStructureModel):
    """Model ulnar artery"""

    name: Literal["ulnar artery"] = "ulnar artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37675"] = "EMAPA_37675"


class _Ureteric_Artery(_MouseAnatomicalStructureModel):
    """Model ureteric artery"""

    name: Literal["ureteric artery"] = "ureteric artery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37676"] = "EMAPA_37676"


class _Obturator_Vein(_MouseAnatomicalStructureModel):
    """Model obturator vein"""

    name: Literal["obturator vein"] = "obturator vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37677"] = "EMAPA_37677"


class _Pancreatic_Vein(_MouseAnatomicalStructureModel):
    """Model pancreatic vein"""

    name: Literal["pancreatic vein"] = "pancreatic vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37678"] = "EMAPA_37678"


class _Ureteric_Vein(_MouseAnatomicalStructureModel):
    """Model ureteric vein"""

    name: Literal["ureteric vein"] = "ureteric vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37679"] = "EMAPA_37679"


class _Modified_Sebaceous_Gland(_MouseAnatomicalStructureModel):
    """Model modified sebaceous gland"""

    name: Literal["modified sebaceous gland"] = "modified sebaceous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37680"] = "EMAPA_37680"


class _Nasal_Cartilage(_MouseAnatomicalStructureModel):
    """Model nasal cartilage"""

    name: Literal["nasal cartilage"] = "nasal cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37681"] = "EMAPA_37681"


class _Nasopharynx_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model nasopharynx connective tissue"""

    name: Literal["nasopharynx connective tissue"] = "nasopharynx connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37682"] = "EMAPA_37682"


class _Nerve_Plexus(_MouseAnatomicalStructureModel):
    """Model nerve plexus"""

    name: Literal["nerve plexus"] = "nerve plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37683"] = "EMAPA_37683"


class _Nose_Skin(_MouseAnatomicalStructureModel):
    """Model nose skin"""

    name: Literal["nose skin"] = "nose skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37684"] = "EMAPA_37684"


class _Brachiocephalic_Muscle(_MouseAnatomicalStructureModel):
    """Model brachiocephalic muscle"""

    name: Literal["brachiocephalic muscle"] = "brachiocephalic muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37685"] = "EMAPA_37685"


class _Cleidobrachialis_Muscle(_MouseAnatomicalStructureModel):
    """Model cleidobrachialis muscle"""

    name: Literal["cleidobrachialis muscle"] = "cleidobrachialis muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37686"] = "EMAPA_37686"


class _Cleidocephalicus_Muscle(_MouseAnatomicalStructureModel):
    """Model cleidocephalicus muscle"""

    name: Literal["cleidocephalicus muscle"] = "cleidocephalicus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37687"] = "EMAPA_37687"


class _Cleidooccipital_Muscle(_MouseAnatomicalStructureModel):
    """Model cleidooccipital muscle"""

    name: Literal["cleidooccipital muscle"] = "cleidooccipital muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37688"] = "EMAPA_37688"


class _Omohyoid(_MouseAnatomicalStructureModel):
    """Model omohyoid"""

    name: Literal["omohyoid"] = "omohyoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37689"] = "EMAPA_37689"


class _Omotransverse(_MouseAnatomicalStructureModel):
    """Model omotransverse"""

    name: Literal["omotransverse"] = "omotransverse"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37690"] = "EMAPA_37690"


class _Orbitalis_Muscle(_MouseAnatomicalStructureModel):
    """Model orbitalis muscle"""

    name: Literal["orbitalis muscle"] = "orbitalis muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37691"] = "EMAPA_37691"


class _Parotidoauricular(_MouseAnatomicalStructureModel):
    """Model parotidoauricular"""

    name: Literal["parotidoauricular"] = "parotidoauricular"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37692"] = "EMAPA_37692"


class _Sartorius(_MouseAnatomicalStructureModel):
    """Model sartorius"""

    name: Literal["sartorius"] = "sartorius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37693"] = "EMAPA_37693"


class _Semispinalis_Capitis(_MouseAnatomicalStructureModel):
    """Model semispinalis capitis"""

    name: Literal["semispinalis capitis"] = "semispinalis capitis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37694"] = "EMAPA_37694"


class _Semispinalis_Cervicis(_MouseAnatomicalStructureModel):
    """Model semispinalis cervicis"""

    name: Literal["semispinalis cervicis"] = "semispinalis cervicis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37695"] = "EMAPA_37695"


class _Semispinalis_Thoracis(_MouseAnatomicalStructureModel):
    """Model semispinalis thoracis"""

    name: Literal["semispinalis thoracis"] = "semispinalis thoracis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37696"] = "EMAPA_37696"


class _Serratus_Dorsalis_Caudalis(_MouseAnatomicalStructureModel):
    """Model serratus dorsalis caudalis"""

    name: Literal["serratus dorsalis caudalis"] = "serratus dorsalis caudalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37697"] = "EMAPA_37697"


class _Serratus_Dorsalis_Cranialis(_MouseAnatomicalStructureModel):
    """Model serratus dorsalis cranialis"""

    name: Literal["serratus dorsalis cranialis"] = "serratus dorsalis cranialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37698"] = "EMAPA_37698"


class _Sphincter_Colli_Superficialis(_MouseAnatomicalStructureModel):
    """Model sphincter colli superficialis"""

    name: Literal["sphincter colli superficialis"] = "sphincter colli superficialis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37699"] = "EMAPA_37699"


class _Spinalis_Thoracis(_MouseAnatomicalStructureModel):
    """Model spinalis thoracis"""

    name: Literal["spinalis thoracis"] = "spinalis thoracis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37700"] = "EMAPA_37700"


class _Splenius(_MouseAnatomicalStructureModel):
    """Model splenius"""

    name: Literal["splenius"] = "splenius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37701"] = "EMAPA_37701"


class _Sternooccipital(_MouseAnatomicalStructureModel):
    """Model sternooccipital"""

    name: Literal["sternooccipital"] = "sternooccipital"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37702"] = "EMAPA_37702"


class _Zygomaticus_Muscle(_MouseAnatomicalStructureModel):
    """Model zygomaticus muscle"""

    name: Literal["zygomaticus muscle"] = "zygomaticus muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37703"] = "EMAPA_37703"


class _Ophthalmic_Plexus(_MouseAnatomicalStructureModel):
    """Model ophthalmic plexus"""

    name: Literal["ophthalmic plexus"] = "ophthalmic plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37704"] = "EMAPA_37704"


class _Oropharynx_Epithelium(_MouseAnatomicalStructureModel):
    """Model oropharynx epithelium"""

    name: Literal["oropharynx epithelium"] = "oropharynx epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37705"] = "EMAPA_37705"


class _Outer_Ear_Cartilage(_MouseAnatomicalStructureModel):
    """Model outer ear cartilage"""

    name: Literal["outer ear cartilage"] = "outer ear cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37706"] = "EMAPA_37706"


class _Outflow_Tract_Pericardium(_MouseAnatomicalStructureModel):
    """Model outflow tract pericardium"""

    name: Literal["outflow tract pericardium"] = "outflow tract pericardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37707"] = "EMAPA_37707"


class _Outflow_Tract_Smooth_Muscle(_MouseAnatomicalStructureModel):
    """Model outflow tract smooth muscle"""

    name: Literal["outflow tract smooth muscle"] = "outflow tract smooth muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37708"] = "EMAPA_37708"


class _Rectus_Thoracis(_MouseAnatomicalStructureModel):
    """Model rectus thoracis"""

    name: Literal["rectus thoracis"] = "rectus thoracis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37709"] = "EMAPA_37709"


class _Pancreas_Lobe(_MouseAnatomicalStructureModel):
    """Model pancreas lobe"""

    name: Literal["pancreas lobe"] = "pancreas lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37710"] = "EMAPA_37710"


class _Pancreas_Left_Lobe(_MouseAnatomicalStructureModel):
    """Model pancreas left lobe"""

    name: Literal["pancreas left lobe"] = "pancreas left lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37711"] = "EMAPA_37711"


class _Pancreas_Right_Lobe(_MouseAnatomicalStructureModel):
    """Model pancreas right lobe"""

    name: Literal["pancreas right lobe"] = "pancreas right lobe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37712"] = "EMAPA_37712"


class _Pararenal_Fat(_MouseAnatomicalStructureModel):
    """Model pararenal fat"""

    name: Literal["pararenal fat"] = "pararenal fat"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37713"] = "EMAPA_37713"


class _Parietal_Mesothelium(_MouseAnatomicalStructureModel):
    """Model parietal mesothelium"""

    name: Literal["parietal mesothelium"] = "parietal mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37714"] = "EMAPA_37714"


class _Perianal_Skin(_MouseAnatomicalStructureModel):
    """Model perianal skin"""

    name: Literal["perianal skin"] = "perianal skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37715"] = "EMAPA_37715"


class _Perifornical_Nucleus(_MouseAnatomicalStructureModel):
    """Model perifornical nucleus"""

    name: Literal["perifornical nucleus"] = "perifornical nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37716"] = "EMAPA_37716"


class _Peripeduncular_Nucleus(_MouseAnatomicalStructureModel):
    """Model peripeduncular nucleus"""

    name: Literal["peripeduncular nucleus"] = "peripeduncular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37717"] = "EMAPA_37717"


class _Phrenic_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model phrenic nerve trunk"""

    name: Literal["phrenic nerve trunk"] = "phrenic nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37718"] = "EMAPA_37718"


class _Axillary_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model axillary nerve trunk"""

    name: Literal["axillary nerve trunk"] = "axillary nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37719"] = "EMAPA_37719"


class _Intercostal_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model intercostal nerve trunk"""

    name: Literal["intercostal nerve trunk"] = "intercostal nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37720"] = "EMAPA_37720"


class _Post_Cranial_Axial_Skeleton(_MouseAnatomicalStructureModel):
    """Model post-cranial axial skeleton"""

    name: Literal["post-cranial axial skeleton"] = "post-cranial axial skeleton"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37721"] = "EMAPA_37721"


class _Presacral_Vertebra(_MouseAnatomicalStructureModel):
    """Model presacral vertebra"""

    name: Literal["presacral vertebra"] = "presacral vertebra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37722"] = "EMAPA_37722"


class _Prescapular_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model prescapular lymph node"""

    name: Literal["prescapular lymph node"] = "prescapular lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37723"] = "EMAPA_37723"


class _Retropharyngeal_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model retropharyngeal lymph node"""

    name: Literal["retropharyngeal lymph node"] = "retropharyngeal lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37724"] = "EMAPA_37724"


class _Superficial_Cervical_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model superficial cervical lymph node"""

    name: Literal["superficial cervical lymph node"] = "superficial cervical lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37725"] = "EMAPA_37725"


class _Principal_Nucleus(_MouseAnatomicalStructureModel):
    """Model principal nucleus"""

    name: Literal["principal nucleus"] = "principal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37726"] = "EMAPA_37726"


class _Transverse_Nucleus(_MouseAnatomicalStructureModel):
    """Model transverse nucleus"""

    name: Literal["transverse nucleus"] = "transverse nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37727"] = "EMAPA_37727"


class _Proximal_Sesamoid_Bone_Of_Foot(_MouseAnatomicalStructureModel):
    """Model proximal sesamoid bone of foot"""

    name: Literal["proximal sesamoid bone of foot"] = "proximal sesamoid bone of foot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37728"] = "EMAPA_37728"


class _Proximal_Sesamoid_Bone_Of_Hand(_MouseAnatomicalStructureModel):
    """Model proximal sesamoid bone of hand"""

    name: Literal["proximal sesamoid bone of hand"] = "proximal sesamoid bone of hand"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37729"] = "EMAPA_37729"


class _Raphe_Obscurus_Nucleus(_MouseAnatomicalStructureModel):
    """Model raphe obscurus nucleus"""

    name: Literal["raphe obscurus nucleus"] = "raphe obscurus nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37730"] = "EMAPA_37730"


class _Reproductive_Organ(_MouseAnatomicalStructureModel):
    """Model reproductive organ"""

    name: Literal["reproductive organ"] = "reproductive organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37731"] = "EMAPA_37731"


class _Retrochiasmatic_Area(_MouseAnatomicalStructureModel):
    """Model retrochiasmatic area"""

    name: Literal["retrochiasmatic area"] = "retrochiasmatic area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37732"] = "EMAPA_37732"


class _Rhomboid(_MouseAnatomicalStructureModel):
    """Model rhomboid"""

    name: Literal["rhomboid"] = "rhomboid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37733"] = "EMAPA_37733"


class _Rib_Dorsal_Segment(_MouseAnatomicalStructureModel):
    """Model rib dorsal segment"""

    name: Literal["rib dorsal segment"] = "rib dorsal segment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37734"] = "EMAPA_37734"


class _Head_Of_Rib(_MouseAnatomicalStructureModel):
    """Model head of rib"""

    name: Literal["head of rib"] = "head of rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37735"] = "EMAPA_37735"


class _Tubercle_Of_Rib(_MouseAnatomicalStructureModel):
    """Model tubercle of rib"""

    name: Literal["tubercle of rib"] = "tubercle of rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37736"] = "EMAPA_37736"


class _Scalenus_Dorsalis(_MouseAnatomicalStructureModel):
    """Model scalenus dorsalis"""

    name: Literal["scalenus dorsalis"] = "scalenus dorsalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37737"] = "EMAPA_37737"


class _Scalenus_Medius(_MouseAnatomicalStructureModel):
    """Model scalenus medius"""

    name: Literal["scalenus medius"] = "scalenus medius"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37738"] = "EMAPA_37738"


class _Segmental_Bronchus(_MouseAnatomicalStructureModel):
    """Model segmental bronchus"""

    name: Literal["segmental bronchus"] = "segmental bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37739"] = "EMAPA_37739"


class _Segmental_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model segmental bronchus epithelium"""

    name: Literal["segmental bronchus epithelium"] = "segmental bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37740"] = "EMAPA_37740"


class _Sensory_Circumventricular_Organ(_MouseAnatomicalStructureModel):
    """Model sensory circumventricular organ"""

    name: Literal["sensory circumventricular organ"] = "sensory circumventricular organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37741"] = "EMAPA_37741"


class _Supraoptic_Crest(_MouseAnatomicalStructureModel):
    """Model supraoptic crest"""

    name: Literal["supraoptic crest"] = "supraoptic crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37742"] = "EMAPA_37742"


class _Skeletal_Muscle_Connective_Tissue(_MouseAnatomicalStructureModel):
    """Model skeletal muscle connective tissue"""

    name: Literal["skeletal muscle connective tissue"] = "skeletal muscle connective tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37743"] = "EMAPA_37743"


class _Skeletal_Tissue(_MouseAnatomicalStructureModel):
    """Model skeletal tissue"""

    name: Literal["skeletal tissue"] = "skeletal tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37744"] = "EMAPA_37744"


class _Small_Intestine_Mesentery(_MouseAnatomicalStructureModel):
    """Model small intestine mesentery"""

    name: Literal["small intestine mesentery"] = "small intestine mesentery"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37745"] = "EMAPA_37745"


class _Snout_Skin(_MouseAnatomicalStructureModel):
    """Model snout skin"""

    name: Literal["snout skin"] = "snout skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37746"] = "EMAPA_37746"


class _Spinal_Cord_Central_Gray(_MouseAnatomicalStructureModel):
    """Model spinal cord central gray"""

    name: Literal["spinal cord central gray"] = "spinal cord central gray"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37747"] = "EMAPA_37747"


class _Spinal_Cord_Dorsal_Commissural_Nucleus(_MouseAnatomicalStructureModel):
    """Model spinal cord dorsal commissural nucleus"""

    name: Literal["spinal cord dorsal commissural nucleus"] = "spinal cord dorsal commissural nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37748"] = "EMAPA_37748"


class _Spinal_Cord_Reticular_Nucleus(_MouseAnatomicalStructureModel):
    """Model spinal cord reticular nucleus"""

    name: Literal["spinal cord reticular nucleus"] = "spinal cord reticular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37749"] = "EMAPA_37749"


class _Spleen_Periarteriolar_Lymphatic_Sheath(_MouseAnatomicalStructureModel):
    """Model spleen periarteriolar lymphatic sheath"""

    name: Literal["spleen periarteriolar lymphatic sheath"] = "spleen periarteriolar lymphatic sheath"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37750"] = "EMAPA_37750"


class _Spleen_Venous_Sinus(_MouseAnatomicalStructureModel):
    """Model spleen venous sinus"""

    name: Literal["spleen venous sinus"] = "spleen venous sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37751"] = "EMAPA_37751"


class _Splenic_Cord(_MouseAnatomicalStructureModel):
    """Model splenic cord"""

    name: Literal["splenic cord"] = "splenic cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37752"] = "EMAPA_37752"


class _Stomach_Greater_Curvature(_MouseAnatomicalStructureModel):
    """Model stomach greater curvature"""

    name: Literal["stomach greater curvature"] = "stomach greater curvature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37753"] = "EMAPA_37753"


class _Stomach_Lesser_Curvature(_MouseAnatomicalStructureModel):
    """Model stomach lesser curvature"""

    name: Literal["stomach lesser curvature"] = "stomach lesser curvature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37754"] = "EMAPA_37754"


class _Superficial_Palmar_Arch(_MouseAnatomicalStructureModel):
    """Model superficial palmar arch"""

    name: Literal["superficial palmar arch"] = "superficial palmar arch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37755"] = "EMAPA_37755"


class _Superior_Salivatory_Nucleus(_MouseAnatomicalStructureModel):
    """Model superior salivatory nucleus"""

    name: Literal["superior salivatory nucleus"] = "superior salivatory nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37756"] = "EMAPA_37756"


class _Sural_Nerve(_MouseAnatomicalStructureModel):
    """Model sural nerve"""

    name: Literal["sural nerve"] = "sural nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37757"] = "EMAPA_37757"


class _Symphysis(_MouseAnatomicalStructureModel):
    """Model symphysis"""

    name: Literal["symphysis"] = "symphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37758"] = "EMAPA_37758"


class _Tail_Muscle(_MouseAnatomicalStructureModel):
    """Model tail muscle"""

    name: Literal["tail muscle"] = "tail muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37759"] = "EMAPA_37759"


class _Tail_Tip(_MouseAnatomicalStructureModel):
    """Model tail tip"""

    name: Literal["tail tip"] = "tail tip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37760"] = "EMAPA_37760"


class _Tail_Vein(_MouseAnatomicalStructureModel):
    """Model tail vein"""

    name: Literal["tail vein"] = "tail vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37761"] = "EMAPA_37761"


class _Intertarsal_Joint(_MouseAnatomicalStructureModel):
    """Model intertarsal joint"""

    name: Literal["intertarsal joint"] = "intertarsal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37762"] = "EMAPA_37762"


class _Terminal_Bronchus(_MouseAnatomicalStructureModel):
    """Model terminal bronchus"""

    name: Literal["terminal bronchus"] = "terminal bronchus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37763"] = "EMAPA_37763"


class _Terminal_Bronchus_Epithelium(_MouseAnatomicalStructureModel):
    """Model terminal bronchus epithelium"""

    name: Literal["terminal bronchus epithelium"] = "terminal bronchus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37764"] = "EMAPA_37764"


class _Thoracic_Segment_Skin(_MouseAnatomicalStructureModel):
    """Model thoracic segment skin"""

    name: Literal["thoracic segment skin"] = "thoracic segment skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37765"] = "EMAPA_37765"


class _Thymus_Lymphoid_Tissue(_MouseAnatomicalStructureModel):
    """Model thymus lymphoid tissue"""

    name: Literal["thymus lymphoid tissue"] = "thymus lymphoid tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37766"] = "EMAPA_37766"


class _Thyroid_Gland_Capsule(_MouseAnatomicalStructureModel):
    """Model thyroid gland capsule"""

    name: Literal["thyroid gland capsule"] = "thyroid gland capsule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37767"] = "EMAPA_37767"


class _Thyroid_Gland_Medulla(_MouseAnatomicalStructureModel):
    """Model thyroid gland medulla"""

    name: Literal["thyroid gland medulla"] = "thyroid gland medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37768"] = "EMAPA_37768"


class _Thyroid_Gland_Parenchyma(_MouseAnatomicalStructureModel):
    """Model thyroid gland parenchyma"""

    name: Literal["thyroid gland parenchyma"] = "thyroid gland parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37769"] = "EMAPA_37769"


class _Tibia_Diaphysis(_MouseAnatomicalStructureModel):
    """Model tibia diaphysis"""

    name: Literal["tibia diaphysis"] = "tibia diaphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37770"] = "EMAPA_37770"


class _Tibia_Epiphysis(_MouseAnatomicalStructureModel):
    """Model tibia epiphysis"""

    name: Literal["tibia epiphysis"] = "tibia epiphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37771"] = "EMAPA_37771"


class _Tibia_Metaphysis(_MouseAnatomicalStructureModel):
    """Model tibia metaphysis"""

    name: Literal["tibia metaphysis"] = "tibia metaphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37772"] = "EMAPA_37772"


class _Trigeminal_V_Principal_Sensory_Nucleus(_MouseAnatomicalStructureModel):
    """Model trigeminal V principal sensory nucleus"""

    name: Literal["trigeminal V principal sensory nucleus"] = "trigeminal V principal sensory nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37773"] = "EMAPA_37773"


class _True_Rib(_MouseAnatomicalStructureModel):
    """Model true rib"""

    name: Literal["true rib"] = "true rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37774"] = "EMAPA_37774"


class _Tympanic_Cavity_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model tympanic cavity blood vessel"""

    name: Literal["tympanic cavity blood vessel"] = "tympanic cavity blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37775"] = "EMAPA_37775"


class _Tympanic_Cavity_Muscle(_MouseAnatomicalStructureModel):
    """Model tympanic cavity muscle"""

    name: Literal["tympanic cavity muscle"] = "tympanic cavity muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37776"] = "EMAPA_37776"


class _Tympanic_Cavity_Nerve(_MouseAnatomicalStructureModel):
    """Model tympanic cavity nerve"""

    name: Literal["tympanic cavity nerve"] = "tympanic cavity nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37777"] = "EMAPA_37777"


class _Tympanic_Cavity(_MouseAnatomicalStructureModel):
    """Model tympanic cavity"""

    name: Literal["tympanic cavity"] = "tympanic cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37778"] = "EMAPA_37778"


class _Ureter_Luminal_Urothelium(_MouseAnatomicalStructureModel):
    """Model ureter luminal urothelium"""

    name: Literal["ureter luminal urothelium"] = "ureter luminal urothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37779"] = "EMAPA_37779"


class _Ureter_Subluminal_Urothelium(_MouseAnatomicalStructureModel):
    """Model ureter subluminal urothelium"""

    name: Literal["ureter subluminal urothelium"] = "ureter subluminal urothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37780"] = "EMAPA_37780"


class _Ureteral_Valve(_MouseAnatomicalStructureModel):
    """Model ureteral valve"""

    name: Literal["ureteral valve"] = "ureteral valve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37781"] = "EMAPA_37781"


class _Ureteropelvic_Junction(_MouseAnatomicalStructureModel):
    """Model ureteropelvic junction"""

    name: Literal["ureteropelvic junction"] = "ureteropelvic junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37782"] = "EMAPA_37782"


class _Ureterovesical_Junction(_MouseAnatomicalStructureModel):
    """Model ureterovesical junction"""

    name: Literal["ureterovesical junction"] = "ureterovesical junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37783"] = "EMAPA_37783"


class _Urethra_Gland(_MouseAnatomicalStructureModel):
    """Model urethra gland"""

    name: Literal["urethra gland"] = "urethra gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37784"] = "EMAPA_37784"


class _Urethra_Lamina_Propria(_MouseAnatomicalStructureModel):
    """Model urethra lamina propria"""

    name: Literal["urethra lamina propria"] = "urethra lamina propria"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37785"] = "EMAPA_37785"


class _Urethra_Mesenchymal_Layer(_MouseAnatomicalStructureModel):
    """Model urethra mesenchymal layer"""

    name: Literal["urethra mesenchymal layer"] = "urethra mesenchymal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37786"] = "EMAPA_37786"


class _Urethra_Muscle(_MouseAnatomicalStructureModel):
    """Model urethra muscle"""

    name: Literal["urethra muscle"] = "urethra muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37787"] = "EMAPA_37787"


class _Urethra_Skeletal_Muscle(_MouseAnatomicalStructureModel):
    """Model urethra skeletal muscle"""

    name: Literal["urethra skeletal muscle"] = "urethra skeletal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37788"] = "EMAPA_37788"


class _Urethral_Sphincter(_MouseAnatomicalStructureModel):
    """Model urethral sphincter"""

    name: Literal["urethral sphincter"] = "urethral sphincter"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37789"] = "EMAPA_37789"


class _Urethralis(_MouseAnatomicalStructureModel):
    """Model urethralis"""

    name: Literal["urethralis"] = "urethralis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37790"] = "EMAPA_37790"


class _Urinary_Bladder_Muscle(_MouseAnatomicalStructureModel):
    """Model urinary bladder muscle"""

    name: Literal["urinary bladder muscle"] = "urinary bladder muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37791"] = "EMAPA_37791"


class _Uterus_Serosa(_MouseAnatomicalStructureModel):
    """Model uterus serosa"""

    name: Literal["uterus serosa"] = "uterus serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37792"] = "EMAPA_37792"


class _Vagina_Sebaceous_Gland(_MouseAnatomicalStructureModel):
    """Model vagina sebaceous gland"""

    name: Literal["vagina sebaceous gland"] = "vagina sebaceous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37793"] = "EMAPA_37793"


class _Vagina_Squamous_Epithelium(_MouseAnatomicalStructureModel):
    """Model vagina squamous epithelium"""

    name: Literal["vagina squamous epithelium"] = "vagina squamous epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37794"] = "EMAPA_37794"


class _Vaginal_Hymen(_MouseAnatomicalStructureModel):
    """Model vaginal hymen"""

    name: Literal["vaginal hymen"] = "vaginal hymen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37795"] = "EMAPA_37795"


class _Vaginal_Vein(_MouseAnatomicalStructureModel):
    """Model vaginal vein"""

    name: Literal["vaginal vein"] = "vaginal vein"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37796"] = "EMAPA_37796"


class _Vagus_Nerve(_MouseAnatomicalStructureModel):
    """Model vagus nerve"""

    name: Literal["vagus nerve"] = "vagus nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37797"] = "EMAPA_37797"


class _Left_Vagus_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model left vagus nerve trunk"""

    name: Literal["left vagus nerve trunk"] = "left vagus nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37798"] = "EMAPA_37798"


class _Right_Vagus_Nerve_Trunk(_MouseAnatomicalStructureModel):
    """Model right vagus nerve trunk"""

    name: Literal["right vagus nerve trunk"] = "right vagus nerve trunk"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37799"] = "EMAPA_37799"


class _Vena_Cava_Endothelium(_MouseAnatomicalStructureModel):
    """Model vena cava endothelium"""

    name: Literal["vena cava endothelium"] = "vena cava endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37800"] = "EMAPA_37800"


class _Vaginal_Venous_Plexus(_MouseAnatomicalStructureModel):
    """Model vaginal venous plexus"""

    name: Literal["vaginal venous plexus"] = "vaginal venous plexus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37801"] = "EMAPA_37801"


class _Vertebra_Cranial_Articular_Process(_MouseAnatomicalStructureModel):
    """Model vertebra cranial articular process"""

    name: Literal["vertebra cranial articular process"] = "vertebra cranial articular process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37802"] = "EMAPA_37802"


class _Vertebra_Neural_Canal(_MouseAnatomicalStructureModel):
    """Model vertebra neural canal"""

    name: Literal["vertebra neural canal"] = "vertebra neural canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37803"] = "EMAPA_37803"


class _Visceral_Mesothelium(_MouseAnatomicalStructureModel):
    """Model visceral mesothelium"""

    name: Literal["visceral mesothelium"] = "visceral mesothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37804"] = "EMAPA_37804"


class _Vitreous_Chamber(_MouseAnatomicalStructureModel):
    """Model vitreous chamber"""

    name: Literal["vitreous chamber"] = "vitreous chamber"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37805"] = "EMAPA_37805"


class _White_Fibrocartilage(_MouseAnatomicalStructureModel):
    """Model white fibrocartilage"""

    name: Literal["white fibrocartilage"] = "white fibrocartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37806"] = "EMAPA_37806"


class _Zygomatic_Bone_Temporal_Process(_MouseAnatomicalStructureModel):
    """Model zygomatic bone temporal process"""

    name: Literal["zygomatic bone temporal process"] = "zygomatic bone temporal process"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37807"] = "EMAPA_37807"


class _Zymbal_S_Gland(_MouseAnatomicalStructureModel):
    """Model Zymbal's gland"""

    name: Literal["Zymbal's gland"] = "Zymbal's gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37808"] = "EMAPA_37808"


class _Bronchus_Basement_Membrane(_MouseAnatomicalStructureModel):
    """Model bronchus basement membrane"""

    name: Literal["bronchus basement membrane"] = "bronchus basement membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37809"] = "EMAPA_37809"


class _Bronchus_Basal_Lamina(_MouseAnatomicalStructureModel):
    """Model bronchus basal lamina"""

    name: Literal["bronchus basal lamina"] = "bronchus basal lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37810"] = "EMAPA_37810"


class _Bronchus_Reticular_Lamina(_MouseAnatomicalStructureModel):
    """Model bronchus reticular lamina"""

    name: Literal["bronchus reticular lamina"] = "bronchus reticular lamina"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37811"] = "EMAPA_37811"


class _Cerebellar_Glomerulus(_MouseAnatomicalStructureModel):
    """Model cerebellar glomerulus"""

    name: Literal["cerebellar glomerulus"] = "cerebellar glomerulus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37812"] = "EMAPA_37812"


class _Subarachnoid_Cistern(_MouseAnatomicalStructureModel):
    """Model subarachnoid cistern"""

    name: Literal["subarachnoid cistern"] = "subarachnoid cistern"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37813"] = "EMAPA_37813"


class _Cerebellomedullary_Cistern(_MouseAnatomicalStructureModel):
    """Model cerebellomedullary cistern"""

    name: Literal["cerebellomedullary cistern"] = "cerebellomedullary cistern"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37814"] = "EMAPA_37814"


class _Lateral_Cerebellomedullary_Cistern(_MouseAnatomicalStructureModel):
    """Model lateral cerebellomedullary cistern"""

    name: Literal["lateral cerebellomedullary cistern"] = "lateral cerebellomedullary cistern"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37815"] = "EMAPA_37815"


class _Posterior_Cerebellomedullary_Cistern(_MouseAnatomicalStructureModel):
    """Model posterior cerebellomedullary cistern"""

    name: Literal["posterior cerebellomedullary cistern"] = "posterior cerebellomedullary cistern"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37816"] = "EMAPA_37816"


class _Quadrigeminal_Cistern(_MouseAnatomicalStructureModel):
    """Model quadrigeminal cistern"""

    name: Literal["quadrigeminal cistern"] = "quadrigeminal cistern"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37817"] = "EMAPA_37817"


class _Cerebellum_Fissure(_MouseAnatomicalStructureModel):
    """Model cerebellum fissure"""

    name: Literal["cerebellum fissure"] = "cerebellum fissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37818"] = "EMAPA_37818"


class _Cerebellum_Interpositus_Nucleus(_MouseAnatomicalStructureModel):
    """Model cerebellum interpositus nucleus"""

    name: Literal["cerebellum interpositus nucleus"] = "cerebellum interpositus nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37819"] = "EMAPA_37819"


class _Cerebellum_Globose_Nucleus(_MouseAnatomicalStructureModel):
    """Model cerebellum globose nucleus"""

    name: Literal["cerebellum globose nucleus"] = "cerebellum globose nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37820"] = "EMAPA_37820"


class _Cerebellum_Emboliform_Nucleus(_MouseAnatomicalStructureModel):
    """Model cerebellum emboliform nucleus"""

    name: Literal["cerebellum emboliform nucleus"] = "cerebellum emboliform nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37821"] = "EMAPA_37821"


class _Cerebellum_Intermediate_Zone(_MouseAnatomicalStructureModel):
    """Model cerebellum intermediate zone"""

    name: Literal["cerebellum intermediate zone"] = "cerebellum intermediate zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37822"] = "EMAPA_37822"


class _Cerebellum_Vermis_Lobule_Viia(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule VIIA"""

    name: Literal["cerebellum vermis lobule VIIA"] = "cerebellum vermis lobule VIIA"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37823"] = "EMAPA_37823"


class _Cerebellum_Vermis_Lobule_Viib(_MouseAnatomicalStructureModel):
    """Model cerebellum vermis lobule VIIB"""

    name: Literal["cerebellum vermis lobule VIIB"] = "cerebellum vermis lobule VIIB"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37824"] = "EMAPA_37824"


class _Cervical_Rib(_MouseAnatomicalStructureModel):
    """Model cervical rib"""

    name: Literal["cervical rib"] = "cervical rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37825"] = "EMAPA_37825"


class _Neck_Of_Rib(_MouseAnatomicalStructureModel):
    """Model neck of rib"""

    name: Literal["neck of rib"] = "neck of rib"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37826"] = "EMAPA_37826"


class _Chin(_MouseAnatomicalStructureModel):
    """Model chin"""

    name: Literal["chin"] = "chin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37827"] = "EMAPA_37827"


class _Cingulum_Bundle(_MouseAnatomicalStructureModel):
    """Model cingulum bundle"""

    name: Literal["cingulum bundle"] = "cingulum bundle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37828"] = "EMAPA_37828"


class _Circle_Of_Willis(_MouseAnatomicalStructureModel):
    """Model circle of Willis"""

    name: Literal["circle of Willis"] = "circle of Willis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37829"] = "EMAPA_37829"


class _Cochlea_Basement_Membrane(_MouseAnatomicalStructureModel):
    """Model cochlea basement membrane"""

    name: Literal["cochlea basement membrane"] = "cochlea basement membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37830"] = "EMAPA_37830"


class _External_Nose(_MouseAnatomicalStructureModel):
    """Model external nose"""

    name: Literal["external nose"] = "external nose"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37831"] = "EMAPA_37831"


class _Columella_Nasi(_MouseAnatomicalStructureModel):
    """Model columella nasi"""

    name: Literal["columella nasi"] = "columella nasi"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37832"] = "EMAPA_37832"


class _Ventricle_Compact_Myocardium(_MouseAnatomicalStructureModel):
    """Model ventricle compact myocardium"""

    name: Literal["ventricle compact myocardium"] = "ventricle compact myocardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37833"] = "EMAPA_37833"


class _Conjunctival_Fornix(_MouseAnatomicalStructureModel):
    """Model conjunctival fornix"""

    name: Literal["conjunctival fornix"] = "conjunctival fornix"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37834"] = "EMAPA_37834"


class _Corneo_Scleral_Junction(_MouseAnatomicalStructureModel):
    """Model corneo-scleral junction"""

    name: Literal["corneo-scleral junction"] = "corneo-scleral junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37835"] = "EMAPA_37835"


class _Coronary_Sinus(_MouseAnatomicalStructureModel):
    """Model coronary sinus"""

    name: Literal["coronary sinus"] = "coronary sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37836"] = "EMAPA_37836"


class _Crista_Terminalis(_MouseAnatomicalStructureModel):
    """Model crista terminalis"""

    name: Literal["crista terminalis"] = "crista terminalis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37837"] = "EMAPA_37837"


class _Crypt_Of_Lieberkuhn_Of_Duodenum(_MouseAnatomicalStructureModel):
    """Model crypt of Lieberkuhn of duodenum"""

    name: Literal["crypt of Lieberkuhn of duodenum"] = "crypt of Lieberkuhn of duodenum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37838"] = "EMAPA_37838"


class _Crypt_Of_Lieberkuhn_Of_Ileum(_MouseAnatomicalStructureModel):
    """Model crypt of Lieberkuhn of ileum"""

    name: Literal["crypt of Lieberkuhn of ileum"] = "crypt of Lieberkuhn of ileum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37839"] = "EMAPA_37839"


class _Crypt_Of_Lieberkuhn_Of_Jejunum(_MouseAnatomicalStructureModel):
    """Model crypt of Lieberkuhn of jejunum"""

    name: Literal["crypt of Lieberkuhn of jejunum"] = "crypt of Lieberkuhn of jejunum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37840"] = "EMAPA_37840"


class _Cutaneous_Elastic_Tissue(_MouseAnatomicalStructureModel):
    """Model cutaneous elastic tissue"""

    name: Literal["cutaneous elastic tissue"] = "cutaneous elastic tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37841"] = "EMAPA_37841"


class _Depressor_Anguli_Oris(_MouseAnatomicalStructureModel):
    """Model depressor anguli oris"""

    name: Literal["depressor anguli oris"] = "depressor anguli oris"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37842"] = "EMAPA_37842"


class _Alimentary_System_Organ(_MouseAnatomicalStructureModel):
    """Model alimentary system organ"""

    name: Literal["alimentary system organ"] = "alimentary system organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37843"] = "EMAPA_37843"


class _Dorsal_Telencephalic_Commissure(_MouseAnatomicalStructureModel):
    """Model dorsal telencephalic commissure"""

    name: Literal["dorsal telencephalic commissure"] = "dorsal telencephalic commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37844"] = "EMAPA_37844"


class _Ventral_Telencephalic_Commissure(_MouseAnatomicalStructureModel):
    """Model ventral telencephalic commissure"""

    name: Literal["ventral telencephalic commissure"] = "ventral telencephalic commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37845"] = "EMAPA_37845"


class _Reticular_Tissue(_MouseAnatomicalStructureModel):
    """Model reticular tissue"""

    name: Literal["reticular tissue"] = "reticular tissue"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37846"] = "EMAPA_37846"


class _Endoneurium(_MouseAnatomicalStructureModel):
    """Model endoneurium"""

    name: Literal["endoneurium"] = "endoneurium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37847"] = "EMAPA_37847"


class _Epineurium(_MouseAnatomicalStructureModel):
    """Model epineurium"""

    name: Literal["epineurium"] = "epineurium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37848"] = "EMAPA_37848"


class _Perineurium(_MouseAnatomicalStructureModel):
    """Model perineurium"""

    name: Literal["perineurium"] = "perineurium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37849"] = "EMAPA_37849"


class _Endoneurial_Fluid(_MouseAnatomicalStructureModel):
    """Model endoneurial fluid"""

    name: Literal["endoneurial fluid"] = "endoneurial fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37850"] = "EMAPA_37850"


class _Epaxial_Musculature(_MouseAnatomicalStructureModel):
    """Model epaxial musculature"""

    name: Literal["epaxial musculature"] = "epaxial musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37851"] = "EMAPA_37851"


class _Hypaxial_Musculature(_MouseAnatomicalStructureModel):
    """Model hypaxial musculature"""

    name: Literal["hypaxial musculature"] = "hypaxial musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37852"] = "EMAPA_37852"


class _Body_Wall_Musculature(_MouseAnatomicalStructureModel):
    """Model body wall musculature"""

    name: Literal["body wall musculature"] = "body wall musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37853"] = "EMAPA_37853"


class _Girdle_Region(_MouseAnatomicalStructureModel):
    """Model girdle region"""

    name: Literal["girdle region"] = "girdle region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37854"] = "EMAPA_37854"


class _Girdle_Musculature(_MouseAnatomicalStructureModel):
    """Model girdle musculature"""

    name: Literal["girdle musculature"] = "girdle musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37855"] = "EMAPA_37855"


class _Pectoral_Girdle_Region(_MouseAnatomicalStructureModel):
    """Model pectoral girdle region"""

    name: Literal["pectoral girdle region"] = "pectoral girdle region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37856"] = "EMAPA_37856"


class _Pectoral_Girdle_Musculature(_MouseAnatomicalStructureModel):
    """Model pectoral girdle musculature"""

    name: Literal["pectoral girdle musculature"] = "pectoral girdle musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37857"] = "EMAPA_37857"


class _Limb_Girdle_Complex(_MouseAnatomicalStructureModel):
    """Model limb-girdle complex"""

    name: Literal["limb-girdle complex"] = "limb-girdle complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37858"] = "EMAPA_37858"


class _Limb_Girdle_Complex_Musculature(_MouseAnatomicalStructureModel):
    """Model limb-girdle complex musculature"""

    name: Literal["limb-girdle complex musculature"] = "limb-girdle complex musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37859"] = "EMAPA_37859"


class _Pectoral_Complex(_MouseAnatomicalStructureModel):
    """Model pectoral complex"""

    name: Literal["pectoral complex"] = "pectoral complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37860"] = "EMAPA_37860"


class _Pectoral_Complex_Musculature(_MouseAnatomicalStructureModel):
    """Model pectoral complex musculature"""

    name: Literal["pectoral complex musculature"] = "pectoral complex musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37861"] = "EMAPA_37861"


class _Pelvic_Girdle_Region(_MouseAnatomicalStructureModel):
    """Model pelvic girdle region"""

    name: Literal["pelvic girdle region"] = "pelvic girdle region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37862"] = "EMAPA_37862"


class _Pelvic_Complex(_MouseAnatomicalStructureModel):
    """Model pelvic complex"""

    name: Literal["pelvic complex"] = "pelvic complex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37863"] = "EMAPA_37863"


class _Pelvic_Complex_Musculature(_MouseAnatomicalStructureModel):
    """Model pelvic complex  musculature"""

    name: Literal["pelvic complex  musculature"] = "pelvic complex  musculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37864"] = "EMAPA_37864"


class _Ependyma(_MouseAnatomicalStructureModel):
    """Model ependyma"""

    name: Literal["ependyma"] = "ependyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37865"] = "EMAPA_37865"


class _Epidermal_Dermal_Junction(_MouseAnatomicalStructureModel):
    """Model epidermal-dermal junction"""

    name: Literal["epidermal-dermal junction"] = "epidermal-dermal junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37866"] = "EMAPA_37866"


class _Ovary_Follicular_Antrum(_MouseAnatomicalStructureModel):
    """Model ovary follicular antrum"""

    name: Literal["ovary follicular antrum"] = "ovary follicular antrum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37867"] = "EMAPA_37867"


class _Foramen_Magnum(_MouseAnatomicalStructureModel):
    """Model foramen magnum"""

    name: Literal["foramen magnum"] = "foramen magnum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37868"] = "EMAPA_37868"


class _Forehead(_MouseAnatomicalStructureModel):
    """Model forehead"""

    name: Literal["forehead"] = "forehead"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37869"] = "EMAPA_37869"


class _Genu_Of_Facial_Nerve(_MouseAnatomicalStructureModel):
    """Model genu of facial nerve"""

    name: Literal["genu of facial nerve"] = "genu of facial nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37870"] = "EMAPA_37870"


class _Nasal_Gland(_MouseAnatomicalStructureModel):
    """Model nasal gland"""

    name: Literal["nasal gland"] = "nasal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37871"] = "EMAPA_37871"


class _Glymphatic_System(_MouseAnatomicalStructureModel):
    """Model glymphatic system"""

    name: Literal["glymphatic system"] = "glymphatic system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37872"] = "EMAPA_37872"


class _Golgi_Tendon_Organ(_MouseAnatomicalStructureModel):
    """Model golgi tendon organ"""

    name: Literal["golgi tendon organ"] = "golgi tendon organ"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37873"] = "EMAPA_37873"


class _Gonial_Bone(_MouseAnatomicalStructureModel):
    """Model gonial bone"""

    name: Literal["gonial bone"] = "gonial bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37874"] = "EMAPA_37874"


class _Habenular_Commissure(_MouseAnatomicalStructureModel):
    """Model habenular commissure"""

    name: Literal["habenular commissure"] = "habenular commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37875"] = "EMAPA_37875"


class _Hair_Follicle_Bulge(_MouseAnatomicalStructureModel):
    """Model hair follicle bulge"""

    name: Literal["hair follicle bulge"] = "hair follicle bulge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37876"] = "EMAPA_37876"


class _Hair_Follicle_Isthmus(_MouseAnatomicalStructureModel):
    """Model hair follicle isthmus"""

    name: Literal["hair follicle isthmus"] = "hair follicle isthmus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37877"] = "EMAPA_37877"


class _Hair_Follicle_Matrix_Region(_MouseAnatomicalStructureModel):
    """Model hair follicle matrix region"""

    name: Literal["hair follicle matrix region"] = "hair follicle matrix region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37878"] = "EMAPA_37878"


class _Hemotrichorial_Placental_Membrane(_MouseAnatomicalStructureModel):
    """Model hemotrichorial placental membrane"""

    name: Literal["hemotrichorial placental membrane"] = "hemotrichorial placental membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37879"] = "EMAPA_37879"


class _Hepatic_Cord(_MouseAnatomicalStructureModel):
    """Model hepatic cord"""

    name: Literal["hepatic cord"] = "hepatic cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37880"] = "EMAPA_37880"


class _Inguinal_Canal(_MouseAnatomicalStructureModel):
    """Model inguinal canal"""

    name: Literal["inguinal canal"] = "inguinal canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37881"] = "EMAPA_37881"


class _Inner_Ear_Canal(_MouseAnatomicalStructureModel):
    """Model inner ear canal"""

    name: Literal["inner ear canal"] = "inner ear canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37882"] = "EMAPA_37882"


class _Integumental_System_Adnexa(_MouseAnatomicalStructureModel):
    """Model integumental system adnexa"""

    name: Literal["integumental system adnexa"] = "integumental system adnexa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37883"] = "EMAPA_37883"


class _Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model interphalangeal joint"""

    name: Literal["interphalangeal joint"] = "interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37884"] = "EMAPA_37884"


class _Collecting_Duct_Epithelium(_MouseAnatomicalStructureModel):
    """Model collecting duct epithelium"""

    name: Literal["collecting duct epithelium"] = "collecting duct epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37885"] = "EMAPA_37885"


class _Metanephros_Corticomedullary_Boundary(_MouseAnatomicalStructureModel):
    """Model metanephros corticomedullary boundary"""

    name: Literal["metanephros corticomedullary boundary"] = "metanephros corticomedullary boundary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37886"] = "EMAPA_37886"


class _Dorsal_Corticospinal_Tract(_MouseAnatomicalStructureModel):
    """Model dorsal corticospinal tract"""

    name: Literal["dorsal corticospinal tract"] = "dorsal corticospinal tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37887"] = "EMAPA_37887"


class _Lateral_Corticospinal_Tract(_MouseAnatomicalStructureModel):
    """Model lateral corticospinal tract"""

    name: Literal["lateral corticospinal tract"] = "lateral corticospinal tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37888"] = "EMAPA_37888"


class _Ventral_Corticospinal_Tract(_MouseAnatomicalStructureModel):
    """Model ventral corticospinal tract"""

    name: Literal["ventral corticospinal tract"] = "ventral corticospinal tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37889"] = "EMAPA_37889"


class _Head_Of_Fibula(_MouseAnatomicalStructureModel):
    """Model head of fibula"""

    name: Literal["head of fibula"] = "head of fibula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37890"] = "EMAPA_37890"


class _Neck_Of_Fibula(_MouseAnatomicalStructureModel):
    """Model neck of fibula"""

    name: Literal["neck of fibula"] = "neck of fibula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37891"] = "EMAPA_37891"


class _Body_Of_Fibula(_MouseAnatomicalStructureModel):
    """Model body of fibula"""

    name: Literal["body of fibula"] = "body of fibula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37892"] = "EMAPA_37892"


class _Lateral_Malleolus_Of_Fibula(_MouseAnatomicalStructureModel):
    """Model lateral malleolus of fibula"""

    name: Literal["lateral malleolus of fibula"] = "lateral malleolus of fibula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37893"] = "EMAPA_37893"


class _Lateral_Nasal_Gland(_MouseAnatomicalStructureModel):
    """Model lateral nasal gland"""

    name: Literal["lateral nasal gland"] = "lateral nasal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37894"] = "EMAPA_37894"


class _Line_Of_Schwalbe(_MouseAnatomicalStructureModel):
    """Model line of Schwalbe"""

    name: Literal["line of Schwalbe"] = "line of Schwalbe"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37895"] = "EMAPA_37895"


class _Long_Bone_Epiphyseal_Plate_Ossification_Zone(_MouseAnatomicalStructureModel):
    """Model long bone epiphyseal plate ossification zone"""

    name: Literal["long bone epiphyseal plate ossification zone"] = "long bone epiphyseal plate ossification zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37896"] = "EMAPA_37896"


class _Lymph_Node_Medullary_Cord(_MouseAnatomicalStructureModel):
    """Model lymph node medullary cord"""

    name: Literal["lymph node medullary cord"] = "lymph node medullary cord"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37897"] = "EMAPA_37897"


class _Lymph_Node_Medullary_Sinus(_MouseAnatomicalStructureModel):
    """Model lymph node medullary sinus"""

    name: Literal["lymph node medullary sinus"] = "lymph node medullary sinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37898"] = "EMAPA_37898"


class _Major_Sublingual_Duct(_MouseAnatomicalStructureModel):
    """Model major sublingual duct"""

    name: Literal["major sublingual duct"] = "major sublingual duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37899"] = "EMAPA_37899"


class _Mammary_Duct_Terminal_End_Bud(_MouseAnatomicalStructureModel):
    """Model mammary duct terminal end bud"""

    name: Literal["mammary duct terminal end bud"] = "mammary duct terminal end bud"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37900"] = "EMAPA_37900"


class _Mammary_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model mammary fat pad"""

    name: Literal["mammary fat pad"] = "mammary fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37901"] = "EMAPA_37901"


class _Mammary_Gland_Luminal_Epithelium(_MouseAnatomicalStructureModel):
    """Model mammary gland luminal epithelium"""

    name: Literal["mammary gland luminal epithelium"] = "mammary gland luminal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37902"] = "EMAPA_37902"


class _Mammary_Gland_Myoepithelium(_MouseAnatomicalStructureModel):
    """Model mammary gland myoepithelium"""

    name: Literal["mammary gland myoepithelium"] = "mammary gland myoepithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37903"] = "EMAPA_37903"


class _Mammillothalamic_Tract_Of_Hypothalamus(_MouseAnatomicalStructureModel):
    """Model mammillothalamic tract of hypothalamus"""

    name: Literal["mammillothalamic tract of hypothalamus"] = "mammillothalamic tract of hypothalamus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37904"] = "EMAPA_37904"


class _Eyelid_Margin(_MouseAnatomicalStructureModel):
    """Model eyelid margin"""

    name: Literal["eyelid margin"] = "eyelid margin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37905"] = "EMAPA_37905"


class _Medullary_Ray(_MouseAnatomicalStructureModel):
    """Model medullary ray"""

    name: Literal["medullary ray"] = "medullary ray"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37906"] = "EMAPA_37906"


class _Mesangial_Matrix(_MouseAnatomicalStructureModel):
    """Model mesangial matrix"""

    name: Literal["mesangial matrix"] = "mesangial matrix"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37907"] = "EMAPA_37907"


class _Metoptic_Pillar(_MouseAnatomicalStructureModel):
    """Model metoptic pillar"""

    name: Literal["metoptic pillar"] = "metoptic pillar"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37908"] = "EMAPA_37908"


class _Minor_Sublingual_Duct(_MouseAnatomicalStructureModel):
    """Model minor sublingual duct"""

    name: Literal["minor sublingual duct"] = "minor sublingual duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37909"] = "EMAPA_37909"


class _Molar_Crown(_MouseAnatomicalStructureModel):
    """Model molar crown"""

    name: Literal["molar crown"] = "molar crown"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37910"] = "EMAPA_37910"


class _Floor_Of_Oral_Cavity(_MouseAnatomicalStructureModel):
    """Model floor of oral cavity"""

    name: Literal["floor of oral cavity"] = "floor of oral cavity"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37911"] = "EMAPA_37911"


class _Urethra_Mucosa(_MouseAnatomicalStructureModel):
    """Model urethra mucosa"""

    name: Literal["urethra mucosa"] = "urethra mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37912"] = "EMAPA_37912"


class _Mucous_Gland(_MouseAnatomicalStructureModel):
    """Model mucous gland"""

    name: Literal["mucous gland"] = "mucous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37913"] = "EMAPA_37913"


class _Nasal_Concha_Of_Ethmoid_Bone(_MouseAnatomicalStructureModel):
    """Model nasal concha of ethmoid bone"""

    name: Literal["nasal concha of ethmoid bone"] = "nasal concha of ethmoid bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37914"] = "EMAPA_37914"


class _Nose_Tip(_MouseAnatomicalStructureModel):
    """Model nose tip"""

    name: Literal["nose tip"] = "nose tip"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37915"] = "EMAPA_37915"


class _Ocular_Fundus(_MouseAnatomicalStructureModel):
    """Model ocular fundus"""

    name: Literal["ocular fundus"] = "ocular fundus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37916"] = "EMAPA_37916"


class _Main_Olfactory_Bulb_Layer(_MouseAnatomicalStructureModel):
    """Model main olfactory bulb layer"""

    name: Literal["main olfactory bulb layer"] = "main olfactory bulb layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37917"] = "EMAPA_37917"


class _Olfactory_Segment_Of_Nasal_Mucosa(_MouseAnatomicalStructureModel):
    """Model olfactory segment of nasal mucosa"""

    name: Literal["olfactory segment of nasal mucosa"] = "olfactory segment of nasal mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37918"] = "EMAPA_37918"


class _Pretectal_Nucleus(_MouseAnatomicalStructureModel):
    """Model pretectal nucleus"""

    name: Literal["pretectal nucleus"] = "pretectal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37919"] = "EMAPA_37919"


class _Anterior_Pretectal_Nucleus(_MouseAnatomicalStructureModel):
    """Model anterior pretectal nucleus"""

    name: Literal["anterior pretectal nucleus"] = "anterior pretectal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37920"] = "EMAPA_37920"


class _Olivary_Pretectal_Nucleus(_MouseAnatomicalStructureModel):
    """Model olivary pretectal nucleus"""

    name: Literal["olivary pretectal nucleus"] = "olivary pretectal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37921"] = "EMAPA_37921"


class _Posterior_Pretectal_Nucleus(_MouseAnatomicalStructureModel):
    """Model posterior pretectal nucleus"""

    name: Literal["posterior pretectal nucleus"] = "posterior pretectal nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37922"] = "EMAPA_37922"


class _Osteoid(_MouseAnatomicalStructureModel):
    """Model osteoid"""

    name: Literal["osteoid"] = "osteoid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37923"] = "EMAPA_37923"


class _Otolith(_MouseAnatomicalStructureModel):
    """Model otolith"""

    name: Literal["otolith"] = "otolith"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37924"] = "EMAPA_37924"


class _Left_Ventricle_Outflow_Part(_MouseAnatomicalStructureModel):
    """Model left ventricle outflow part"""

    name: Literal["left ventricle outflow part"] = "left ventricle outflow part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37925"] = "EMAPA_37925"


class _Right_Ventricle_Outflow_Part(_MouseAnatomicalStructureModel):
    """Model right ventricle outflow part"""

    name: Literal["right ventricle outflow part"] = "right ventricle outflow part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37926"] = "EMAPA_37926"


class _Ovary_Cortex(_MouseAnatomicalStructureModel):
    """Model ovary cortex"""

    name: Literal["ovary cortex"] = "ovary cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37927"] = "EMAPA_37927"


class _Ovary_Medulla(_MouseAnatomicalStructureModel):
    """Model ovary medulla"""

    name: Literal["ovary medulla"] = "ovary medulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37928"] = "EMAPA_37928"


class _Palatal_Muscle(_MouseAnatomicalStructureModel):
    """Model palatal muscle"""

    name: Literal["palatal muscle"] = "palatal muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37929"] = "EMAPA_37929"


class _Palatal_Bone(_MouseAnatomicalStructureModel):
    """Model palatal bone"""

    name: Literal["palatal bone"] = "palatal bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37930"] = "EMAPA_37930"


class _Palatine_Bone_Horizontal_Plate(_MouseAnatomicalStructureModel):
    """Model palatine bone horizontal plate"""

    name: Literal["palatine bone horizontal plate"] = "palatine bone horizontal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37931"] = "EMAPA_37931"


class _Palatine_Process_Of_Maxilla(_MouseAnatomicalStructureModel):
    """Model palatine process of maxilla"""

    name: Literal["palatine process of maxilla"] = "palatine process of maxilla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37932"] = "EMAPA_37932"


class _Parotid_Gland_Acinus(_MouseAnatomicalStructureModel):
    """Model parotid gland acinus"""

    name: Literal["parotid gland acinus"] = "parotid gland acinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37933"] = "EMAPA_37933"


class _Parotid_Gland_Myoepithelium(_MouseAnatomicalStructureModel):
    """Model parotid gland myoepithelium"""

    name: Literal["parotid gland myoepithelium"] = "parotid gland myoepithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37934"] = "EMAPA_37934"


class _Pecitinate_Muscle(_MouseAnatomicalStructureModel):
    """Model pecitinate muscle"""

    name: Literal["pecitinate muscle"] = "pecitinate muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37935"] = "EMAPA_37935"


class _Perianal_Gland(_MouseAnatomicalStructureModel):
    """Model perianal gland"""

    name: Literal["perianal gland"] = "perianal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37936"] = "EMAPA_37936"


class _Periorbital_Skin(_MouseAnatomicalStructureModel):
    """Model periorbital skin"""

    name: Literal["periorbital skin"] = "periorbital skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37937"] = "EMAPA_37937"


class _Peripheral_Lymph_Node(_MouseAnatomicalStructureModel):
    """Model peripheral lymph node"""

    name: Literal["peripheral lymph node"] = "peripheral lymph node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37938"] = "EMAPA_37938"


class _Peyer_S_Patch_T_Cell_Area(_MouseAnatomicalStructureModel):
    """Model Peyer's patch T cell area"""

    name: Literal["Peyer's patch T cell area"] = "Peyer's patch T cell area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37939"] = "EMAPA_37939"


class _Pubic_Symphysis(_MouseAnatomicalStructureModel):
    """Model pubic symphysis"""

    name: Literal["pubic symphysis"] = "pubic symphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37940"] = "EMAPA_37940"


class _Lung_Acinus(_MouseAnatomicalStructureModel):
    """Model lung acinus"""

    name: Literal["lung acinus"] = "lung acinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37941"] = "EMAPA_37941"


class _Lung_Alveolar_Parenchyma(_MouseAnatomicalStructureModel):
    """Model lung alveolar parenchyma"""

    name: Literal["lung alveolar parenchyma"] = "lung alveolar parenchyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37942"] = "EMAPA_37942"


class _Pulmonary_Neuroendocrine_Body(_MouseAnatomicalStructureModel):
    """Model pulmonary neuroendocrine body"""

    name: Literal["pulmonary neuroendocrine body"] = "pulmonary neuroendocrine body"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37943"] = "EMAPA_37943"


class _Pyloric_Canal(_MouseAnatomicalStructureModel):
    """Model pyloric canal"""

    name: Literal["pyloric canal"] = "pyloric canal"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37944"] = "EMAPA_37944"


class _Pyramidal_Decussation(_MouseAnatomicalStructureModel):
    """Model pyramidal decussation"""

    name: Literal["pyramidal decussation"] = "pyramidal decussation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37945"] = "EMAPA_37945"


class _Respiratory_Conducting_Tube(_MouseAnatomicalStructureModel):
    """Model respiratory conducting tube"""

    name: Literal["respiratory conducting tube"] = "respiratory conducting tube"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37946"] = "EMAPA_37946"


class _Retrosplenial_Granular_Cortex(_MouseAnatomicalStructureModel):
    """Model retrosplenial granular cortex"""

    name: Literal["retrosplenial granular cortex"] = "retrosplenial granular cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37947"] = "EMAPA_37947"


class _Molar_Root(_MouseAnatomicalStructureModel):
    """Model molar root"""

    name: Literal["molar root"] = "molar root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37948"] = "EMAPA_37948"


class _Scalp(_MouseAnatomicalStructureModel):
    """Model scalp"""

    name: Literal["scalp"] = "scalp"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37949"] = "EMAPA_37949"


class _Serous_Gland(_MouseAnatomicalStructureModel):
    """Model serous gland"""

    name: Literal["serous gland"] = "serous gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37950"] = "EMAPA_37950"


class _Sinotubular_Junction(_MouseAnatomicalStructureModel):
    """Model sinotubular junction"""

    name: Literal["sinotubular junction"] = "sinotubular junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37951"] = "EMAPA_37951"


class _Forehead_Skin(_MouseAnatomicalStructureModel):
    """Model forehead skin"""

    name: Literal["forehead skin"] = "forehead skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37952"] = "EMAPA_37952"


class _Somatic_Motor_System(_MouseAnatomicalStructureModel):
    """Model somatic motor system"""

    name: Literal["somatic motor system"] = "somatic motor system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37953"] = "EMAPA_37953"


class _Somatic_Sensory_System(_MouseAnatomicalStructureModel):
    """Model somatic sensory system"""

    name: Literal["somatic sensory system"] = "somatic sensory system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37954"] = "EMAPA_37954"


class _Spinal_Cord_Commissure(_MouseAnatomicalStructureModel):
    """Model spinal cord commissure"""

    name: Literal["spinal cord commissure"] = "spinal cord commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37955"] = "EMAPA_37955"


class _Spinal_Cord_Ventral_Commissure(_MouseAnatomicalStructureModel):
    """Model spinal cord ventral commissure"""

    name: Literal["spinal cord ventral commissure"] = "spinal cord ventral commissure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37956"] = "EMAPA_37956"


class _Autonomic_Nerve(_MouseAnatomicalStructureModel):
    """Model autonomic nerve"""

    name: Literal["autonomic nerve"] = "autonomic nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37957"] = "EMAPA_37957"


class _Sympathetic_Nerve(_MouseAnatomicalStructureModel):
    """Model sympathetic nerve"""

    name: Literal["sympathetic nerve"] = "sympathetic nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37958"] = "EMAPA_37958"


class _Splanchnic_Nerve(_MouseAnatomicalStructureModel):
    """Model splanchnic nerve"""

    name: Literal["splanchnic nerve"] = "splanchnic nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37959"] = "EMAPA_37959"


class _Spleen_Primary_B_Follicle(_MouseAnatomicalStructureModel):
    """Model spleen primary B follicle"""

    name: Literal["spleen primary B follicle"] = "spleen primary B follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37960"] = "EMAPA_37960"


class _Spleen_Secondary_B_Follicle(_MouseAnatomicalStructureModel):
    """Model spleen secondary B follicle"""

    name: Literal["spleen secondary B follicle"] = "spleen secondary B follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37961"] = "EMAPA_37961"


class _Spleen_B_Cell_Corona(_MouseAnatomicalStructureModel):
    """Model spleen B cell corona"""

    name: Literal["spleen B cell corona"] = "spleen B cell corona"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37962"] = "EMAPA_37962"


class _Spleen_Follicular_Dendritic_Cell_Network(_MouseAnatomicalStructureModel):
    """Model spleen follicular dendritic cell network"""

    name: Literal["spleen follicular dendritic cell network"] = "spleen follicular dendritic cell network"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37963"] = "EMAPA_37963"


class _Spleen_Perifollicular_Zone(_MouseAnatomicalStructureModel):
    """Model spleen perifollicular zone"""

    name: Literal["spleen perifollicular zone"] = "spleen perifollicular zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37964"] = "EMAPA_37964"


class _Stomach_Smooth_Muscle_Inner_Oblique_Layer(_MouseAnatomicalStructureModel):
    """Model stomach smooth muscle inner oblique layer"""

    name: Literal["stomach smooth muscle inner oblique layer"] = "stomach smooth muscle inner oblique layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37965"] = "EMAPA_37965"


class _Stomach_Smooth_Muscle_Outer_Longitudinal_Layer(_MouseAnatomicalStructureModel):
    """Model stomach smooth muscle outer longitudinal layer"""

    name: Literal["stomach smooth muscle outer longitudinal layer"] = "stomach smooth muscle outer longitudinal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37966"] = "EMAPA_37966"


class _Subarcuate_Fossa(_MouseAnatomicalStructureModel):
    """Model subarcuate fossa"""

    name: Literal["subarcuate fossa"] = "subarcuate fossa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37967"] = "EMAPA_37967"


class _Subendocardium(_MouseAnatomicalStructureModel):
    """Model subendocardium"""

    name: Literal["subendocardium"] = "subendocardium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37968"] = "EMAPA_37968"


class _Subglottic_Region(_MouseAnatomicalStructureModel):
    """Model subglottic region"""

    name: Literal["subglottic region"] = "subglottic region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37969"] = "EMAPA_37969"


class _Submucosal_Gland(_MouseAnatomicalStructureModel):
    """Model submucosal gland"""

    name: Literal["submucosal gland"] = "submucosal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37970"] = "EMAPA_37970"


class _Tail_Hair(_MouseAnatomicalStructureModel):
    """Model tail hair"""

    name: Literal["tail hair"] = "tail hair"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37971"] = "EMAPA_37971"


class _Meibomian_Gland_Acinus(_MouseAnatomicalStructureModel):
    """Model meibomian gland acinus"""

    name: Literal["meibomian gland acinus"] = "meibomian gland acinus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37972"] = "EMAPA_37972"


class _Throat(_MouseAnatomicalStructureModel):
    """Model throat"""

    name: Literal["throat"] = "throat"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37973"] = "EMAPA_37973"


class _Thymus_Corticomedullary_Boundary(_MouseAnatomicalStructureModel):
    """Model thymus corticomedullary boundary"""

    name: Literal["thymus corticomedullary boundary"] = "thymus corticomedullary boundary"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37974"] = "EMAPA_37974"


class _Tooth_Root(_MouseAnatomicalStructureModel):
    """Model tooth root"""

    name: Literal["tooth root"] = "tooth root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37975"] = "EMAPA_37975"


class _Tunnel_Of_Corti(_MouseAnatomicalStructureModel):
    """Model tunnel of Corti"""

    name: Literal["tunnel of Corti"] = "tunnel of Corti"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37976"] = "EMAPA_37976"


class _Urethral_Meatus(_MouseAnatomicalStructureModel):
    """Model urethral meatus"""

    name: Literal["urethral meatus"] = "urethral meatus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37977"] = "EMAPA_37977"


class _Urothelium(_MouseAnatomicalStructureModel):
    """Model urothelium"""

    name: Literal["urothelium"] = "urothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37978"] = "EMAPA_37978"


class _Uterine_Fat_Pad(_MouseAnatomicalStructureModel):
    """Model uterine fat pad"""

    name: Literal["uterine fat pad"] = "uterine fat pad"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37979"] = "EMAPA_37979"


class _Utriculosaccular_Duct(_MouseAnatomicalStructureModel):
    """Model utriculosaccular duct"""

    name: Literal["utriculosaccular duct"] = "utriculosaccular duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37980"] = "EMAPA_37980"


class _Utricle_Duct(_MouseAnatomicalStructureModel):
    """Model utricle duct"""

    name: Literal["utricle duct"] = "utricle duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37981"] = "EMAPA_37981"


class _Saccule_Duct(_MouseAnatomicalStructureModel):
    """Model saccule duct"""

    name: Literal["saccule duct"] = "saccule duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37982"] = "EMAPA_37982"


class _Vagina_Orifice(_MouseAnatomicalStructureModel):
    """Model vagina orifice"""

    name: Literal["vagina orifice"] = "vagina orifice"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37983"] = "EMAPA_37983"


class _Ventral_Body_Wall(_MouseAnatomicalStructureModel):
    """Model ventral body wall"""

    name: Literal["ventral body wall"] = "ventral body wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37984"] = "EMAPA_37984"


class _Vestibulo_Auditory_System(_MouseAnatomicalStructureModel):
    """Model vestibulo-auditory system"""

    name: Literal["vestibulo-auditory system"] = "vestibulo-auditory system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37985"] = "EMAPA_37985"


class _Vestibular_System(_MouseAnatomicalStructureModel):
    """Model vestibular system"""

    name: Literal["vestibular system"] = "vestibular system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37986"] = "EMAPA_37986"


class _Blood_Vessel_Wall(_MouseAnatomicalStructureModel):
    """Model blood vessel wall"""

    name: Literal["blood vessel wall"] = "blood vessel wall"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37987"] = "EMAPA_37987"


class _Chordamesoderm(_MouseAnatomicalStructureModel):
    """Model chordamesoderm"""

    name: Literal["chordamesoderm"] = "chordamesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37988"] = "EMAPA_37988"


class _Prechordal_Mesoderm(_MouseAnatomicalStructureModel):
    """Model prechordal mesoderm"""

    name: Literal["prechordal mesoderm"] = "prechordal mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37989"] = "EMAPA_37989"


class _Prechordal_Plate(_MouseAnatomicalStructureModel):
    """Model prechordal plate"""

    name: Literal["prechordal plate"] = "prechordal plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37990"] = "EMAPA_37990"


class _Cardiac_Neural_Crest(_MouseAnatomicalStructureModel):
    """Model cardiac neural crest"""

    name: Literal["cardiac neural crest"] = "cardiac neural crest"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37991"] = "EMAPA_37991"


class _Cardiogenic_Splanchnic_Mesoderm(_MouseAnatomicalStructureModel):
    """Model cardiogenic splanchnic mesoderm"""

    name: Literal["cardiogenic splanchnic mesoderm"] = "cardiogenic splanchnic mesoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37992"] = "EMAPA_37992"


class _Primary_Heart_Field(_MouseAnatomicalStructureModel):
    """Model primary heart field"""

    name: Literal["primary heart field"] = "primary heart field"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37993"] = "EMAPA_37993"


class _Neuraxis_Flexure(_MouseAnatomicalStructureModel):
    """Model neuraxis flexure"""

    name: Literal["neuraxis flexure"] = "neuraxis flexure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37994"] = "EMAPA_37994"


class _Cephalic_Midbrain_Flexure(_MouseAnatomicalStructureModel):
    """Model cephalic midbrain flexure"""

    name: Literal["cephalic midbrain flexure"] = "cephalic midbrain flexure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37995"] = "EMAPA_37995"


class _Pontine_Flexure(_MouseAnatomicalStructureModel):
    """Model pontine flexure"""

    name: Literal["pontine flexure"] = "pontine flexure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37996"] = "EMAPA_37996"


class _Cervical_Flexure(_MouseAnatomicalStructureModel):
    """Model cervical flexure"""

    name: Literal["cervical flexure"] = "cervical flexure"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37997"] = "EMAPA_37997"


class _Nephrogenic_Cord_Rostral_Part(_MouseAnatomicalStructureModel):
    """Model nephrogenic cord rostral part"""

    name: Literal["nephrogenic cord rostral part"] = "nephrogenic cord rostral part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37998"] = "EMAPA_37998"


class _Nephrogenic_Cord_Caudal_Part(_MouseAnatomicalStructureModel):
    """Model nephrogenic cord caudal part"""

    name: Literal["nephrogenic cord caudal part"] = "nephrogenic cord caudal part"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_37999"] = "EMAPA_37999"


class _Nephron_Epithelium(_MouseAnatomicalStructureModel):
    """Model nephron epithelium"""

    name: Literal["nephron epithelium"] = "nephron epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38000"] = "EMAPA_38000"


class _Cerebellar_Plate(_MouseAnatomicalStructureModel):
    """Model cerebellar plate"""

    name: Literal["cerebellar plate"] = "cerebellar plate"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38001"] = "EMAPA_38001"


class _Neuromere(_MouseAnatomicalStructureModel):
    """Model neuromere"""

    name: Literal["neuromere"] = "neuromere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38002"] = "EMAPA_38002"


class _Neuropore(_MouseAnatomicalStructureModel):
    """Model neuropore"""

    name: Literal["neuropore"] = "neuropore"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38003"] = "EMAPA_38003"


class _Cruciate_Ligament_Of_Knee(_MouseAnatomicalStructureModel):
    """Model cruciate ligament of knee"""

    name: Literal["cruciate ligament of knee"] = "cruciate ligament of knee"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38004"] = "EMAPA_38004"


class _Meniscus_Of_Knee(_MouseAnatomicalStructureModel):
    """Model meniscus of knee"""

    name: Literal["meniscus of knee"] = "meniscus of knee"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38005"] = "EMAPA_38005"


class _Lateral_Meniscus_Of_Knee(_MouseAnatomicalStructureModel):
    """Model lateral meniscus of knee"""

    name: Literal["lateral meniscus of knee"] = "lateral meniscus of knee"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38006"] = "EMAPA_38006"


class _Medial_Meniscus_Of_Knee(_MouseAnatomicalStructureModel):
    """Model medial meniscus of knee"""

    name: Literal["medial meniscus of knee"] = "medial meniscus of knee"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38007"] = "EMAPA_38007"


class _Deep_Peroneal_Nerve(_MouseAnatomicalStructureModel):
    """Model deep peroneal nerve"""

    name: Literal["deep peroneal nerve"] = "deep peroneal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38008"] = "EMAPA_38008"


class _Superficial_Peroneal_Nerve(_MouseAnatomicalStructureModel):
    """Model superficial peroneal nerve"""

    name: Literal["superficial peroneal nerve"] = "superficial peroneal nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38009"] = "EMAPA_38009"


class _Lateral_Femoral_Cutaneous_Nerve(_MouseAnatomicalStructureModel):
    """Model lateral femoral cutaneous nerve"""

    name: Literal["lateral femoral cutaneous nerve"] = "lateral femoral cutaneous nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38010"] = "EMAPA_38010"


class _Upper_Lip_Skin(_MouseAnatomicalStructureModel):
    """Model upper lip skin"""

    name: Literal["upper lip skin"] = "upper lip skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38011"] = "EMAPA_38011"


class _Lower_Lip_Skin(_MouseAnatomicalStructureModel):
    """Model lower lip skin"""

    name: Literal["lower lip skin"] = "lower lip skin"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38012"] = "EMAPA_38012"


class _Periderm(_MouseAnatomicalStructureModel):
    """Model periderm"""

    name: Literal["periderm"] = "periderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38013"] = "EMAPA_38013"


class _Thymus_Cortex_Epithelium(_MouseAnatomicalStructureModel):
    """Model thymus cortex epithelium"""

    name: Literal["thymus cortex epithelium"] = "thymus cortex epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38014"] = "EMAPA_38014"


class _Thymus_Medulla_Epithelium(_MouseAnatomicalStructureModel):
    """Model thymus medulla epithelium"""

    name: Literal["thymus medulla epithelium"] = "thymus medulla epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38015"] = "EMAPA_38015"


class _Duodenum_Villus(_MouseAnatomicalStructureModel):
    """Model duodenum villus"""

    name: Literal["duodenum villus"] = "duodenum villus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38016"] = "EMAPA_38016"


class _Jejunum_Villus(_MouseAnatomicalStructureModel):
    """Model jejunum villus"""

    name: Literal["jejunum villus"] = "jejunum villus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38017"] = "EMAPA_38017"


class _Ileum_Villus(_MouseAnatomicalStructureModel):
    """Model ileum villus"""

    name: Literal["ileum villus"] = "ileum villus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38018"] = "EMAPA_38018"


class _Gut_Mucosa(_MouseAnatomicalStructureModel):
    """Model gut mucosa"""

    name: Literal["gut mucosa"] = "gut mucosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38019"] = "EMAPA_38019"


class _Gut_Serosa(_MouseAnatomicalStructureModel):
    """Model gut serosa"""

    name: Literal["gut serosa"] = "gut serosa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38020"] = "EMAPA_38020"


class _Bladder_Lumen(_MouseAnatomicalStructureModel):
    """Model bladder lumen"""

    name: Literal["bladder lumen"] = "bladder lumen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38021"] = "EMAPA_38021"


class _Vertebrobasilar_Arterial_System(_MouseAnatomicalStructureModel):
    """Model vertebrobasilar arterial system"""

    name: Literal["vertebrobasilar arterial system"] = "vertebrobasilar arterial system"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38022"] = "EMAPA_38022"


class _Cerebral_Hemisphere(_MouseAnatomicalStructureModel):
    """Model cerebral hemisphere"""

    name: Literal["cerebral hemisphere"] = "cerebral hemisphere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38023"] = "EMAPA_38023"


class _Left_Cerebral_Hemisphere(_MouseAnatomicalStructureModel):
    """Model left cerebral hemisphere"""

    name: Literal["left cerebral hemisphere"] = "left cerebral hemisphere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38024"] = "EMAPA_38024"


class _Right_Cerebral_Hemisphere(_MouseAnatomicalStructureModel):
    """Model right cerebral hemisphere"""

    name: Literal["right cerebral hemisphere"] = "right cerebral hemisphere"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38025"] = "EMAPA_38025"


class _Upper_Jaw_Primordium(_MouseAnatomicalStructureModel):
    """Model upper jaw primordium"""

    name: Literal["upper jaw primordium"] = "upper jaw primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38026"] = "EMAPA_38026"


class _Lower_Jaw_Primordium(_MouseAnatomicalStructureModel):
    """Model lower jaw primordium"""

    name: Literal["lower jaw primordium"] = "lower jaw primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38027"] = "EMAPA_38027"


class _Long_Bone_Epiphyseal_Plate_Resting_Zone(_MouseAnatomicalStructureModel):
    """Model long bone epiphyseal plate resting zone"""

    name: Literal["long bone epiphyseal plate resting zone"] = "long bone epiphyseal plate resting zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38028"] = "EMAPA_38028"


class _Extracellular_Matrix(_MouseAnatomicalStructureModel):
    """Model extracellular matrix"""

    name: Literal["extracellular matrix"] = "extracellular matrix"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38029"] = "EMAPA_38029"


class _Basement_Membrane(_MouseAnatomicalStructureModel):
    """Model basement membrane"""

    name: Literal["basement membrane"] = "basement membrane"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38030"] = "EMAPA_38030"


class _Basement_Membrane_Of_Epithelium(_MouseAnatomicalStructureModel):
    """Model basement membrane of epithelium"""

    name: Literal["basement membrane of epithelium"] = "basement membrane of epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38031"] = "EMAPA_38031"


class _Uterus_Epithelium(_MouseAnatomicalStructureModel):
    """Model uterus epithelium"""

    name: Literal["uterus epithelium"] = "uterus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38032"] = "EMAPA_38032"


class _Atlanto_Occipital_Joint(_MouseAnatomicalStructureModel):
    """Model atlanto-occipital joint"""

    name: Literal["atlanto-occipital joint"] = "atlanto-occipital joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38033"] = "EMAPA_38033"


class _Optic_Choroid_Plus_Pigmented_Retinal_Epithelium(_MouseAnatomicalStructureModel):
    """Model optic choroid plus pigmented retinal epithelium"""

    name: Literal["optic choroid plus pigmented retinal epithelium"] = "optic choroid plus pigmented retinal epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38035"] = "EMAPA_38035"


class _Lymph_Sac(_MouseAnatomicalStructureModel):
    """Model lymph sac"""

    name: Literal["lymph sac"] = "lymph sac"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38036"] = "EMAPA_38036"


class _Mammary_Gland_Primordium(_MouseAnatomicalStructureModel):
    """Model mammary gland primordium"""

    name: Literal["mammary gland primordium"] = "mammary gland primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38037"] = "EMAPA_38037"


class _Mammary_Gland_Primordium_Epithelium(_MouseAnatomicalStructureModel):
    """Model mammary gland primordium epithelium"""

    name: Literal["mammary gland primordium epithelium"] = "mammary gland primordium epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38038"] = "EMAPA_38038"


class _Mammary_Fat_Pad_Precursor(_MouseAnatomicalStructureModel):
    """Model mammary fat pad precursor"""

    name: Literal["mammary fat pad precursor"] = "mammary fat pad precursor"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38039"] = "EMAPA_38039"


class _Mammary_Sprout(_MouseAnatomicalStructureModel):
    """Model mammary sprout"""

    name: Literal["mammary sprout"] = "mammary sprout"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38040"] = "EMAPA_38040"


class _Carpal_Metacarpal_Joint(_MouseAnatomicalStructureModel):
    """Model carpal-metacarpal joint"""

    name: Literal["carpal-metacarpal joint"] = "carpal-metacarpal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38041"] = "EMAPA_38041"


class _Tarsal_Metatarsal_Joint(_MouseAnatomicalStructureModel):
    """Model tarsal-metatarsal joint"""

    name: Literal["tarsal-metatarsal joint"] = "tarsal-metatarsal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38042"] = "EMAPA_38042"


class _Proximal_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model proximal interphalangeal joint"""

    name: Literal["proximal interphalangeal joint"] = "proximal interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38043"] = "EMAPA_38043"


class _Distal_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model distal interphalangeal joint"""

    name: Literal["distal interphalangeal joint"] = "distal interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38044"] = "EMAPA_38044"


class _Forelimb_Proximal_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb proximal interphalangeal joint"""

    name: Literal["forelimb proximal interphalangeal joint"] = "forelimb proximal interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38045"] = "EMAPA_38045"


class _Forelimb_Distal_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model forelimb distal interphalangeal joint"""

    name: Literal["forelimb distal interphalangeal joint"] = "forelimb distal interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38046"] = "EMAPA_38046"


class _Hindlimb_Proximal_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb proximal interphalangeal joint"""

    name: Literal["hindlimb proximal interphalangeal joint"] = "hindlimb proximal interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38047"] = "EMAPA_38047"


class _Hindlimb_Distal_Interphalangeal_Joint(_MouseAnatomicalStructureModel):
    """Model hindlimb distal interphalangeal joint"""

    name: Literal["hindlimb distal interphalangeal joint"] = "hindlimb distal interphalangeal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38048"] = "EMAPA_38048"


class _Joint_Of_Auditory_Ossicle(_MouseAnatomicalStructureModel):
    """Model joint of auditory ossicle"""

    name: Literal["joint of auditory ossicle"] = "joint of auditory ossicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38049"] = "EMAPA_38049"


class _Incudomalleal_Joint(_MouseAnatomicalStructureModel):
    """Model incudomalleal joint"""

    name: Literal["incudomalleal joint"] = "incudomalleal joint"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38050"] = "EMAPA_38050"


class _Heart_Trabecula(_MouseAnatomicalStructureModel):
    """Model heart trabecula"""

    name: Literal["heart trabecula"] = "heart trabecula"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38051"] = "EMAPA_38051"


class _Atrial_Trabecula_Cardiac_Muscle(_MouseAnatomicalStructureModel):
    """Model atrial trabecula cardiac muscle"""

    name: Literal["atrial trabecula cardiac muscle"] = "atrial trabecula cardiac muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38052"] = "EMAPA_38052"


class _Atrioventricular_Sulcus(_MouseAnatomicalStructureModel):
    """Model atrioventricular sulcus"""

    name: Literal["atrioventricular sulcus"] = "atrioventricular sulcus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38053"] = "EMAPA_38053"


class _Limb_Tendon(_MouseAnatomicalStructureModel):
    """Model limb tendon"""

    name: Literal["limb tendon"] = "limb tendon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38054"] = "EMAPA_38054"


class _Tendon_Primordium(_MouseAnatomicalStructureModel):
    """Model tendon primordium"""

    name: Literal["tendon primordium"] = "tendon primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38055"] = "EMAPA_38055"


class _Limb_Tendon_Primordium(_MouseAnatomicalStructureModel):
    """Model limb tendon primordium"""

    name: Literal["limb tendon primordium"] = "limb tendon primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38056"] = "EMAPA_38056"


class _Forelimb_Tendon_Primordium(_MouseAnatomicalStructureModel):
    """Model forelimb tendon primordium"""

    name: Literal["forelimb tendon primordium"] = "forelimb tendon primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38057"] = "EMAPA_38057"


class _Hindlimb_Tendon_Primordium(_MouseAnatomicalStructureModel):
    """Model hindlimb tendon primordium"""

    name: Literal["hindlimb tendon primordium"] = "hindlimb tendon primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38058"] = "EMAPA_38058"


class _Forelimb_Tendon(_MouseAnatomicalStructureModel):
    """Model forelimb tendon"""

    name: Literal["forelimb tendon"] = "forelimb tendon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38059"] = "EMAPA_38059"


class _Hindlimb_Tendon(_MouseAnatomicalStructureModel):
    """Model hindlimb tendon"""

    name: Literal["hindlimb tendon"] = "hindlimb tendon"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38060"] = "EMAPA_38060"


class _Forelimb_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model forelimb joint primordium"""

    name: Literal["forelimb joint primordium"] = "forelimb joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38061"] = "EMAPA_38061"


class _Hindlimb_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model hindlimb joint primordium"""

    name: Literal["hindlimb joint primordium"] = "hindlimb joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38062"] = "EMAPA_38062"


class _Hand_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model hand joint primordium"""

    name: Literal["hand joint primordium"] = "hand joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38063"] = "EMAPA_38063"


class _Foot_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model foot joint primordium"""

    name: Literal["foot joint primordium"] = "foot joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38064"] = "EMAPA_38064"


class _Anterior_Cruciate_Ligament(_MouseAnatomicalStructureModel):
    """Model anterior cruciate ligament"""

    name: Literal["anterior cruciate ligament"] = "anterior cruciate ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38065"] = "EMAPA_38065"


class _Posterior_Cruciate_Ligament(_MouseAnatomicalStructureModel):
    """Model posterior cruciate ligament"""

    name: Literal["posterior cruciate ligament"] = "posterior cruciate ligament"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38066"] = "EMAPA_38066"


class _Intestine_Smooth_Muscle_Circular_Layer(_MouseAnatomicalStructureModel):
    """Model intestine smooth muscle circular layer"""

    name: Literal["intestine smooth muscle circular layer"] = "intestine smooth muscle circular layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38067"] = "EMAPA_38067"


class _Intestine_Smooth_Muscle_Longitudinal_Layer(_MouseAnatomicalStructureModel):
    """Model intestine smooth muscle longitudinal layer"""

    name: Literal["intestine smooth muscle longitudinal layer"] = "intestine smooth muscle longitudinal layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38068"] = "EMAPA_38068"


class _Secondary_Motor_Cortex(_MouseAnatomicalStructureModel):
    """Model secondary motor cortex"""

    name: Literal["secondary motor cortex"] = "secondary motor cortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38069"] = "EMAPA_38069"


class _Ectorhinal_Area(_MouseAnatomicalStructureModel):
    """Model ectorhinal area"""

    name: Literal["ectorhinal area"] = "ectorhinal area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38070"] = "EMAPA_38070"


class _Infralimbic_Area(_MouseAnatomicalStructureModel):
    """Model infralimbic area"""

    name: Literal["infralimbic area"] = "infralimbic area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38071"] = "EMAPA_38071"


class _Orbital_Area(_MouseAnatomicalStructureModel):
    """Model orbital area"""

    name: Literal["orbital area"] = "orbital area"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38072"] = "EMAPA_38072"


class _Anterior_Medial_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model anterior medial thalamic nucleus"""

    name: Literal["anterior medial thalamic nucleus"] = "anterior medial thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38073"] = "EMAPA_38073"


class _Vestibulocerebellar_Nucleus(_MouseAnatomicalStructureModel):
    """Model vestibulocerebellar nucleus"""

    name: Literal["vestibulocerebellar nucleus"] = "vestibulocerebellar nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38074"] = "EMAPA_38074"


class _Lateral_Dorsal_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral dorsal thalamic nucleus"""

    name: Literal["lateral dorsal thalamic nucleus"] = "lateral dorsal thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38075"] = "EMAPA_38075"


class _Lateral_Posterior_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model lateral posterior thalamic nucleus"""

    name: Literal["lateral posterior thalamic nucleus"] = "lateral posterior thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38076"] = "EMAPA_38076"


class _Ventral_Medial_Thalamic_Nucleus(_MouseAnatomicalStructureModel):
    """Model ventral medial thalamic nucleus"""

    name: Literal["ventral medial thalamic nucleus"] = "ventral medial thalamic nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38077"] = "EMAPA_38077"


class _Cranial_Cartilage(_MouseAnatomicalStructureModel):
    """Model cranial cartilage"""

    name: Literal["cranial cartilage"] = "cranial cartilage"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38078"] = "EMAPA_38078"


class _Tectum_Transversum(_MouseAnatomicalStructureModel):
    """Model tectum transversum"""

    name: Literal["tectum transversum"] = "tectum transversum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38079"] = "EMAPA_38079"


class _Cervical_Loop(_MouseAnatomicalStructureModel):
    """Model cervical loop"""

    name: Literal["cervical loop"] = "cervical loop"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38080"] = "EMAPA_38080"


class _Stellate_Reticulum(_MouseAnatomicalStructureModel):
    """Model stellate reticulum"""

    name: Literal["stellate reticulum"] = "stellate reticulum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38081"] = "EMAPA_38081"


class _Stratum_Intermedium(_MouseAnatomicalStructureModel):
    """Model stratum intermedium"""

    name: Literal["stratum intermedium"] = "stratum intermedium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38082"] = "EMAPA_38082"


class _Hertwig_S_Epithelial_Root_Sheath(_MouseAnatomicalStructureModel):
    """Model Hertwig's epithelial root sheath"""

    name: Literal["Hertwig's epithelial root sheath"] = "Hertwig's epithelial root sheath"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38083"] = "EMAPA_38083"


class _Enamel_Epithelium(_MouseAnatomicalStructureModel):
    """Model enamel epithelium"""

    name: Literal["enamel epithelium"] = "enamel epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38084"] = "EMAPA_38084"


class _Inner_Enamel_Epithelium(_MouseAnatomicalStructureModel):
    """Model inner enamel epithelium"""

    name: Literal["inner enamel epithelium"] = "inner enamel epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38085"] = "EMAPA_38085"


class _Outer_Enamel_Epithelium(_MouseAnatomicalStructureModel):
    """Model outer enamel epithelium"""

    name: Literal["outer enamel epithelium"] = "outer enamel epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38086"] = "EMAPA_38086"


class _Dental_Alveolus(_MouseAnatomicalStructureModel):
    """Model dental alveolus"""

    name: Literal["dental alveolus"] = "dental alveolus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38087"] = "EMAPA_38087"


class _Interalveolar_Bone(_MouseAnatomicalStructureModel):
    """Model interalveolar bone"""

    name: Literal["interalveolar bone"] = "interalveolar bone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38088"] = "EMAPA_38088"


class _Early_Bud_Stage_Tooth(_MouseAnatomicalStructureModel):
    """Model early bud stage tooth"""

    name: Literal["early bud stage tooth"] = "early bud stage tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38089"] = "EMAPA_38089"


class _Late_Bud_Stage_Tooth(_MouseAnatomicalStructureModel):
    """Model late bud stage tooth"""

    name: Literal["late bud stage tooth"] = "late bud stage tooth"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38090"] = "EMAPA_38090"


class _Enamel_Knot(_MouseAnatomicalStructureModel):
    """Model enamel knot"""

    name: Literal["enamel knot"] = "enamel knot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38091"] = "EMAPA_38091"


class _Primary_Enamel_Knot(_MouseAnatomicalStructureModel):
    """Model primary enamel knot"""

    name: Literal["primary enamel knot"] = "primary enamel knot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38092"] = "EMAPA_38092"


class _Secondary_Enamel_Knot(_MouseAnatomicalStructureModel):
    """Model secondary enamel knot"""

    name: Literal["secondary enamel knot"] = "secondary enamel knot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38093"] = "EMAPA_38093"


class _Tertiary_Enamel_Knot(_MouseAnatomicalStructureModel):
    """Model tertiary enamel knot"""

    name: Literal["tertiary enamel knot"] = "tertiary enamel knot"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38094"] = "EMAPA_38094"


class _Tensor_Veli_Palatini(_MouseAnatomicalStructureModel):
    """Model tensor veli palatini"""

    name: Literal["tensor veli palatini"] = "tensor veli palatini"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38095"] = "EMAPA_38095"


class _Levator_Veli_Palatini(_MouseAnatomicalStructureModel):
    """Model levator veli palatini"""

    name: Literal["levator veli palatini"] = "levator veli palatini"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38096"] = "EMAPA_38096"


class _Palatopharyngeus(_MouseAnatomicalStructureModel):
    """Model palatopharyngeus"""

    name: Literal["palatopharyngeus"] = "palatopharyngeus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38097"] = "EMAPA_38097"


class _Limb_Primordium(_MouseAnatomicalStructureModel):
    """Model limb primordium"""

    name: Literal["limb primordium"] = "limb primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38098"] = "EMAPA_38098"


class _Small_Intestine_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model small intestine vascular element"""

    name: Literal["small intestine vascular element"] = "small intestine vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38099"] = "EMAPA_38099"


class _Spleen_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model spleen vascular element"""

    name: Literal["spleen vascular element"] = "spleen vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38100"] = "EMAPA_38100"


class _Intestine_Vascular_Element(_MouseAnatomicalStructureModel):
    """Model intestine vascular element"""

    name: Literal["intestine vascular element"] = "intestine vascular element"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38101"] = "EMAPA_38101"


class _Lateral_Nasal_Gland_2(_MouseAnatomicalStructureModel):
    """Model lateral nasal gland 2"""

    name: Literal["lateral nasal gland 2"] = "lateral nasal gland 2"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38102"] = "EMAPA_38102"


class _Lateral_Nasal_Gland_3(_MouseAnatomicalStructureModel):
    """Model lateral nasal gland 3"""

    name: Literal["lateral nasal gland 3"] = "lateral nasal gland 3"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38103"] = "EMAPA_38103"


class _Lateral_Nasal_Gland_4(_MouseAnatomicalStructureModel):
    """Model lateral nasal gland 4"""

    name: Literal["lateral nasal gland 4"] = "lateral nasal gland 4"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38104"] = "EMAPA_38104"


class _Lateral_Nasal_Gland_5(_MouseAnatomicalStructureModel):
    """Model lateral nasal gland 5"""

    name: Literal["lateral nasal gland 5"] = "lateral nasal gland 5"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38105"] = "EMAPA_38105"


class _Lateral_Nasal_Gland_Duct(_MouseAnatomicalStructureModel):
    """Model lateral nasal gland duct"""

    name: Literal["lateral nasal gland duct"] = "lateral nasal gland duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38106"] = "EMAPA_38106"


class _Lateral_Nasal_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model lateral nasal gland epithelium"""

    name: Literal["lateral nasal gland epithelium"] = "lateral nasal gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38107"] = "EMAPA_38107"


class _Lateral_Nasal_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lateral nasal gland mesenchyme"""

    name: Literal["lateral nasal gland mesenchyme"] = "lateral nasal gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38108"] = "EMAPA_38108"


class _Maxillary_Sinus_Gland_Primordium(_MouseAnatomicalStructureModel):
    """Model maxillary sinus gland primordium"""

    name: Literal["maxillary sinus gland primordium"] = "maxillary sinus gland primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38109"] = "EMAPA_38109"


class _Maxillary_Sinus_Gland_Primordium_Epithelium(_MouseAnatomicalStructureModel):
    """Model maxillary sinus gland primordium epithelium"""

    name: Literal["maxillary sinus gland primordium epithelium"] = "maxillary sinus gland primordium epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38110"] = "EMAPA_38110"


class _Maxillary_Sinus_Gland_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model maxillary sinus gland primordium mesenchyme"""

    name: Literal["maxillary sinus gland primordium mesenchyme"] = "maxillary sinus gland primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38111"] = "EMAPA_38111"


class _Maxillary_Sinus_Gland(_MouseAnatomicalStructureModel):
    """Model maxillary sinus gland"""

    name: Literal["maxillary sinus gland"] = "maxillary sinus gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38112"] = "EMAPA_38112"


class _Maxillary_Sinus_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model maxillary sinus gland epithelium"""

    name: Literal["maxillary sinus gland epithelium"] = "maxillary sinus gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38113"] = "EMAPA_38113"


class _Maxillary_Sinus_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model maxillary sinus gland mesenchyme"""

    name: Literal["maxillary sinus gland mesenchyme"] = "maxillary sinus gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38114"] = "EMAPA_38114"


class _Medial_Nasal_Gland(_MouseAnatomicalStructureModel):
    """Model medial nasal gland"""

    name: Literal["medial nasal gland"] = "medial nasal gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38115"] = "EMAPA_38115"


class _Medial_Nasal_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model medial nasal gland epithelium"""

    name: Literal["medial nasal gland epithelium"] = "medial nasal gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38116"] = "EMAPA_38116"


class _Medial_Nasal_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model medial nasal gland mesenchyme"""

    name: Literal["medial nasal gland mesenchyme"] = "medial nasal gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38117"] = "EMAPA_38117"


class _Steno_S_Gland(_MouseAnatomicalStructureModel):
    """Model Steno's gland"""

    name: Literal["Steno's gland"] = "Steno's gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38118"] = "EMAPA_38118"


class _Steno_S_Duct(_MouseAnatomicalStructureModel):
    """Model Steno's duct"""

    name: Literal["Steno's duct"] = "Steno's duct"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38119"] = "EMAPA_38119"


class _Steno_S_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model Steno's gland epithelium"""

    name: Literal["Steno's gland epithelium"] = "Steno's gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38120"] = "EMAPA_38120"


class _Steno_S_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model Steno's gland mesenchyme"""

    name: Literal["Steno's gland mesenchyme"] = "Steno's gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38121"] = "EMAPA_38121"


class _Maxillary_Sinus_Epithelium(_MouseAnatomicalStructureModel):
    """Model maxillary sinus epithelium"""

    name: Literal["maxillary sinus epithelium"] = "maxillary sinus epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38122"] = "EMAPA_38122"


class _Maxillary_Sinus_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model maxillary sinus mesenchyme"""

    name: Literal["maxillary sinus mesenchyme"] = "maxillary sinus mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38123"] = "EMAPA_38123"


class _Nasal_Gland_Epithelium(_MouseAnatomicalStructureModel):
    """Model nasal gland epithelium"""

    name: Literal["nasal gland epithelium"] = "nasal gland epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38124"] = "EMAPA_38124"


class _Nasal_Gland_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model nasal gland mesenchyme"""

    name: Literal["nasal gland mesenchyme"] = "nasal gland mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38125"] = "EMAPA_38125"


class _Parathyroid_Primordium(_MouseAnatomicalStructureModel):
    """Model parathyroid primordium"""

    name: Literal["parathyroid primordium"] = "parathyroid primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38126"] = "EMAPA_38126"


class _Adrenogonadal_Primordium(_MouseAnatomicalStructureModel):
    """Model adrenogonadal primordium"""

    name: Literal["adrenogonadal primordium"] = "adrenogonadal primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38127"] = "EMAPA_38127"


class _Adrenal_Primordium(_MouseAnatomicalStructureModel):
    """Model adrenal primordium"""

    name: Literal["adrenal primordium"] = "adrenal primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38128"] = "EMAPA_38128"


class _Testis_Epithelium(_MouseAnatomicalStructureModel):
    """Model testis epithelium"""

    name: Literal["testis epithelium"] = "testis epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38129"] = "EMAPA_38129"


class _Foregut_Gland_Primordium(_MouseAnatomicalStructureModel):
    """Model foregut gland primordium"""

    name: Literal["foregut gland primordium"] = "foregut gland primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38130"] = "EMAPA_38130"


class _Mandible_Condylar_Condensation(_MouseAnatomicalStructureModel):
    """Model mandible condylar condensation"""

    name: Literal["mandible condylar condensation"] = "mandible condylar condensation"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38131"] = "EMAPA_38131"


class _Mandibular_Fossa(_MouseAnatomicalStructureModel):
    """Model mandibular fossa"""

    name: Literal["mandibular fossa"] = "mandibular fossa"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38132"] = "EMAPA_38132"


class _Embryonic_Visceral_Endoderm(_MouseAnatomicalStructureModel):
    """Model embryonic visceral endoderm"""

    name: Literal["embryonic visceral endoderm"] = "embryonic visceral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38133"] = "EMAPA_38133"


class _Embryonic_Posterior_Visceral_Endoderm(_MouseAnatomicalStructureModel):
    """Model embryonic posterior visceral endoderm"""

    name: Literal["embryonic posterior visceral endoderm"] = "embryonic posterior visceral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38134"] = "EMAPA_38134"


class _Extraembryonic_Posterior_Visceral_Endoderm(_MouseAnatomicalStructureModel):
    """Model extraembryonic posterior visceral endoderm"""

    name: Literal["extraembryonic posterior visceral endoderm"] = "extraembryonic posterior visceral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38135"] = "EMAPA_38135"


class _Allantois_Associated_Posterior_Visceral_Endoderm(_MouseAnatomicalStructureModel):
    """Model allantois-associated posterior visceral endoderm"""

    name: Literal[
        "allantois-associated posterior visceral endoderm"
    ] = "allantois-associated posterior visceral endoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38136"] = "EMAPA_38136"


class _Allantoic_Core_Domain(_MouseAnatomicalStructureModel):
    """Model Allantoic Core Domain"""

    name: Literal["Allantoic Core Domain"] = "Allantoic Core Domain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38137"] = "EMAPA_38137"


class _Extraembryonic_Primitive_Streak(_MouseAnatomicalStructureModel):
    """Model extraembryonic primitive streak"""

    name: Literal["extraembryonic primitive streak"] = "extraembryonic primitive streak"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38138"] = "EMAPA_38138"


class _Lens_Primordium(_MouseAnatomicalStructureModel):
    """Model lens primordium"""

    name: Literal["lens primordium"] = "lens primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38139"] = "EMAPA_38139"


class _Posterior_Crown_Of_Node(_MouseAnatomicalStructureModel):
    """Model posterior crown of node"""

    name: Literal["posterior crown of node"] = "posterior crown of node"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38140"] = "EMAPA_38140"


class _Marginal_Vein_Of_Limb(_MouseAnatomicalStructureModel):
    """Model marginal vein of limb"""

    name: Literal["marginal vein of limb"] = "marginal vein of limb"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38141"] = "EMAPA_38141"


class _Cortical_Hem(_MouseAnatomicalStructureModel):
    """Model cortical hem"""

    name: Literal["cortical hem"] = "cortical hem"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38142"] = "EMAPA_38142"


class _Nucleus_Of_Lateral_Lemniscus(_MouseAnatomicalStructureModel):
    """Model nucleus of lateral lemniscus"""

    name: Literal["nucleus of lateral lemniscus"] = "nucleus of lateral lemniscus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38143"] = "EMAPA_38143"


class _Dorsal_Nucleus_Of_Lateral_Lemniscus(_MouseAnatomicalStructureModel):
    """Model dorsal nucleus of lateral lemniscus"""

    name: Literal["dorsal nucleus of lateral lemniscus"] = "dorsal nucleus of lateral lemniscus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38144"] = "EMAPA_38144"


class _Intermediate_Nucleus_Of_Lateral_Lemniscus(_MouseAnatomicalStructureModel):
    """Model intermediate nucleus of lateral lemniscus"""

    name: Literal["intermediate nucleus of lateral lemniscus"] = "intermediate nucleus of lateral lemniscus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38145"] = "EMAPA_38145"


class _Ventral_Nucleus_Of_Lateral_Lemniscus(_MouseAnatomicalStructureModel):
    """Model ventral nucleus of lateral lemniscus"""

    name: Literal["ventral nucleus of lateral lemniscus"] = "ventral nucleus of lateral lemniscus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38146"] = "EMAPA_38146"


class _Genital_Tubercle_Surface_Epithelium(_MouseAnatomicalStructureModel):
    """Model genital tubercle surface epithelium"""

    name: Literal["genital tubercle surface epithelium"] = "genital tubercle surface epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38147"] = "EMAPA_38147"


class _Oviduct_Isthmus(_MouseAnatomicalStructureModel):
    """Model oviduct isthmus"""

    name: Literal["oviduct isthmus"] = "oviduct isthmus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38148"] = "EMAPA_38148"


class _Oviduct_Ampulla(_MouseAnatomicalStructureModel):
    """Model oviduct ampulla"""

    name: Literal["oviduct ampulla"] = "oviduct ampulla"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38149"] = "EMAPA_38149"


class _Paramedian_Raphe_Nucleus(_MouseAnatomicalStructureModel):
    """Model paramedian raphe nucleus"""

    name: Literal["paramedian raphe nucleus"] = "paramedian raphe nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38150"] = "EMAPA_38150"


class _Parvicellular_Reticular_Nucleus(_MouseAnatomicalStructureModel):
    """Model parvicellular reticular nucleus"""

    name: Literal["parvicellular reticular nucleus"] = "parvicellular reticular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38151"] = "EMAPA_38151"


class _Cerebral_Peduncle(_MouseAnatomicalStructureModel):
    """Model cerebral peduncle"""

    name: Literal["cerebral peduncle"] = "cerebral peduncle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38152"] = "EMAPA_38152"


class _Lower_Urogenital_Tract(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract"""

    name: Literal["lower urogenital tract"] = "lower urogenital tract"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38153"] = "EMAPA_38153"


class _Lower_Urogenital_Tract_Adventitia(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract adventitia"""

    name: Literal["lower urogenital tract adventitia"] = "lower urogenital tract adventitia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38154"] = "EMAPA_38154"


class _Lower_Urogenital_Tract_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract epithelium"""

    name: Literal["lower urogenital tract epithelium"] = "lower urogenital tract epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38155"] = "EMAPA_38155"


class _Lower_Urogenital_Tract_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract mesenchyme"""

    name: Literal["lower urogenital tract mesenchyme"] = "lower urogenital tract mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38156"] = "EMAPA_38156"


class _Lower_Urogenital_Tract_Muscle(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract muscle"""

    name: Literal["lower urogenital tract muscle"] = "lower urogenital tract muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38157"] = "EMAPA_38157"


class _Lower_Urogenital_Tract_Nerve(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract nerve"""

    name: Literal["lower urogenital tract nerve"] = "lower urogenital tract nerve"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38158"] = "EMAPA_38158"


class _Lower_Urogenital_Tract_Vasculature(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract vasculature"""

    name: Literal["lower urogenital tract vasculature"] = "lower urogenital tract vasculature"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38159"] = "EMAPA_38159"


class _Rostral_Migratory_Stream(_MouseAnatomicalStructureModel):
    """Model rostral migratory stream"""

    name: Literal["rostral migratory stream"] = "rostral migratory stream"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38160"] = "EMAPA_38160"


class _Lower_Urogenital_Tract_Of_Female(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract of female"""

    name: Literal["lower urogenital tract of female"] = "lower urogenital tract of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38161"] = "EMAPA_38161"


class _Lower_Urogenital_Tract_Of_Male(_MouseAnatomicalStructureModel):
    """Model lower urogenital tract of male"""

    name: Literal["lower urogenital tract of male"] = "lower urogenital tract of male"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38162"] = "EMAPA_38162"


class _Female_Lower_Urogenital_Tract_Epithelium(_MouseAnatomicalStructureModel):
    """Model female lower urogenital tract epithelium"""

    name: Literal["female lower urogenital tract epithelium"] = "female lower urogenital tract epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38163"] = "EMAPA_38163"


class _Female_Lower_Urogenital_Tract_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model female lower urogenital tract mesenchyme"""

    name: Literal["female lower urogenital tract mesenchyme"] = "female lower urogenital tract mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38164"] = "EMAPA_38164"


class _Female_Lower_Urogenital_Tract_Muscle(_MouseAnatomicalStructureModel):
    """Model female lower urogenital tract muscle"""

    name: Literal["female lower urogenital tract muscle"] = "female lower urogenital tract muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38165"] = "EMAPA_38165"


class _Male_Lower_Urogenital_Tract_Epithelium(_MouseAnatomicalStructureModel):
    """Model male lower urogenital tract epithelium"""

    name: Literal["male lower urogenital tract epithelium"] = "male lower urogenital tract epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38166"] = "EMAPA_38166"


class _Male_Lower_Urogenital_Tract_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model male lower urogenital tract mesenchyme"""

    name: Literal["male lower urogenital tract mesenchyme"] = "male lower urogenital tract mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38167"] = "EMAPA_38167"


class _Male_Lower_Urogenital_Tract_Muscle(_MouseAnatomicalStructureModel):
    """Model male lower urogenital tract muscle"""

    name: Literal["male lower urogenital tract muscle"] = "male lower urogenital tract muscle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38168"] = "EMAPA_38168"


class _Ciliary_Zonule(_MouseAnatomicalStructureModel):
    """Model ciliary zonule"""

    name: Literal["ciliary zonule"] = "ciliary zonule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38169"] = "EMAPA_38169"


class _External_Genitalia(_MouseAnatomicalStructureModel):
    """Model external genitalia"""

    name: Literal["external genitalia"] = "external genitalia"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38170"] = "EMAPA_38170"


class _Prepuce(_MouseAnatomicalStructureModel):
    """Model prepuce"""

    name: Literal["prepuce"] = "prepuce"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38171"] = "EMAPA_38171"


class _Skeletal_Joint_Primordium(_MouseAnatomicalStructureModel):
    """Model skeletal joint primordium"""

    name: Literal["skeletal joint primordium"] = "skeletal joint primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38172"] = "EMAPA_38172"


class _Anterior_Pre_Placodal_Region(_MouseAnatomicalStructureModel):
    """Model anterior pre-placodal region"""

    name: Literal["anterior pre-placodal region"] = "anterior pre-placodal region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38173"] = "EMAPA_38173"


class _Posterior_Pre_Placodal_Region(_MouseAnatomicalStructureModel):
    """Model posterior pre-placodal region"""

    name: Literal["posterior pre-placodal region"] = "posterior pre-placodal region"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38174"] = "EMAPA_38174"


class _Ventricle_Ependyma(_MouseAnatomicalStructureModel):
    """Model ventricle ependyma"""

    name: Literal["ventricle ependyma"] = "ventricle ependyma"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38175"] = "EMAPA_38175"


class _Lower_Urinary_Tract_Epithelium(_MouseAnatomicalStructureModel):
    """Model lower urinary tract epithelium"""

    name: Literal["lower urinary tract epithelium"] = "lower urinary tract epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38176"] = "EMAPA_38176"


class _Lower_Urinary_Tract_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lower urinary tract mesenchyme"""

    name: Literal["lower urinary tract mesenchyme"] = "lower urinary tract mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38177"] = "EMAPA_38177"


class _Distal_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model distal genital tubercle"""

    name: Literal["distal genital tubercle"] = "distal genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38178"] = "EMAPA_38178"


class _Glans_Of_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model glans of genital tubercle"""

    name: Literal["glans of genital tubercle"] = "glans of genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38179"] = "EMAPA_38179"


class _Proximal_Genital_Tubercle(_MouseAnatomicalStructureModel):
    """Model proximal genital tubercle"""

    name: Literal["proximal genital tubercle"] = "proximal genital tubercle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38180"] = "EMAPA_38180"


class _Nucleus_Incertus(_MouseAnatomicalStructureModel):
    """Model nucleus incertus"""

    name: Literal["nucleus incertus"] = "nucleus incertus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38181"] = "EMAPA_38181"


class _Hair_Peg(_MouseAnatomicalStructureModel):
    """Model hair peg"""

    name: Literal["hair peg"] = "hair peg"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38182"] = "EMAPA_38182"


class _Facial_Prominence(_MouseAnatomicalStructureModel):
    """Model facial prominence"""

    name: Literal["facial prominence"] = "facial prominence"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38183"] = "EMAPA_38183"


class _Facial_Prominence_Ectoderm(_MouseAnatomicalStructureModel):
    """Model facial prominence ectoderm"""

    name: Literal["facial prominence ectoderm"] = "facial prominence ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38184"] = "EMAPA_38184"


class _Facial_Prominence_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model facial prominence mesenchyme"""

    name: Literal["facial prominence mesenchyme"] = "facial prominence mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38185"] = "EMAPA_38185"


class _Mandibular_Process_Ectoderm(_MouseAnatomicalStructureModel):
    """Model mandibular process ectoderm"""

    name: Literal["mandibular process ectoderm"] = "mandibular process ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38186"] = "EMAPA_38186"


class _Maxillary_Process_Ectoderm(_MouseAnatomicalStructureModel):
    """Model maxillary process ectoderm"""

    name: Literal["maxillary process ectoderm"] = "maxillary process ectoderm"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38187"] = "EMAPA_38187"


class _Epididymis_Initial_Segment(_MouseAnatomicalStructureModel):
    """Model epididymis initial segment"""

    name: Literal["epididymis initial segment"] = "epididymis initial segment"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38188"] = "EMAPA_38188"


class _Geschmacksstreifen(_MouseAnatomicalStructureModel):
    """Model geschmacksstreifen"""

    name: Literal["geschmacksstreifen"] = "geschmacksstreifen"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38189"] = "EMAPA_38189"


class _Pallium(_MouseAnatomicalStructureModel):
    """Model pallium"""

    name: Literal["pallium"] = "pallium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38190"] = "EMAPA_38190"


class _Lateral_Pallium(_MouseAnatomicalStructureModel):
    """Model lateral pallium"""

    name: Literal["lateral pallium"] = "lateral pallium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38191"] = "EMAPA_38191"


class _Ventral_Pallium(_MouseAnatomicalStructureModel):
    """Model ventral pallium"""

    name: Literal["ventral pallium"] = "ventral pallium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38192"] = "EMAPA_38192"


class _Subpallium(_MouseAnatomicalStructureModel):
    """Model subpallium"""

    name: Literal["subpallium"] = "subpallium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38193"] = "EMAPA_38193"


class _Diagonal_Domain(_MouseAnatomicalStructureModel):
    """Model diagonal domain"""

    name: Literal["diagonal domain"] = "diagonal domain"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38194"] = "EMAPA_38194"


class _Proximal_Straight_Tubule(_MouseAnatomicalStructureModel):
    """Model proximal straight tubule"""

    name: Literal["proximal straight tubule"] = "proximal straight tubule"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38195"] = "EMAPA_38195"


class _Oocyte_Of_Preantral_Follicle(_MouseAnatomicalStructureModel):
    """Model oocyte of preantral follicle"""

    name: Literal["oocyte of preantral follicle"] = "oocyte of preantral follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38196"] = "EMAPA_38196"


class _Oocyte_Of_Antral_Follicle(_MouseAnatomicalStructureModel):
    """Model oocyte of antral follicle"""

    name: Literal["oocyte of antral follicle"] = "oocyte of antral follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38197"] = "EMAPA_38197"


class _Follicle_Cell_Of_Preantral_Follicle(_MouseAnatomicalStructureModel):
    """Model follicle cell of preantral follicle"""

    name: Literal["follicle cell of preantral follicle"] = "follicle cell of preantral follicle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38198"] = "EMAPA_38198"


class _Dorsal_Aorta_Endothelium(_MouseAnatomicalStructureModel):
    """Model dorsal aorta endothelium"""

    name: Literal["dorsal aorta endothelium"] = "dorsal aorta endothelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38199"] = "EMAPA_38199"


class _Epidermis_Intermediate_Layer(_MouseAnatomicalStructureModel):
    """Model epidermis intermediate layer"""

    name: Literal["epidermis intermediate layer"] = "epidermis intermediate layer"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38200"] = "EMAPA_38200"


class _Aorta_Gonad_Mesonephros(_MouseAnatomicalStructureModel):
    """Model aorta-gonad-mesonephros"""

    name: Literal["aorta-gonad-mesonephros"] = "aorta-gonad-mesonephros"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38201"] = "EMAPA_38201"


class _Dentate_Notch(_MouseAnatomicalStructureModel):
    """Model dentate notch"""

    name: Literal["dentate notch"] = "dentate notch"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38202"] = "EMAPA_38202"


class _Paratenial_Nucleus(_MouseAnatomicalStructureModel):
    """Model paratenial nucleus"""

    name: Literal["paratenial nucleus"] = "paratenial nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38203"] = "EMAPA_38203"


class _Anterior_Neural_Ridge(_MouseAnatomicalStructureModel):
    """Model anterior neural ridge"""

    name: Literal["anterior neural ridge"] = "anterior neural ridge"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38204"] = "EMAPA_38204"


class _Junctional_Zone(_MouseAnatomicalStructureModel):
    """Model junctional zone"""

    name: Literal["junctional zone"] = "junctional zone"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38205"] = "EMAPA_38205"


class _Temporo_Mandibular_Joint_Disc(_MouseAnatomicalStructureModel):
    """Model temporo-mandibular joint disc"""

    name: Literal["temporo-mandibular joint disc"] = "temporo-mandibular joint disc"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38206"] = "EMAPA_38206"


class _Entopeduncular_Nucleus(_MouseAnatomicalStructureModel):
    """Model entopeduncular nucleus"""

    name: Literal["entopeduncular nucleus"] = "entopeduncular nucleus"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38207"] = "EMAPA_38207"


class _Craniofacial_Suture(_MouseAnatomicalStructureModel):
    """Model craniofacial suture"""

    name: Literal["craniofacial suture"] = "craniofacial suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38208"] = "EMAPA_38208"


class _Facial_Suture(_MouseAnatomicalStructureModel):
    """Model facial suture"""

    name: Literal["facial suture"] = "facial suture"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38209"] = "EMAPA_38209"


class _Fontanelle(_MouseAnatomicalStructureModel):
    """Model fontanelle"""

    name: Literal["fontanelle"] = "fontanelle"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38210"] = "EMAPA_38210"


class _Coronal_Suture_Frontal_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model coronal suture frontal osteogenic front"""

    name: Literal["coronal suture frontal osteogenic front"] = "coronal suture frontal osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38211"] = "EMAPA_38211"


class _Coronal_Suture_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model coronal suture mesenchyme"""

    name: Literal["coronal suture mesenchyme"] = "coronal suture mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38212"] = "EMAPA_38212"


class _Coronal_Suture_Parietal_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model coronal suture parietal osteogenic front"""

    name: Literal["coronal suture parietal osteogenic front"] = "coronal suture parietal osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38213"] = "EMAPA_38213"


class _Frontal_Suture_Frontal_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model frontal suture frontal osteogenic front"""

    name: Literal["frontal suture frontal osteogenic front"] = "frontal suture frontal osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38214"] = "EMAPA_38214"


class _Frontal_Suture_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model frontal suture mesenchyme"""

    name: Literal["frontal suture mesenchyme"] = "frontal suture mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38215"] = "EMAPA_38215"


class _Lambdoid_Suture_Interparietal_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model lambdoid suture interparietal osteogenic front"""

    name: Literal["lambdoid suture interparietal osteogenic front"] = "lambdoid suture interparietal osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38216"] = "EMAPA_38216"


class _Lambdoid_Suture_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model lambdoid suture mesenchyme"""

    name: Literal["lambdoid suture mesenchyme"] = "lambdoid suture mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38217"] = "EMAPA_38217"


class _Lambdoid_Suture_Parietal_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model lambdoid suture parietal osteogenic front"""

    name: Literal["lambdoid suture parietal osteogenic front"] = "lambdoid suture parietal osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38218"] = "EMAPA_38218"


class _Sagittal_Suture_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model sagittal suture mesenchyme"""

    name: Literal["sagittal suture mesenchyme"] = "sagittal suture mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38219"] = "EMAPA_38219"


class _Sagittal_Suture_Parietal_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model sagittal suture parietal osteogenic front"""

    name: Literal["sagittal suture parietal osteogenic front"] = "sagittal suture parietal osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38220"] = "EMAPA_38220"


class _Salivary_Gland_Primordium(_MouseAnatomicalStructureModel):
    """Model salivary gland primordium"""

    name: Literal["salivary gland primordium"] = "salivary gland primordium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38221"] = "EMAPA_38221"


class _Salivary_Gland_Primordium_Epithelium(_MouseAnatomicalStructureModel):
    """Model salivary gland primordium epithelium"""

    name: Literal["salivary gland primordium epithelium"] = "salivary gland primordium epithelium"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38222"] = "EMAPA_38222"


class _Salivary_Gland_Primordium_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model salivary gland primordium mesenchyme"""

    name: Literal["salivary gland primordium mesenchyme"] = "salivary gland primordium mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38223"] = "EMAPA_38223"


class _Humerus_Epiphysis(_MouseAnatomicalStructureModel):
    """Model humerus epiphysis"""

    name: Literal["humerus epiphysis"] = "humerus epiphysis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38224"] = "EMAPA_38224"


class _Muscle_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model muscle blood vessel"""

    name: Literal["muscle blood vessel"] = "muscle blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38225"] = "EMAPA_38225"


class _Skin_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model skin blood vessel"""

    name: Literal["skin blood vessel"] = "skin blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38226"] = "EMAPA_38226"


class _Thymus_Blood_Vessel(_MouseAnatomicalStructureModel):
    """Model thymus blood vessel"""

    name: Literal["thymus blood vessel"] = "thymus blood vessel"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38227"] = "EMAPA_38227"


class _Body_Of_Stomach_Gastric_Gland(_MouseAnatomicalStructureModel):
    """Model body of stomach gastric gland"""

    name: Literal["body of stomach gastric gland"] = "body of stomach gastric gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38228"] = "EMAPA_38228"


class _Gubernaculum(_MouseAnatomicalStructureModel):
    """Model gubernaculum"""

    name: Literal["gubernaculum"] = "gubernaculum"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38229"] = "EMAPA_38229"


class _Gubernaculum_Of_Female(_MouseAnatomicalStructureModel):
    """Model gubernaculum of female"""

    name: Literal["gubernaculum of female"] = "gubernaculum of female"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38230"] = "EMAPA_38230"


class _Von_Ebner_S_Gland(_MouseAnatomicalStructureModel):
    """Model von Ebner's gland"""

    name: Literal["von Ebner's gland"] = "von Ebner's gland"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38231"] = "EMAPA_38231"


class _Interfollicular_Epidermis(_MouseAnatomicalStructureModel):
    """Model interfollicular epidermis"""

    name: Literal["interfollicular epidermis"] = "interfollicular epidermis"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38232"] = "EMAPA_38232"


class _Dermo_Epidermal_Junction(_MouseAnatomicalStructureModel):
    """Model dermo-epidermal junction"""

    name: Literal["dermo-epidermal junction"] = "dermo-epidermal junction"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38233"] = "EMAPA_38233"


class _Cranial_Suture_Mesenchyme(_MouseAnatomicalStructureModel):
    """Model cranial suture mesenchyme"""

    name: Literal["cranial suture mesenchyme"] = "cranial suture mesenchyme"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38234"] = "EMAPA_38234"


class _Cranial_Suture_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model cranial suture osteogenic front"""

    name: Literal["cranial suture osteogenic front"] = "cranial suture osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38235"] = "EMAPA_38235"


class _Coronal_Suture_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model coronal suture osteogenic front"""

    name: Literal["coronal suture osteogenic front"] = "coronal suture osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38236"] = "EMAPA_38236"


class _Lambdoid_Suture_Osteogenic_Front(_MouseAnatomicalStructureModel):
    """Model lambdoid suture osteogenic front"""

    name: Literal["lambdoid suture osteogenic front"] = "lambdoid suture osteogenic front"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38237"] = "EMAPA_38237"


class _Exocoelomic_Cavity_Fluid(_MouseAnatomicalStructureModel):
    """Model exocoelomic cavity fluid"""

    name: Literal["exocoelomic cavity fluid"] = "exocoelomic cavity fluid"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38238"] = "EMAPA_38238"


class _Cortical_Antihem(_MouseAnatomicalStructureModel):
    """Model cortical antihem"""

    name: Literal["cortical antihem"] = "cortical antihem"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38239"] = "EMAPA_38239"


class _Basal_Cell_Layer_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model basal cell layer of pelvic urethra"""

    name: Literal["basal cell layer of pelvic urethra"] = "basal cell layer of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38240"] = "EMAPA_38240"


class _Intermediate_Cell_Layer_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model intermediate cell layer of pelvic urethra"""

    name: Literal["intermediate cell layer of pelvic urethra"] = "intermediate cell layer of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38241"] = "EMAPA_38241"


class _Superficial_Cell_Layer_Of_Pelvic_Urethra(_MouseAnatomicalStructureModel):
    """Model superficial cell layer of pelvic urethra"""

    name: Literal["superficial cell layer of pelvic urethra"] = "superficial cell layer of pelvic urethra"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38242"] = "EMAPA_38242"


class _Spinal_Nerve_Root(_MouseAnatomicalStructureModel):
    """Model spinal nerve root"""

    name: Literal["spinal nerve root"] = "spinal nerve root"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38243"] = "EMAPA_38243"


class _Paleocortex(_MouseAnatomicalStructureModel):
    """Model paleocortex"""

    name: Literal["paleocortex"] = "paleocortex"
    registry: Registry.ONE_OF = Registry.EMAPA
    registry_identifier: Literal["EMAPA_38244"] = "EMAPA_38244"


class MouseAnatomicalStructure:
    """MouseAnatomicalStructure"""

    ANATOMICAL_STRUCTURE = _Anatomical_Structure()
    FIRST_POLAR_BODY = _First_Polar_Body()
    _1_CELL_STAGE_EMBRYO = _1_Cell_Stage_Embryo()
    SECOND_POLAR_BODY = _Second_Polar_Body()
    ZONA_PELLUCIDA = _Zona_Pellucida()
    _2_CELL_STAGE_EMBRYO = _2_Cell_Stage_Embryo()
    _4_8_CELL_STAGE_EMBRYO = _4_8_Cell_Stage_Embryo()
    EMBRYO = _Embryo()
    COMPACTED_MORULA = _Compacted_Morula()
    INNER_CELL_MASS = _Inner_Cell_Mass()
    EXTRAEMBRYONIC_COMPONENT = _Extraembryonic_Component()
    EXTRAEMBRYONIC_CAVITY = _Extraembryonic_Cavity()
    BLASTOCOELIC_CAVITY = _Blastocoelic_Cavity()
    TROPHECTODERM = _Trophectoderm()
    MURAL_TROPHECTODERM = _Mural_Trophectoderm()
    POLAR_TROPHECTODERM = _Polar_Trophectoderm()
    EPIBLAST = _Epiblast()
    PRIMITIVE_ENDODERM = _Primitive_Endoderm()
    EXTRAEMBRYONIC_ENDODERM = _Extraembryonic_Endoderm()
    PARIETAL_ENDODERM = _Parietal_Endoderm()
    EXTRAEMBRYONIC_COMPONENT_CAVITY = _Extraembryonic_Component_Cavity()
    YOLK_SAC_CAVITY = _Yolk_Sac_Cavity()
    INTERMEDIATE_ENDODERM = _Intermediate_Endoderm()
    REICHERT_S_MEMBRANE = _Reichert_S_Membrane()
    EXTRAEMBRYONIC_VISCERAL_ENDODERM = _Extraembryonic_Visceral_Endoderm()
    ECTOPLACENTAL_CONE = _Ectoplacental_Cone()
    BODY_CAVITY_OR_LINING = _Body_Cavity_Or_Lining()
    PROAMNIOTIC_CAVITY_EMBRYONIC_PART = _Proamniotic_Cavity_Embryonic_Part()
    EMBRYO_ENDODERM = _Embryo_Endoderm()
    PROAMNIOTIC_CAVITY_EXTRAEMBRYONIC_PART = _Proamniotic_Cavity_Extraembryonic_Part()
    EXTRAEMBRYONIC_ECTODERM = _Extraembryonic_Ectoderm()
    PRIMARY_TROPHOBLAST_GIANT_CELL = _Primary_Trophoblast_Giant_Cell()
    CYTOTROPHOBLAST = _Cytotrophoblast()
    SYNCYTIOTROPHOBLAST = _Syncytiotrophoblast()
    EMBRYO_ECTODERM = _Embryo_Ectoderm()
    DEFINITIVE_ENDODERM = _Definitive_Endoderm()
    EMBRYO_MESODERM = _Embryo_Mesoderm()
    PRIMITIVE_STREAK = _Primitive_Streak()
    NEURAL_ECTODERM = _Neural_Ectoderm()
    NON_NEURAL_ECTODERM = _Non_Neural_Ectoderm()
    NODE = _Node()
    AMNIOTIC_FOLD = _Amniotic_Fold()
    AMNIOTIC_FOLD_ECTODERM = _Amniotic_Fold_Ectoderm()
    AMNIOTIC_FOLD_MESODERM = _Amniotic_Fold_Mesoderm()
    AMNIOTIC_CAVITY = _Amniotic_Cavity()
    ECTOPLACENTAL_CAVITY = _Ectoplacental_Cavity()
    EXOCOELOMIC_CAVITY = _Exocoelomic_Cavity()
    CAVITY_WITHIN_AMNIOTIC_FOLD = _Cavity_Within_Amniotic_Fold()
    YOLK_SAC = _Yolk_Sac()
    YOLK_SAC_ENDODERM = _Yolk_Sac_Endoderm()
    YOLK_SAC_MESODERM = _Yolk_Sac_Mesoderm()
    INTRAEMBRYONIC_COELOM = _Intraembryonic_Coelom()
    FUTURE_BRAIN = _Future_Brain()
    FUTURE_BRAIN_NEURAL_FOLD = _Future_Brain_Neural_Fold()
    FUTURE_BRAIN_NEURAL_CREST = _Future_Brain_Neural_Crest()
    FUTURE_SPINAL_CORD = _Future_Spinal_Cord()
    FUTURE_SPINAL_CORD_NEURAL_PLATE = _Future_Spinal_Cord_Neural_Plate()
    SURFACE_ECTODERM = _Surface_Ectoderm()
    MESENCHYME = _Mesenchyme()
    HEAD_MESENCHYME = _Head_Mesenchyme()
    MESENCHYME_DERIVED_FROM_HEAD_MESODERM = _Mesenchyme_Derived_From_Head_Mesoderm()
    NOTOCHORDAL_PLATE = _Notochordal_Plate()
    NOTOCHORDAL_PROCESS = _Notochordal_Process()
    ORGAN_SYSTEM = _Organ_System()
    CARDIOVASCULAR_SYSTEM = _Cardiovascular_System()
    HEART = _Heart()
    CARDIOGENIC_PLATE = _Cardiogenic_Plate()
    ALLANTOIS = _Allantois()
    ALLANTOIS_MESODERM = _Allantois_Mesoderm()
    AMNION = _Amnion()
    AMNION_ECTODERM = _Amnion_Ectoderm()
    AMNION_MESODERM = _Amnion_Mesoderm()
    CHORION = _Chorion()
    CHORION_ECTODERM = _Chorion_Ectoderm()
    CHORION_MESODERM = _Chorion_Mesoderm()
    BLOOD_ISLAND = _Blood_Island()
    PRIMORDIAL_GERM_CELL_OF_YOLK_SAC = _Primordial_Germ_Cell_Of_Yolk_Sac()
    BRANCHIAL_ARCH = _Branchial_Arch()
    _1ST_BRANCHIAL_ARCH = _1St_Branchial_Arch()
    _1ST_BRANCHIAL_GROOVE = _1St_Branchial_Groove()
    _1ST_BRANCHIAL_GROOVE_ECTODERM = _1St_Branchial_Groove_Ectoderm()
    _1ST_BRANCHIAL_MEMBRANE = _1St_Branchial_Membrane()
    _1ST_BRANCHIAL_MEMBRANE_ECTODERM = _1St_Branchial_Membrane_Ectoderm()
    _1ST_BRANCHIAL_MEMBRANE_ENDODERM = _1St_Branchial_Membrane_Endoderm()
    _1ST_BRANCHIAL_POUCH = _1St_Branchial_Pouch()
    _1ST_BRANCHIAL_POUCH_ENDODERM = _1St_Branchial_Pouch_Endoderm()
    _1ST_BRANCHIAL_ARCH_ECTODERM = _1St_Branchial_Arch_Ectoderm()
    _1ST_BRANCHIAL_ARCH_ENDODERM = _1St_Branchial_Arch_Endoderm()
    _1ST_BRANCHIAL_ARCH_MESENCHYME = _1St_Branchial_Arch_Mesenchyme()
    _1ST_BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_NEURAL_CREST = (
        _1St_Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest()
    )
    _1ST_BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_HEAD_MESODERM = (
        _1St_Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm()
    )
    PERICARDIAL_COMPONENT = _Pericardial_Component()
    PERICARDIAL_CAVITY = _Pericardial_Cavity()
    PERICARDIUM = _Pericardium()
    PERICARDIO_PERITONEAL_COMPONENT = _Pericardio_Peritoneal_Component()
    PERICARDIO_PERITONEAL_COMPONENT_CAVITY = _Pericardio_Peritoneal_Component_Cavity()
    PERICARDIO_PERITONEAL_COMPONENT_MESOTHELIUM = _Pericardio_Peritoneal_Component_Mesothelium()
    PERITONEAL_COMPONENT = _Peritoneal_Component()
    PERITONEAL_CAVITY = _Peritoneal_Cavity()
    PERITONEUM = _Peritoneum()
    FUTURE_MIDBRAIN = _Future_Midbrain()
    FUTURE_MIDBRAIN_FLOOR_PLATE = _Future_Midbrain_Floor_Plate()
    FUTURE_MIDBRAIN_NEURAL_FOLD = _Future_Midbrain_Neural_Fold()
    FUTURE_MIDBRAIN_NEURAL_CREST = _Future_Midbrain_Neural_Crest()
    FUTURE_PROSENCEPHALON = _Future_Prosencephalon()
    FUTURE_PROSENCEPHALON_FLOOR_PLATE = _Future_Prosencephalon_Floor_Plate()
    FUTURE_PROSENCEPHALON_NEURAL_FOLD = _Future_Prosencephalon_Neural_Fold()
    FUTURE_PROSENCEPHALON_NEURAL_CREST = _Future_Prosencephalon_Neural_Crest()
    FUTURE_HINDBRAIN = _Future_Hindbrain()
    ANTERIOR_PRO_RHOMBOMERE = _Anterior_Pro_Rhombomere()
    ANTERIOR_PRO_RHOMBOMERE_FLOOR_PLATE = _Anterior_Pro_Rhombomere_Floor_Plate()
    ANTERIOR_PRO_RHOMBOMERE_NEURAL_FOLD = _Anterior_Pro_Rhombomere_Neural_Fold()
    ANTERIOR_PRO_RHOMBOMERE_NEURAL_CREST = _Anterior_Pro_Rhombomere_Neural_Crest()
    FUTURE_HINDBRAIN_NEURAL_ECTODERM = _Future_Hindbrain_Neural_Ectoderm()
    FUTURE_HINDBRAIN_FLOOR_PLATE = _Future_Hindbrain_Floor_Plate()
    FUTURE_HINDBRAIN_NEURAL_FOLD = _Future_Hindbrain_Neural_Fold()
    FUTURE_HINDBRAIN_NEURAL_CREST = _Future_Hindbrain_Neural_Crest()
    POSTERIOR_PRO_RHOMBOMERE = _Posterior_Pro_Rhombomere()
    POSTERIOR_PRO_RHOMBOMERE_FLOOR_PLATE = _Posterior_Pro_Rhombomere_Floor_Plate()
    POSTERIOR_PRO_RHOMBOMERE_NEURAL_FOLD = _Posterior_Pro_Rhombomere_Neural_Fold()
    POSTERIOR_PRO_RHOMBOMERE_NEURAL_CREST = _Posterior_Pro_Rhombomere_Neural_Crest()
    PRE_OTIC_SULCUS = _Pre_Otic_Sulcus()
    FUTURE_SPINAL_CORD_NEURAL_FOLD = _Future_Spinal_Cord_Neural_Fold()
    FUTURE_SPINAL_CORD_NEURAL_CREST = _Future_Spinal_Cord_Neural_Crest()
    NEURAL_TUBE = _Neural_Tube()
    NEURAL_TUBE_FLOOR_PLATE = _Neural_Tube_Floor_Plate()
    NEURAL_TUBE_LATERAL_WALL = _Neural_Tube_Lateral_Wall()
    NEURAL_LUMEN = _Neural_Lumen()
    NEURAL_TUBE_ROOF_PLATE = _Neural_Tube_Roof_Plate()
    HEAD_MESENCHYME_DERIVED_FROM_NEURAL_CREST = _Head_Mesenchyme_Derived_From_Neural_Crest()
    TRIGEMINAL_NEURAL_CREST = _Trigeminal_Neural_Crest()
    HEAD_PARAXIAL_MESENCHYME = _Head_Paraxial_Mesenchyme()
    HEAD_SOMITE = _Head_Somite()
    SOMITE_01 = _Somite_01()
    SOMITE_02 = _Somite_02()
    SOMITE_03 = _Somite_03()
    SOMITE_04 = _Somite_04()
    TRUNK_MESENCHYME = _Trunk_Mesenchyme()
    INTERMEDIATE_MESENCHYME = _Intermediate_Mesenchyme()
    LATERAL_PLATE_MESODERM = _Lateral_Plate_Mesoderm()
    SOMATOPLEURE = _Somatopleure()
    SPLANCHNOPLEURE = _Splanchnopleure()
    TRUNK_MESENCHYME_DERIVED_FROM_NEURAL_CREST = _Trunk_Mesenchyme_Derived_From_Neural_Crest()
    TRUNK_PARAXIAL_MESENCHYME = _Trunk_Paraxial_Mesenchyme()
    TRUNK_SOMITE = _Trunk_Somite()
    SOMITE_05 = _Somite_05()
    SOMITE_06 = _Somite_06()
    SOMITE_07 = _Somite_07()
    SOMITE_08 = _Somite_08()
    TRUNK_UNSEGMENTED_MESENCHYME = _Trunk_Unsegmented_Mesenchyme()
    PRIMORDIAL_GERM_CELL_OF_TRUNK_MESENCHYME = _Primordial_Germ_Cell_Of_Trunk_Mesenchyme()
    NOTOCHORD = _Notochord()
    SENSORY_ORGAN_SYSTEM = _Sensory_Organ_System()
    EAR = _Ear()
    INNER_EAR = _Inner_Ear()
    OTIC_PLACODE = _Otic_Placode()
    OTIC_PLACODE_MESENCHYME = _Otic_Placode_Mesenchyme()
    OTIC_PLACODE_EPITHELIUM = _Otic_Placode_Epithelium()
    EYE = _Eye()
    OPTIC_SULCUS = _Optic_Sulcus()
    OPTIC_SULCUS_NEURAL_ECTODERM = _Optic_Sulcus_Neural_Ectoderm()
    ARTERIAL_SYSTEM = _Arterial_System()
    DORSAL_AORTA = _Dorsal_Aorta()
    LEFT_DORSAL_AORTA = _Left_Dorsal_Aorta()
    RIGHT_DORSAL_AORTA = _Right_Dorsal_Aorta()
    VITELLINE_ARTERY = _Vitelline_Artery()
    PRIMITIVE_HEART_TUBE_CARDIAC_JELLY = _Primitive_Heart_Tube_Cardiac_Jelly()
    PRIMITIVE_HEART_TUBE_ENDOCARDIAL_TUBE = _Primitive_Heart_Tube_Endocardial_Tube()
    PRIMITIVE_HEART_TUBE_CARDIAC_MUSCLE = _Primitive_Heart_Tube_Cardiac_Muscle()
    HEART_MESENTERY = _Heart_Mesentery()
    DORSAL_MESOCARDIUM = _Dorsal_Mesocardium()
    TRANSVERSE_PERICARDIAL_SINUS = _Transverse_Pericardial_Sinus()
    PRIMITIVE_HEART_TUBE = _Primitive_Heart_Tube()
    SINUS_VENOSUS = _Sinus_Venosus()
    SINUS_VENOSUS_LEFT_HORN = _Sinus_Venosus_Left_Horn()
    SINUS_VENOSUS_RIGHT_HORN = _Sinus_Venosus_Right_Horn()
    VENOUS_SYSTEM = _Venous_System()
    ANTERIOR_CARDINAL_VEIN = _Anterior_Cardinal_Vein()
    PRIMARY_HEAD_VEIN = _Primary_Head_Vein()
    UMBILICAL_VEIN_EMBRYONIC_PART = _Umbilical_Vein_Embryonic_Part()
    VITELLINE_VEIN_EMBRYONIC_PART = _Vitelline_Vein_Embryonic_Part()
    VISCERAL_ORGAN_SYSTEM = _Visceral_Organ_System()
    ALIMENTARY_SYSTEM = _Alimentary_System()
    GUT = _Gut()
    FOREGUT_DIVERTICULUM = _Foregut_Diverticulum()
    FOREGUT_DIVERTICULUM_MESENCHYME = _Foregut_Diverticulum_Mesenchyme()
    FOREGUT_DIVERTICULUM_ENDODERM = _Foregut_Diverticulum_Endoderm()
    HINDGUT_DIVERTICULUM = _Hindgut_Diverticulum()
    HINDGUT_DIVERTICULUM_MESENCHYME = _Hindgut_Diverticulum_Mesenchyme()
    HINDGUT_DIVERTICULUM_ENDODERM = _Hindgut_Diverticulum_Endoderm()
    PRIMORDIAL_GERM_CELL_OF_HINDGUT = _Primordial_Germ_Cell_Of_Hindgut()
    MIDGUT = _Midgut()
    MIDGUT_MESENCHYME = _Midgut_Mesenchyme()
    MIDGUT_ENDODERM = _Midgut_Endoderm()
    MOUTH_FOREGUT_JUNCTION = _Mouth_Foregut_Junction()
    BUCCOPHARYNGEAL_MEMBRANE = _Buccopharyngeal_Membrane()
    BUCCOPHARYNGEAL_MEMBRANE_ECTODERM = _Buccopharyngeal_Membrane_Ectoderm()
    BUCCOPHARYNGEAL_MEMBRANE_ENDODERM = _Buccopharyngeal_Membrane_Endoderm()
    ORAL_REGION = _Oral_Region()
    STOMATODEUM = _Stomatodeum()
    ALLANTOIS_MESENCHYME = _Allantois_Mesenchyme()
    AMNION_MESENCHYME = _Amnion_Mesenchyme()
    CHORION_MESENCHYME = _Chorion_Mesenchyme()
    YOLK_SAC_MESENCHYME = _Yolk_Sac_Mesenchyme()
    _2ND_BRANCHIAL_ARCH = _2Nd_Branchial_Arch()
    _2ND_BRANCHIAL_MEMBRANE = _2Nd_Branchial_Membrane()
    _2ND_BRANCHIAL_MEMBRANE_ENDODERM = _2Nd_Branchial_Membrane_Endoderm()
    _2ND_BRANCHIAL_POUCH = _2Nd_Branchial_Pouch()
    _2ND_BRANCHIAL_POUCH_ENDODERM = _2Nd_Branchial_Pouch_Endoderm()
    _2ND_BRANCHIAL_ARCH_ECTODERM = _2Nd_Branchial_Arch_Ectoderm()
    _2ND_BRANCHIAL_ARCH_ENDODERM = _2Nd_Branchial_Arch_Endoderm()
    _2ND_BRANCHIAL_ARCH_MESENCHYME = _2Nd_Branchial_Arch_Mesenchyme()
    _2ND_BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_HEAD_MESODERM = (
        _2Nd_Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm()
    )
    _2ND_BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_NEURAL_CREST = (
        _2Nd_Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest()
    )
    PERICARDIO_PERITONEAL_CANAL = _Pericardio_Peritoneal_Canal()
    PERICARDIO_PERITONEAL_CANAL_CAVITY = _Pericardio_Peritoneal_Canal_Cavity()
    PERICARDIO_PERITONEAL_CANAL_MESOTHELIUM = _Pericardio_Peritoneal_Canal_Mesothelium()
    FUTURE_MIDBRAIN_ROOF_PLATE = _Future_Midbrain_Roof_Plate()
    FUTURE_HINDBRAIN_POSTERIOR_TO_RHOMBOMERE_5 = _Future_Hindbrain_Posterior_To_Rhombomere_5()
    FUTURE_HINDBRAIN_POSTERIOR_TO_RHOMBOMERE_5_FLOOR_PLATE = _Future_Hindbrain_Posterior_To_Rhombomere_5_Floor_Plate()
    FUTURE_HINDBRAIN_POSTERIOR_TO_RHOMBOMERE_5_NEURAL_FOLD = _Future_Hindbrain_Posterior_To_Rhombomere_5_Neural_Fold()
    FUTURE_HINDBRAIN_POSTERIOR_TO_RHOMBOMERE_5_NEURAL_CREST = _Future_Hindbrain_Posterior_To_Rhombomere_5_Neural_Crest()
    RHOMBOMERE_1 = _Rhombomere_1()
    RHOMBOMERE_1_FLOOR_PLATE = _Rhombomere_1_Floor_Plate()
    RHOMBOMERE_1_NEURAL_FOLD = _Rhombomere_1_Neural_Fold()
    RHOMBOMERE_2 = _Rhombomere_2()
    RHOMBOMERE_2_FLOOR_PLATE = _Rhombomere_2_Floor_Plate()
    RHOMBOMERE_2_NEURAL_FOLD = _Rhombomere_2_Neural_Fold()
    RHOMBOMERE_2_NEURAL_CREST = _Rhombomere_2_Neural_Crest()
    RHOMBOMERE_3 = _Rhombomere_3()
    RHOMBOMERE_3_FLOOR_PLATE = _Rhombomere_3_Floor_Plate()
    RHOMBOMERE_3_NEURAL_FOLD = _Rhombomere_3_Neural_Fold()
    RHOMBOMERE_3_NEURAL_CREST = _Rhombomere_3_Neural_Crest()
    RHOMBOMERE_4 = _Rhombomere_4()
    RHOMBOMERE_4_FLOOR_PLATE = _Rhombomere_4_Floor_Plate()
    RHOMBOMERE_4_NEURAL_FOLD = _Rhombomere_4_Neural_Fold()
    RHOMBOMERE_4_NEURAL_CREST = _Rhombomere_4_Neural_Crest()
    RHOMBOMERE_5 = _Rhombomere_5()
    RHOMBOMERE_5_FLOOR_PLATE = _Rhombomere_5_Floor_Plate()
    RHOMBOMERE_5_NEURAL_FOLD = _Rhombomere_5_Neural_Fold()
    RHOMBOMERE_5_NEURAL_CREST = _Rhombomere_5_Neural_Crest()
    RHOMBOMERE_1_NEURAL_CREST = _Rhombomere_1_Neural_Crest()
    NEURAL_LUMINAL_OCCLUSION = _Neural_Luminal_Occlusion()
    FACIAL_NEURAL_CREST = _Facial_Neural_Crest()
    FACIO_ACOUSTIC_NEURAL_CREST = _Facio_Acoustic_Neural_Crest()
    SOMITE_09 = _Somite_09()
    SOMITE_10 = _Somite_10()
    SOMITE_11 = _Somite_11()
    SOMITE_12 = _Somite_12()
    SOMITE_13 = _Somite_13()
    SEPTUM_TRANSVERSUM = _Septum_Transversum()
    SEPTUM_TRANSVERSUM_HEPATIC_COMPONENT = _Septum_Transversum_Hepatic_Component()
    SEPTUM_TRANSVERSUM_NON_HEPATIC_COMPONENT = _Septum_Transversum_Non_Hepatic_Component()
    OPTIC_EMINENCE = _Optic_Eminence()
    OPTIC_EMINENCE_MESENCHYME = _Optic_Eminence_Mesenchyme()
    OPTIC_PIT = _Optic_Pit()
    OPTIC_PIT_NEURAL_ECTODERM = _Optic_Pit_Neural_Ectoderm()
    COMMON_DORSAL_AORTA = _Common_Dorsal_Aorta()
    INTERNAL_CAROTID_ARTERY = _Internal_Carotid_Artery()
    LEFT_INTERNAL_CAROTID_ARTERY = _Left_Internal_Carotid_Artery()
    RIGHT_INTERNAL_CAROTID_ARTERY = _Right_Internal_Carotid_Artery()
    UMBILICAL_ARTERY_EMBRYONIC_PART = _Umbilical_Artery_Embryonic_Part()
    BLOOD = _Blood()
    BULBUS_CORDIS = _Bulbus_Cordis()
    BULBUS_CORDIS_CAUDAL_HALF = _Bulbus_Cordis_Caudal_Half()
    BULBUS_CORDIS_CAUDAL_HALF_CARDIAC_JELLY = _Bulbus_Cordis_Caudal_Half_Cardiac_Jelly()
    BULBUS_CORDIS_CAUDAL_HALF_ENDOCARDIAL_TUBE = _Bulbus_Cordis_Caudal_Half_Endocardial_Tube()
    BULBUS_CORDIS_CAUDAL_HALF_CARDIAC_MUSCLE = _Bulbus_Cordis_Caudal_Half_Cardiac_Muscle()
    BULBUS_CORDIS_ROSTRAL_HALF = _Bulbus_Cordis_Rostral_Half()
    BULBUS_CORDIS_ROSTRAL_HALF_CARDIAC_JELLY = _Bulbus_Cordis_Rostral_Half_Cardiac_Jelly()
    BULBUS_CORDIS_ROSTRAL_HALF_ENDOCARDIAL_TUBE = _Bulbus_Cordis_Rostral_Half_Endocardial_Tube()
    BULBUS_CORDIS_ROSTRAL_HALF_CARDIAC_MUSCLE = _Bulbus_Cordis_Rostral_Half_Cardiac_Muscle()
    COMMON_ATRIAL_CHAMBER = _Common_Atrial_Chamber()
    COMMON_ATRIAL_CHAMBER_CARDIAC_JELLY = _Common_Atrial_Chamber_Cardiac_Jelly()
    COMMON_ATRIAL_CHAMBER_ENDOCARDIAL_TUBE = _Common_Atrial_Chamber_Endocardial_Tube()
    COMMON_ATRIAL_CHAMBER_CARDIAC_MUSCLE = _Common_Atrial_Chamber_Cardiac_Muscle()
    OUTFLOW_TRACT = _Outflow_Tract()
    OUTFLOW_TRACT_CARDIAC_JELLY = _Outflow_Tract_Cardiac_Jelly()
    OUTFLOW_TRACT_ENDOCARDIAL_TUBE = _Outflow_Tract_Endocardial_Tube()
    OUTFLOW_TRACT_MESENCHYME = _Outflow_Tract_Mesenchyme()
    PRIMITIVE_VENTRICLE = _Primitive_Ventricle()
    PRIMITIVE_VENTRICLE_CARDIAC_JELLY = _Primitive_Ventricle_Cardiac_Jelly()
    PRIMITIVE_VENTRICLE_ENDOCARDIAL_TUBE = _Primitive_Ventricle_Endocardial_Tube()
    PRIMITIVE_VENTRICLE_CARDIAC_MUSCLE = _Primitive_Ventricle_Cardiac_Muscle()
    CARDINAL_VEIN = _Cardinal_Vein()
    COMMON_CARDINAL_VEIN = _Common_Cardinal_Vein()
    POSTERIOR_CARDINAL_VEIN = _Posterior_Cardinal_Vein()
    LEFT_UMBILICAL_VEIN_EMBRYONIC_PART = _Left_Umbilical_Vein_Embryonic_Part()
    RIGHT_UMBILICAL_VEIN_EMBRYONIC_PART = _Right_Umbilical_Vein_Embryonic_Part()
    THYROID_PRIMORDIUM = _Thyroid_Primordium()
    THYROID_PRIMORDIUM_MESENCHYME = _Thyroid_Primordium_Mesenchyme()
    FOREGUT_MIDGUT_JUNCTION = _Foregut_Midgut_Junction()
    FOREGUT_MIDGUT_JUNCTION_MESENCHYME = _Foregut_Midgut_Junction_Mesenchyme()
    FOREGUT_MIDGUT_JUNCTION_MESENTERY = _Foregut_Midgut_Junction_Mesentery()
    FOREGUT_MIDGUT_JUNCTION_DORSAL_MESENTERY = _Foregut_Midgut_Junction_Dorsal_Mesentery()
    GENITOURINARY_SYSTEM = _Genitourinary_System()
    NEPHROGENIC_CORD = _Nephrogenic_Cord()
    PRESUMPTIVE_NEPHRIC_DUCT = _Presumptive_Nephric_Duct()
    EXTRAEMBRYONIC_VASCULAR_SYSTEM = _Extraembryonic_Vascular_System()
    EXTRAEMBRYONIC_ARTERIAL_SYSTEM = _Extraembryonic_Arterial_System()
    UMBILICAL_ARTERY_EXTRAEMBRYONIC_PART = _Umbilical_Artery_Extraembryonic_Part()
    COMMON_UMBILICAL_ARTERY = _Common_Umbilical_Artery()
    EXTRAEMBRYONIC_VENOUS_SYSTEM = _Extraembryonic_Venous_System()
    UMBILICAL_VEIN_EXTRAEMBRYONIC_PART = _Umbilical_Vein_Extraembryonic_Part()
    COMMON_UMBILICAL_VEIN = _Common_Umbilical_Vein()
    LEFT_UMBILICAL_VEIN_EXTRAEMBRYONIC_PART = _Left_Umbilical_Vein_Extraembryonic_Part()
    RIGHT_UMBILICAL_VEIN_EXTRAEMBRYONIC_PART = _Right_Umbilical_Vein_Extraembryonic_Part()
    VITELLINE_VEIN_EXTRAEMBRYONIC_PART = _Vitelline_Vein_Extraembryonic_Part()
    LEFT_VITELLINE_VEIN_EXTRAEMBRYONIC_PART = _Left_Vitelline_Vein_Extraembryonic_Part()
    RIGHT_VITELLINE_VEIN_EXTRAEMBRYONIC_PART = _Right_Vitelline_Vein_Extraembryonic_Part()
    _1ST_BRANCHIAL_ARCH_MANDIBULAR_COMPONENT = _1St_Branchial_Arch_Mandibular_Component()
    _1ST_BRANCHIAL_ARCH_MANDIBULAR_COMPONENT_ECTODERM = _1St_Branchial_Arch_Mandibular_Component_Ectoderm()
    _1ST_BRANCHIAL_ARCH_MANDIBULAR_COMPONENT_ENDODERM = _1St_Branchial_Arch_Mandibular_Component_Endoderm()
    _1ST_BRANCHIAL_ARCH_MANDIBULAR_COMPONENT_MESENCHYME = _1St_Branchial_Arch_Mandibular_Component_Mesenchyme()
    _1ST_BRANCHIAL_ARCH_MANDIBULAR_COMPONENT_MESENCHYME_DERIVED_FROM_HEAD_MESODERM = (
        _1St_Branchial_Arch_Mandibular_Component_Mesenchyme_Derived_From_Head_Mesoderm()
    )
    _1ST_BRANCHIAL_ARCH_MANDIBULAR_COMPONENT_MESENCHYME_DERIVED_FROM_NEURAL_CREST = (
        _1St_Branchial_Arch_Mandibular_Component_Mesenchyme_Derived_From_Neural_Crest()
    )
    _1ST_BRANCHIAL_ARCH_MAXILLARY_COMPONENT = _1St_Branchial_Arch_Maxillary_Component()
    _1ST_BRANCHIAL_ARCH_MAXILLARY_COMPONENT_ECTODERM = _1St_Branchial_Arch_Maxillary_Component_Ectoderm()
    _1ST_BRANCHIAL_ARCH_MAXILLARY_COMPONENT_ENDODERM = _1St_Branchial_Arch_Maxillary_Component_Endoderm()
    _1ST_BRANCHIAL_ARCH_MAXILLARY_COMPONENT_MESENCHYME = _1St_Branchial_Arch_Maxillary_Component_Mesenchyme()
    _1ST_BRANCHIAL_ARCH_MAXILLARY_COMPONENT_MESENCHYME_DERIVED_FROM_HEAD_MESODERM = (
        _1St_Branchial_Arch_Maxillary_Component_Mesenchyme_Derived_From_Head_Mesoderm()
    )
    _1ST_BRANCHIAL_ARCH_MAXILLARY_COMPONENT_MESENCHYME_DERIVED_FROM_NEURAL_CREST = (
        _1St_Branchial_Arch_Maxillary_Component_Mesenchyme_Derived_From_Neural_Crest()
    )
    _1ST_BRANCHIAL_ARCH_MAXILLARY_MANDIBULAR_GROOVE = _1St_Branchial_Arch_Maxillary_Mandibular_Groove()
    _1ST_BRANCHIAL_ARCH_MAXILLARY_MANDIBULAR_GROOVE_ECTODERM = (
        _1St_Branchial_Arch_Maxillary_Mandibular_Groove_Ectoderm()
    )
    _2ND_BRANCHIAL_GROOVE = _2Nd_Branchial_Groove()
    _2ND_BRANCHIAL_GROOVE_ECTODERM = _2Nd_Branchial_Groove_Ectoderm()
    _2ND_BRANCHIAL_MEMBRANE_ECTODERM = _2Nd_Branchial_Membrane_Ectoderm()
    _3RD_BRANCHIAL_ARCH = _3Rd_Branchial_Arch()
    _3RD_BRANCHIAL_ARCH_ECTODERM = _3Rd_Branchial_Arch_Ectoderm()
    _3RD_BRANCHIAL_ARCH_ENDODERM = _3Rd_Branchial_Arch_Endoderm()
    _3RD_BRANCHIAL_ARCH_MESENCHYME = _3Rd_Branchial_Arch_Mesenchyme()
    _3RD_BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_HEAD_MESODERM = (
        _3Rd_Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm()
    )
    _3RD_BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_NEURAL_CREST = (
        _3Rd_Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest()
    )
    LIMB = _Limb()
    FORELIMB_BUD = _Forelimb_Bud()
    FORELIMB_BUD_ECTODERM = _Forelimb_Bud_Ectoderm()
    FORELIMB_BUD_MESENCHYME = _Forelimb_Bud_Mesenchyme()
    MESENCHYME_DERIVED_FROM_LATERAL_PLATE = _Mesenchyme_Derived_From_Lateral_Plate()
    MESENCHYME_DERIVED_FROM_SOMATOPLEURE = _Mesenchyme_Derived_From_Somatopleure()
    MESENCHYME_DERIVED_FROM_SPLANCHNOPLEURE = _Mesenchyme_Derived_From_Splanchnopleure()
    SOMITE_05_DERMOMYOTOME = _Somite_05_Dermomyotome()
    SOMITE_05_MYOCOELE = _Somite_05_Myocoele()
    SOMITE_05_SCLEROTOME = _Somite_05_Sclerotome()
    SOMITE_06_DERMOMYOTOME = _Somite_06_Dermomyotome()
    SOMITE_06_MYOCOELE = _Somite_06_Myocoele()
    SOMITE_06_SCLEROTOME = _Somite_06_Sclerotome()
    SOMITE_07_DERMOMYOTOME = _Somite_07_Dermomyotome()
    SOMITE_07_MYOCOELE = _Somite_07_Myocoele()
    SOMITE_07_SCLEROTOME = _Somite_07_Sclerotome()
    SOMITE_08_DERMOMYOTOME = _Somite_08_Dermomyotome()
    SOMITE_08_MYOCOELE = _Somite_08_Myocoele()
    SOMITE_08_SCLEROTOME = _Somite_08_Sclerotome()
    SOMITE_09_DERMOMYOTOME = _Somite_09_Dermomyotome()
    SOMITE_09_MYOCOELE = _Somite_09_Myocoele()
    SOMITE_09_SCLEROTOME = _Somite_09_Sclerotome()
    SOMITE_10_DERMOMYOTOME = _Somite_10_Dermomyotome()
    SOMITE_10_MYOCOELE = _Somite_10_Myocoele()
    SOMITE_10_SCLEROTOME = _Somite_10_Sclerotome()
    SOMITE_11_DERMOMYOTOME = _Somite_11_Dermomyotome()
    SOMITE_11_MYOCOELE = _Somite_11_Myocoele()
    SOMITE_11_SCLEROTOME = _Somite_11_Sclerotome()
    SOMITE_12_DERMOMYOTOME = _Somite_12_Dermomyotome()
    SOMITE_12_MYOCOELE = _Somite_12_Myocoele()
    SOMITE_12_SCLEROTOME = _Somite_12_Sclerotome()
    SOMITE_13_DERMOMYOTOME = _Somite_13_Dermomyotome()
    SOMITE_13_MYOCOELE = _Somite_13_Myocoele()
    SOMITE_13_SCLEROTOME = _Somite_13_Sclerotome()
    SOMITE_14 = _Somite_14()
    SOMITE_14_DERMOMYOTOME = _Somite_14_Dermomyotome()
    SOMITE_14_MYOCOELE = _Somite_14_Myocoele()
    SOMITE_14_SCLEROTOME = _Somite_14_Sclerotome()
    SOMITE_15 = _Somite_15()
    SOMITE_15_DERMOMYOTOME = _Somite_15_Dermomyotome()
    SOMITE_15_MYOCOELE = _Somite_15_Myocoele()
    SOMITE_15_SCLEROTOME = _Somite_15_Sclerotome()
    SOMITE_16 = _Somite_16()
    SOMITE_16_DERMOMYOTOME = _Somite_16_Dermomyotome()
    SOMITE_16_MYOCOELE = _Somite_16_Myocoele()
    SOMITE_16_SCLEROTOME = _Somite_16_Sclerotome()
    SOMITE_17 = _Somite_17()
    SOMITE_17_DERMOMYOTOME = _Somite_17_Dermomyotome()
    SOMITE_17_MYOCOELE = _Somite_17_Myocoele()
    SOMITE_17_SCLEROTOME = _Somite_17_Sclerotome()
    SOMITE_18 = _Somite_18()
    SOMITE_18_DERMOMYOTOME = _Somite_18_Dermomyotome()
    SOMITE_18_MYOCOELE = _Somite_18_Myocoele()
    SOMITE_18_SCLEROTOME = _Somite_18_Sclerotome()
    SOMITE_19 = _Somite_19()
    SOMITE_19_DERMOMYOTOME = _Somite_19_Dermomyotome()
    SOMITE_19_MYOCOELE = _Somite_19_Myocoele()
    SOMITE_19_SCLEROTOME = _Somite_19_Sclerotome()
    SOMITE_20 = _Somite_20()
    SOMITE_20_DERMOMYOTOME = _Somite_20_Dermomyotome()
    SOMITE_20_MYOCOELE = _Somite_20_Myocoele()
    SOMITE_20_SCLEROTOME = _Somite_20_Sclerotome()
    NERVOUS_SYSTEM = _Nervous_System()
    CENTRAL_NERVOUS_SYSTEM = _Central_Nervous_System()
    FUTURE_MIDBRAIN_LATERAL_WALL = _Future_Midbrain_Lateral_Wall()
    RHOMBOMERE_1_LATERAL_WALL = _Rhombomere_1_Lateral_Wall()
    RHOMBOMERE_1_ROOF_PLATE = _Rhombomere_1_Roof_Plate()
    RHOMBOMERE_2_LATERAL_WALL = _Rhombomere_2_Lateral_Wall()
    RHOMBOMERE_2_ROOF_PLATE = _Rhombomere_2_Roof_Plate()
    RHOMBOMERE_3_LATERAL_WALL = _Rhombomere_3_Lateral_Wall()
    RHOMBOMERE_3_ROOF_PLATE = _Rhombomere_3_Roof_Plate()
    RHOMBOMERE_4_LATERAL_WALL = _Rhombomere_4_Lateral_Wall()
    RHOMBOMERE_4_ROOF_PLATE = _Rhombomere_4_Roof_Plate()
    RHOMBOMERE_5_LATERAL_WALL = _Rhombomere_5_Lateral_Wall()
    RHOMBOMERE_5_ROOF_PLATE = _Rhombomere_5_Roof_Plate()
    RHOMBOMERE_6 = _Rhombomere_6()
    RHOMBOMERE_6_FLOOR_PLATE = _Rhombomere_6_Floor_Plate()
    RHOMBOMERE_6_LATERAL_WALL = _Rhombomere_6_Lateral_Wall()
    RHOMBOMERE_6_ROOF_PLATE = _Rhombomere_6_Roof_Plate()
    RHOMBOMERE_7 = _Rhombomere_7()
    RHOMBOMERE_7_FLOOR_PLATE = _Rhombomere_7_Floor_Plate()
    RHOMBOMERE_7_LATERAL_WALL = _Rhombomere_7_Lateral_Wall()
    RHOMBOMERE_7_ROOF_PLATE = _Rhombomere_7_Roof_Plate()
    RHOMBOMERE_8 = _Rhombomere_8()
    RHOMBOMERE_8_FLOOR_PLATE = _Rhombomere_8_Floor_Plate()
    RHOMBOMERE_8_LATERAL_WALL = _Rhombomere_8_Lateral_Wall()
    RHOMBOMERE_8_ROOF_PLATE = _Rhombomere_8_Roof_Plate()
    PROSENCEPHALON = _Prosencephalon()
    PROSENCEPHALON_FLOOR_PLATE = _Prosencephalon_Floor_Plate()
    FUTURE_DIENCEPHALON = _Future_Diencephalon()
    FUTURE_DIENCEPHALON_FLOOR_PLATE = _Future_Diencephalon_Floor_Plate()
    FUTURE_DIENCEPHALON_LATERAL_WALL = _Future_Diencephalon_Lateral_Wall()
    FUTURE_DIENCEPHALON_NEURAL_CREST = _Future_Diencephalon_Neural_Crest()
    FUTURE_DIENCEPHALON_ROOF_PLATE = _Future_Diencephalon_Roof_Plate()
    PROSENCEPHALON_LATERAL_WALL = _Prosencephalon_Lateral_Wall()
    PROSENCEPHALIC_VESICLE = _Prosencephalic_Vesicle()
    PROSENCEPHALON_ROOF_PLATE = _Prosencephalon_Roof_Plate()
    ROSTRAL_NEUROPORE = _Rostral_Neuropore()
    PROSENCEPHALON_NEURAL_CREST = _Prosencephalon_Neural_Crest()
    CAUDAL_NEUROPORE = _Caudal_Neuropore()
    OTIC_PIT = _Otic_Pit()
    OTIC_PIT_MESENCHYME = _Otic_Pit_Mesenchyme()
    OTIC_PIT_EPITHELIUM = _Otic_Pit_Epithelium()
    OPTIC_EMINENCE_SURFACE_ECTODERM = _Optic_Eminence_Surface_Ectoderm()
    OPTIC_VESICLE = _Optic_Vesicle()
    OPTIC_VESICLE_NEURAL_ECTODERM = _Optic_Vesicle_Neural_Ectoderm()
    NOSE = _Nose()
    OLFACTORY_PLACODE = _Olfactory_Placode()
    LEFT_UMBILICAL_ARTERY = _Left_Umbilical_Artery()
    RIGHT_UMBILICAL_ARTERY = _Right_Umbilical_Artery()
    ATRIOVENTRICULAR_CANAL = _Atrioventricular_Canal()
    VESSELS_CONNECTING_INTERNAL_CAROTID_ARTERY_TO_PRIMARY_HEAD_VEINS = (
        _Vessels_Connecting_Internal_Carotid_Artery_To_Primary_Head_Veins()
    )
    FOREGUT = _Foregut()
    PHARYNGEAL_REGION = _Pharyngeal_Region()
    PHARYNGEAL_REGION_MESENCHYME = _Pharyngeal_Region_Mesenchyme()
    PHARYNGEAL_REGION_EPITHELIUM = _Pharyngeal_Region_Epithelium()
    PHARYNGEAL_REGION_VASCULAR_ELEMENT = _Pharyngeal_Region_Vascular_Element()
    FOREGUT_VASCULAR_ELEMENT = _Foregut_Vascular_Element()
    FOREGUT_GLAND = _Foregut_Gland()
    BILIARY_BUD = _Biliary_Bud()
    BILIARY_BUD_EXTRAHEPATIC_PART = _Biliary_Bud_Extrahepatic_Part()
    BILIARY_BUD_INTRAHEPATIC_PART = _Biliary_Bud_Intrahepatic_Part()
    FOREGUT_MIDGUT_JUNCTION_EPITHELIUM = _Foregut_Midgut_Junction_Epithelium()
    FOREGUT_MIDGUT_JUNCTION_VASCULAR_ELEMENT = _Foregut_Midgut_Junction_Vascular_Element()
    HINDGUT_DIVERTICULUM_EPITHELIUM = _Hindgut_Diverticulum_Epithelium()
    HINDGUT_DIVERTICULUM_VASCULAR_ELEMENT = _Hindgut_Diverticulum_Vascular_Element()
    MIDGUT_EPITHELIUM = _Midgut_Epithelium()
    MIDGUT_VASCULAR_ELEMENT = _Midgut_Vascular_Element()
    STOMATODEUM_GLAND = _Stomatodeum_Gland()
    STOMATODEUM_ECTODERM = _Stomatodeum_Ectoderm()
    GENITOURINARY_SYSTEM_MESENCHYME = _Genitourinary_System_Mesenchyme()
    NEPHRIC_DUCT = _Nephric_Duct()
    PRIMORDIAL_GERM_CELL_OF_GONAD = _Primordial_Germ_Cell_Of_Gonad()
    PRONEPHROS = _Pronephros()
    TAIL_BUD = _Tail_Bud()
    _3RD_BRANCHIAL_GROOVE = _3Rd_Branchial_Groove()
    _3RD_BRANCHIAL_GROOVE_ECTODERM = _3Rd_Branchial_Groove_Ectoderm()
    _3RD_BRANCHIAL_MEMBRANE = _3Rd_Branchial_Membrane()
    _3RD_BRANCHIAL_MEMBRANE_ECTODERM = _3Rd_Branchial_Membrane_Ectoderm()
    _3RD_BRANCHIAL_MEMBRANE_ENDODERM = _3Rd_Branchial_Membrane_Endoderm()
    _3RD_BRANCHIAL_POUCH = _3Rd_Branchial_Pouch()
    _3RD_BRANCHIAL_POUCH_ENDODERM = _3Rd_Branchial_Pouch_Endoderm()
    PARIETAL_PERICARDIUM = _Parietal_Pericardium()
    VISCERAL_PERICARDIUM = _Visceral_Pericardium()
    PERICARDIO_PERITONEAL_CANAL_PARIETAL_MESOTHELIUM = _Pericardio_Peritoneal_Canal_Parietal_Mesothelium()
    PERITONEUM_PARIETAL_MESOTHELIUM = _Peritoneum_Parietal_Mesothelium()
    PERITONEUM_VISCERAL_MESOTHELIUM = _Peritoneum_Visceral_Mesothelium()
    HINDLIMB_RIDGE = _Hindlimb_Ridge()
    HINDLIMB_RIDGE_ECTODERM = _Hindlimb_Ridge_Ectoderm()
    HINDLIMB_RIDGE_MESENCHYME = _Hindlimb_Ridge_Mesenchyme()
    TRUNK_MESENCHYME_DERIVED_FROM_NEURAL_CREST_LATERAL_MIGRATION_PATHWAY = (
        _Trunk_Mesenchyme_Derived_From_Neural_Crest_Lateral_Migration_Pathway()
    )
    TRUNK_MESENCHYME_DERIVED_FROM_NEURAL_CREST_MEDIAL_MIGRATION_PATHWAY = (
        _Trunk_Mesenchyme_Derived_From_Neural_Crest_Medial_Migration_Pathway()
    )
    SOMITE_21 = _Somite_21()
    SOMITE_21_DERMOMYOTOME = _Somite_21_Dermomyotome()
    SOMITE_21_MYOCOELE = _Somite_21_Myocoele()
    SOMITE_21_SCLEROTOME = _Somite_21_Sclerotome()
    SOMITE_22 = _Somite_22()
    SOMITE_22_DERMOMYOTOME = _Somite_22_Dermomyotome()
    SOMITE_22_MYOCOELE = _Somite_22_Myocoele()
    SOMITE_22_SCLEROTOME = _Somite_22_Sclerotome()
    SOMITE_23 = _Somite_23()
    SOMITE_23_DERMOMYOTOME = _Somite_23_Dermomyotome()
    SOMITE_23_MYOCOELE = _Somite_23_Myocoele()
    SOMITE_23_SCLEROTOME = _Somite_23_Sclerotome()
    SOMITE_24 = _Somite_24()
    SOMITE_24_DERMOMYOTOME = _Somite_24_Dermomyotome()
    SOMITE_24_MYOCOELE = _Somite_24_Myocoele()
    SOMITE_24_SCLEROTOME = _Somite_24_Sclerotome()
    SOMITE_25 = _Somite_25()
    SOMITE_25_DERMOMYOTOME = _Somite_25_Dermomyotome()
    SOMITE_25_MYOCOELE = _Somite_25_Myocoele()
    SOMITE_25_SCLEROTOME = _Somite_25_Sclerotome()
    SOMITE_26 = _Somite_26()
    SOMITE_26_DERMOMYOTOME = _Somite_26_Dermomyotome()
    SOMITE_26_MYOCOELE = _Somite_26_Myocoele()
    SOMITE_26_SCLEROTOME = _Somite_26_Sclerotome()
    SOMITE_27 = _Somite_27()
    SOMITE_27_DERMOMYOTOME = _Somite_27_Dermomyotome()
    SOMITE_27_MYOCOELE = _Somite_27_Myocoele()
    SOMITE_27_SCLEROTOME = _Somite_27_Sclerotome()
    SOMITE_28 = _Somite_28()
    SOMITE_28_DERMOMYOTOME = _Somite_28_Dermomyotome()
    SOMITE_28_MYOCOELE = _Somite_28_Myocoele()
    SOMITE_28_SCLEROTOME = _Somite_28_Sclerotome()
    SOMITE_29 = _Somite_29()
    SOMITE_29_DERMOMYOTOME = _Somite_29_Dermomyotome()
    SOMITE_29_MYOCOELE = _Somite_29_Myocoele()
    SOMITE_29_SCLEROTOME = _Somite_29_Sclerotome()
    SOMITE_30 = _Somite_30()
    SOMITE_30_DERMOMYOTOME = _Somite_30_Dermomyotome()
    SOMITE_30_MYOCOELE = _Somite_30_Myocoele()
    SOMITE_30_SCLEROTOME = _Somite_30_Sclerotome()
    FUTURE_FOREBRAIN = _Future_Forebrain()
    FUTURE_NEUROHYPOPHYSIS = _Future_Neurohypophysis()
    TELENCEPHALIC_VESICLE = _Telencephalic_Vesicle()
    TELENCEPHALON_FLOOR_PLATE = _Telencephalon_Floor_Plate()
    TELENCEPHALON_LATERAL_WALL = _Telencephalon_Lateral_Wall()
    TELENCEPHALON_ROOF_PLATE = _Telencephalon_Roof_Plate()
    CENTRAL_NERVOUS_SYSTEM_GANGLION = _Central_Nervous_System_Ganglion()
    CRANIAL_GANGLION = _Cranial_Ganglion()
    FACIO_ACOUSTIC_PREGANGLION_COMPLEX = _Facio_Acoustic_Preganglion_Complex()
    GLOSSOPHARYNGEAL_PREGANGLION = _Glossopharyngeal_Preganglion()
    GLOSSOPHARYNGEAL_VAGUS_PREGANGLION_COMPLEX = _Glossopharyngeal_Vagus_Preganglion_Complex()
    TRIGEMINAL_PREGANGLION = _Trigeminal_Preganglion()
    VAGUS_PREGANGLION = _Vagus_Preganglion()
    PERIPHERAL_NERVOUS_SYSTEM = _Peripheral_Nervous_System()
    SPINAL_COMPONENT_OF_PERIPHERAL_NERVOUS_SYSTEM = _Spinal_Component_Of_Peripheral_Nervous_System()
    SPINAL_GANGLION = _Spinal_Ganglion()
    DORSAL_ROOT_GANGLION = _Dorsal_Root_Ganglion()
    OTOCYST = _Otocyst()
    OTOCYST_MESENCHYME = _Otocyst_Mesenchyme()
    OTOCYST_EPITHELIUM = _Otocyst_Epithelium()
    LENS_PLACODE = _Lens_Placode()
    EYE_MESENCHYME = _Eye_Mesenchyme()
    OPTIC_CUP = _Optic_Cup()
    OPTIC_CUP_INNER_LAYER = _Optic_Cup_Inner_Layer()
    OPTIC_CUP_INTRARETINAL_SPACE = _Optic_Cup_Intraretinal_Space()
    OPTIC_CUP_OUTER_LAYER = _Optic_Cup_Outer_Layer()
    OPTIC_STALK = _Optic_Stalk()
    NASO_LACRIMAL_GROOVE = _Naso_Lacrimal_Groove()
    NASAL_PROCESS = _Nasal_Process()
    FRONTO_NASAL_PROCESS = _Fronto_Nasal_Process()
    FRONTO_NASAL_PROCESS_ECTODERM = _Fronto_Nasal_Process_Ectoderm()
    FRONTO_NASAL_PROCESS_MESENCHYME = _Fronto_Nasal_Process_Mesenchyme()
    BRANCHIAL_ARCH_ARTERY = _Branchial_Arch_Artery()
    _1ST_ARCH_ARTERY = _1St_Arch_Artery()
    _2ND_ARCH_ARTERY = _2Nd_Arch_Artery()
    _3RD_ARCH_ARTERY = _3Rd_Arch_Artery()
    HEART_ATRIUM = _Heart_Atrium()
    COMMON_ATRIAL_CHAMBER_ENDOCARDIAL_LINING = _Common_Atrial_Chamber_Endocardial_Lining()
    BULBOVENTRICULAR_GROOVE = _Bulboventricular_Groove()
    BULBUS_CORDIS_CAUDAL_HALF_ENDOCARDIAL_LINING = _Bulbus_Cordis_Caudal_Half_Endocardial_Lining()
    BULBUS_CORDIS_ROSTRAL_HALF_ENDOCARDIAL_LINING = _Bulbus_Cordis_Rostral_Half_Endocardial_Lining()
    ENDOCARDIAL_CUSHION = _Endocardial_Cushion()
    PRIMITIVE_VENTRICLE_ENDOCARDIAL_LINING = _Primitive_Ventricle_Endocardial_Lining()
    LEFT_VITELLINE_VEIN_EMBRYONIC_PART = _Left_Vitelline_Vein_Embryonic_Part()
    RIGHT_VITELLINE_VEIN_EMBRYONIC_PART = _Right_Vitelline_Vein_Embryonic_Part()
    ESOPHAGEAL_REGION = _Esophageal_Region()
    ESOPHAGEAL_REGION_MESENCHYME = _Esophageal_Region_Mesenchyme()
    ESOPHAGEAL_REGION_EPITHELIUM = _Esophageal_Region_Epithelium()
    ESOPHAGEAL_REGION_MESENTERY = _Esophageal_Region_Mesentery()
    DORSAL_MESO_ESOPHAGUS = _Dorsal_Meso_Esophagus()
    ESOPHAGEAL_REGION_VASCULAR_ELEMENT = _Esophageal_Region_Vascular_Element()
    PHARYNX = _Pharynx()
    PHARYNX_MESENCHYME = _Pharynx_Mesenchyme()
    PHARYNX_EPITHELIUM = _Pharynx_Epithelium()
    PHARYNX_VASCULAR_ELEMENT = _Pharynx_Vascular_Element()
    FOREGUT_MESENTERY = _Foregut_Mesentery()
    FOREGUT_DORSAL_MESENTERY = _Foregut_Dorsal_Mesentery()
    FOREGUT_VENTRAL_MESENTERY = _Foregut_Ventral_Mesentery()
    GALLBLADDER_PRIMORDIUM = _Gallbladder_Primordium()
    FOREGUT_MIDGUT_JUNCTION_VENTRAL_MESENTERY = _Foregut_Midgut_Junction_Ventral_Mesentery()
    HINDGUT = _Hindgut()
    HINDGUT_MESENCHYME = _Hindgut_Mesenchyme()
    HINDGUT_EPITHELIUM = _Hindgut_Epithelium()
    HINDGUT_MESENTERY = _Hindgut_Mesentery()
    HINDGUT_DORSAL_MESENTERY = _Hindgut_Dorsal_Mesentery()
    HINDGUT_VASCULAR_ELEMENT = _Hindgut_Vascular_Element()
    MIDGUT_MESENTERY = _Midgut_Mesentery()
    MIDGUT_DORSAL_MESENTERY = _Midgut_Dorsal_Mesentery()
    ORAL_REGION_GLAND = _Oral_Region_Gland()
    FUTURE_ADENOHYPOPHYSIS = _Future_Adenohypophysis()
    RATHKE_S_POUCH = _Rathke_S_Pouch()
    ORAL_REGION_ECTODERM = _Oral_Region_Ectoderm()
    RESPIRATORY_SYSTEM = _Respiratory_System()
    LUNG = _Lung()
    LEFT_LUNG_RUDIMENT = _Left_Lung_Rudiment()
    LEFT_LUNG_RUDIMENT_MESENCHYME = _Left_Lung_Rudiment_Mesenchyme()
    LEFT_LUNG_RUDIMENT_EPITHELIUM = _Left_Lung_Rudiment_Epithelium()
    LEFT_LUNG_RUDIMENT_VASCULAR_ELEMENT = _Left_Lung_Rudiment_Vascular_Element()
    RIGHT_LUNG_RUDIMENT = _Right_Lung_Rudiment()
    RIGHT_LUNG_RUDIMENT_MESENCHYME = _Right_Lung_Rudiment_Mesenchyme()
    RIGHT_LUNG_RUDIMENT_EPITHELIUM = _Right_Lung_Rudiment_Epithelium()
    RIGHT_LUNG_RUDIMENT_VASCULAR_ELEMENT = _Right_Lung_Rudiment_Vascular_Element()
    RESPIRATORY_TRACT = _Respiratory_Tract()
    LOWER_RESPIRATORY_TRACT = _Lower_Respiratory_Tract()
    LARYNGO_TRACHEAL_GROOVE = _Laryngo_Tracheal_Groove()
    TRACHEAL_DIVERTICULUM = _Tracheal_Diverticulum()
    TRACHEAL_DIVERTICULUM_MESENCHYME = _Tracheal_Diverticulum_Mesenchyme()
    TRACHEAL_DIVERTICULUM_EPITHELIUM = _Tracheal_Diverticulum_Epithelium()
    TRACHEAL_DIVERTICULUM_VASCULAR_ELEMENT = _Tracheal_Diverticulum_Vascular_Element()
    MESONEPHROS = _Mesonephros()
    MESONEPHROS_MESENCHYME = _Mesonephros_Mesenchyme()
    MESONEPHRIC_TUBULE = _Mesonephric_Tubule()
    TAIL = _Tail()
    TAIL_MESENCHYME = _Tail_Mesenchyme()
    TAIL_MESENCHYME_DERIVED_FROM_NEURAL_CREST = _Tail_Mesenchyme_Derived_From_Neural_Crest()
    TAIL_PARAXIAL_MESENCHYME = _Tail_Paraxial_Mesenchyme()
    TAIL_UNSEGMENTED_MESENCHYME = _Tail_Unsegmented_Mesenchyme()
    TAIL_NERVOUS_SYSTEM = _Tail_Nervous_System()
    TAIL_CENTRAL_NERVOUS_SYSTEM = _Tail_Central_Nervous_System()
    TAIL_FUTURE_SPINAL_CORD = _Tail_Future_Spinal_Cord()
    TAIL_NEURAL_PLATE = _Tail_Neural_Plate()
    TAIL_NEURAL_TUBE = _Tail_Neural_Tube()
    _3RD_BRANCHIAL_POUCH_DORSAL_ENDODERM = _3Rd_Branchial_Pouch_Dorsal_Endoderm()
    _3RD_BRANCHIAL_POUCH_VENTRAL_ENDODERM = _3Rd_Branchial_Pouch_Ventral_Endoderm()
    _4TH_BRANCHIAL_ARCH = _4Th_Branchial_Arch()
    _4TH_BRANCHIAL_GROOVE = _4Th_Branchial_Groove()
    _4TH_BRANCHIAL_GROOVE_ECTODERM = _4Th_Branchial_Groove_Ectoderm()
    _4TH_BRANCHIAL_MEMBRANE = _4Th_Branchial_Membrane()
    _4TH_BRANCHIAL_MEMBRANE_ECTODERM = _4Th_Branchial_Membrane_Ectoderm()
    _4TH_BRANCHIAL_MEMBRANE_ENDODERM = _4Th_Branchial_Membrane_Endoderm()
    _4TH_BRANCHIAL_POUCH = _4Th_Branchial_Pouch()
    _4TH_BRANCHIAL_POUCH_ENDODERM = _4Th_Branchial_Pouch_Endoderm()
    _4TH_BRANCHIAL_ARCH_ECTODERM = _4Th_Branchial_Arch_Ectoderm()
    _4TH_BRANCHIAL_ARCH_ENDODERM = _4Th_Branchial_Arch_Endoderm()
    _4TH_BRANCHIAL_ARCH_MESENCHYME = _4Th_Branchial_Arch_Mesenchyme()
    _4TH_BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_HEAD_MESODERM = (
        _4Th_Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm()
    )
    _4TH_BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_NEURAL_CREST = (
        _4Th_Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest()
    )
    PLEURAL_COMPONENT = _Pleural_Component()
    PLEURAL_CAVITY = _Pleural_Cavity()
    PLEURA = _Pleura()
    PARIETAL_PLEURA = _Parietal_Pleura()
    VISCERAL_PLEURA = _Visceral_Pleura()
    FORELIMB_BUD_APICAL_ECTODERMAL_RIDGE = _Forelimb_Bud_Apical_Ectodermal_Ridge()
    HINDLIMB_BUD = _Hindlimb_Bud()
    HINDLIMB_BUD_ECTODERM = _Hindlimb_Bud_Ectoderm()
    HINDLIMB_BUD_MESENCHYME = _Hindlimb_Bud_Mesenchyme()
    FUTURE_MIDBRAIN_VENTRICULAR_LAYER = _Future_Midbrain_Ventricular_Layer()
    RHOMBOMERE_1_VENTRICULAR_LAYER = _Rhombomere_1_Ventricular_Layer()
    RHOMBOMERE_2_VENTRICULAR_LAYER = _Rhombomere_2_Ventricular_Layer()
    RHOMBOMERE_3_VENTRICULAR_LAYER = _Rhombomere_3_Ventricular_Layer()
    RHOMBOMERE_4_VENTRICULAR_LAYER = _Rhombomere_4_Ventricular_Layer()
    RHOMBOMERE_5_VENTRICULAR_LAYER = _Rhombomere_5_Ventricular_Layer()
    RHOMBOMERE_6_VENTRICULAR_LAYER = _Rhombomere_6_Ventricular_Layer()
    RHOMBOMERE_7_VENTRICULAR_LAYER = _Rhombomere_7_Ventricular_Layer()
    RHOMBOMERE_8_VENTRICULAR_LAYER = _Rhombomere_8_Ventricular_Layer()
    FACIO_ACOUSTIC_GANGLION_COMPLEX = _Facio_Acoustic_Ganglion_Complex()
    GLOSSOPHARYNGEAL_GANGLION = _Glossopharyngeal_Ganglion()
    GLOSSOPHARYNGEAL_VAGUS_GANGLION_COMPLEX = _Glossopharyngeal_Vagus_Ganglion_Complex()
    TRIGEMINAL_GANGLION = _Trigeminal_Ganglion()
    VAGUS_GANGLION = _Vagus_Ganglion()
    LENS_PIT = _Lens_Pit()
    NASAL_PIT = _Nasal_Pit()
    NASAL_PIT_EPITHELIUM = _Nasal_Pit_Epithelium()
    FRONTAL_PROCESS = _Frontal_Process()
    FRONTAL_PROCESS_ECTODERM = _Frontal_Process_Ectoderm()
    FRONTAL_PROCESS_MESENCHYME = _Frontal_Process_Mesenchyme()
    LATERO_NASAL_PROCESS = _Latero_Nasal_Process()
    LATERO_NASAL_PROCESS_ECTODERM = _Latero_Nasal_Process_Ectoderm()
    LATERO_NASAL_PROCESS_MESENCHYME = _Latero_Nasal_Process_Mesenchyme()
    MEDIAL_NASAL_PROCESS = _Medial_Nasal_Process()
    MEDIAL_NASAL_PROCESS_ECTODERM = _Medial_Nasal_Process_Ectoderm()
    MEDIAL_NASAL_PROCESS_MESENCHYME = _Medial_Nasal_Process_Mesenchyme()
    PRINCIPAL_ARTERY_TO_FORELIMB = _Principal_Artery_To_Forelimb()
    PRINCIPAL_ARTERY_TO_HINDLIMB = _Principal_Artery_To_Hindlimb()
    COMMON_ATRIAL_CHAMBER_LEFT_PART = _Common_Atrial_Chamber_Left_Part()
    COMMON_ATRIAL_CHAMBER_LEFT_PART_CARDIAC_JELLY = _Common_Atrial_Chamber_Left_Part_Cardiac_Jelly()
    COMMON_ATRIAL_CHAMBER_LEFT_PART_ENDOCARDIAL_LINING = _Common_Atrial_Chamber_Left_Part_Endocardial_Lining()
    LEFT_AURICULAR_REGION = _Left_Auricular_Region()
    LEFT_AURICULAR_REGION_ENDOCARDIAL_LINING = _Left_Auricular_Region_Endocardial_Lining()
    LEFT_AURICULAR_REGION_CARDIAC_MUSCLE = _Left_Auricular_Region_Cardiac_Muscle()
    COMMON_ATRIAL_CHAMBER_LEFT_PART_CARDIAC_MUSCLE = _Common_Atrial_Chamber_Left_Part_Cardiac_Muscle()
    COMMON_ATRIAL_CHAMBER_RIGHT_PART = _Common_Atrial_Chamber_Right_Part()
    COMMON_ATRIAL_CHAMBER_RIGHT_PART_CARDIAC_JELLY = _Common_Atrial_Chamber_Right_Part_Cardiac_Jelly()
    COMMON_ATRIAL_CHAMBER_RIGHT_PART_ENDOCARDIAL_LINING = _Common_Atrial_Chamber_Right_Part_Endocardial_Lining()
    COMMON_ATRIAL_CHAMBER_RIGHT_PART_CARDIAC_MUSCLE = _Common_Atrial_Chamber_Right_Part_Cardiac_Muscle()
    RIGHT_AURICULAR_REGION = _Right_Auricular_Region()
    RIGHT_AURICULAR_REGION_ENDOCARDIAL_LINING = _Right_Auricular_Region_Endocardial_Lining()
    RIGHT_AURICULAR_REGION_CARDIAC_MUSCLE = _Right_Auricular_Region_Cardiac_Muscle()
    AORTICO_PULMONARY_SPIRAL_SEPTUM = _Aortico_Pulmonary_Spiral_Septum()
    INTER_SUBCARDINAL_VENOUS_ANASTOMOSIS = _Inter_Subcardinal_Venous_Anastomosis()
    SUBCARDINAL_VEIN = _Subcardinal_Vein()
    SUPRACARDINAL_VEIN = _Supracardinal_Vein()
    ANAL_REGION = _Anal_Region()
    CLOACAL_MEMBRANE = _Cloacal_Membrane()
    ESOPHAGUS = _Esophagus()
    ESOPHAGUS_MESENCHYME = _Esophagus_Mesenchyme()
    ESOPHAGUS_EPITHELIUM = _Esophagus_Epithelium()
    ESOPHAGUS_MESENTERY = _Esophagus_Mesentery()
    ESOPHAGUS_VASCULAR_ELEMENT = _Esophagus_Vascular_Element()
    ORAL_REGION_EPITHELIUM = _Oral_Region_Epithelium()
    LIVER_AND_BILIARY_SYSTEM = _Liver_And_Biliary_System()
    CYSTIC_DUCT = _Cystic_Duct()
    HEPATIC_DUCT = _Hepatic_Duct()
    HEPATIC_DUCT_EXTRAHEPATIC_PART = _Hepatic_Duct_Extrahepatic_Part()
    HEPATIC_DUCT_INTRAHEPATIC_PART = _Hepatic_Duct_Intrahepatic_Part()
    LIVER = _Liver()
    HEPATIC_PRIMORDIUM = _Hepatic_Primordium()
    HEPATIC_PRIMORDIUM_PARENCHYMA = _Hepatic_Primordium_Parenchyma()
    MAIN_BRONCHUS = _Main_Bronchus()
    MAIN_BRONCHUS_MESENCHYME = _Main_Bronchus_Mesenchyme()
    MAIN_BRONCHUS_EPITHELIUM = _Main_Bronchus_Epithelium()
    MAIN_BRONCHUS_VASCULAR_ELEMENT = _Main_Bronchus_Vascular_Element()
    TRACHEA = _Trachea()
    TRACHEA_MESENCHYME = _Trachea_Mesenchyme()
    TRACHEA_EPITHELIUM = _Trachea_Epithelium()
    TRACHEA_VASCULAR_ELEMENT = _Trachea_Vascular_Element()
    GONAD_PRIMORDIUM = _Gonad_Primordium()
    GONAD_PRIMORDIUM_MESENCHYME = _Gonad_Primordium_Mesenchyme()
    TAIL_SOMITE = _Tail_Somite()
    SOMITE_31 = _Somite_31()
    SOMITE_31_DERMOMYOTOME = _Somite_31_Dermomyotome()
    SOMITE_31_MYOCOELE = _Somite_31_Myocoele()
    SOMITE_31_SCLEROTOME = _Somite_31_Sclerotome()
    SOMITE_32 = _Somite_32()
    SOMITE_32_DERMOMYOTOME = _Somite_32_Dermomyotome()
    SOMITE_32_MYOCOELE = _Somite_32_Myocoele()
    SOMITE_32_SCLEROTOME = _Somite_32_Sclerotome()
    SOMITE_33 = _Somite_33()
    SOMITE_33_DERMOMYOTOME = _Somite_33_Dermomyotome()
    SOMITE_33_MYOCOELE = _Somite_33_Myocoele()
    SOMITE_33_SCLEROTOME = _Somite_33_Sclerotome()
    SOMITE_34 = _Somite_34()
    SOMITE_34_DERMOMYOTOME = _Somite_34_Dermomyotome()
    SOMITE_34_MYOCOELE = _Somite_34_Myocoele()
    SOMITE_34_SCLEROTOME = _Somite_34_Sclerotome()
    SOMITE_35 = _Somite_35()
    SOMITE_35_DERMOMYOTOME = _Somite_35_Dermomyotome()
    SOMITE_35_MYOCOELE = _Somite_35_Myocoele()
    SOMITE_35_SCLEROTOME = _Somite_35_Sclerotome()
    TAIL_NEURAL_CREST = _Tail_Neural_Crest()
    _2ND_BRANCHIAL_ARCH_EPITHELIUM = _2Nd_Branchial_Arch_Epithelium()
    _3RD_BRANCHIAL_GROOVE_EPITHELIUM = _3Rd_Branchial_Groove_Epithelium()
    CERVICAL_SINUS = _Cervical_Sinus()
    GREATER_SAC = _Greater_Sac()
    GREATER_SAC_CAVITY = _Greater_Sac_Cavity()
    GREATER_SAC_MESOTHELIUM = _Greater_Sac_Mesothelium()
    GREATER_SAC_PARIETAL_MESOTHELIUM = _Greater_Sac_Parietal_Mesothelium()
    OMENTAL_BURSA = _Omental_Bursa()
    OMENTAL_BURSA_MESOTHELIUM = _Omental_Bursa_Mesothelium()
    OMENTAL_BURSA_PARIETAL_MESOTHELIUM = _Omental_Bursa_Parietal_Mesothelium()
    HINDLIMB_BUD_APICAL_ECTODERMAL_RIDGE = _Hindlimb_Bud_Apical_Ectodermal_Ridge()
    BODY_WALL_MESENCHYME = _Body_Wall_Mesenchyme()
    BRAIN = _Brain()
    FOREBRAIN = _Forebrain()
    DIENCEPHALON = _Diencephalon()
    DIENCEPHALON_GLAND = _Diencephalon_Gland()
    INFUNDIBULAR_RECESS_OF_3RD_VENTRICLE = _Infundibular_Recess_Of_3Rd_Ventricle()
    _3RD_VENTRICLE = _3Rd_Ventricle()
    DIENCEPHALIC_PART_OF_INTERVENTRICULAR_FORAMEN = _Diencephalic_Part_Of_Interventricular_Foramen()
    OPTIC_RECESS = _Optic_Recess()
    DIENCEPHALON_FLOOR_PLATE = _Diencephalon_Floor_Plate()
    DIENCEPHALON_LAMINA_TERMINALIS = _Diencephalon_Lamina_Terminalis()
    DIENCEPHALON_LATERAL_WALL = _Diencephalon_Lateral_Wall()
    DIENCEPHALON_LATERAL_WALL_MANTLE_LAYER = _Diencephalon_Lateral_Wall_Mantle_Layer()
    DIENCEPHALON_LATERAL_WALL_MARGINAL_LAYER = _Diencephalon_Lateral_Wall_Marginal_Layer()
    DIENCEPHALON_LATERAL_WALL_VENTRICULAR_LAYER = _Diencephalon_Lateral_Wall_Ventricular_Layer()
    DIENCEPHALON_ROOF_PLATE = _Diencephalon_Roof_Plate()
    TELENCEPHALON = _Telencephalon()
    TELENCEPHALON_MANTLE_LAYER = _Telencephalon_Mantle_Layer()
    TELENCEPHALON_MARGINAL_LAYER = _Telencephalon_Marginal_Layer()
    TELENCEPHALON_VENTRICULAR_LAYER = _Telencephalon_Ventricular_Layer()
    LATERAL_VENTRICLE = _Lateral_Ventricle()
    TELENCEPHALIC_PART_OF_INTERVENTRICULAR_FORAMEN = _Telencephalic_Part_Of_Interventricular_Foramen()
    HINDBRAIN = _Hindbrain()
    _4TH_VENTRICLE = _4Th_Ventricle()
    RHOMBOMERE_1_MANTLE_LAYER = _Rhombomere_1_Mantle_Layer()
    RHOMBOMERE_1_MARGINAL_LAYER = _Rhombomere_1_Marginal_Layer()
    RHOMBOMERE_2_MANTLE_LAYER = _Rhombomere_2_Mantle_Layer()
    RHOMBOMERE_2_MARGINAL_LAYER = _Rhombomere_2_Marginal_Layer()
    RHOMBOMERE_3_MANTLE_LAYER = _Rhombomere_3_Mantle_Layer()
    RHOMBOMERE_3_MARGINAL_LAYER = _Rhombomere_3_Marginal_Layer()
    RHOMBOMERE_4_MANTLE_LAYER = _Rhombomere_4_Mantle_Layer()
    RHOMBOMERE_4_MARGINAL_LAYER = _Rhombomere_4_Marginal_Layer()
    RHOMBOMERE_5_MANTLE_LAYER = _Rhombomere_5_Mantle_Layer()
    RHOMBOMERE_5_MARGINAL_LAYER = _Rhombomere_5_Marginal_Layer()
    RHOMBOMERE_6_MANTLE_LAYER = _Rhombomere_6_Mantle_Layer()
    RHOMBOMERE_6_MARGINAL_LAYER = _Rhombomere_6_Marginal_Layer()
    RHOMBOMERE_7_MANTLE_LAYER = _Rhombomere_7_Mantle_Layer()
    RHOMBOMERE_7_MARGINAL_LAYER = _Rhombomere_7_Marginal_Layer()
    RHOMBOMERE_8_MANTLE_LAYER = _Rhombomere_8_Mantle_Layer()
    RHOMBOMERE_8_MARGINAL_LAYER = _Rhombomere_8_Marginal_Layer()
    MIDBRAIN = _Midbrain()
    MIDBRAIN_FLOOR_PLATE = _Midbrain_Floor_Plate()
    MIDBRAIN_LATERAL_WALL = _Midbrain_Lateral_Wall()
    MIDBRAIN_MANTLE_LAYER = _Midbrain_Mantle_Layer()
    MIDBRAIN_MARGINAL_LAYER = _Midbrain_Marginal_Layer()
    MIDBRAIN_VENTRICULAR_LAYER = _Midbrain_Ventricular_Layer()
    MESENCEPHALIC_VESICLE = _Mesencephalic_Vesicle()
    MIDBRAIN_ROOF_PLATE = _Midbrain_Roof_Plate()
    ACOUSTIC_GANGLION = _Acoustic_Ganglion()
    AUTONOMIC_NERVOUS_SYSTEM = _Autonomic_Nervous_System()
    SYMPATHETIC_NERVOUS_SYSTEM = _Sympathetic_Nervous_System()
    PERIPHERAL_NERVE_TRUNK = _Peripheral_Nerve_Trunk()
    SPINAL_NERVE_PLEXUS = _Spinal_Nerve_Plexus()
    BRACHIAL_PLEXUS = _Brachial_Plexus()
    SPINAL_NERVE = _Spinal_Nerve()
    SEGMENTAL_SPINAL_NERVE = _Segmental_Spinal_Nerve()
    OUTER_EAR = _Outer_Ear()
    BRANCHIAL_MEMBRANE = _Branchial_Membrane()
    BRANCHIAL_MEMBRANE_EPITHELIUM = _Branchial_Membrane_Epithelium()
    ENDOLYMPHATIC_APPENDAGE = _Endolymphatic_Appendage()
    ENDOLYMPHATIC_APPENDAGE_MESENCHYME = _Endolymphatic_Appendage_Mesenchyme()
    ENDOLYMPHATIC_APPENDAGE_EPITHELIUM = _Endolymphatic_Appendage_Epithelium()
    REST_OF_OTOCYST = _Rest_Of_Otocyst()
    REST_OF_OTOCYST_MESENCHYME = _Rest_Of_Otocyst_Mesenchyme()
    REST_OF_OTOCYST_EPITHELIUM = _Rest_Of_Otocyst_Epithelium()
    MIDDLE_EAR = _Middle_Ear()
    MIDDLE_EAR_MESENCHYME = _Middle_Ear_Mesenchyme()
    TUBOTYMPANIC_RECESS = _Tubotympanic_Recess()
    EYE_SURFACE_ECTODERM = _Eye_Surface_Ectoderm()
    _4TH_ARCH_ARTERY = _4Th_Arch_Artery()
    _6TH_ARCH_ARTERY = _6Th_Arch_Artery()
    DUCTUS_CAROTICUS = _Ductus_Caroticus()
    OPHTHALMIC_ARTERY = _Ophthalmic_Artery()
    PULMONARY_ARTERY = _Pulmonary_Artery()
    COMMON_ATRIAL_CHAMBER_RIGHT_PART_VALVE = _Common_Atrial_Chamber_Right_Part_Valve()
    COMMON_ATRIAL_CHAMBER_RIGHT_PART_VENOUS_VALVE = _Common_Atrial_Chamber_Right_Part_Venous_Valve()
    INTERATRIAL_SEPTUM = _Interatrial_Septum()
    FORAMEN_PRIMUM = _Foramen_Primum()
    SEPTUM_PRIMUM = _Septum_Primum()
    ASCENDING_AORTA = _Ascending_Aorta()
    PULMONARY_TRUNK = _Pulmonary_Trunk()
    MARGINAL_VEIN_OF_FORELIMB = _Marginal_Vein_Of_Forelimb()
    MARGINAL_VEIN_OF_HINDLIMB = _Marginal_Vein_Of_Hindlimb()
    PRINCIPAL_VEIN_OF_FORELIMB = _Principal_Vein_Of_Forelimb()
    PRINCIPAL_VEIN_OF_HINDLIMB = _Principal_Vein_Of_Hindlimb()
    VITELLINE_VENOUS_PLEXUS = _Vitelline_Venous_Plexus()
    STOMACH = _Stomach()
    STOMACH_MESENCHYME = _Stomach_Mesenchyme()
    STOMACH_EPITHELIUM = _Stomach_Epithelium()
    STOMACH_MESENTERY = _Stomach_Mesentery()
    DORSAL_MESOGASTRIUM = _Dorsal_Mesogastrium()
    VENTRAL_MESOGASTRIUM = _Ventral_Mesogastrium()
    STOMACH_VASCULAR_ELEMENT = _Stomach_Vascular_Element()
    HINDGUT_DIVERTICULUM_POSTANAL_COMPONENT = _Hindgut_Diverticulum_Postanal_Component()
    HINDGUT_DIVERTICULUM_POSTANAL_COMPONENT_MESENCHYME = _Hindgut_Diverticulum_Postanal_Component_Mesenchyme()
    HINDGUT_DIVERTICULUM_POSTANAL_COMPONENT_EPITHELIUM = _Hindgut_Diverticulum_Postanal_Component_Epithelium()
    HINDGUT_DIVERTICULUM_POSTANAL_COMPONENT_VASCULAR_ELEMENT = (
        _Hindgut_Diverticulum_Postanal_Component_Vascular_Element()
    )
    HINDGUT_DIVERTICULUM_PREANAL_COMPONENT = _Hindgut_Diverticulum_Preanal_Component()
    HINDGUT_DIVERTICULUM_PREANAL_COMPONENT_MESENCHYME = _Hindgut_Diverticulum_Preanal_Component_Mesenchyme()
    HINDGUT_DIVERTICULUM_PREANAL_COMPONENT_EPITHELIUM = _Hindgut_Diverticulum_Preanal_Component_Epithelium()
    HINDGUT_DIVERTICULUM_PREANAL_COMPONENT_VASCULAR_ELEMENT = _Hindgut_Diverticulum_Preanal_Component_Vascular_Element()
    MIDGUT_LOOP = _Midgut_Loop()
    MIDGUT_LOOP_MESENCHYME = _Midgut_Loop_Mesenchyme()
    MIDGUT_LOOP_EPITHELIUM = _Midgut_Loop_Epithelium()
    MIDGUT_LOOP_MESENTERY = _Midgut_Loop_Mesentery()
    MIDGUT_LOOP_DORSAL_MESENTERY = _Midgut_Loop_Dorsal_Mesentery()
    MIDGUT_LOOP_VASCULAR_ELEMENT = _Midgut_Loop_Vascular_Element()
    SOMITE_36 = _Somite_36()
    SOMITE_36_DERMOMYOTOME = _Somite_36_Dermomyotome()
    SOMITE_36_MYOCOELE = _Somite_36_Myocoele()
    SOMITE_36_SCLEROTOME = _Somite_36_Sclerotome()
    SOMITE_37 = _Somite_37()
    SOMITE_37_DERMOMYOTOME = _Somite_37_Dermomyotome()
    SOMITE_37_MYOCOELE = _Somite_37_Myocoele()
    SOMITE_37_SCLEROTOME = _Somite_37_Sclerotome()
    SOMITE_38 = _Somite_38()
    SOMITE_38_DERMOMYOTOME = _Somite_38_Dermomyotome()
    SOMITE_38_MYOCOELE = _Somite_38_Myocoele()
    SOMITE_38_SCLEROTOME = _Somite_38_Sclerotome()
    SOMITE_39 = _Somite_39()
    SOMITE_39_DERMOMYOTOME = _Somite_39_Dermomyotome()
    SOMITE_39_MYOCOELE = _Somite_39_Myocoele()
    SOMITE_39_SCLEROTOME = _Somite_39_Sclerotome()
    FOREGUT_MIDGUT_JUNCTION_GLAND = _Foregut_Midgut_Junction_Gland()
    PANCREAS_PRIMORDIUM = _Pancreas_Primordium()
    PANCREAS_PRIMORDIUM_DORSAL_BUD = _Pancreas_Primordium_Dorsal_Bud()
    THYROID_GLAND = _Thyroid_Gland()
    FORAMEN_CAECUM = _Foramen_Caecum()
    THYROGLOSSAL_DUCT = _Thyroglossal_Duct()
    METENCEPHALON = _Metencephalon()
    METENCEPHALON_LATERAL_WALL = _Metencephalon_Lateral_Wall()
    METENCEPHALON_ALAR_PLATE = _Metencephalon_Alar_Plate()
    CEREBELLUM_PRIMORDIUM = _Cerebellum_Primordium()
    METENCEPHALON_ALAR_PLATE_MANTLE_LAYER = _Metencephalon_Alar_Plate_Mantle_Layer()
    METENCEPHALON_ALAR_PLATE_MARGINAL_LAYER = _Metencephalon_Alar_Plate_Marginal_Layer()
    METENCEPHALON_ALAR_PLATE_VENTRICULAR_LAYER = _Metencephalon_Alar_Plate_Ventricular_Layer()
    METENCEPHALON_BASAL_PLATE = _Metencephalon_Basal_Plate()
    METENCEPHALON_BASAL_PLATE_MANTLE_LAYER = _Metencephalon_Basal_Plate_Mantle_Layer()
    METENCEPHALON_BASAL_PLATE_MARGINAL_LAYER = _Metencephalon_Basal_Plate_Marginal_Layer()
    METENCEPHALON_BASAL_PLATE_VENTRICULAR_LAYER = _Metencephalon_Basal_Plate_Ventricular_Layer()
    MYELENCEPHALON = _Myelencephalon()
    MYELENCEPHALON_LATERAL_WALL = _Myelencephalon_Lateral_Wall()
    MYELENCEPHALON_ALAR_PLATE = _Myelencephalon_Alar_Plate()
    MYELENCEPHALON_ALAR_PLATE_MANTLE_LAYER = _Myelencephalon_Alar_Plate_Mantle_Layer()
    MYELENCEPHALON_ALAR_PLATE_MARGINAL_LAYER = _Myelencephalon_Alar_Plate_Marginal_Layer()
    MYELENCEPHALON_ALAR_PLATE_VENTRICULAR_LAYER = _Myelencephalon_Alar_Plate_Ventricular_Layer()
    MYELENCEPHALON_BASAL_PLATE = _Myelencephalon_Basal_Plate()
    MYELENCEPHALON_BASAL_PLATE_MANTLE_LAYER = _Myelencephalon_Basal_Plate_Mantle_Layer()
    MYELENCEPHALON_BASAL_PLATE_MARGINAL_LAYER = _Myelencephalon_Basal_Plate_Marginal_Layer()
    MYELENCEPHALON_BASAL_PLATE_VENTRICULAR_LAYER = _Myelencephalon_Basal_Plate_Ventricular_Layer()
    NEURAL_TUBE_MANTLE_LAYER = _Neural_Tube_Mantle_Layer()
    NEURAL_TUBE_ALAR_COLUMNS = _Neural_Tube_Alar_Columns()
    NEURAL_TUBE_BASAL_COLUMNS = _Neural_Tube_Basal_Columns()
    NEURAL_TUBE_MARGINAL_LAYER = _Neural_Tube_Marginal_Layer()
    NEURAL_TUBE_VENTRICULAR_LAYER = _Neural_Tube_Ventricular_Layer()
    INFERIOR_GLOSSOPHARYNGEAL_GANGLION = _Inferior_Glossopharyngeal_Ganglion()
    SUPERIOR_GLOSSOPHARYNGEAL_GANGLION = _Superior_Glossopharyngeal_Ganglion()
    INFERIOR_VAGUS_GANGLION = _Inferior_Vagus_Ganglion()
    SUPERIOR_VAGUS_GANGLION = _Superior_Vagus_Ganglion()
    SYMPATHETIC_GANGLION = _Sympathetic_Ganglion()
    THORACIC_GANGLION = _Thoracic_Ganglion()
    CORNEA = _Cornea()
    CORNEA_EPITHELIUM = _Cornea_Epithelium()
    LENS_VESICLE = _Lens_Vesicle()
    LENS_VESICLE_CAVITY = _Lens_Vesicle_Cavity()
    LENS_VESICLE_EPITHELIUM = _Lens_Vesicle_Epithelium()
    OPTIC_FISSURE = _Optic_Fissure()
    PERIOPTIC_MESENCHYME = _Perioptic_Mesenchyme()
    RETINA = _Retina()
    EMBRYONIC_FISSURE = _Embryonic_Fissure()
    INTRARETINAL_SPACE = _Intraretinal_Space()
    NEURAL_RETINAL_EPITHELIUM = _Neural_Retinal_Epithelium()
    PIGMENTED_RETINAL_EPITHELIUM = _Pigmented_Retinal_Epithelium()
    ENDODERM_COMPONENT_OF_ANAL_MEMBRANE = _Endoderm_Component_Of_Anal_Membrane()
    FOREGUT_DUODENUM = _Foregut_Duodenum()
    DUODENUM_ROSTRAL_PART = _Duodenum_Rostral_Part()
    DUODENUM_ROSTRAL_PART_MESENCHYME = _Duodenum_Rostral_Part_Mesenchyme()
    DUODENUM_ROSTRAL_PART_EPITHELIUM = _Duodenum_Rostral_Part_Epithelium()
    DUODENUM_ROSTRAL_PART_MESENTERY = _Duodenum_Rostral_Part_Mesentery()
    DUODENUM_ROSTRAL_PART_MESODUODENUM = _Duodenum_Rostral_Part_Mesoduodenum()
    DUODENUM_ROSTRAL_PART_VASCULAR_ELEMENT = _Duodenum_Rostral_Part_Vascular_Element()
    TONGUE = _Tongue()
    LINGUAL_SWELLING = _Lingual_Swelling()
    MEDIAN_LINGUAL_SWELLING = _Median_Lingual_Swelling()
    MEDIAN_LINGUAL_SWELLING_EPITHELIUM = _Median_Lingual_Swelling_Epithelium()
    LATERAL_LINGUAL_SWELLING = _Lateral_Lingual_Swelling()
    LATERAL_LINGUAL_SWELLING_EPITHELIUM = _Lateral_Lingual_Swelling_Epithelium()
    LATERAL_LINGUAL_SWELLING_MESENCHYME = _Lateral_Lingual_Swelling_Mesenchyme()
    MEDIAN_LINGUAL_SWELLING_MESENCHYME = _Median_Lingual_Swelling_Mesenchyme()
    MIDGUT_DERIVED_DUODENUM = _Midgut_Derived_Duodenum()
    DUODENUM_CAUDAL_PART = _Duodenum_Caudal_Part()
    DUODENUM_CAUDAL_PART_MESENCHYME = _Duodenum_Caudal_Part_Mesenchyme()
    DUODENUM_CAUDAL_PART_EPITHELIUM = _Duodenum_Caudal_Part_Epithelium()
    DUODENUM_CAUDAL_PART_MESENTERY = _Duodenum_Caudal_Part_Mesentery()
    DUODENUM_CAUDAL_PART_MESODUODENUM = _Duodenum_Caudal_Part_Mesoduodenum()
    DUODENUM_CAUDAL_PART_VASCULAR_ELEMENT = _Duodenum_Caudal_Part_Vascular_Element()
    ORONASAL_CAVITY = _Oronasal_Cavity()
    COMMON_BILE_DUCT = _Common_Bile_Duct()
    GALLBLADDER = _Gallbladder()
    LIVER_PARENCHYMA = _Liver_Parenchyma()
    STOMACH_PYLORIC_REGION_MUSCULARIS = _Stomach_Pyloric_Region_Muscularis()
    URETERIC_BUD = _Ureteric_Bud()
    URORECTAL_SEPTUM = _Urorectal_Septum()
    SKELETON = _Skeleton()
    AXIAL_SKELETON = _Axial_Skeleton()
    AXIAL_SKELETON_CERVICAL_REGION = _Axial_Skeleton_Cervical_Region()
    CERVICAL_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Cervical_Vertebral_Pre_Cartilage_Condensation()
    SOMITE_40 = _Somite_40()
    SOMITE_40_DERMOMYOTOME = _Somite_40_Dermomyotome()
    SOMITE_40_MYOCOELE = _Somite_40_Myocoele()
    SOMITE_40_SCLEROTOME = _Somite_40_Sclerotome()
    SOMITE_41 = _Somite_41()
    SOMITE_41_DERMOMYOTOME = _Somite_41_Dermomyotome()
    SOMITE_41_MYOCOELE = _Somite_41_Myocoele()
    SOMITE_41_SCLEROTOME = _Somite_41_Sclerotome()
    SOMITE_42 = _Somite_42()
    SOMITE_42_DERMOMYOTOME = _Somite_42_Dermomyotome()
    SOMITE_42_MYOCOELE = _Somite_42_Myocoele()
    SOMITE_42_SCLEROTOME = _Somite_42_Sclerotome()
    SOMITE_43 = _Somite_43()
    SOMITE_43_DERMOMYOTOME = _Somite_43_Dermomyotome()
    SOMITE_43_MYOCOELE = _Somite_43_Myocoele()
    SOMITE_43_SCLEROTOME = _Somite_43_Sclerotome()
    SOMITE_44 = _Somite_44()
    SOMITE_44_DERMOMYOTOME = _Somite_44_Dermomyotome()
    SOMITE_44_MYOCOELE = _Somite_44_Myocoele()
    SOMITE_44_SCLEROTOME = _Somite_44_Sclerotome()
    SOMITE_45 = _Somite_45()
    SOMITE_45_DERMOMYOTOME = _Somite_45_Dermomyotome()
    SOMITE_45_MYOCOELE = _Somite_45_Myocoele()
    SOMITE_45_SCLEROTOME = _Somite_45_Sclerotome()
    _1ST_BRANCHIAL_GROOVE_EPITHELIUM = _1St_Branchial_Groove_Epithelium()
    FUTURE_ARM = _Future_Arm()
    FUTURE_ARM_ECTODERM = _Future_Arm_Ectoderm()
    FUTURE_ARM_MESENCHYME = _Future_Arm_Mesenchyme()
    HANDPLATE = _Handplate()
    HANDPLATE_ECTODERM = _Handplate_Ectoderm()
    HANDPLATE_APICAL_ECTODERMAL_RIDGE = _Handplate_Apical_Ectodermal_Ridge()
    HANDPLATE_MESENCHYME = _Handplate_Mesenchyme()
    FOOTPLATE = _Footplate()
    FOOTPLATE_ECTODERM = _Footplate_Ectoderm()
    FOOTPLATE_APICAL_ECTODERMAL_RIDGE = _Footplate_Apical_Ectodermal_Ridge()
    FOOTPLATE_MESENCHYME = _Footplate_Mesenchyme()
    FUTURE_LEG = _Future_Leg()
    FUTURE_LEG_ECTODERM = _Future_Leg_Ectoderm()
    FUTURE_LEG_MESENCHYME = _Future_Leg_Mesenchyme()
    PANCREAS_PRIMORDIUM_VENTRAL_BUD = _Pancreas_Primordium_Ventral_Bud()
    _4TH_VENTRICLE_LATERAL_RECESS = _4Th_Ventricle_Lateral_Recess()
    METENCEPHALON_FLOOR_PLATE = _Metencephalon_Floor_Plate()
    METENCEPHALON_ROOF = _Metencephalon_Roof()
    MYELENCEPHALON_FLOOR_PLATE = _Myelencephalon_Floor_Plate()
    MYELENCEPHALON_ROOF_PLATE = _Myelencephalon_Roof_Plate()
    CENTRAL_NERVOUS_SYSTEM_NERVE = _Central_Nervous_System_Nerve()
    CRANIAL_NERVE = _Cranial_Nerve()
    ACCESSORY_NERVE = _Accessory_Nerve()
    ACCESSORY_NERVE_CRANIAL_COMPONENT = _Accessory_Nerve_Cranial_Component()
    ACCESSORY_NERVE_SPINAL_COMPONENT = _Accessory_Nerve_Spinal_Component()
    GLOSSOPHARYNGEAL_NERVE = _Glossopharyngeal_Nerve()
    HYPOGLOSSAL_NERVE = _Hypoglossal_Nerve()
    PARASYMPATHETIC_NERVOUS_SYSTEM = _Parasympathetic_Nervous_System()
    PARASYMPATHETIC_NERVE = _Parasympathetic_Nerve()
    VAGAL_NERVE_TRUNK = _Vagal_Nerve_Trunk()
    VAGUS_NERVE_RIGHT_RECURRENT_LARYNGEAL_BRANCH = _Vagus_Nerve_Right_Recurrent_Laryngeal_Branch()
    MEDIAN_NERVE = _Median_Nerve()
    RADIAL_NERVE = _Radial_Nerve()
    ULNAR_NERVE = _Ulnar_Nerve()
    AUDITORY_HILLOCKS = _Auditory_Hillocks()
    FUTURE_TYMPANIC_MEMBRANE = _Future_Tympanic_Membrane()
    FUTURE_TYMPANIC_MEMBRANE_EPITHELIUM = _Future_Tympanic_Membrane_Epithelium()
    INNER_EAR_VESTIBULAR_COMPONENT = _Inner_Ear_Vestibular_Component()
    DUCTUS_REUNIENS = _Ductus_Reuniens()
    DUCTUS_REUNIENS_MESENCHYME = _Ductus_Reuniens_Mesenchyme()
    DUCTUS_REUNIENS_EPITHELIUM = _Ductus_Reuniens_Epithelium()
    SACCULE = _Saccule()
    SACCULE_MESENCHYME = _Saccule_Mesenchyme()
    SACCULE_EPITHELIUM = _Saccule_Epithelium()
    UTRICLE = _Utricle()
    UTRICLE_MESENCHYME = _Utricle_Mesenchyme()
    UTRICLE_EPITHELIUM = _Utricle_Epithelium()
    POSTERIOR_SEMICIRCULAR_CANAL = _Posterior_Semicircular_Canal()
    POSTERIOR_SEMICIRCULAR_CANAL_MESENCHYME = _Posterior_Semicircular_Canal_Mesenchyme()
    POSTERIOR_SEMICIRCULAR_CANAL_EPITHELIUM = _Posterior_Semicircular_Canal_Epithelium()
    SUPERIOR_SEMICIRCULAR_CANAL = _Superior_Semicircular_Canal()
    SUPERIOR_SEMICIRCULAR_CANAL_MESENCHYME = _Superior_Semicircular_Canal_Mesenchyme()
    SUPERIOR_SEMICIRCULAR_CANAL_EPITHELIUM = _Superior_Semicircular_Canal_Epithelium()
    HYALOID_CAVITY = _Hyaloid_Cavity()
    HYALOID_VASCULAR_PLEXUS = _Hyaloid_Vascular_Plexus()
    LENS_VESICLE_ANTERIOR_EPITHELIUM = _Lens_Vesicle_Anterior_Epithelium()
    LENS_VESICLE_EQUATORIAL_EPITHELIUM = _Lens_Vesicle_Equatorial_Epithelium()
    LENS_VESICLE_POSTERIOR_EPITHELIUM = _Lens_Vesicle_Posterior_Epithelium()
    BASILAR_ARTERY = _Basilar_Artery()
    HYOID_ARTERY = _Hyoid_Artery()
    ILIAC_ARTERY = _Iliac_Artery()
    COMMON_ILIAC_ARTERY = _Common_Iliac_Artery()
    MAXILLARY_ARTERY = _Maxillary_Artery()
    MESENTERIC_ARTERY = _Mesenteric_Artery()
    STAPEDIAL_ARTERY = _Stapedial_Artery()
    VERTEBRAL_ARTERY = _Vertebral_Artery()
    LEFT_ATRIUM = _Left_Atrium()
    LEFT_ATRIUM_AURICULAR_REGION = _Left_Atrium_Auricular_Region()
    LEFT_ATRIUM_AURICULAR_REGION_ENDOCARDIAL_LINING = _Left_Atrium_Auricular_Region_Endocardial_Lining()
    LEFT_ATRIUM_AURICULAR_REGION_CARDIAC_MUSCLE = _Left_Atrium_Auricular_Region_Cardiac_Muscle()
    LEFT_ATRIUM_ENDOCARDIAL_LINING = _Left_Atrium_Endocardial_Lining()
    LEFT_ATRIUM_CARDIAC_MUSCLE = _Left_Atrium_Cardiac_Muscle()
    RIGHT_ATRIUM = _Right_Atrium()
    RIGHT_ATRIUM_AURICULAR_REGION = _Right_Atrium_Auricular_Region()
    RIGHT_ATRIUM_AURICULAR_REGION_ENDOCARDIAL_LINING = _Right_Atrium_Auricular_Region_Endocardial_Lining()
    RIGHT_ATRIUM_AURICULAR_REGION_CARDIAC_MUSCLE = _Right_Atrium_Auricular_Region_Cardiac_Muscle()
    RIGHT_ATRIUM_ENDOCARDIAL_LINING = _Right_Atrium_Endocardial_Lining()
    RIGHT_ATRIUM_CARDIAC_MUSCLE = _Right_Atrium_Cardiac_Muscle()
    RIGHT_ATRIUM_VALVE = _Right_Atrium_Valve()
    RIGHT_ATRIUM_VENOUS_VALVE = _Right_Atrium_Venous_Valve()
    OUTFLOW_TRACT_AORTIC_COMPONENT = _Outflow_Tract_Aortic_Component()
    OUTFLOW_TRACT_PULMONARY_COMPONENT = _Outflow_Tract_Pulmonary_Component()
    HEART_VENTRICLE = _Heart_Ventricle()
    BULBAR_RIDGE = _Bulbar_Ridge()
    INTERVENTRICULAR_SEPTUM = _Interventricular_Septum()
    INTERVENTRICULAR_SEPTUM_ENDOCARDIAL_LINING = _Interventricular_Septum_Endocardial_Lining()
    INTERVENTRICULAR_SEPTUM_CARDIAC_MUSCLE = _Interventricular_Septum_Cardiac_Muscle()
    INTERVENTRICULAR_GROOVE = _Interventricular_Groove()
    HEART_LEFT_VENTRICLE = _Heart_Left_Ventricle()
    LEFT_VENTRICLE_ENDOCARDIAL_LINING = _Left_Ventricle_Endocardial_Lining()
    LEFT_VENTRICLE_CARDIAC_MUSCLE = _Left_Ventricle_Cardiac_Muscle()
    HEART_RIGHT_VENTRICLE = _Heart_Right_Ventricle()
    RIGHT_VENTRICLE_ENDOCARDIAL_LINING = _Right_Ventricle_Endocardial_Lining()
    RIGHT_VENTRICLE_CARDIAC_MUSCLE = _Right_Ventricle_Cardiac_Muscle()
    DUCTUS_VENOSUS = _Ductus_Venosus()
    MESENTERIC_VEIN = _Mesenteric_Vein()
    PORTAL_VEIN = _Portal_Vein()
    ROSTRAL_TWO_THIRDS_OF_ANAL_CANAL = _Rostral_Two_Thirds_Of_Anal_Canal()
    HYOID_PRE_CARTILAGE_CONDENSATION = _Hyoid_Pre_Cartilage_Condensation()
    HYPOBRANCHIAL_EMINENCE = _Hypobranchial_Eminence()
    OCCIPITAL_MYOTOME = _Occipital_Myotome()
    EPIGLOTTAL_PRIMORDIUM = _Epiglottal_Primordium()
    MANDIBULAR_PROCESS = _Mandibular_Process()
    MANDIBLE_PRIMORDIUM = _Mandible_Primordium()
    MANDIBULAR_PROCESS_MESENCHYME = _Mandibular_Process_Mesenchyme()
    MECKEL_S_CARTILAGE_PRE_CARTILAGE_CONDENSATION = _Meckel_S_Cartilage_Pre_Cartilage_Condensation()
    MAXILLARY_PROCESS = _Maxillary_Process()
    MAXILLA_PRIMORDIUM = _Maxilla_Primordium()
    MAXILLARY_PROCESS_MESENCHYME = _Maxillary_Process_Mesenchyme()
    PALATAL_SHELF = _Palatal_Shelf()
    PALATAL_SHELF_EPITHELIUM = _Palatal_Shelf_Epithelium()
    PALATAL_SHELF_MESENCHYME = _Palatal_Shelf_Mesenchyme()
    LIVER_SINUSOID = _Liver_Sinusoid()
    URINARY_SYSTEM = _Urinary_System()
    URINARY_SYSTEM_MESENTERY = _Urinary_System_Mesentery()
    UROGENITAL_MESENTERY = _Urogenital_Mesentery()
    METANEPHROS = _Metanephros()
    METANEPHRIC_MESENCHYME = _Metanephric_Mesenchyme()
    UROGENITAL_MEMBRANE = _Urogenital_Membrane()
    UROGENITAL_SINUS = _Urogenital_Sinus()
    REPRODUCTIVE_SYSTEM = _Reproductive_System()
    GENITAL_TUBERCLE = _Genital_Tubercle()
    GONAD = _Gonad()
    COELOMIC_EPITHELIUM_OF_GONAD = _Coelomic_Epithelium_Of_Gonad()
    GONADAL_MESENCHYME = _Gonadal_Mesenchyme()
    ARYTENOID_SWELLING_PRE_CARTILAGE_CONDENSATION = _Arytenoid_Swelling_Pre_Cartilage_Condensation()
    LEFT_LUNG_RUDIMENT_LOBAR_BRONCHUS = _Left_Lung_Rudiment_Lobar_Bronchus()
    LEFT_LUNG_RUDIMENT_LOBAR_BRONCHUS_MESENCHYME = _Left_Lung_Rudiment_Lobar_Bronchus_Mesenchyme()
    LEFT_LUNG_RUDIMENT_LOBAR_BRONCHUS_EPITHELIUM = _Left_Lung_Rudiment_Lobar_Bronchus_Epithelium()
    LEFT_LUNG_RUDIMENT_LOBAR_BRONCHUS_VASCULAR_ELEMENT = _Left_Lung_Rudiment_Lobar_Bronchus_Vascular_Element()
    CERVICAL_VERTEBRAL_CARTILAGE_CONDENSATION = _Cervical_Vertebral_Cartilage_Condensation()
    AXIAL_SKELETON_LUMBAR_REGION = _Axial_Skeleton_Lumbar_Region()
    LUMBAR_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Lumbar_Vertebral_Pre_Cartilage_Condensation()
    SCLEROTOME_CONDENSATION = _Sclerotome_Condensation()
    AXIAL_SKELETON_THORACIC_REGION = _Axial_Skeleton_Thoracic_Region()
    RIB_PRE_CARTILAGE_CONDENSATION = _Rib_Pre_Cartilage_Condensation()
    THORACIC_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Thoracic_Vertebral_Pre_Cartilage_Condensation()
    SOMITE_46 = _Somite_46()
    SOMITE_46_DERMOMYOTOME = _Somite_46_Dermomyotome()
    SOMITE_46_MYOCOELE = _Somite_46_Myocoele()
    SOMITE_46_SCLEROTOME = _Somite_46_Sclerotome()
    SOMITE_47 = _Somite_47()
    SOMITE_47_DERMOMYOTOME = _Somite_47_Dermomyotome()
    SOMITE_47_MYOCOELE = _Somite_47_Myocoele()
    SOMITE_47_SCLEROTOME = _Somite_47_Sclerotome()
    SOMITE_48 = _Somite_48()
    SOMITE_48_DERMOMYOTOME = _Somite_48_Dermomyotome()
    SOMITE_48_MYOCOELE = _Somite_48_Myocoele()
    SOMITE_48_SCLEROTOME = _Somite_48_Sclerotome()
    ORAL_CAVITY = _Oral_Cavity()
    FORELIMB = _Forelimb()
    ARM = _Arm()
    ELBOW = _Elbow()
    ELBOW_EPITHELIUM = _Elbow_Epithelium()
    ELBOW_MESENCHYME = _Elbow_Mesenchyme()
    FOREARM = _Forearm()
    FOREARM_EPITHELIUM = _Forearm_Epithelium()
    FOREARM_MESENCHYME = _Forearm_Mesenchyme()
    RADIUS_ULNA_PRE_CARTILAGE_CONDENSATION = _Radius_Ulna_Pre_Cartilage_Condensation()
    SHOULDER = _Shoulder()
    SHOULDER_EPITHELIUM = _Shoulder_Epithelium()
    SHOULDER_MESENCHYME = _Shoulder_Mesenchyme()
    UPPER_ARM = _Upper_Arm()
    UPPER_ARM_EPITHELIUM = _Upper_Arm_Epithelium()
    UPPER_ARM_MESENCHYME = _Upper_Arm_Mesenchyme()
    HUMERUS_PRE_CARTILAGE_CONDENSATION = _Humerus_Pre_Cartilage_Condensation()
    HAND = _Hand()
    FORELIMB_DIGIT_1 = _Forelimb_Digit_1()
    FORELIMB_DIGIT_1_EPITHELIUM = _Forelimb_Digit_1_Epithelium()
    FORELIMB_DIGIT_1_MESENCHYME = _Forelimb_Digit_1_Mesenchyme()
    FORELIMB_DIGIT_2 = _Forelimb_Digit_2()
    FORELIMB_DIGIT_2_EPITHELIUM = _Forelimb_Digit_2_Epithelium()
    FORELIMB_DIGIT_2_MESENCHYME = _Forelimb_Digit_2_Mesenchyme()
    FORELIMB_DIGIT_3 = _Forelimb_Digit_3()
    FORELIMB_DIGIT_3_EPITHELIUM = _Forelimb_Digit_3_Epithelium()
    FORELIMB_DIGIT_3_MESENCHYME = _Forelimb_Digit_3_Mesenchyme()
    FORELIMB_DIGIT_4 = _Forelimb_Digit_4()
    FORELIMB_DIGIT_4_EPITHELIUM = _Forelimb_Digit_4_Epithelium()
    FORELIMB_DIGIT_4_MESENCHYME = _Forelimb_Digit_4_Mesenchyme()
    FORELIMB_DIGIT_5 = _Forelimb_Digit_5()
    FORELIMB_DIGIT_5_EPITHELIUM = _Forelimb_Digit_5_Epithelium()
    FORELIMB_DIGIT_5_MESENCHYME = _Forelimb_Digit_5_Mesenchyme()
    HAND_REST_OF_EPITHELIUM = _Hand_Rest_Of_Epithelium()
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_1_AND_2 = _Interdigital_Region_Between_Forelimb_Digits_1_And_2()
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_1_AND_2_EPITHELIUM = (
        _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Epithelium()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_1_AND_2_MESENCHYME = (
        _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Mesenchyme()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_2_AND_3 = _Interdigital_Region_Between_Forelimb_Digits_2_And_3()
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_2_AND_3_EPITHELIUM = (
        _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Epithelium()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_2_AND_3_MESENCHYME = (
        _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Mesenchyme()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_3_AND_4 = _Interdigital_Region_Between_Forelimb_Digits_3_And_4()
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_3_AND_4_EPITHELIUM = (
        _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Epithelium()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_3_AND_4_MESENCHYME = (
        _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Mesenchyme()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_4_AND_5 = _Interdigital_Region_Between_Forelimb_Digits_4_And_5()
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_4_AND_5_EPITHELIUM = (
        _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Epithelium()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_4_AND_5_MESENCHYME = (
        _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Mesenchyme()
    )
    HAND_MESENCHYME = _Hand_Mesenchyme()
    HINDLIMB = _Hindlimb()
    FOOT = _Foot()
    HINDLIMB_DIGIT_1 = _Hindlimb_Digit_1()
    HINDLIMB_DIGIT_1_EPITHELIUM = _Hindlimb_Digit_1_Epithelium()
    HINDLIMB_DIGIT_1_MESENCHYME = _Hindlimb_Digit_1_Mesenchyme()
    HINDLIMB_DIGIT_2 = _Hindlimb_Digit_2()
    HINDLIMB_DIGIT_2_EPITHELIUM = _Hindlimb_Digit_2_Epithelium()
    HINDLIMB_DIGIT_2_MESENCHYME = _Hindlimb_Digit_2_Mesenchyme()
    HINDLIMB_DIGIT_3 = _Hindlimb_Digit_3()
    HINDLIMB_DIGIT_3_EPITHELIUM = _Hindlimb_Digit_3_Epithelium()
    HINDLIMB_DIGIT_3_MESENCHYME = _Hindlimb_Digit_3_Mesenchyme()
    HINDLIMB_DIGIT_4 = _Hindlimb_Digit_4()
    HINDLIMB_DIGIT_4_EPITHELIUM = _Hindlimb_Digit_4_Epithelium()
    HINDLIMB_DIGIT_4_MESENCHYME = _Hindlimb_Digit_4_Mesenchyme()
    HINDLIMB_DIGIT_5 = _Hindlimb_Digit_5()
    HINDLIMB_DIGIT_5_EPITHELIUM = _Hindlimb_Digit_5_Epithelium()
    HINDLIMB_DIGIT_5_MESENCHYME = _Hindlimb_Digit_5_Mesenchyme()
    FOOT_REST_OF_EPITHELIUM = _Foot_Rest_Of_Epithelium()
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_1_AND_2 = _Interdigital_Region_Between_Hindlimb_Digits_1_And_2()
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_1_AND_2_EPITHELIUM = (
        _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Epithelium()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_1_AND_2_MESENCHYME = (
        _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Mesenchyme()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_2_AND_3 = _Interdigital_Region_Between_Hindlimb_Digits_2_And_3()
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_2_AND_3_EPITHELIUM = (
        _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Epithelium()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_2_AND_3_MESENCHYME = (
        _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Mesenchyme()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_3_AND_4 = _Interdigital_Region_Between_Hindlimb_Digits_3_And_4()
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_3_AND_4_EPITHELIUM = (
        _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Epithelium()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_3_AND_4_MESENCHYME = (
        _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Mesenchyme()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_4_AND_5 = _Interdigital_Region_Between_Hindlimb_Digits_4_And_5()
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_4_AND_5_EPITHELIUM = (
        _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Epithelium()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_4_AND_5_MESENCHYME = (
        _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Mesenchyme()
    )
    FOOT_MESENCHYME = _Foot_Mesenchyme()
    LEG = _Leg()
    HIP = _Hip()
    HIP_EPITHELIUM = _Hip_Epithelium()
    HIP_MESENCHYME = _Hip_Mesenchyme()
    KNEE = _Knee()
    KNEE_EPITHELIUM = _Knee_Epithelium()
    KNEE_MESENCHYME = _Knee_Mesenchyme()
    LOWER_LEG = _Lower_Leg()
    LOWER_LEG_EPITHELIUM = _Lower_Leg_Epithelium()
    LOWER_LEG_MESENCHYME = _Lower_Leg_Mesenchyme()
    UPPER_LEG = _Upper_Leg()
    UPPER_LEG_EPITHELIUM = _Upper_Leg_Epithelium()
    UPPER_LEG_MESENCHYME = _Upper_Leg_Mesenchyme()
    FEMUR_PRE_CARTILAGE_CONDENSATION = _Femur_Pre_Cartilage_Condensation()
    PANCREAS = _Pancreas()
    BODY_OF_PANCREAS = _Body_Of_Pancreas()
    DORSAL_PANCREATIC_DUCT_OF_PANCREAS_BODY = _Dorsal_Pancreatic_Duct_Of_Pancreas_Body()
    PANCREAS_BODY_PARENCHYMA = _Pancreas_Body_Parenchyma()
    HEAD_OF_PANCREAS = _Head_Of_Pancreas()
    PANCREAS_HEAD_PARENCHYMA = _Pancreas_Head_Parenchyma()
    UNCINATE_PROCESS = _Uncinate_Process()
    VENTRAL_PANCREATIC_DUCT = _Ventral_Pancreatic_Duct()
    TAIL_OF_PANCREAS = _Tail_Of_Pancreas()
    DORSAL_PANCREATIC_DUCT_OF_PANCREAS_TAIL = _Dorsal_Pancreatic_Duct_Of_Pancreas_Tail()
    PANCREAS_TAIL_PARENCHYMA = _Pancreas_Tail_Parenchyma()
    ADENOHYPOPHYSIS = _Adenohypophysis()
    ADENOHYPOPHYSIS_PARS_ANTERIOR = _Adenohypophysis_Pars_Anterior()
    ADENOHYPOPHYSIS_PARS_INTERMEDIA = _Adenohypophysis_Pars_Intermedia()
    ADENOHYPOPHYSIS_PARS_TUBERALIS = _Adenohypophysis_Pars_Tuberalis()
    REMNANT_OF_RATHKE_S_POUCH = _Remnant_Of_Rathke_S_Pouch()
    NEUROHYPOPHYSIS = _Neurohypophysis()
    NEUROHYPOPHYSIS_INFUNDIBULUM = _Neurohypophysis_Infundibulum()
    MEDIAN_EMINENCE = _Median_Eminence()
    THYMUS_PRIMORDIUM = _Thymus_Primordium()
    INTEGUMENTAL_SYSTEM = _Integumental_System()
    SKIN = _Skin()
    DERMIS = _Dermis()
    EPIDERMIS = _Epidermis()
    VIBRISSA = _Vibrissa()
    VIBRISSA_EPITHELIUM = _Vibrissa_Epithelium()
    VIBRISSA_MESENCHYME = _Vibrissa_Mesenchyme()
    EPITHALAMUS = _Epithalamus()
    EPITHALAMUS_MANTLE_LAYER = _Epithalamus_Mantle_Layer()
    EPITHALAMUS_MARGINAL_LAYER = _Epithalamus_Marginal_Layer()
    EPITHALAMUS_VENTRICULAR_LAYER = _Epithalamus_Ventricular_Layer()
    HYPOTHALAMUS = _Hypothalamus()
    HYPOTHALAMUS_MANTLE_LAYER = _Hypothalamus_Mantle_Layer()
    HYPOTHALAMUS_MARGINAL_LAYER = _Hypothalamus_Marginal_Layer()
    HYPOTHALAMUS_VENTRICULAR_LAYER = _Hypothalamus_Ventricular_Layer()
    THALAMUS = _Thalamus()
    THALAMUS_MANTLE_LAYER = _Thalamus_Mantle_Layer()
    THALAMUS_MARGINAL_LAYER = _Thalamus_Marginal_Layer()
    THALAMUS_VENTRICULAR_LAYER = _Thalamus_Ventricular_Layer()
    CEREBRAL_CORTEX = _Cerebral_Cortex()
    CEREBRAL_CORTEX_MANTLE_LAYER = _Cerebral_Cortex_Mantle_Layer()
    CEREBRAL_CORTEX_MARGINAL_LAYER = _Cerebral_Cortex_Marginal_Layer()
    CEREBRAL_CORTEX_VENTRICULAR_LAYER = _Cerebral_Cortex_Ventricular_Layer()
    CHOROID_INVAGINATION = _Choroid_Invagination()
    CORPUS_STRIATUM = _Corpus_Striatum()
    MEDULLA_OBLONGATA = _Medulla_Oblongata()
    MEDULLA_OBLONGATA_FLOOR_PLATE = _Medulla_Oblongata_Floor_Plate()
    MEDULLA_OBLONGATA_LATERAL_WALL = _Medulla_Oblongata_Lateral_Wall()
    MEDULLA_OBLONGATA_ALAR_PLATE = _Medulla_Oblongata_Alar_Plate()
    MEDULLA_OBLONGATA_ALAR_PLATE_MANTLE_LAYER = _Medulla_Oblongata_Alar_Plate_Mantle_Layer()
    MEDULLA_OBLONGATA_ALAR_PLATE_MARGINAL_LAYER = _Medulla_Oblongata_Alar_Plate_Marginal_Layer()
    MEDULLA_OBLONGATA_ALAR_PLATE_VENTRICULAR_LAYER = _Medulla_Oblongata_Alar_Plate_Ventricular_Layer()
    MEDULLA_OBLONGATA_BASAL_PLATE = _Medulla_Oblongata_Basal_Plate()
    MEDULLA_OBLONGATA_BASAL_PLATE_MANTLE_LAYER = _Medulla_Oblongata_Basal_Plate_Mantle_Layer()
    MEDULLA_OBLONGATA_BASAL_PLATE_MARGINAL_LAYER = _Medulla_Oblongata_Basal_Plate_Marginal_Layer()
    MEDULLA_OBLONGATA_BASAL_PLATE_VENTRICULAR_LAYER = _Medulla_Oblongata_Basal_Plate_Ventricular_Layer()
    MEDULLA_OBLONGATA_SULCUS_LIMITANS = _Medulla_Oblongata_Sulcus_Limitans()
    MEDULLA_OBLONGATA_ROOF = _Medulla_Oblongata_Roof()
    PONS = _Pons()
    PONS_MANTLE_LAYER = _Pons_Mantle_Layer()
    PONS_MARGINAL_LAYER = _Pons_Marginal_Layer()
    PONS_VENTRICULAR_LAYER = _Pons_Ventricular_Layer()
    METENCEPHALON_SULCUS_LIMITANS = _Metencephalon_Sulcus_Limitans()
    METENCEPHALON_PART_OF_4TH_VENTRICLE_CHOROID_PLEXUS = _Metencephalon_Part_Of_4Th_Ventricle_Choroid_Plexus()
    FACIAL_GANGLION = _Facial_Ganglion()
    VESTIBULO_COCHLEAR_GANGLION_COMPLEX = _Vestibulo_Cochlear_Ganglion_Complex()
    VESTIBULO_COCHLEAR_GANGLION = _Vestibulo_Cochlear_Ganglion()
    COCHLEAR_GANGLION = _Cochlear_Ganglion()
    VESTIBULAR_GANGLION = _Vestibular_Ganglion()
    OCULOMOTOR_NERVE = _Oculomotor_Nerve()
    OPTIC_NERVE = _Optic_Nerve()
    TRIGEMINAL_NERVE = _Trigeminal_Nerve()
    SPINAL_CORD = _Spinal_Cord()
    SPINAL_CORD_FLOOR_PLATE = _Spinal_Cord_Floor_Plate()
    SPINAL_CORD_LATERAL_WALL = _Spinal_Cord_Lateral_Wall()
    SPINAL_CORD_MANTLE_LAYER = _Spinal_Cord_Mantle_Layer()
    ALAR_COLUMNS = _Alar_Columns()
    BASAL_COLUMNS = _Basal_Columns()
    SPINAL_CORD_MARGINAL_LAYER = _Spinal_Cord_Marginal_Layer()
    SPINAL_CORD_SULCUS_LIMITANS = _Spinal_Cord_Sulcus_Limitans()
    SPINAL_CORD_VENTRICULAR_LAYER = _Spinal_Cord_Ventricular_Layer()
    SPINAL_CORD_ROOF_PLATE = _Spinal_Cord_Roof_Plate()
    LUMBOSACRAL_PLEXUS = _Lumbosacral_Plexus()
    EXTERNAL_AUDITORY_MEATUS = _External_Auditory_Meatus()
    PINNA = _Pinna()
    PINNA_MESENCHYME = _Pinna_Mesenchyme()
    PINNA_SURFACE_EPITHELIUM = _Pinna_Surface_Epithelium()
    ENDOLYMPHATIC_SAC = _Endolymphatic_Sac()
    ENDOLYMPHATIC_SAC_MESENCHYME = _Endolymphatic_Sac_Mesenchyme()
    ENDOLYMPHATIC_SAC_EPITHELIUM = _Endolymphatic_Sac_Epithelium()
    OTIC_CAPSULE = _Otic_Capsule()
    COCHLEA = _Cochlea()
    COCHLEAR_DUCT = _Cochlear_Duct()
    COCHLEAR_DUCT_MESENCHYME = _Cochlear_Duct_Mesenchyme()
    COCHLEAR_DUCT_EPITHELIUM = _Cochlear_Duct_Epithelium()
    PHARYNGO_TYMPANIC_TUBE = _Pharyngo_Tympanic_Tube()
    CORNEA_STROMA = _Cornea_Stroma()
    OPTIC_CHIASMA = _Optic_Chiasma()
    NASAL_CAVITY = _Nasal_Cavity()
    NASAL_CAVITY_EPITHELIUM = _Nasal_Cavity_Epithelium()
    OLFACTORY_EPITHELIUM = _Olfactory_Epithelium()
    NASAL_CAVITY_RESPIRATORY_EPITHELIUM = _Nasal_Cavity_Respiratory_Epithelium()
    NASAL_SEPTUM = _Nasal_Septum()
    FRONTAL_PROCESS_EPITHELIUM = _Frontal_Process_Epithelium()
    LATERO_NASAL_PROCESS_EPITHELIUM = _Latero_Nasal_Process_Epithelium()
    MEDIAL_NASAL_PROCESS_EPITHELIUM = _Medial_Nasal_Process_Epithelium()
    VOMERONASAL_ORGAN = _Vomeronasal_Organ()
    ARCH_OF_AORTA = _Arch_Of_Aorta()
    EXTERNAL_ILIAC_ARTERY = _External_Iliac_Artery()
    INNOMINATE_ARTERY = _Innominate_Artery()
    INTERSEGMENTAL_ARTERY = _Intersegmental_Artery()
    SUBCLAVIAN_ARTERY = _Subclavian_Artery()
    ATRIOVENTRICULAR_ENDOCARDIAL_CUSHION = _Atrioventricular_Endocardial_Cushion()
    OUTFLOW_TRACT_PULMONARY_COMPONENT_PROXIMAL_PART = _Outflow_Tract_Pulmonary_Component_Proximal_Part()
    INTERNAL_JUGULAR_VEIN = _Internal_Jugular_Vein()
    SUBCLAVIAN_VEIN = _Subclavian_Vein()
    HYOID_CARTILAGE_CONDENSATION = _Hyoid_Cartilage_Condensation()
    STOMACH_GLANDULAR_REGION = _Stomach_Glandular_Region()
    STOMACH_GLANDULAR_REGION_MESENCHYME = _Stomach_Glandular_Region_Mesenchyme()
    STOMACH_GLANDULAR_REGION_EPITHELIUM = _Stomach_Glandular_Region_Epithelium()
    STOMACH_GLANDULAR_REGION_VASCULAR_ELEMENT = _Stomach_Glandular_Region_Vascular_Element()
    STOMACH_PROVENTRICULAR_REGION = _Stomach_Proventricular_Region()
    STOMACH_PROVENTRICULAR_REGION_MESENCHYME = _Stomach_Proventricular_Region_Mesenchyme()
    STOMACH_PROVENTRICULAR_REGION_EPITHELIUM = _Stomach_Proventricular_Region_Epithelium()
    STOMACH_PROVENTRICULAR_REGION_VASCULAR_ELEMENT = _Stomach_Proventricular_Region_Vascular_Element()
    STOMACH_PYLORIC_REGION = _Stomach_Pyloric_Region()
    STOMACH_PYLORIC_REGION_MESENCHYME = _Stomach_Pyloric_Region_Mesenchyme()
    STOMACH_PYLORIC_REGION_EPITHELIUM = _Stomach_Pyloric_Region_Epithelium()
    STOMACH_PYLORIC_REGION_VASCULAR_ELEMENT = _Stomach_Pyloric_Region_Vascular_Element()
    MECKEL_S_CARTILAGE = _Meckel_S_Cartilage()
    MANDIBLE_PRIMORDIUM_ALVEOLAR_SULCUS = _Mandible_Primordium_Alveolar_Sulcus()
    MAXILLARY_PROCESS_EPITHELIUM = _Maxillary_Process_Epithelium()
    MAXILLARY_PROCESS_SKELETON = _Maxillary_Process_Skeleton()
    MAXILLA = _Maxilla()
    MAXILLARY_PROCESS_ALVEOLAR_SULCUS = _Maxillary_Process_Alveolar_Sulcus()
    PREMAXILLA = _Premaxilla()
    PRIMARY_PALATE = _Primary_Palate()
    PRIMARY_PALATE_EPITHELIUM = _Primary_Palate_Epithelium()
    PRIMARY_PALATE_MESENCHYME = _Primary_Palate_Mesenchyme()
    PRIMITIVE_COLLECTING_DUCT = _Primitive_Collecting_Duct()
    ARYTENOID_SWELLING_CARTILAGE_CONDENSATION = _Arytenoid_Swelling_Cartilage_Condensation()
    LEFT_LUNG = _Left_Lung()
    LEFT_LUNG_MESENCHYME = _Left_Lung_Mesenchyme()
    LEFT_LUNG_EPITHELIUM = _Left_Lung_Epithelium()
    LEFT_LUNG_LOBAR_BRONCHUS = _Left_Lung_Lobar_Bronchus()
    LEFT_LUNG_LOBAR_BRONCHUS_MESENCHYME = _Left_Lung_Lobar_Bronchus_Mesenchyme()
    LEFT_LUNG_LOBAR_BRONCHUS_EPITHELIUM = _Left_Lung_Lobar_Bronchus_Epithelium()
    LEFT_LUNG_LOBAR_BRONCHUS_VASCULAR_ELEMENT = _Left_Lung_Lobar_Bronchus_Vascular_Element()
    LEFT_LUNG_VASCULAR_ELEMENT = _Left_Lung_Vascular_Element()
    RIGHT_LUNG = _Right_Lung()
    RIGHT_LUNG_MESENCHYME = _Right_Lung_Mesenchyme()
    RIGHT_LUNG_EPITHELIUM = _Right_Lung_Epithelium()
    RIGHT_LUNG_LOBAR_BRONCHUS = _Right_Lung_Lobar_Bronchus()
    RIGHT_LUNG_LOBAR_BRONCHUS_MESENCHYME = _Right_Lung_Lobar_Bronchus_Mesenchyme()
    RIGHT_LUNG_LOBAR_BRONCHUS_EPITHELIUM = _Right_Lung_Lobar_Bronchus_Epithelium()
    RIGHT_LUNG_LOBAR_BRONCHUS_VASCULAR_ELEMENT = _Right_Lung_Lobar_Bronchus_Vascular_Element()
    RIGHT_LUNG_VASCULAR_ELEMENT = _Right_Lung_Vascular_Element()
    UPPER_RESPIRATORY_TRACT = _Upper_Respiratory_Tract()
    NASOPHARYNX = _Nasopharynx()
    NASOPHARYNX_MESENCHYME = _Nasopharynx_Mesenchyme()
    NASOPHARYNX_EPITHELIUM = _Nasopharynx_Epithelium()
    NASOPHARYNX_VASCULAR_ELEMENT = _Nasopharynx_Vascular_Element()
    CERVICAL_VERTEBRA = _Cervical_Vertebra()
    LUMBAR_VERTEBRAL_CARTILAGE_CONDENSATION = _Lumbar_Vertebral_Cartilage_Condensation()
    AXIAL_SKELETON_SACRAL_REGION = _Axial_Skeleton_Sacral_Region()
    SACRAL_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Sacral_Vertebral_Pre_Cartilage_Condensation()
    RIB_CARTILAGE_CONDENSATION = _Rib_Cartilage_Condensation()
    THORACIC_VERTEBRAL_CARTILAGE_CONDENSATION = _Thoracic_Vertebral_Cartilage_Condensation()
    CRANIUM = _Cranium()
    CHONDROCRANIUM = _Chondrocranium()
    TEMPORAL_BONE = _Temporal_Bone()
    TEMPORAL_BONE_PETROUS_PART = _Temporal_Bone_Petrous_Part()
    SOMITE_49 = _Somite_49()
    SOMITE_49_DERMOMYOTOME = _Somite_49_Dermomyotome()
    SOMITE_49_MYOCOELE = _Somite_49_Myocoele()
    SOMITE_49_SCLEROTOME = _Somite_49_Sclerotome()
    SOMITE_50 = _Somite_50()
    SOMITE_50_DERMOMYOTOME = _Somite_50_Dermomyotome()
    SOMITE_50_MYOCOELE = _Somite_50_Myocoele()
    SOMITE_50_SCLEROTOME = _Somite_50_Sclerotome()
    SOMITE_51 = _Somite_51()
    SOMITE_51_DERMOMYOTOME = _Somite_51_Dermomyotome()
    SOMITE_51_MYOCOELE = _Somite_51_Myocoele()
    SOMITE_51_SCLEROTOME = _Somite_51_Sclerotome()
    SOMITE_52 = _Somite_52()
    SOMITE_52_DERMOMYOTOME = _Somite_52_Dermomyotome()
    SOMITE_52_MYOCOELE = _Somite_52_Myocoele()
    SOMITE_52_SCLEROTOME = _Somite_52_Sclerotome()
    TAIL_SPINAL_CORD = _Tail_Spinal_Cord()
    DIAPHRAGM = _Diaphragm()
    DIAPHRAGM_CENTRAL_TENDON = _Diaphragm_Central_Tendon()
    CRUS_OF_DIAPHRAGM = _Crus_Of_Diaphragm()
    PLEURO_PERICARDIAL_CANAL = _Pleuro_Pericardial_Canal()
    PLEURO_PERICARDIAL_CANAL_MESOTHELIAL_LINING = _Pleuro_Pericardial_Canal_Mesothelial_Lining()
    PLEURO_PERICARDIAL_FOLDS = _Pleuro_Pericardial_Folds()
    PLEURO_PERITONEAL_CANAL = _Pleuro_Peritoneal_Canal()
    PLEURO_PERITONEAL_CANAL_MESOTHELIAL_LINING = _Pleuro_Peritoneal_Canal_Mesothelial_Lining()
    PLEURO_PERITONEAL_MEMBRANE = _Pleuro_Peritoneal_Membrane()
    ELBOW_JOINT_PRIMORDIUM = _Elbow_Joint_Primordium()
    RADIUS_ULNA_CARTILAGE_CONDENSATION = _Radius_Ulna_Cartilage_Condensation()
    SHOULDER_JOINT_PRIMORDIUM = _Shoulder_Joint_Primordium()
    HUMERUS_CARTILAGE_CONDENSATION = _Humerus_Cartilage_Condensation()
    FORELIMB_DIGIT_1_METACARPUS_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_1_Metacarpus_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_1_PHALANX_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_1_Phalanx_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_2_METACARPUS_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_2_Metacarpus_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_2_PHALANX_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_2_Phalanx_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_3_METACARPUS_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_3_Metacarpus_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_3_PHALANX_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_3_Phalanx_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_4_METACARPUS_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_4_Metacarpus_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_4_PHALANX_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_4_Phalanx_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_5_METACARPUS_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_5_Metacarpus_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_5_PHALANX_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_5_Phalanx_Pre_Cartilage_Condensation()
    CARPUS_PRE_CARTILAGE_CONDENSATION = _Carpus_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_1_METATARSUS_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_1_Metatarsus_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_1_PHALANX_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_1_Phalanx_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_2_METATARSUS_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_2_Metatarsus_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_2_PHALANX_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_2_Phalanx_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_3_METATARSUS_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_3_Metatarsus_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_3_PHALANX_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_3_Phalanx_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_4_METATARSUS_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_4_Metatarsus_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_4_PHALANX_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_4_Phalanx_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_5_METATARSUS_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_5_Metatarsus_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_5_PHALANX_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_5_Phalanx_Pre_Cartilage_Condensation()
    FUTURE_TARSUS = _Future_Tarsus()
    CALCANEUM_PRE_CARTILAGE_CONDENSATION = _Calcaneum_Pre_Cartilage_Condensation()
    FUTURE_TARSUS_REST_OF_MESENCHYME = _Future_Tarsus_Rest_Of_Mesenchyme()
    TALUS_PRE_CARTILAGE_CONDENSATION = _Talus_Pre_Cartilage_Condensation()
    HIP_JOINT_PRIMORDIUM = _Hip_Joint_Primordium()
    KNEE_JOINT_PRIMORDIUM = _Knee_Joint_Primordium()
    TIBIA_FIBULA_PRE_CARTILAGE_CONDENSATION = _Tibia_Fibula_Pre_Cartilage_Condensation()
    FEMUR_CARTILAGE_CONDENSATION = _Femur_Cartilage_Condensation()
    VERTEBRAL_AXIS_MUSCULATURE = _Vertebral_Axis_Musculature()
    ANTERIOR_ABDOMINAL_WALL_MUSCULATURE = _Anterior_Abdominal_Wall_Musculature()
    ANTERIOR_ABDOMINAL_WALL_MUSCLE = _Anterior_Abdominal_Wall_Muscle()
    ANTERIOR_ABDOMINAL_WALL_UNDIFFERENTIATED_PRE_MUSCLE_MASS = (
        _Anterior_Abdominal_Wall_Undifferentiated_Pre_Muscle_Mass()
    )
    PECTORAL_GIRDLE_AND_THORACIC_BODY_WALL_MUSCULATURE = _Pectoral_Girdle_And_Thoracic_Body_Wall_Musculature()
    PECTORAL_GIRDLE_AND_THORACIC_BODY_WALL_MUSCLE = _Pectoral_Girdle_And_Thoracic_Body_Wall_Muscle()
    DELTOID_PRE_MUSCLE_MASS = _Deltoid_Pre_Muscle_Mass()
    SUBSCAPULARIS_PRE_MUSCLE_MASS = _Subscapularis_Pre_Muscle_Mass()
    SALIVARY_GLAND = _Salivary_Gland()
    SUBLINGUAL_GLAND_PRIMORDIUM = _Sublingual_Gland_Primordium()
    SUBLINGUAL_GLAND_PRIMORDIUM_EPITHELIUM = _Sublingual_Gland_Primordium_Epithelium()
    SUBLINGUAL_GLAND_PRIMORDIUM_MESENCHYME = _Sublingual_Gland_Primordium_Mesenchyme()
    SUBMANDIBULAR_GLAND_PRIMORDIUM = _Submandibular_Gland_Primordium()
    SUBMANDIBULAR_GLAND_PRIMORDIUM_EPITHELIUM = _Submandibular_Gland_Primordium_Epithelium()
    SUBMANDIBULAR_GLAND_PRIMORDIUM_MESENCHYME = _Submandibular_Gland_Primordium_Mesenchyme()
    INTEGUMENTAL_SYSTEM_GLAND = _Integumental_System_Gland()
    MAMMARY_GLAND = _Mammary_Gland()
    MAMMARY_GLAND_EPITHELIUM = _Mammary_Gland_Epithelium()
    MAMMARY_MESENCHYME = _Mammary_Mesenchyme()
    VIBRISSA_DERMAL_COMPONENT = _Vibrissa_Dermal_Component()
    VIBRISSA_EPIDERMAL_COMPONENT = _Vibrissa_Epidermal_Component()
    DIENCEPHALON_MENINGES = _Diencephalon_Meninges()
    DIENCEPHALON_ARACHNOID_MATER = _Diencephalon_Arachnoid_Mater()
    DIENCEPHALON_DURA_MATER = _Diencephalon_Dura_Mater()
    DIENCEPHALON_PIA_MATER = _Diencephalon_Pia_Mater()
    CHOROID_FISSURE = _Choroid_Fissure()
    LATERAL_VENTRICLE_CHOROID_PLEXUS = _Lateral_Ventricle_Choroid_Plexus()
    ANTERIOR_HORN_OF_LATERAL_VENTRICLE = _Anterior_Horn_Of_Lateral_Ventricle()
    INFERIOR_HORN_OF_LATERAL_VENTRICLE = _Inferior_Horn_Of_Lateral_Ventricle()
    POSTERIOR_HORN_OF_LATERAL_VENTRICLE = _Posterior_Horn_Of_Lateral_Ventricle()
    SUPERIOR_HORN_OF_LATERAL_VENTRICLE = _Superior_Horn_Of_Lateral_Ventricle()
    TELENCEPHALON_MENINGES = _Telencephalon_Meninges()
    TELENCEPHALON_ARACHNOID_MATER = _Telencephalon_Arachnoid_Mater()
    TELENCEPHALON_DURA_MATER = _Telencephalon_Dura_Mater()
    TELENCEPHALON_PIA_MATER = _Telencephalon_Pia_Mater()
    OLFACTORY_LOBE = _Olfactory_Lobe()
    OLFACTORY_CORTEX = _Olfactory_Cortex()
    OLFACTORY_CORTEX_MANTLE_LAYER = _Olfactory_Cortex_Mantle_Layer()
    OLFACTORY_CORTEX_MARGINAL_LAYER = _Olfactory_Cortex_Marginal_Layer()
    OLFACTORY_CORTEX_VENTRICULAR_LAYER = _Olfactory_Cortex_Ventricular_Layer()
    HINDBRAIN_MENINGES = _Hindbrain_Meninges()
    HINDBRAIN_ARACHNOID_MATER = _Hindbrain_Arachnoid_Mater()
    HINDBRAIN_DURA_MATER = _Hindbrain_Dura_Mater()
    HINDBRAIN_PIA_MATER = _Hindbrain_Pia_Mater()
    CEREBELLUM = _Cerebellum()
    CEREBELLUM_MANTLE_LAYER = _Cerebellum_Mantle_Layer()
    CEREBELLUM_MARGINAL_LAYER = _Cerebellum_Marginal_Layer()
    CEREBELLUM_VENTRICULAR_LAYER = _Cerebellum_Ventricular_Layer()
    MIDBRAIN_MENINGES = _Midbrain_Meninges()
    MIDBRAIN_ARACHNOID_MATER = _Midbrain_Arachnoid_Mater()
    MIDBRAIN_DURA_MATER = _Midbrain_Dura_Mater()
    MIDBRAIN_PIA_MATER = _Midbrain_Pia_Mater()
    CEREBRAL_AQUEDUCT = _Cerebral_Aqueduct()
    FACIAL_NERVE = _Facial_Nerve()
    OLFACTORY_NERVE = _Olfactory_Nerve()
    TRIGEMINAL_NERVE_MANDIBULAR_DIVISION = _Trigeminal_Nerve_Mandibular_Division()
    TRIGEMINAL_NERVE_MAXILLARY_DIVISION = _Trigeminal_Nerve_Maxillary_Division()
    TRIGEMINAL_NERVE_OPHTHALMIC_DIVISION = _Trigeminal_Nerve_Ophthalmic_Division()
    VESTIBULOCOCHLEAR_NERVE = _Vestibulocochlear_Nerve()
    VESTIBULOCOCHLEAR_NERVE_COCHLEAR_COMPONENT = _Vestibulocochlear_Nerve_Cochlear_Component()
    VESTIBULOCOCHLEAR_NERVE_VESTIBULAR_COMPONENT = _Vestibulocochlear_Nerve_Vestibular_Component()
    SPINAL_CORD_MENINGES = _Spinal_Cord_Meninges()
    SPINAL_CORD_ARACHNOID_MATER = _Spinal_Cord_Arachnoid_Mater()
    SPINAL_CORD_DURA_MATER = _Spinal_Cord_Dura_Mater()
    SPINAL_CORD_PIA_MATER = _Spinal_Cord_Pia_Mater()
    PHRENIC_NERVE = _Phrenic_Nerve()
    INNER_EAR_LABYRINTH = _Inner_Ear_Labyrinth()
    LABYRINTH_MESENCHYME = _Labyrinth_Mesenchyme()
    LABYRINTH_EPITHELIUM = _Labyrinth_Epithelium()
    CRUS_COMMUNE = _Crus_Commune()
    CRUS_COMMUNE_MESENCHYME = _Crus_Commune_Mesenchyme()
    CRUS_COMMUNE_EPITHELIUM = _Crus_Commune_Epithelium()
    LATERAL_SEMICIRCULAR_CANAL = _Lateral_Semicircular_Canal()
    LATERAL_SEMICIRCULAR_CANAL_MESENCHYME = _Lateral_Semicircular_Canal_Mesenchyme()
    LATERAL_SEMICIRCULAR_CANAL_EPITHELIUM = _Lateral_Semicircular_Canal_Epithelium()
    OSSICLE = _Ossicle()
    INCUS_PRE_CARTILAGE_CONDENSATION = _Incus_Pre_Cartilage_Condensation()
    MALLEUS_PRE_CARTILAGE_CONDENSATION = _Malleus_Pre_Cartilage_Condensation()
    STAPES_PRE_CARTILAGE_CONDENSATION = _Stapes_Pre_Cartilage_Condensation()
    CHOROIDAL_VASCULATURE = _Choroidal_Vasculature()
    EYELID = _Eyelid()
    INNER_CANTHUS = _Inner_Canthus()
    LOWER_EYELID = _Lower_Eyelid()
    LOWER_EYELID_EPITHELIUM = _Lower_Eyelid_Epithelium()
    LOWER_EYELID_MESENCHYME = _Lower_Eyelid_Mesenchyme()
    UPPER_EYELID = _Upper_Eyelid()
    UPPER_EYELID_EPITHELIUM = _Upper_Eyelid_Epithelium()
    UPPER_EYELID_MESENCHYME = _Upper_Eyelid_Mesenchyme()
    VITREOUS_HUMOUR = _Vitreous_Humour()
    LENS = _Lens()
    LENS_ANTERIOR_EPITHELIUM = _Lens_Anterior_Epithelium()
    LENS_EQUATORIAL_EPITHELIUM = _Lens_Equatorial_Epithelium()
    LENS_FIBER = _Lens_Fiber()
    ANTERIOR_LENS_FIBER = _Anterior_Lens_Fiber()
    POSTERIOR_LENS_FIBER = _Posterior_Lens_Fiber()
    EYE_SKELETAL_MUSCLE = _Eye_Skeletal_Muscle()
    EXTRINSIC_OCULAR_PRE_MUSCLE_MASS = _Extrinsic_Ocular_Pre_Muscle_Mass()
    NARIS = _Naris()
    EXTERNAL_NARIS = _External_Naris()
    POSTERIOR_NARIS = _Posterior_Naris()
    POSTERIOR_NARIS_EPITHELIUM = _Posterior_Naris_Epithelium()
    PRIMARY_CHOANA = _Primary_Choana()
    NASAL_CAPSULE = _Nasal_Capsule()
    NASO_LACRIMAL_DUCT = _Naso_Lacrimal_Duct()
    ANTERIOR_CEREBRAL_ARTERY = _Anterior_Cerebral_Artery()
    COMMON_CAROTID_ARTERY = _Common_Carotid_Artery()
    ABDOMINAL_AORTA = _Abdominal_Aorta()
    POST_DUCTAL_PART_OF_THORACIC_AORTA = _Post_Ductal_Part_Of_Thoracic_Aorta()
    DUCTUS_ARTERIOSUS = _Ductus_Arteriosus()
    HEPATIC_ARTERY = _Hepatic_Artery()
    INTERNAL_ILIAC_ARTERY = _Internal_Iliac_Artery()
    POSTERIOR_CEREBRAL_ARTERY = _Posterior_Cerebral_Artery()
    FORAMEN_SECUNDUM = _Foramen_Secundum()
    SEPTUM_SECUNDUM = _Septum_Secundum()
    BULBOVENTRICULAR_REGION = _Bulboventricular_Region()
    BULBAR_CUSHION = _Bulbar_Cushion()
    ENDOCARDIAL_TISSUE = _Endocardial_Tissue()
    HEART_VALVE = _Heart_Valve()
    AORTIC_VALVE = _Aortic_Valve()
    MITRAL_VALVE = _Mitral_Valve()
    PULMONARY_VALVE = _Pulmonary_Valve()
    TRICUSPID_VALVE = _Tricuspid_Valve()
    COMMON_ILIAC_VEIN = _Common_Iliac_Vein()
    EXTERNAL_JUGULAR_VEIN = _External_Jugular_Vein()
    FEMORAL_VEIN = _Femoral_Vein()
    TONGUE_EPITHELIUM = _Tongue_Epithelium()
    TONGUE_MESENCHYME = _Tongue_Mesenchyme()
    TONGUE_MUSCLE = _Tongue_Muscle()
    TONGUE_EXTRINSIC_PRE_MUSCLE_MASS = _Tongue_Extrinsic_Pre_Muscle_Mass()
    STOMACH_FUNDUS = _Stomach_Fundus()
    STOMACH_FUNDUS_MESENCHYME = _Stomach_Fundus_Mesenchyme()
    STOMACH_FUNDUS_EPITHELIUM = _Stomach_Fundus_Epithelium()
    STOMACH_FUNDUS_VASCULAR_ELEMENT = _Stomach_Fundus_Vascular_Element()
    LESSER_OMENTUM = _Lesser_Omentum()
    PYLORIC_ANTRUM = _Pyloric_Antrum()
    PERINEAL_BODY = _Perineal_Body()
    PERINEAL_BODY_MESENCHYME = _Perineal_Body_Mesenchyme()
    PERINEAL_BODY_EPITHELIUM = _Perineal_Body_Epithelium()
    PERINEAL_BODY_VASCULAR_ELEMENT = _Perineal_Body_Vascular_Element()
    RECTUM = _Rectum()
    RECTUM_MESENCHYME = _Rectum_Mesenchyme()
    RECTUM_EPITHELIUM = _Rectum_Epithelium()
    RECTUM_VASCULAR_ELEMENT = _Rectum_Vascular_Element()
    LOWER_JAW = _Lower_Jaw()
    LOWER_LIP = _Lower_Lip()
    LOWER_JAW_SKELETON = _Lower_Jaw_Skeleton()
    MANDIBLE_MESENCHYME = _Mandible_Mesenchyme()
    LOWER_JAW_MESENCHYME = _Lower_Jaw_Mesenchyme()
    LOWER_JAW_TOOTH = _Lower_Jaw_Tooth()
    LOWER_JAW_INCISOR = _Lower_Jaw_Incisor()
    LOWER_JAW_INCISOR_EPITHELIUM = _Lower_Jaw_Incisor_Epithelium()
    LOWER_JAW_INCISOR_MESENCHYME = _Lower_Jaw_Incisor_Mesenchyme()
    LOWER_JAW_MOLAR = _Lower_Jaw_Molar()
    LOWER_JAW_MOLAR_EPITHELIUM = _Lower_Jaw_Molar_Epithelium()
    LOWER_JAW_MOLAR_MESENCHYME = _Lower_Jaw_Molar_Mesenchyme()
    UPPER_JAW = _Upper_Jaw()
    UPPER_LIP = _Upper_Lip()
    PHILTRUM = _Philtrum()
    UPPER_JAW_SKELETON = _Upper_Jaw_Skeleton()
    UPPER_JAW_MESENCHYME = _Upper_Jaw_Mesenchyme()
    UPPER_JAW_ALVEOLAR_SULCUS = _Upper_Jaw_Alveolar_Sulcus()
    UPPER_JAW_TOOTH = _Upper_Jaw_Tooth()
    UPPER_JAW_INCISOR = _Upper_Jaw_Incisor()
    UPPER_JAW_INCISOR_EPITHELIUM = _Upper_Jaw_Incisor_Epithelium()
    UPPER_JAW_INCISOR_MESENCHYME = _Upper_Jaw_Incisor_Mesenchyme()
    UPPER_JAW_MOLAR = _Upper_Jaw_Molar()
    UPPER_JAW_MOLAR_EPITHELIUM = _Upper_Jaw_Molar_Epithelium()
    UPPER_JAW_MOLAR_MESENCHYME = _Upper_Jaw_Molar_Mesenchyme()
    LIVER_BARE_AREA = _Liver_Bare_Area()
    RENAL_PELVIS = _Renal_Pelvis()
    URETER = _Ureter()
    RENAL_CORTEX = _Renal_Cortex()
    NEPHROGENIC_INTERSTITIUM = _Nephrogenic_Interstitium()
    EARLY_NEPHRON = _Early_Nephron()
    PHALLIC_URETHRA_OF_MALE = _Phallic_Urethra_Of_Male()
    FEMALE_REPRODUCTIVE_SYSTEM = _Female_Reproductive_System()
    MESOVARIUM = _Mesovarium()
    OVARY = _Ovary()
    SURFACE_EPITHELIUM_OF_OVARY = _Surface_Epithelium_Of_Ovary()
    GERM_CELL_OF_OVARY = _Germ_Cell_Of_Ovary()
    RETE_OVARII_OF_OVARY = _Rete_Ovarii_Of_Ovary()
    MALE_REPRODUCTIVE_SYSTEM = _Male_Reproductive_System()
    GENITAL_TUBERCLE_OF_MALE = _Genital_Tubercle_Of_Male()
    NEPHRIC_DUCT_OF_MALE__MESONEPHRIC_PORTION = _Nephric_Duct_Of_Male_Mesonephric_Portion()
    MESORCHIUM = _Mesorchium()
    TESTIS = _Testis()
    COELOMIC_EPITHELIUM_OF_TESTIS = _Coelomic_Epithelium_Of_Testis()
    GERM_CELL_OF_TESTIS = _Germ_Cell_Of_Testis()
    LEFT_LUNG_HILUS = _Left_Lung_Hilus()
    RIGHT_LUNG_ACCESSORY_LOBE = _Right_Lung_Accessory_Lobe()
    RIGHT_LUNG_ACCESSORY_LOBE_LOBAR_BRONCHUS = _Right_Lung_Accessory_Lobe_Lobar_Bronchus()
    RIGHT_LUNG_ACCESSORY_LOBE_LOBAR_BRONCHUS_MESENCHYME = _Right_Lung_Accessory_Lobe_Lobar_Bronchus_Mesenchyme()
    RIGHT_LUNG_ACCESSORY_LOBE_LOBAR_BRONCHUS_EPITHELIUM = _Right_Lung_Accessory_Lobe_Lobar_Bronchus_Epithelium()
    RIGHT_LUNG_ACCESSORY_LOBE_LOBAR_BRONCHUS_VASCULAR_ELEMENT = (
        _Right_Lung_Accessory_Lobe_Lobar_Bronchus_Vascular_Element()
    )
    RIGHT_LUNG_CAUDAL_LOBE = _Right_Lung_Caudal_Lobe()
    RIGHT_LUNG_CAUDAL_LOBE_LOBAR_BRONCHUS = _Right_Lung_Caudal_Lobe_Lobar_Bronchus()
    RIGHT_LUNG_CAUDAL_LOBE_LOBAR_BRONCHUS_MESENCHYME = _Right_Lung_Caudal_Lobe_Lobar_Bronchus_Mesenchyme()
    RIGHT_LUNG_CAUDAL_LOBE_LOBAR_BRONCHUS_EPITHELIUM = _Right_Lung_Caudal_Lobe_Lobar_Bronchus_Epithelium()
    RIGHT_LUNG_CAUDAL_LOBE_LOBAR_BRONCHUS_VASCULAR_ELEMENT = _Right_Lung_Caudal_Lobe_Lobar_Bronchus_Vascular_Element()
    RIGHT_LUNG_CRANIAL_LOBE = _Right_Lung_Cranial_Lobe()
    RIGHT_LUNG_CRANIAL_LOBE_LOBAR_BRONCHUS = _Right_Lung_Cranial_Lobe_Lobar_Bronchus()
    RIGHT_LUNG_CRANIAL_LOBE_LOBAR_BRONCHUS_MESENCHYME = _Right_Lung_Cranial_Lobe_Lobar_Bronchus_Mesenchyme()
    RIGHT_LUNG_CRANIAL_LOBE_LOBAR_BRONCHUS_EPITHELIUM = _Right_Lung_Cranial_Lobe_Lobar_Bronchus_Epithelium()
    RIGHT_LUNG_CRANIAL_LOBE_LOBAR_BRONCHUS_VASCULAR_ELEMENT = _Right_Lung_Cranial_Lobe_Lobar_Bronchus_Vascular_Element()
    RIGHT_LUNG_HILUS = _Right_Lung_Hilus()
    RIGHT_LUNG_MIDDLE_LOBE = _Right_Lung_Middle_Lobe()
    RIGHT_LUNG_MIDDLE_LOBE_LOBAR_BRONCHUS = _Right_Lung_Middle_Lobe_Lobar_Bronchus()
    RIGHT_LUNG_MIDDLE_LOBE_LOBAR_BRONCHUS_MESENCHYME = _Right_Lung_Middle_Lobe_Lobar_Bronchus_Mesenchyme()
    RIGHT_LUNG_MIDDLE_LOBE_LOBAR_BRONCHUS_EPITHELIUM = _Right_Lung_Middle_Lobe_Lobar_Bronchus_Epithelium()
    RIGHT_LUNG_MIDDLE_LOBE_LOBAR_BRONCHUS_VASCULAR_ELEMENT = _Right_Lung_Middle_Lobe_Lobar_Bronchus_Vascular_Element()
    LUMBAR_VERTEBRA = _Lumbar_Vertebra()
    NUCLEUS_PULPOSUS = _Nucleus_Pulposus()
    SACRAL_VERTEBRAL_CARTILAGE_CONDENSATION = _Sacral_Vertebral_Cartilage_Condensation()
    RIB = _Rib()
    THORACIC_VERTEBRA = _Thoracic_Vertebra()
    BASIOCCIPITAL_PRE_CARTILAGE_CONDENSATION = _Basioccipital_Pre_Cartilage_Condensation()
    BASISPHENOID_PRE_CARTILAGE_CONDENSATION = _Basisphenoid_Pre_Cartilage_Condensation()
    EXOCCIPITAL_PRE_CARTILAGE_CONDENSATION = _Exoccipital_Pre_Cartilage_Condensation()
    SPHENOID_BONE_PRE_CARTILAGE_CONDENSATION = _Sphenoid_Bone_Pre_Cartilage_Condensation()
    VAULT_OF_SKULL = _Vault_Of_Skull()
    FRONTAL_BONE_PRIMORDIUM = _Frontal_Bone_Primordium()
    INTER_PARIETAL_BONE_PRIMORDIUM = _Inter_Parietal_Bone_Primordium()
    PARIETAL_BONE_PRIMORDIUM = _Parietal_Bone_Primordium()
    TEMPORAL_BONE_SQUAMOUS_PART = _Temporal_Bone_Squamous_Part()
    VISCEROCRANIUM = _Viscerocranium()
    ETHMOID_BONE_PRIMORDIUM = _Ethmoid_Bone_Primordium()
    FACIAL_BONE_PRIMORDIUM = _Facial_Bone_Primordium()
    THORACIC_SEGMENT_SKELETON = _Thoracic_Segment_Skeleton()
    CLAVICLE_PRE_CARTILAGE_CONDENSATION = _Clavicle_Pre_Cartilage_Condensation()
    SCAPULA_PRE_CARTILAGE_CONDENSATION = _Scapula_Pre_Cartilage_Condensation()
    PELVIC_GIRDLE_SKELETON = _Pelvic_Girdle_Skeleton()
    ILIUM_PRE_CARTILAGE_CONDENSATION = _Ilium_Pre_Cartilage_Condensation()
    SOMITE_53 = _Somite_53()
    SOMITE_53_DERMOMYOTOME = _Somite_53_Dermomyotome()
    SOMITE_53_MYOCOELE = _Somite_53_Myocoele()
    SOMITE_53_SCLEROTOME = _Somite_53_Sclerotome()
    SOMITE_54 = _Somite_54()
    SOMITE_54_DERMOMYOTOME = _Somite_54_Dermomyotome()
    SOMITE_54_MYOCOELE = _Somite_54_Myocoele()
    SOMITE_54_SCLEROTOME = _Somite_54_Sclerotome()
    SOMITE_55 = _Somite_55()
    SOMITE_55_DERMOMYOTOME = _Somite_55_Dermomyotome()
    SOMITE_55_MYOCOELE = _Somite_55_Myocoele()
    SOMITE_55_SCLEROTOME = _Somite_55_Sclerotome()
    TAIL_SKELETON = _Tail_Skeleton()
    AXIAL_SKELETON_TAIL_REGION = _Axial_Skeleton_Tail_Region()
    TAIL_VERTEBRAL_CARTILAGE_CONDENSATION = _Tail_Vertebral_Cartilage_Condensation()
    TAIL_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tail_Vertebral_Pre_Cartilage_Condensation()
    DIAPHRAGM_DOME = _Diaphragm_Dome()
    LEFT_HEPATIC_RECESS = _Left_Hepatic_Recess()
    OMENTAL_BURSA_INFERIOR_RECESS = _Omental_Bursa_Inferior_Recess()
    OMENTAL_BURSA_SUPERIOR_RECESS = _Omental_Bursa_Superior_Recess()
    RIGHT_HEPATIC_RECESS = _Right_Hepatic_Recess()
    ELBOW_SKIN = _Elbow_Skin()
    ELBOW_DERMIS = _Elbow_Dermis()
    ELBOW_EPIDERMIS = _Elbow_Epidermis()
    RADIUS_CARTILAGE_CONDENSATION = _Radius_Cartilage_Condensation()
    ULNA_CARTILAGE_CONDENSATION = _Ulna_Cartilage_Condensation()
    FOREARM_SKIN = _Forearm_Skin()
    FOREARM_DERMIS = _Forearm_Dermis()
    FOREARM_EPIDERMIS = _Forearm_Epidermis()
    SHOULDER_SKIN = _Shoulder_Skin()
    SHOULDER_DERMIS = _Shoulder_Dermis()
    SHOULDER_EPIDERMIS = _Shoulder_Epidermis()
    UPPER_ARM_SKIN = _Upper_Arm_Skin()
    UPPER_ARM_DERMIS = _Upper_Arm_Dermis()
    UPPER_ARM_EPIDERMIS = _Upper_Arm_Epidermis()
    FORELIMB_DIGIT_1_METACARPUS_CARTILAGE_CONDENSATION = _Forelimb_Digit_1_Metacarpus_Cartilage_Condensation()
    FORELIMB_DIGIT_1_PHALANX_CARTILAGE_CONDENSATION = _Forelimb_Digit_1_Phalanx_Cartilage_Condensation()
    FORELIMB_DIGIT_1_SKIN = _Forelimb_Digit_1_Skin()
    FORELIMB_DIGIT_1_DERMIS = _Forelimb_Digit_1_Dermis()
    FORELIMB_DIGIT_1_EPIDERMIS = _Forelimb_Digit_1_Epidermis()
    FORELIMB_DIGIT_2_METACARPUS_CARTILAGE_CONDENSATION = _Forelimb_Digit_2_Metacarpus_Cartilage_Condensation()
    FORELIMB_DIGIT_2_PHALANX_CARTILAGE_CONDENSATION = _Forelimb_Digit_2_Phalanx_Cartilage_Condensation()
    FORELIMB_DIGIT_2_SKIN = _Forelimb_Digit_2_Skin()
    FORELIMB_DIGIT_2_DERMIS = _Forelimb_Digit_2_Dermis()
    FORELIMB_DIGIT_2_EPIDERMIS = _Forelimb_Digit_2_Epidermis()
    FORELIMB_DIGIT_3_METACARPUS_CARTILAGE_CONDENSATION = _Forelimb_Digit_3_Metacarpus_Cartilage_Condensation()
    FORELIMB_DIGIT_3_PHALANX_CARTILAGE_CONDENSATION = _Forelimb_Digit_3_Phalanx_Cartilage_Condensation()
    FORELIMB_DIGIT_3_SKIN = _Forelimb_Digit_3_Skin()
    FORELIMB_DIGIT_3_DERMIS = _Forelimb_Digit_3_Dermis()
    FORELIMB_DIGIT_3_EPIDERMIS = _Forelimb_Digit_3_Epidermis()
    FORELIMB_DIGIT_4_METACARPUS_CARTILAGE_CONDENSATION = _Forelimb_Digit_4_Metacarpus_Cartilage_Condensation()
    FORELIMB_DIGIT_4_PHALANX_CARTILAGE_CONDENSATION = _Forelimb_Digit_4_Phalanx_Cartilage_Condensation()
    FORELIMB_DIGIT_4_SKIN = _Forelimb_Digit_4_Skin()
    FORELIMB_DIGIT_4_DERMIS = _Forelimb_Digit_4_Dermis()
    FORELIMB_DIGIT_4_EPIDERMIS = _Forelimb_Digit_4_Epidermis()
    FORELIMB_DIGIT_5_METACARPUS_CARTILAGE_CONDENSATION = _Forelimb_Digit_5_Metacarpus_Cartilage_Condensation()
    FORELIMB_DIGIT_5_PHALANX_CARTILAGE_CONDENSATION = _Forelimb_Digit_5_Phalanx_Cartilage_Condensation()
    FORELIMB_DIGIT_5_SKIN = _Forelimb_Digit_5_Skin()
    FORELIMB_DIGIT_5_DERMIS = _Forelimb_Digit_5_Dermis()
    FORELIMB_DIGIT_5_EPIDERMIS = _Forelimb_Digit_5_Epidermis()
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_1_AND_2_SKIN = (
        _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Skin()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_1_AND_2_DERMIS = (
        _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Dermis()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_1_AND_2_EPIDERMIS = (
        _Interdigital_Region_Between_Forelimb_Digits_1_And_2_Epidermis()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_2_AND_3_SKIN = (
        _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Skin()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_2_AND_3_DERMIS = (
        _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Dermis()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_2_AND_3_EPIDERMIS = (
        _Interdigital_Region_Between_Forelimb_Digits_2_And_3_Epidermis()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_3_AND_4_SKIN = (
        _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Skin()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_3_AND_4_DERMIS = (
        _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Dermis()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_3_AND_4_EPIDERMIS = (
        _Interdigital_Region_Between_Forelimb_Digits_3_And_4_Epidermis()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_4_AND_5_SKIN = (
        _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Skin()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_4_AND_5_DERMIS = (
        _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Dermis()
    )
    INTERDIGITAL_REGION_BETWEEN_FORELIMB_DIGITS_4_AND_5_EPIDERMIS = (
        _Interdigital_Region_Between_Forelimb_Digits_4_And_5_Epidermis()
    )
    CARPUS_CARTILAGE_CONDENSATION = _Carpus_Cartilage_Condensation()
    HAND_REST_OF_SKIN = _Hand_Rest_Of_Skin()
    HAND_REST_OF_SKIN_DERMIS = _Hand_Rest_Of_Skin_Dermis()
    HAND_REST_OF_SKIN_EPIDERMIS = _Hand_Rest_Of_Skin_Epidermis()
    HINDLIMB_DIGIT_1_METATARSUS_CARTILAGE_CONDENSATION = _Hindlimb_Digit_1_Metatarsus_Cartilage_Condensation()
    HINDLIMB_DIGIT_1_PHALANX_CARTILAGE_CONDENSATION = _Hindlimb_Digit_1_Phalanx_Cartilage_Condensation()
    HINDLIMB_DIGIT_1_SKIN = _Hindlimb_Digit_1_Skin()
    HINDLIMB_DIGIT_1_DERMIS = _Hindlimb_Digit_1_Dermis()
    HINDLIMB_DIGIT_1_EPIDERMIS = _Hindlimb_Digit_1_Epidermis()
    HINDLIMB_DIGIT_2_METATARSUS_CARTILAGE_CONDENSATION = _Hindlimb_Digit_2_Metatarsus_Cartilage_Condensation()
    HINDLIMB_DIGIT_2_PHALANX_CARTILAGE_CONDENSATION = _Hindlimb_Digit_2_Phalanx_Cartilage_Condensation()
    HINDLIMB_DIGIT_2_SKIN = _Hindlimb_Digit_2_Skin()
    HINDLIMB_DIGIT_2_DERMIS = _Hindlimb_Digit_2_Dermis()
    HINDLIMB_DIGIT_2_EPIDERMIS = _Hindlimb_Digit_2_Epidermis()
    HINDLIMB_DIGIT_3_METATARSUS_CARTILAGE_CONDENSATION = _Hindlimb_Digit_3_Metatarsus_Cartilage_Condensation()
    HINDLIMB_DIGIT_3_PHALANX_CARTILAGE_CONDENSATION = _Hindlimb_Digit_3_Phalanx_Cartilage_Condensation()
    HINDLIMB_DIGIT_3_SKIN = _Hindlimb_Digit_3_Skin()
    HINDLIMB_DIGIT_3_DERMIS = _Hindlimb_Digit_3_Dermis()
    HINDLIMB_DIGIT_3_EPIDERMIS = _Hindlimb_Digit_3_Epidermis()
    HINDLIMB_DIGIT_4_METATARSUS_CARTILAGE_CONDENSATION = _Hindlimb_Digit_4_Metatarsus_Cartilage_Condensation()
    HINDLIMB_DIGIT_4_PHALANX_CARTILAGE_CONDENSATION = _Hindlimb_Digit_4_Phalanx_Cartilage_Condensation()
    HINDLIMB_DIGIT_4_SKIN = _Hindlimb_Digit_4_Skin()
    HINDLIMB_DIGIT_4_DERMIS = _Hindlimb_Digit_4_Dermis()
    HINDLIMB_DIGIT_4_EPIDERMIS = _Hindlimb_Digit_4_Epidermis()
    HINDLIMB_DIGIT_5_METATARSUS_CARTILAGE_CONDENSATION = _Hindlimb_Digit_5_Metatarsus_Cartilage_Condensation()
    HINDLIMB_DIGIT_5_PHALANX_CARTILAGE_CONDENSATION = _Hindlimb_Digit_5_Phalanx_Cartilage_Condensation()
    HINDLIMB_DIGIT_5_SKIN = _Hindlimb_Digit_5_Skin()
    HINDLIMB_DIGIT_5_DERMIS = _Hindlimb_Digit_5_Dermis()
    HINDLIMB_DIGIT_5_EPIDERMIS = _Hindlimb_Digit_5_Epidermis()
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_1_AND_2_SKIN = (
        _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Skin()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_1_AND_2_DERMIS = (
        _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Dermis()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_1_AND_2_EPIDERMIS = (
        _Interdigital_Region_Between_Hindlimb_Digits_1_And_2_Epidermis()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_2_AND_3_SKIN = (
        _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Skin()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_2_AND_3_DERMIS = (
        _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Dermis()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_2_AND_3_EPIDERMIS = (
        _Interdigital_Region_Between_Hindlimb_Digits_2_And_3_Epidermis()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_3_AND_4_SKIN = (
        _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Skin()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_3_AND_4_DERMIS = (
        _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Dermis()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_3_AND_4_EPIDERMIS = (
        _Interdigital_Region_Between_Hindlimb_Digits_3_And_4_Epidermis()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_4_AND_5_SKIN = (
        _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Skin()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_4_AND_5_DERMIS = (
        _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Dermis()
    )
    INTERDIGITAL_REGION_BETWEEN_HINDLIMB_DIGITS_4_AND_5_EPIDERMIS = (
        _Interdigital_Region_Between_Hindlimb_Digits_4_And_5_Epidermis()
    )
    CALCANEUM_CARTILAGE_CONDENSATION = _Calcaneum_Cartilage_Condensation()
    TALUS_CARTILAGE_CONDENSATION = _Talus_Cartilage_Condensation()
    FOOT_REST_OF_SKIN = _Foot_Rest_Of_Skin()
    FOOT_REST_OF_SKIN_DERMIS = _Foot_Rest_Of_Skin_Dermis()
    FOOT_REST_OF_SKIN_EPIDERMIS = _Foot_Rest_Of_Skin_Epidermis()
    HIP_SKIN = _Hip_Skin()
    HIP_DERMIS = _Hip_Dermis()
    HIP_EPIDERMIS = _Hip_Epidermis()
    KNEE_SKIN = _Knee_Skin()
    KNEE_DERMIS = _Knee_Dermis()
    KNEE_EPIDERMIS = _Knee_Epidermis()
    FIBULA_CARTILAGE_CONDENSATION = _Fibula_Cartilage_Condensation()
    TIBIA_CARTILAGE_CONDENSATION = _Tibia_Cartilage_Condensation()
    LOWER_LEG_SKIN = _Lower_Leg_Skin()
    LOWER_LEG_DERMIS = _Lower_Leg_Dermis()
    LOWER_LEG_EPIDERMIS = _Lower_Leg_Epidermis()
    UPPER_LEG_SKIN = _Upper_Leg_Skin()
    UPPER_LEG_DERMIS = _Upper_Leg_Dermis()
    UPPER_LEG_EPIDERMIS = _Upper_Leg_Epidermis()
    EXTERNAL_OBLIQUE_MUSCLE = _External_Oblique_Muscle()
    INTERNAL_OBLIQUE_MUSCLE = _Internal_Oblique_Muscle()
    RECTUS_ABDOMINIS = _Rectus_Abdominis()
    TRANSVERSUS_ABDOMINIS = _Transversus_Abdominis()
    AXIAL_MUSCULATURE = _Axial_Musculature()
    AXIAL_MUSCLE = _Axial_Muscle()
    ERECTOR_SPINAE = _Erector_Spinae()
    PSOAS_MAJOR = _Psoas_Major()
    PSOAS_MINOR = _Psoas_Minor()
    CRANIAL_MUSCULATURE = _Cranial_Musculature()
    CRANIAL_MUSCLE = _Cranial_Muscle()
    DELTOID = _Deltoid()
    LATISSIMUS_DORSI = _Latissimus_Dorsi()
    PECTORALIS_MAJOR = _Pectoralis_Major()
    PECTORALIS_MINOR = _Pectoralis_Minor()
    SUBSCAPULARIS = _Subscapularis()
    SUPRASPINATUS = _Supraspinatus()
    TRAPEZIUS = _Trapezius()
    PELVIC_GIRDLE_MUSCULATURE = _Pelvic_Girdle_Musculature()
    PELVIC_GIRDLE_MUSCLE = _Pelvic_Girdle_Muscle()
    GLUTEAL_MUSCLE = _Gluteal_Muscle()
    INTEGUMENTAL_SYSTEM_MUSCLE = _Integumental_System_Muscle()
    INTEGUMENTAL_SYSTEM_SUPERFICIAL_MUSCLE = _Integumental_System_Superficial_Muscle()
    PANNICULUS_CARNOSUS_GROUP = _Panniculus_Carnosus_Group()
    PLATYSMA = _Platysma()
    THYROID_GLAND_ISTHMUS = _Thyroid_Gland_Isthmus()
    THYROID_GLAND_LOBE = _Thyroid_Gland_Lobe()
    THYROID_GLAND_LEFT_LOBE = _Thyroid_Gland_Left_Lobe()
    THYROID_GLAND_RIGHT_LOBE = _Thyroid_Gland_Right_Lobe()
    DIENCEPHALON_INTERNAL_CAPSULE = _Diencephalon_Internal_Capsule()
    CAUDATE_NUCLEUS = _Caudate_Nucleus()
    LENTIFORM_NUCLEUS = _Lentiform_Nucleus()
    TENTORIUM_CEREBELLI = _Tentorium_Cerebelli()
    HINDBRAIN_SUBARACHNOID_SPACE = _Hindbrain_Subarachnoid_Space()
    PONTINE_CISTERN = _Pontine_Cistern()
    MIDBRAIN_TEGMENTUM = _Midbrain_Tegmentum()
    ABDUCENS_NERVE = _Abducens_Nerve()
    FACIAL_NERVE_CHORDA_TYMPANI_BRANCH = _Facial_Nerve_Chorda_Tympani_Branch()
    TROCHLEAR_NERVE = _Trochlear_Nerve()
    CONUS_MEDULLARIS = _Conus_Medullaris()
    FILUM_TERMINALE = _Filum_Terminale()
    AUTONOMIC_GANGLION = _Autonomic_Ganglion()
    CILIARY_GANGLION = _Ciliary_Ganglion()
    PARAGANGLION_OF_ZUCKERKANDL = _Paraganglion_Of_Zuckerkandl()
    AUTONOMIC_NERVE_PLEXUS = _Autonomic_Nerve_Plexus()
    HYPOGASTRIC_PLEXUS = _Hypogastric_Plexus()
    CERVICO_THORACIC_GANGLION = _Cervico_Thoracic_Ganglion()
    INTERCOSTAL_NERVE = _Intercostal_Nerve()
    INCUS_CARTILAGE_CONDENSATION = _Incus_Cartilage_Condensation()
    MALLEUS_CARTILAGE_CONDENSATION = _Malleus_Cartilage_Condensation()
    STAPES_CARTILAGE_CONDENSATION = _Stapes_Cartilage_Condensation()
    EYE_ANTERIOR_CHAMBER = _Eye_Anterior_Chamber()
    AQUEOUS_HUMOUR = _Aqueous_Humour()
    CONJUNCTIVAL_SAC = _Conjunctival_Sac()
    EXTRINSIC_OCULAR_MUSCLE = _Extrinsic_Ocular_Muscle()
    TUNICA_VASCULOSA_LENTIS = _Tunica_Vasculosa_Lentis()
    VASA_HYALOIDEA_PROPRIA = _Vasa_Hyaloidea_Propria()
    LENS_CAPSULE = _Lens_Capsule()
    OPTIC_DISC = _Optic_Disc()
    MIDDLE_CEREBRAL_ARTERY = _Middle_Cerebral_Artery()
    SPINAL_ARTERY = _Spinal_Artery()
    ANTERIOR_SPINAL_ARTERY = _Anterior_Spinal_Artery()
    POSTERIOR_SPINAL_ARTERY = _Posterior_Spinal_Artery()
    FORAMEN_OVALE_OF_INTERATRIAL_SEPTUM = _Foramen_Ovale_Of_Interatrial_Septum()
    INTERVENTRICULAR_SEPTUM_MEMBRANOUS_PART = _Interventricular_Septum_Membranous_Part()
    INTERVENTRICULAR_SEPTUM_MUSCULAR_PART = _Interventricular_Septum_Muscular_Part()
    LYMPHATIC_SYSTEM = _Lymphatic_System()
    JUGULAR_LYMPH_SAC = _Jugular_Lymph_Sac()
    AZYGOS_VEIN = _Azygos_Vein()
    HEMIAZYGOS_VEIN = _Hemiazygos_Vein()
    HEPATICO_CARDIAC_VEIN = _Hepatico_Cardiac_Vein()
    LEFT_HEPATICO_CARDIAC_VEIN = _Left_Hepatico_Cardiac_Vein()
    RIGHT_HEPATICO_CARDIAC_VEIN = _Right_Hepatico_Cardiac_Vein()
    SPINAL_VEIN = _Spinal_Vein()
    ANAL_CANAL = _Anal_Canal()
    ANAL_CANAL_ROSTRAL_PART = _Anal_Canal_Rostral_Part()
    ANAL_CANAL_ROSTRAL_PART_MESENCHYME = _Anal_Canal_Rostral_Part_Mesenchyme()
    ANAL_CANAL_ROSTRAL_PART_EPITHELIUM = _Anal_Canal_Rostral_Part_Epithelium()
    ANAL_CANAL_ROSTRAL_PART_VASCULAR_ELEMENT = _Anal_Canal_Rostral_Part_Vascular_Element()
    ANAL_CANAL_CAUDAL_PART = _Anal_Canal_Caudal_Part()
    ANAL_CANAL_CAUDAL_PART_MESENCHYME = _Anal_Canal_Caudal_Part_Mesenchyme()
    ANAL_CANAL_CAUDAL_PART_EPITHELIUM = _Anal_Canal_Caudal_Part_Epithelium()
    ANAL_CANAL_CAUDAL_PART_VASCULAR_ELEMENT = _Anal_Canal_Caudal_Part_Vascular_Element()
    EXTERNAL_ANAL_SPHINCTER = _External_Anal_Sphincter()
    INTERNAL_ANAL_SPHINCTER = _Internal_Anal_Sphincter()
    GASTRO_ESOPHAGEAL_JUNCTION = _Gastro_Esophageal_Junction()
    GASTRO_ESOPHAGEAL_JUNCTION_MESENCHYME = _Gastro_Esophageal_Junction_Mesenchyme()
    GASTRO_ESOPHAGEAL_JUNCTION_EPITHELIUM = _Gastro_Esophageal_Junction_Epithelium()
    GASTRO_ESOPHAGEAL_JUNCTION_VASCULAR_ELEMENT = _Gastro_Esophageal_Junction_Vascular_Element()
    CIRCUMVALLATE_PAPILLAE = _Circumvallate_Papillae()
    FUNGIFORM_PAPILLAE = _Fungiform_Papillae()
    INTERMOLAR_EMINENCE = _Intermolar_Eminence()
    MEDIAN_FIBROUS_SEPTUM = _Median_Fibrous_Septum()
    TONGUE_EXTRINSIC_MUSCLE = _Tongue_Extrinsic_Muscle()
    GENIOGLOSSUS = _Genioglossus()
    HYOGLOSSUS = _Hyoglossus()
    PALATOGLOSSUS = _Palatoglossus()
    STYLOGLOSSUS = _Styloglossus()
    TONGUE_INTRINSIC_MUSCLE = _Tongue_Intrinsic_Muscle()
    TONGUE_INTRINSIC_MUSCLE_TRANSVERSE_COMPONENT = _Tongue_Intrinsic_Muscle_Transverse_Component()
    TONGUE_INTRINSIC_MUSCLE_VERTICAL_COMPONENT = _Tongue_Intrinsic_Muscle_Vertical_Component()
    STOMACH_FUNDUS_GLANDULAR_MUCOUS_MEMBRANE = _Stomach_Fundus_Glandular_Mucous_Membrane()
    GASTRO_SPLENIC_LIGAMENT = _Gastro_Splenic_Ligament()
    LIENO_RENAL_LIGAMENT = _Lieno_Renal_Ligament()
    FALCIFORM_LIGAMENT = _Falciform_Ligament()
    EPIGLOTTIS = _Epiglottis()
    MANDIBLE = _Mandible()
    LOWER_JAW_ALVEOLAR_SULCUS = _Lower_Jaw_Alveolar_Sulcus()
    LOWER_JAW_INCISOR_DENTAL_LAMINA = _Lower_Jaw_Incisor_Dental_Lamina()
    LOWER_JAW_INCISOR_ENAMEL_ORGAN = _Lower_Jaw_Incisor_Enamel_Organ()
    LOWER_JAW_INCISOR_DENTAL_PAPILLA = _Lower_Jaw_Incisor_Dental_Papilla()
    LOWER_JAW_MOLAR_DENTAL_LAMINA = _Lower_Jaw_Molar_Dental_Lamina()
    LOWER_JAW_MOLAR_ENAMEL_ORGAN = _Lower_Jaw_Molar_Enamel_Organ()
    LOWER_JAW_MOLAR_DENTAL_PAPILLA = _Lower_Jaw_Molar_Dental_Papilla()
    UPPER_JAW_INCISOR_DENTAL_LAMINA = _Upper_Jaw_Incisor_Dental_Lamina()
    UPPER_JAW_INCISOR_ENAMEL_ORGAN = _Upper_Jaw_Incisor_Enamel_Organ()
    UPPER_JAW_INCISOR_DENTAL_PAPILLA = _Upper_Jaw_Incisor_Dental_Papilla()
    UPPER_JAW_MOLAR_DENTAL_LAMINA = _Upper_Jaw_Molar_Dental_Lamina()
    UPPER_JAW_MOLAR_ENAMEL_ORGAN = _Upper_Jaw_Molar_Enamel_Organ()
    UPPER_JAW_MOLAR_DENTAL_PAPILLA = _Upper_Jaw_Molar_Dental_Papilla()
    LEFT_HEPATIC_DUCT_INTRAHEPATIC_PART = _Left_Hepatic_Duct_Intrahepatic_Part()
    RIGHT_HEPATIC_DUCT_INTRAHEPATIC_PART = _Right_Hepatic_Duct_Intrahepatic_Part()
    LIVER_LOBE = _Liver_Lobe()
    LIVER_LEFT_LOBE = _Liver_Left_Lobe()
    LIVER_LEFT_LOBE_BARE_AREA = _Liver_Left_Lobe_Bare_Area()
    LIVER_LEFT_LOBE_HEPATIC_SINUSOID = _Liver_Left_Lobe_Hepatic_Sinusoid()
    LIVER_LEFT_LOBE_PARENCHYMA = _Liver_Left_Lobe_Parenchyma()
    LIVER_RIGHT_LOBE = _Liver_Right_Lobe()
    LIVER_RIGHT_LOBE_BARE_AREA = _Liver_Right_Lobe_Bare_Area()
    LIVER_CAUDATE_LOBE = _Liver_Caudate_Lobe()
    LIVER_CAUDATE_LOBE_HEPATIC_SINUSOID = _Liver_Caudate_Lobe_Hepatic_Sinusoid()
    LIVER_CAUDATE_LOBE_PARENCHYMA = _Liver_Caudate_Lobe_Parenchyma()
    LIVER_RIGHT_LOBE_HEPATIC_SINUSOID = _Liver_Right_Lobe_Hepatic_Sinusoid()
    LIVER_RIGHT_LOBE_PARENCHYMA = _Liver_Right_Lobe_Parenchyma()
    LIVER_QUADRATE_LOBE = _Liver_Quadrate_Lobe()
    LIVER_QUADRATE_LOBE_HEPATIC_SINUSOID = _Liver_Quadrate_Lobe_Hepatic_Sinusoid()
    LIVER_QUADRATE_LOBE_PARENCHYMA = _Liver_Quadrate_Lobe_Parenchyma()
    BLADDER = _Bladder()
    URACHUS = _Urachus()
    RENAL_MEDULLARY_INTERSTITIUM = _Renal_Medullary_Interstitium()
    MULLERIAN_TUBERCLE = _Mullerian_Tubercle()
    LABIAL_FOLD = _Labial_Fold()
    MEDIASTINUM_TESTIS = _Mediastinum_Testis()
    RETE_TESTIS = _Rete_Testis()
    LARYNX = _Larynx()
    LARYNX_MUCOUS_MEMBRANE = _Larynx_Mucous_Membrane()
    SACRAL_VERTEBRA = _Sacral_Vertebra()
    BASIOCCIPITAL_CARTILAGE_CONDENSATION = _Basioccipital_Cartilage_Condensation()
    BASISPHENOID_CARTILAGE_CONDENSATION = _Basisphenoid_Cartilage_Condensation()
    EXOCCIPITAL_CARTILAGE_CONDENSATION = _Exoccipital_Cartilage_Condensation()
    SPHENOID_BONE = _Sphenoid_Bone()
    SUPRAOCCIPITAL_CARTILAGE_CONDENSATION = _Supraoccipital_Cartilage_Condensation()
    CLAVICLE_CARTILAGE_CONDENSATION = _Clavicle_Cartilage_Condensation()
    SCAPULA_CARTILAGE_CONDENSATION = _Scapula_Cartilage_Condensation()
    STERNUM = _Sternum()
    STERNEBRA_PRE_CARTILAGE_CONDENSATION = _Sternebra_Pre_Cartilage_Condensation()
    ACETABULAR_REGION = _Acetabular_Region()
    ILIUM_CARTILAGE_CONDENSATION = _Ilium_Cartilage_Condensation()
    ISCHIUM_PRE_CARTILAGE_CONDENSATION = _Ischium_Pre_Cartilage_Condensation()
    PUBIS_PRE_CARTILAGE_CONDENSATION = _Pubis_Pre_Cartilage_Condensation()
    SOMITE_56 = _Somite_56()
    SOMITE_56_DERMOMYOTOME = _Somite_56_Dermomyotome()
    SOMITE_56_MYOCOELE = _Somite_56_Myocoele()
    SOMITE_56_SCLEROTOME = _Somite_56_Sclerotome()
    SOMITE_57 = _Somite_57()
    SOMITE_57_DERMOMYOTOME = _Somite_57_Dermomyotome()
    SOMITE_57_MYOCOELE = _Somite_57_Myocoele()
    SOMITE_57_SCLEROTOME = _Somite_57_Sclerotome()
    SOMITE_58 = _Somite_58()
    SOMITE_58_DERMOMYOTOME = _Somite_58_Dermomyotome()
    SOMITE_58_MYOCOELE = _Somite_58_Myocoele()
    SOMITE_58_SCLEROTOME = _Somite_58_Sclerotome()
    SOMITE_59 = _Somite_59()
    SOMITE_59_DERMOMYOTOME = _Somite_59_Dermomyotome()
    SOMITE_59_MYOCOELE = _Somite_59_Myocoele()
    SOMITE_59_SCLEROTOME = _Somite_59_Sclerotome()
    SOMITE_60 = _Somite_60()
    SOMITE_60_DERMOMYOTOME = _Somite_60_Dermomyotome()
    SOMITE_60_MYOCOELE = _Somite_60_Myocoele()
    SOMITE_60_SCLEROTOME = _Somite_60_Sclerotome()
    TAIL_PERIPHERAL_NERVOUS_SYSTEM = _Tail_Peripheral_Nervous_System()
    TAIL_GANGLION = _Tail_Ganglion()
    TAIL_DORSAL_ROOT_GANGLION = _Tail_Dorsal_Root_Ganglion()
    TAIL_VERTEBRA = _Tail_Vertebra()
    FOREGUT_DIVERTICULUM_LUMEN = _Foregut_Diverticulum_Lumen()
    HINDGUT_DIVERTICULUM_LUMEN = _Hindgut_Diverticulum_Lumen()
    MIDGUT_LUMEN = _Midgut_Lumen()
    DUODENUM_ROSTRAL_PART_LUMEN = _Duodenum_Rostral_Part_Lumen()
    GASTRO_ESOPHAGEAL_JUNCTION_LUMEN = _Gastro_Esophageal_Junction_Lumen()
    ESOPHAGUS_LUMEN = _Esophagus_Lumen()
    PHARYNX_LUMEN = _Pharynx_Lumen()
    STOMACH_FUNDUS_LUMEN = _Stomach_Fundus_Lumen()
    STOMACH_GLANDULAR_REGION_LUMEN = _Stomach_Glandular_Region_Lumen()
    STOMACH_PROVENTRICULAR_REGION_LUMEN = _Stomach_Proventricular_Region_Lumen()
    STOMACH_PYLORIC_REGION_LUMEN = _Stomach_Pyloric_Region_Lumen()
    FOREGUT_MIDGUT_JUNCTION_LUMEN = _Foregut_Midgut_Junction_Lumen()
    PERINEAL_BODY_LUMEN = _Perineal_Body_Lumen()
    RECTUM_LUMEN = _Rectum_Lumen()
    DUODENUM_CAUDAL_PART_LUMEN = _Duodenum_Caudal_Part_Lumen()
    MIDGUT_LOOP_LUMEN = _Midgut_Loop_Lumen()
    ANAL_CANAL_CAUDAL_PART_LUMEN = _Anal_Canal_Caudal_Part_Lumen()
    ANAL_CANAL_ROSTRAL_PART_LUMEN = _Anal_Canal_Rostral_Part_Lumen()
    STOMACH_LUMEN = _Stomach_Lumen()
    HINDGUT_LUMEN = _Hindgut_Lumen()
    HINDGUT_DIVERTICULUM_POSTANAL_COMPONENT_LUMEN = _Hindgut_Diverticulum_Postanal_Component_Lumen()
    HINDGUT_DIVERTICULUM_PREANAL_COMPONENT_LUMEN = _Hindgut_Diverticulum_Preanal_Component_Lumen()
    ORAL_REGION_CAVITY = _Oral_Region_Cavity()
    FOREGUT_LUMEN = _Foregut_Lumen()
    ESOPHAGEAL_REGION_LUMEN = _Esophageal_Region_Lumen()
    PHARYNGEAL_REGION_LUMEN = _Pharyngeal_Region_Lumen()
    FOREGUT_MIDGUT_JUNCTION_ENDODERM = _Foregut_Midgut_Junction_Endoderm()
    PHYSIOLOGICAL_UMBILICAL_HERNIA = _Physiological_Umbilical_Hernia()
    PHYSIOLOGICAL_UMBILICAL_HERNIA_DERMIS = _Physiological_Umbilical_Hernia_Dermis()
    PHYSIOLOGICAL_UMBILICAL_HERNIA_EPIDERMIS = _Physiological_Umbilical_Hernia_Epidermis()
    CARINA_TRACHEA = _Carina_Trachea()
    CARINA_TRACHEA_MESENCHYME = _Carina_Trachea_Mesenchyme()
    CARINA_TRACHEA_EPITHELIUM = _Carina_Trachea_Epithelium()
    CARINA_TRACHEA_VASCULAR_ELEMENT = _Carina_Trachea_Vascular_Element()
    GREATER_SAC_VISCERAL_MESOTHELIUM = _Greater_Sac_Visceral_Mesothelium()
    VENA_CAVA = _Vena_Cava()
    INFERIOR_VENA_CAVA = _Inferior_Vena_Cava()
    SUPERIOR_VENA_CAVA = _Superior_Vena_Cava()
    LEFT_SUPERIOR_VENA_CAVA = _Left_Superior_Vena_Cava()
    RIGHT_SUPERIOR_VENA_CAVA = _Right_Superior_Vena_Cava()
    INFERIOR_VENA_CAVA_POST_HEPATIC_PART = _Inferior_Vena_Cava_Post_Hepatic_Part()
    INFERIOR_VENA_CAVA_PRE_HEPATIC_PART = _Inferior_Vena_Cava_Pre_Hepatic_Part()
    INFERIOR_VENA_CAVA_LEFT_POST_HEPATIC_PART = _Inferior_Vena_Cava_Left_Post_Hepatic_Part()
    INFERIOR_VENA_CAVA_RIGHT_POST_HEPATIC_PART = _Inferior_Vena_Cava_Right_Post_Hepatic_Part()
    GLAND = _Gland()
    ADRENAL_GLAND = _Adrenal_Gland()
    ADRENAL_CORTEX = _Adrenal_Cortex()
    ADRENAL_MEDULLA = _Adrenal_Medulla()
    DIAPHRAGM_MESOTHELIUM = _Diaphragm_Mesothelium()
    ELBOW_REST_OF_MESENCHYME = _Elbow_Rest_Of_Mesenchyme()
    FOREARM_REST_OF_MESENCHYME = _Forearm_Rest_Of_Mesenchyme()
    SHOULDER_REST_OF_MESENCHYME = _Shoulder_Rest_Of_Mesenchyme()
    UPPER_ARM_REST_OF_MESENCHYME = _Upper_Arm_Rest_Of_Mesenchyme()
    HIP_REST_OF_MESENCHYME = _Hip_Rest_Of_Mesenchyme()
    KNEE_REST_OF_MESENCHYME = _Knee_Rest_Of_Mesenchyme()
    LOWER_LEG_REST_OF_MESENCHYME = _Lower_Leg_Rest_Of_Mesenchyme()
    UPPER_LEG_REST_OF_MESENCHYME = _Upper_Leg_Rest_Of_Mesenchyme()
    CERVICAL_GANGLION = _Cervical_Ganglion()
    INFERIOR_CERVICAL_GANGLION = _Inferior_Cervical_Ganglion()
    MIDDLE_CERVICAL_GANGLION = _Middle_Cervical_Ganglion()
    SUPERIOR_CERVICAL_GANGLION = _Superior_Cervical_Ganglion()
    NASAL_SEPTUM_EPITHELIUM = _Nasal_Septum_Epithelium()
    NASAL_SEPTUM_MESENCHYME = _Nasal_Septum_Mesenchyme()
    VOMERONASAL_ORGAN_EPITHELIUM = _Vomeronasal_Organ_Epithelium()
    VOMERONASAL_ORGAN_MESENCHYME = _Vomeronasal_Organ_Mesenchyme()
    OTIC_PIT_LUMEN = _Otic_Pit_Lumen()
    OMENTAL_BURSA_CAVITY = _Omental_Bursa_Cavity()
    HAND_SKIN = _Hand_Skin()
    HAND_DERMIS = _Hand_Dermis()
    HAND_EPIDERMIS = _Hand_Epidermis()
    PALMAR_PAD = _Palmar_Pad()
    TARSUS_REST_OF_MESENCHYME = _Tarsus_Rest_Of_Mesenchyme()
    FOOT_SKIN = _Foot_Skin()
    FOOT_DERMIS = _Foot_Dermis()
    FOOT_EPIDERMIS = _Foot_Epidermis()
    PLANTAR_PAD = _Plantar_Pad()
    FABELLA_PRE_CARTILAGE_CONDENSATION = _Fabella_Pre_Cartilage_Condensation()
    PATELLAR_LIGAMENT = _Patellar_Ligament()
    PATELLA_PRE_CARTILAGE_CONDENSATION = _Patella_Pre_Cartilage_Condensation()
    ILIO_PSOAS = _Ilio_Psoas()
    INTERCOSTAL_MUSCLE = _Intercostal_Muscle()
    INTERCOSTAL_MUSCLE_EXTERNAL_LAYER = _Intercostal_Muscle_External_Layer()
    INTERCOSTAL_MUSCLE_INTERNAL_LAYER = _Intercostal_Muscle_Internal_Layer()
    QUADRATUS_LUMBORUM = _Quadratus_Lumborum()
    SERRATUS_VENTRALIS = _Serratus_Ventralis()
    INFRASPINATUS = _Infraspinatus()
    GLUTEUS_MAXIMUS = _Gluteus_Maximus()
    SPLEEN_PRIMORDIUM = _Spleen_Primordium()
    PAROTID_GLAND = _Parotid_Gland()
    PAROTID_GLAND_EPITHELIUM = _Parotid_Gland_Epithelium()
    PAROTID_GLAND_MESENCHYME = _Parotid_Gland_Mesenchyme()
    THYROGLOSSAL_DUCT_MEDIAN_LOBE = _Thyroglossal_Duct_Median_Lobe()
    MAMMARY_LINE = _Mammary_Line()
    EPITHALAMIC_RECESS = _Epithalamic_Recess()
    _3RD_VENTRICLE_CHOROID_PLEXUS = _3Rd_Ventricle_Choroid_Plexus()
    PINEAL_PRIMORDIUM = _Pineal_Primordium()
    INTERTHALAMIC_ADHESION = _Interthalamic_Adhesion()
    HEAD_OF_CAUDATE_NUCLEUS = _Head_Of_Caudate_Nucleus()
    TAIL_OF_CAUDATE_NUCLEUS = _Tail_Of_Caudate_Nucleus()
    HEAD_OF_LATERAL_VENTRICLE = _Head_Of_Lateral_Ventricle()
    TAIL_OF_LATERAL_VENTRICLE = _Tail_Of_Lateral_Ventricle()
    FALX_CEREBRI = _Falx_Cerebri()
    MEDULLARY_RAPHE = _Medullary_Raphe()
    CEREBELLUM_INTRAVENTRICULAR_PORTION = _Cerebellum_Intraventricular_Portion()
    CEREBELLUM_INTRAVENTRICULAR_PORTION_MANTLE_LAYER = _Cerebellum_Intraventricular_Portion_Mantle_Layer()
    CEREBELLUM_INTRAVENTRICULAR_PORTION_MARGINAL_LAYER = _Cerebellum_Intraventricular_Portion_Marginal_Layer()
    CEREBELLUM_INTRAVENTRICULAR_PORTION_VENTRICULAR_LAYER = _Cerebellum_Intraventricular_Portion_Ventricular_Layer()
    REST_OF_CEREBELLUM = _Rest_Of_Cerebellum()
    REST_OF_CEREBELLUM_MANTLE_LAYER = _Rest_Of_Cerebellum_Mantle_Layer()
    REST_OF_CEREBELLUM_MARGINAL_LAYER = _Rest_Of_Cerebellum_Marginal_Layer()
    REST_OF_CEREBELLUM_VENTRICULAR_LAYER = _Rest_Of_Cerebellum_Ventricular_Layer()
    METENCEPHALON_REST_OF_ALAR_PLATE = _Metencephalon_Rest_Of_Alar_Plate()
    METENCEPHALON_REST_OF_ALAR_PLATE_MANTLE_LAYER = _Metencephalon_Rest_Of_Alar_Plate_Mantle_Layer()
    METENCEPHALON_REST_OF_ALAR_PLATE_MARGINAL_LAYER = _Metencephalon_Rest_Of_Alar_Plate_Marginal_Layer()
    METENCEPHALON_REST_OF_ALAR_PLATE_VENTRICULAR_LAYER = _Metencephalon_Rest_Of_Alar_Plate_Ventricular_Layer()
    DORSAL_GREY_HORN = _Dorsal_Grey_Horn()
    VENTRAL_GREY_HORN = _Ventral_Grey_Horn()
    INTERMEDIATE_GREY_HORN = _Intermediate_Grey_Horn()
    SCIATIC_NERVE = _Sciatic_Nerve()
    FUTURE_TYMPANIC_MEMBRANE_ENDOTHELIUM = _Future_Tympanic_Membrane_Endothelium()
    ENDOLYMPHATIC_DUCT = _Endolymphatic_Duct()
    ENDOLYMPHATIC_DUCT_MESENCHYME = _Endolymphatic_Duct_Mesenchyme()
    ENDOLYMPHATIC_DUCT_EPITHELIUM = _Endolymphatic_Duct_Epithelium()
    INCUS = _Incus()
    MALLEUS = _Malleus()
    STAPES = _Stapes()
    STAPEDIUS_MUSCLE = _Stapedius_Muscle()
    TENSOR_TYMPANI_MUSCLE = _Tensor_Tympani_Muscle()
    CONJUNCTIVAL_SAC_LOWER_RECESS = _Conjunctival_Sac_Lower_Recess()
    CONJUNCTIVAL_SAC_UPPER_RECESS = _Conjunctival_Sac_Upper_Recess()
    NEURAL_RETINA = _Neural_Retina()
    RETINA_NERVE_FIBER_LAYER = _Retina_Nerve_Fiber_Layer()
    RETINA_NUCLEAR_LAYER = _Retina_Nuclear_Layer()
    NASAL_MEATUS = _Nasal_Meatus()
    ANTERIOR_NARIS = _Anterior_Naris()
    ANTERIOR_NARIS_EPITHELIUM = _Anterior_Naris_Epithelium()
    EXTERNAL_NARIS_EPITHELIUM = _External_Naris_Epithelium()
    COMMUNICATING_ARTERY = _Communicating_Artery()
    ANTERIOR_COMMUNICATING_ARTERY = _Anterior_Communicating_Artery()
    POSTERIOR_COMMUNICATING_ARTERY = _Posterior_Communicating_Artery()
    AORTA = _Aorta()
    THORACIC_AORTA = _Thoracic_Aorta()
    DESCENDING_THORACIC_AORTA = _Descending_Thoracic_Aorta()
    DESCENDING_AORTA = _Descending_Aorta()
    BRONCHIAL_ARTERY = _Bronchial_Artery()
    CAROTID_ARTERY = _Carotid_Artery()
    EXTERNAL_CAROTID_ARTERY = _External_Carotid_Artery()
    CEREBRAL_ARTERY = _Cerebral_Artery()
    INTERNAL_THORACIC_ARTERY = _Internal_Thoracic_Artery()
    INFERIOR_MESENTERIC_ARTERY = _Inferior_Mesenteric_Artery()
    SUPERIOR_MESENTERIC_ARTERY = _Superior_Mesenteric_Artery()
    OVARIAN_ARTERY = _Ovarian_Artery()
    TESTICULAR_ARTERY = _Testicular_Artery()
    THYROID_ARTERY = _Thyroid_Artery()
    INFERIOR_THYROID_ARTERY = _Inferior_Thyroid_Artery()
    SUPERIOR_THYROID_ARTERY = _Superior_Thyroid_Artery()
    AORTIC_SINUS = _Aortic_Sinus()
    TRABECULAE_CARNEAE = _Trabeculae_Carneae()
    AORTIC_VALVE_LEAFLET = _Aortic_Valve_Leaflet()
    MITRAL_VALVE_LEAFLET = _Mitral_Valve_Leaflet()
    PULMONARY_VALVE_LEAFLET = _Pulmonary_Valve_Leaflet()
    TRICUSPID_VALVE_LEAFLET = _Tricuspid_Valve_Leaflet()
    BRAIN_VENOUS_SYSTEM = _Brain_Venous_System()
    HINDBRAIN_VENOUS_SYSTEM = _Hindbrain_Venous_System()
    HINDBRAIN_VENOUS_SINUS = _Hindbrain_Venous_Sinus()
    HINDBRAIN_VENOUS_DURAL_SINUS = _Hindbrain_Venous_Dural_Sinus()
    INFERIOR_SAGITTAL_SINUS = _Inferior_Sagittal_Sinus()
    SUPERIOR_SAGITTAL_SINUS = _Superior_Sagittal_Sinus()
    TRANSVERSE_SINUS = _Transverse_Sinus()
    JUGULAR_VEIN = _Jugular_Vein()
    INTERNAL_THORACIC_VEIN = _Internal_Thoracic_Vein()
    INFERIOR_MESENTERIC_VEIN = _Inferior_Mesenteric_Vein()
    SUPERIOR_MESENTERIC_VEIN = _Superior_Mesenteric_Vein()
    OVARIAN_VEIN = _Ovarian_Vein()
    PULMONARY_VEIN = _Pulmonary_Vein()
    SUPERIOR_VESICAL_VEIN = _Superior_Vesical_Vein()
    TESTICULAR_VEIN = _Testicular_Vein()
    THYROID_VEIN = _Thyroid_Vein()
    PHARYNX_SKELETON = _Pharynx_Skeleton()
    HYOID = _Hyoid()
    HYOID_GREATER_HORN = _Hyoid_Greater_Horn()
    HYOID_LESSER_HORN = _Hyoid_Lesser_Horn()
    HYOID_BODY = _Hyoid_Body()
    FRENULUM = _Frenulum()
    GREATER_OMENTUM = _Greater_Omentum()
    FOREGUT_MIDGUT_JUNCTION_DUODENUM = _Foregut_Midgut_Junction_Duodenum()
    DUODENAL_PAPILLA = _Duodenal_Papilla()
    SPHINCTER_OF_ODDI = _Sphincter_Of_Oddi()
    RECTUM_MESENTERY = _Rectum_Mesentery()
    RECTUM_DORSAL_MESENTERY = _Rectum_Dorsal_Mesentery()
    JEJUNUM = _Jejunum()
    JEJUNUM_EPITHELIUM = _Jejunum_Epithelium()
    JEJUNUM_VASCULAR_ELEMENT = _Jejunum_Vascular_Element()
    JEJUNUM_MESENTERY = _Jejunum_Mesentery()
    JEJUNUM_DORSAL_MESENTERY = _Jejunum_Dorsal_Mesentery()
    LIVER_LEFT_LOBE_HEPATIC_DUCT = _Liver_Left_Lobe_Hepatic_Duct()
    RENAL_CALYX = _Renal_Calyx()
    MAJOR_CALYX = _Major_Calyx()
    MINOR_CALYX = _Minor_Calyx()
    RENAL_CAPSULE = _Renal_Capsule()
    GENITAL_TUBERCLE_OF_FEMALE = _Genital_Tubercle_Of_Female()
    DUCTUS_DEFERENS = _Ductus_Deferens()
    PENIS = _Penis()
    SEMINIFEROUS_CORD = _Seminiferous_Cord()
    INTERSTITIUM_OF_THE_TESTIS = _Interstitium_Of_The_Testis()
    URETHRA_OF_MALE = _Urethra_Of_Male()
    URETHRAL_FOLD_OF_MALE = _Urethral_Fold_Of_Male()
    RESPIRATORY_SYSTEM_CARTILAGE = _Respiratory_System_Cartilage()
    ARYTENOID_CARTILAGE = _Arytenoid_Cartilage()
    CRICOID_CARTILAGE = _Cricoid_Cartilage()
    LARYNGEAL_CARTILAGE = _Laryngeal_Cartilage()
    THYROID_CARTILAGE = _Thyroid_Cartilage()
    TRACHEA_CARTILAGINOUS_RING = _Trachea_Cartilaginous_Ring()
    BASIOCCIPITAL_BONE = _Basioccipital_Bone()
    BASISPHENOID_BONE = _Basisphenoid_Bone()
    CAROTID_CANAL = _Carotid_Canal()
    EXOCCIPITAL_BONE = _Exoccipital_Bone()
    FORAMEN_OVALE_OF_CHONDROCRANIUM = _Foramen_Ovale_Of_Chondrocranium()
    FORAMEN_ROTUNDUM = _Foramen_Rotundum()
    JUGULAR_FORAMEN = _Jugular_Foramen()
    TEMPORO_MANDIBULAR_JOINT_PRIMORDIUM = _Temporo_Mandibular_Joint_Primordium()
    PARIETAL_BONE = _Parietal_Bone()
    OPTIC_FORAMEN = _Optic_Foramen()
    ORBITAL_FISSURE = _Orbital_Fissure()
    SUPERIOR_ORBITAL_FISSURE = _Superior_Orbital_Fissure()
    ORBITO_SPHENOID = _Orbito_Sphenoid()
    CLAVICLE = _Clavicle()
    SCAPULA = _Scapula()
    MANUBRIUM_STERNI = _Manubrium_Sterni()
    STERNEBRA = _Sternebra()
    XIPHISTERNUM = _Xiphisternum()
    ILIUM = _Ilium()
    ISCHIUM = _Ischium()
    PUBIS = _Pubis()
    JEJUNUM_LUMEN = _Jejunum_Lumen()
    FORELIMB_DIGIT_1_NAIL = _Forelimb_Digit_1_Nail()
    FORELIMB_DIGIT_2_NAIL = _Forelimb_Digit_2_Nail()
    FORELIMB_DIGIT_3_NAIL = _Forelimb_Digit_3_Nail()
    FORELIMB_DIGIT_4_NAIL = _Forelimb_Digit_4_Nail()
    FORELIMB_DIGIT_5_NAIL = _Forelimb_Digit_5_Nail()
    HINDLIMB_DIGIT_1_NAIL = _Hindlimb_Digit_1_Nail()
    HINDLIMB_DIGIT_2_NAIL = _Hindlimb_Digit_2_Nail()
    HINDLIMB_DIGIT_3_NAIL = _Hindlimb_Digit_3_Nail()
    HINDLIMB_DIGIT_4_NAIL = _Hindlimb_Digit_4_Nail()
    HINDLIMB_DIGIT_5_NAIL = _Hindlimb_Digit_5_Nail()
    AXILLARY_ARTERY = _Axillary_Artery()
    EPIGASTRIC_ARTERY = _Epigastric_Artery()
    INFERIOR_EPIGASTRIC_ARTERY = _Inferior_Epigastric_Artery()
    SUPERIOR_EPIGASTRIC_ARTERY = _Superior_Epigastric_Artery()
    INTERCOSTAL_ARTERY = _Intercostal_Artery()
    GREATER_PALATINE_ARTERY = _Greater_Palatine_Artery()
    AXILLARY_VEIN = _Axillary_Vein()
    EPIGASTRIC_VEIN = _Epigastric_Vein()
    INFERIOR_EPIGASTRIC_VEIN = _Inferior_Epigastric_Vein()
    SUPERIOR_EPIGASTRIC_VEIN = _Superior_Epigastric_Vein()
    INTERCOSTAL_VEIN = _Intercostal_Vein()
    INFERIOR_THYROID_VEIN = _Inferior_Thyroid_Vein()
    SUPERIOR_THYROID_VEIN = _Superior_Thyroid_Vein()
    HEMOLYMPHOID_SYSTEM = _Hemolymphoid_System()
    HEMOLYMPHOID_SYSTEM_GLAND = _Hemolymphoid_System_Gland()
    SPLEEN = _Spleen()
    THYMUS = _Thymus()
    HAIR = _Hair()
    HAIR_BULB = _Hair_Bulb()
    HAIR_FOLLICLE = _Hair_Follicle()
    HAIR_ROOT_SHEATH = _Hair_Root_Sheath()
    PINEAL_GLAND = _Pineal_Gland()
    ANTERIOR_HORN_OF_LATERAL_VENTRICLE_CHOROID_PLEXUS = _Anterior_Horn_Of_Lateral_Ventricle_Choroid_Plexus()
    LATERAL_VENTRICLE_INFERIOR_HORN_CHOROID_PLEXUS = _Lateral_Ventricle_Inferior_Horn_Choroid_Plexus()
    POSTERIOR_HORN_OF_LATERAL_VENTRICLE_CHOROID_PLEXUS = _Posterior_Horn_Of_Lateral_Ventricle_Choroid_Plexus()
    SUPERIOR_HORN_OF_LATERAL_VENTRICLE_CHOROID_PLEXUS = _Superior_Horn_Of_Lateral_Ventricle_Choroid_Plexus()
    HEAD_OF_LATERAL_VENTRICLE_CHOROID_PLEXUS = _Head_Of_Lateral_Ventricle_Choroid_Plexus()
    TAIL_OF_LATERAL_VENTRICLE_CHOROID_PLEXUS = _Tail_Of_Lateral_Ventricle_Choroid_Plexus()
    MEDULLA_OBLONGATA_REST_OF_BASAL_PLATE = _Medulla_Oblongata_Rest_Of_Basal_Plate()
    MEDULLA_OBLONGATA_REST_OF_BASAL_PLATE_MANTLE_LAYER = _Medulla_Oblongata_Rest_Of_Basal_Plate_Mantle_Layer()
    MEDULLA_OBLONGATA_REST_OF_BASAL_PLATE_MARGINAL_LAYER = _Medulla_Oblongata_Rest_Of_Basal_Plate_Marginal_Layer()
    MEDULLA_OBLONGATA_REST_OF_BASAL_PLATE_VENTRICULAR_LAYER = _Medulla_Oblongata_Rest_Of_Basal_Plate_Ventricular_Layer()
    MEDULLARY_RAPHE_MANTLE_LAYER = _Medullary_Raphe_Mantle_Layer()
    MEDULLARY_RAPHE_MARGINAL_LAYER = _Medullary_Raphe_Marginal_Layer()
    MEDULLARY_RAPHE_VENTRICULAR_LAYER = _Medullary_Raphe_Ventricular_Layer()
    TEMPORAL_LOBE = _Temporal_Lobe()
    TEMPORAL_LOBE_MARGINAL_LAYER = _Temporal_Lobe_Marginal_Layer()
    TEMPORAL_LOBE_VENTRICULAR_LAYER = _Temporal_Lobe_Ventricular_Layer()
    AXILLARY_NERVE = _Axillary_Nerve()
    OTIC_CARTILAGE = _Otic_Cartilage()
    DESCEMET_S_MEMBRANE = _Descemet_S_Membrane()
    EYE_SMOOTH_MUSCLE = _Eye_Smooth_Muscle()
    INTRINSIC_OCULAR_MUSCLE = _Intrinsic_Ocular_Muscle()
    SUBLINGUAL_GLAND = _Sublingual_Gland()
    SUBLINGUAL_GLAND_EPITHELIUM = _Sublingual_Gland_Epithelium()
    SUBLINGUAL_GLAND_MESENCHYME = _Sublingual_Gland_Mesenchyme()
    SUBMANDIBULAR_GLAND = _Submandibular_Gland()
    SUBMANDIBULAR_GLAND_EPITHELIUM = _Submandibular_Gland_Epithelium()
    SUBMANDIBULAR_GLAND_MESENCHYME = _Submandibular_Gland_Mesenchyme()
    GUT_GLAND = _Gut_Gland()
    ANAL_CANAL_EPITHELIUM = _Anal_Canal_Epithelium()
    ANAL_CANAL_LUMEN = _Anal_Canal_Lumen()
    ANAL_CANAL_VASCULAR_ELEMENT = _Anal_Canal_Vascular_Element()
    DUODENUM = _Duodenum()
    FILIFORM_PAPILLAE = _Filiform_Papillae()
    PERINEAL_BODY_MUSCLE = _Perineal_Body_Muscle()
    COLON = _Colon()
    COLON_EPITHELIUM = _Colon_Epithelium()
    COLON_MESENTERY = _Colon_Mesentery()
    COLON_DORSAL_MESENTERY = _Colon_Dorsal_Mesentery()
    COLON_VASCULAR_ELEMENT = _Colon_Vascular_Element()
    COLON_LUMEN = _Colon_Lumen()
    SECONDARY_PALATE = _Secondary_Palate()
    SOFT_PALATE = _Soft_Palate()
    SOFT_PALATE_EPITHELIUM = _Soft_Palate_Epithelium()
    SOFT_PALATE_MESENCHYME = _Soft_Palate_Mesenchyme()
    HARD_PALATE = _Hard_Palate()
    HARD_PALATE_EPITHELIUM = _Hard_Palate_Epithelium()
    HARD_PALATE_MESENCHYME = _Hard_Palate_Mesenchyme()
    NASOPALATINE_DUCT = _Nasopalatine_Duct()
    SUBLINGUAL_CARUNCLE = _Sublingual_Caruncle()
    SULCUS_TERMINALIS = _Sulcus_Terminalis()
    PHARYNX_SKELETAL_MUSCLE = _Pharynx_Skeletal_Muscle()
    PHARYNGEAL_CONSTRICTOR_MUSCLE = _Pharyngeal_Constrictor_Muscle()
    INFERIOR_PHARYNGEAL_CONSTRICTOR_MUSCLE = _Inferior_Pharyngeal_Constrictor_Muscle()
    SUPERIOR_PHARYNGEAL_CONSTRICTOR_MUSCLE = _Superior_Pharyngeal_Constrictor_Muscle()
    LOWER_JAW_GUM = _Lower_Jaw_Gum()
    LOWER_JAW_GUM_EPITHELIUM = _Lower_Jaw_Gum_Epithelium()
    LOWER_JAW_GUM_MESENCHYME = _Lower_Jaw_Gum_Mesenchyme()
    UPPER_JAW_GUM = _Upper_Jaw_Gum()
    UPPER_JAW_GUM_EPITHELIUM = _Upper_Jaw_Gum_Epithelium()
    UPPER_JAW_GUM_MESENCHYME = _Upper_Jaw_Gum_Mesenchyme()
    CORTICAL_RENAL_TUBULE = _Cortical_Renal_Tubule()
    FEMALE_CYSTIC_VESICULAR_APPENDAGE = _Female_Cystic_Vesicular_Appendage()
    OVIDUCT = _Oviduct()
    UTERINE_HORN = _Uterine_Horn()
    VAGINA = _Vagina()
    UPPER_VAGINA = _Upper_Vagina()
    GLANS_PENIS = _Glans_Penis()
    PREPUCE_OF_MALE = _Prepuce_Of_Male()
    EFFERENT_DUCT_OF_SEMINAL_VESICLE = _Efferent_Duct_Of_Seminal_Vesicle()
    PELVIC_URETHRA_OF_MALE = _Pelvic_Urethra_Of_Male()
    SINOVAGINAL_BULB = _Sinovaginal_Bulb()
    LEFT_LUNG_BRONCHIOLE = _Left_Lung_Bronchiole()
    LEFT_LUNG_ALVEOLAR_SYSTEM = _Left_Lung_Alveolar_System()
    RIGHT_LUNG_ACCESSORY_LOBE_BRONCHIOLE = _Right_Lung_Accessory_Lobe_Bronchiole()
    RIGHT_LUNG_ACCESSORY_LOBE_ALVEOLAR_SYSTEM = _Right_Lung_Accessory_Lobe_Alveolar_System()
    RIGHT_LUNG_CAUDAL_LOBE_BRONCHIOLE = _Right_Lung_Caudal_Lobe_Bronchiole()
    RIGHT_LUNG_CAUDAL_LOBE_ALVEOLAR_SYSTEM = _Right_Lung_Caudal_Lobe_Alveolar_System()
    RIGHT_LUNG_CRANIAL_LOBE_BRONCHIOLE = _Right_Lung_Cranial_Lobe_Bronchiole()
    RIGHT_LUNG_CRANIAL_LOBE_ALVEOLAR_SYSTEM = _Right_Lung_Cranial_Lobe_Alveolar_System()
    RIGHT_LUNG_MIDDLE_LOBE_BRONCHIOLE = _Right_Lung_Middle_Lobe_Bronchiole()
    RIGHT_LUNG_MIDDLE_LOBE_ALVEOLAR_SYSTEM = _Right_Lung_Middle_Lobe_Alveolar_System()
    CRUCIATE_LIGAMENT_OF_ATLAS = _Cruciate_Ligament_Of_Atlas()
    HYPOGLOSSAL_CANAL = _Hypoglossal_Canal()
    SPHENOIDAL_CANAL = _Sphenoidal_Canal()
    ZYGOMATIC_PROCESS = _Zygomatic_Process()
    FRONTAL_BONE = _Frontal_Bone()
    INTER_PARIETAL_BONE = _Inter_Parietal_Bone()
    ETHMOID_BONE = _Ethmoid_Bone()
    FACIAL_BONE = _Facial_Bone()
    COSTO_VERTEBRAL_JOINT = _Costo_Vertebral_Joint()
    SYNOVIAL_CAVITY_OF_HIP_BONE = _Synovial_Cavity_Of_Hip_Bone()
    TEMPORAL_LOBE_MANTLE_LAYER = _Temporal_Lobe_Mantle_Layer()
    SCLERA = _Sclera()
    PEYER_S_PATCH = _Peyer_S_Patch()
    FIBROUS_PERICARDIUM = _Fibrous_Pericardium()
    SEROSAL_PERICARDIUM = _Serosal_Pericardium()
    PARIETAL_SEROSAL_PERICARDIUM = _Parietal_Serosal_Pericardium()
    VISCERAL_SEROSAL_PERICARDIUM = _Visceral_Serosal_Pericardium()
    INCISIVE_CANAL = _Incisive_Canal()
    C1_VERTEBRA_HYPOCHORDAL_ARCH = _C1_Vertebra_Hypochordal_Arch()
    PINEAL_GLAND_STALK = _Pineal_Gland_Stalk()
    DENTATE_GYRUS = _Dentate_Gyrus()
    ANTERIOR_COMMISSURE = _Anterior_Commissure()
    HIPPOCAMPUS_MANTLE_LAYER = _Hippocampus_Mantle_Layer()
    HIPPOCAMPUS_MARGINAL_LAYER = _Hippocampus_Marginal_Layer()
    ALLOCORTEX = _Allocortex()
    HIPPOCAMPUS_VENTRICULAR_LAYER = _Hippocampus_Ventricular_Layer()
    ALLOCORTEX_MANTLE_LAYER = _Allocortex_Mantle_Layer()
    ALLOCORTEX_MARGINAL_LAYER = _Allocortex_Marginal_Layer()
    ALLOCORTEX_VENTRICULAR_LAYER = _Allocortex_Ventricular_Layer()
    CEREBELLUM_DORSAL_PART = _Cerebellum_Dorsal_Part()
    CEREBELLUM_DORSAL_PART_MANTLE_LAYER = _Cerebellum_Dorsal_Part_Mantle_Layer()
    CEREBELLUM_DORSAL_PART_MARGINAL_LAYER = _Cerebellum_Dorsal_Part_Marginal_Layer()
    CEREBELLUM_DORSAL_PART_VENTRICULAR_LAYER = _Cerebellum_Dorsal_Part_Ventricular_Layer()
    TECTUM = _Tectum()
    MIDBRAIN_ROOF_PLATE_CAUDAL_PART = _Midbrain_Roof_Plate_Caudal_Part()
    DIENCEPHALON_SUBARACHNOID_SPACE = _Diencephalon_Subarachnoid_Space()
    TELENCEPHALON_SUBARACHNOID_SPACE = _Telencephalon_Subarachnoid_Space()
    MIDBRAIN_SUBARACHNOID_SPACE = _Midbrain_Subarachnoid_Space()
    INTERPEDUNCULAR_CISTERN = _Interpeduncular_Cistern()
    CISTERNA_CHIASMATICA = _Cisterna_Chiasmatica()
    CAVERNOUS_SINUS = _Cavernous_Sinus()
    SIGMOID_SINUS = _Sigmoid_Sinus()
    ORGAN_OF_CORTI = _Organ_Of_Corti()
    TYMPANIC_MEMBRANE = _Tympanic_Membrane()
    TYMPANIC_MEMBRANE_ENDOTHELIUM = _Tympanic_Membrane_Endothelium()
    TYMPANIC_MEMBRANE_EPITHELIUM = _Tympanic_Membrane_Epithelium()
    CILIARY_BODY = _Ciliary_Body()
    MEDULLA_OBLONGATA_PART_OF_4TH_VENTRICLE_CHOROID_PLEXUS = _Medulla_Oblongata_Part_Of_4Th_Ventricle_Choroid_Plexus()
    OPTIC_CHOROID = _Optic_Choroid()
    DUODENUM_EPITHELIUM = _Duodenum_Epithelium()
    DUODENUM_LUMEN = _Duodenum_Lumen()
    DUODENUM_MESENTERY = _Duodenum_Mesentery()
    MESODUODENUM = _Mesoduodenum()
    DUODENUM_VASCULAR_ELEMENT = _Duodenum_Vascular_Element()
    GASTRO_ESOPHAGEAL_JUNCTION_MESENTERY = _Gastro_Esophageal_Junction_Mesentery()
    SUSPENSORY_LIGAMENT_OF_OVARY = _Suspensory_Ligament_Of_Ovary()
    APPENDIX_EPIDIDYMIS = _Appendix_Epididymis()
    APPENDIX_TESTIS = _Appendix_Testis()
    EJACULATORY_DUCT = _Ejaculatory_Duct()
    GUBERNACULUM_OF_MALE = _Gubernaculum_Of_Male()
    LARYNX_ADITUS = _Larynx_Aditus()
    MAIN_BRONCHUS_CARTILAGE = _Main_Bronchus_Cartilage()
    CAUDATE_PUTAMEN = _Caudate_Putamen()
    LUMBAR_ARTERY = _Lumbar_Artery()
    SUBCOSTAL_ARTERY = _Subcostal_Artery()
    REST_OF_UPPER_LIP = _Rest_Of_Upper_Lip()
    LEFT_HEPATIC_DUCT_EXTRAHEPATIC_PART = _Left_Hepatic_Duct_Extrahepatic_Part()
    RIGHT_HEPATIC_DUCT_EXTRAHEPATIC_PART = _Right_Hepatic_Duct_Extrahepatic_Part()
    COMMON_HEPATIC_DUCT = _Common_Hepatic_Duct()
    ELBOW_JOINT = _Elbow_Joint()
    RADIUS = _Radius()
    ULNA = _Ulna()
    SHOULDER_JOINT = _Shoulder_Joint()
    HUMERUS = _Humerus()
    UPPER_ARM_MUSCLE = _Upper_Arm_Muscle()
    BICEPS_BRACHII = _Biceps_Brachii()
    BRACHIALIS = _Brachialis()
    TERES_MAJOR = _Teres_Major()
    TRICEPS_BRACHII = _Triceps_Brachii()
    FORELIMB_DIGIT_1_METACARPAL = _Forelimb_Digit_1_Metacarpal()
    FORELIMB_DIGIT_1_PHALANX = _Forelimb_Digit_1_Phalanx()
    FORELIMB_DIGIT_2_METACARPAL = _Forelimb_Digit_2_Metacarpal()
    FORELIMB_DIGIT_2_PHALANX = _Forelimb_Digit_2_Phalanx()
    FORELIMB_DIGIT_3_METACARPAL = _Forelimb_Digit_3_Metacarpal()
    FORELIMB_DIGIT_3_PHALANX = _Forelimb_Digit_3_Phalanx()
    FORELIMB_DIGIT_4_METACARPAL = _Forelimb_Digit_4_Metacarpal()
    FORELIMB_DIGIT_4_PHALANX = _Forelimb_Digit_4_Phalanx()
    FORELIMB_DIGIT_5_METACARPAL = _Forelimb_Digit_5_Metacarpal()
    FORELIMB_DIGIT_5_PHALANX = _Forelimb_Digit_5_Phalanx()
    CARPUS = _Carpus()
    HINDLIMB_DIGIT_1_METATARSAL = _Hindlimb_Digit_1_Metatarsal()
    HINDLIMB_DIGIT_1_PHALANX = _Hindlimb_Digit_1_Phalanx()
    HINDLIMB_DIGIT_2_METATARSAL = _Hindlimb_Digit_2_Metatarsal()
    HINDLIMB_DIGIT_2_PHALANX = _Hindlimb_Digit_2_Phalanx()
    HINDLIMB_DIGIT_3_METATARSAL = _Hindlimb_Digit_3_Metatarsal()
    HINDLIMB_DIGIT_3_PHALANX = _Hindlimb_Digit_3_Phalanx()
    HINDLIMB_DIGIT_4_METATARSAL = _Hindlimb_Digit_4_Metatarsal()
    HINDLIMB_DIGIT_4_PHALANX = _Hindlimb_Digit_4_Phalanx()
    HINDLIMB_DIGIT_5_METATARSAL = _Hindlimb_Digit_5_Metatarsal()
    HINDLIMB_DIGIT_5_PHALANX = _Hindlimb_Digit_5_Phalanx()
    TARSUS = _Tarsus()
    CALCANEUS = _Calcaneus()
    TALUS = _Talus()
    HIP_JOINT = _Hip_Joint()
    KNEE_JOINT = _Knee_Joint()
    FABELLA_CARTILAGE_CONDENSATION = _Fabella_Cartilage_Condensation()
    PATELLA_CARTILAGE_CONDENSATION = _Patella_Cartilage_Condensation()
    FIBULA = _Fibula()
    TIBIA = _Tibia()
    FEMUR = _Femur()
    UPPER_LEG_MUSCLE = _Upper_Leg_Muscle()
    HAMSTRING_MUSCLE = _Hamstring_Muscle()
    QUADRICEPS_FEMORIS_MUSCLE = _Quadriceps_Femoris_Muscle()
    LENTICULAR_NUCLEUS = _Lenticular_Nucleus()
    ORBITAL_FAT_PAD = _Orbital_Fat_Pad()
    HARDERIAN_GLAND = _Harderian_Gland()
    IRIS = _Iris()
    RETINA_INNER_NUCLEAR_LAYER = _Retina_Inner_Nuclear_Layer()
    NEURAL_RETINA_INTERMEDIATE_ANUCLEAR_LAYER = _Neural_Retina_Intermediate_Anuclear_Layer()
    RETINA_OUTER_NUCLEAR_LAYER = _Retina_Outer_Nuclear_Layer()
    PECTINATE_LINE = _Pectinate_Line()
    CORONARY_ARTERY = _Coronary_Artery()
    MANDIBULAR_CANAL = _Mandibular_Canal()
    GLUTEUS_MEDIUS = _Gluteus_Medius()
    ILIACUS = _Iliacus()
    LEVATOR_ANI = _Levator_Ani()
    ADDUCTOR_MUSCLE_OF_LEG = _Adductor_Muscle_Of_Leg()
    TRIGEMINAL_NERVE_LINGUAL_BRANCH = _Trigeminal_Nerve_Lingual_Branch()
    GLANS_OF_FEMALE_GENITAL_TUBERCLE = _Glans_Of_Female_Genital_Tubercle()
    FEMALE_INGUINAL_CANAL = _Female_Inguinal_Canal()
    FEMALE_INGUINAL_RING = _Female_Inguinal_Ring()
    FEMALE_INTERNAL_INGUINAL_RING = _Female_Internal_Inguinal_Ring()
    FEMALE_EXTERNAL_INGUINAL_RING = _Female_External_Inguinal_Ring()
    REST_OF_INTERSTITIUM_OF_THE_TESTIS = _Rest_Of_Interstitium_Of_The_Testis()
    TUNICA_VAGINALIS_TESTIS = _Tunica_Vaginalis_Testis()
    SEMINAL_VESICLE = _Seminal_Vesicle()
    VOCAL_FOLDS = _Vocal_Folds()
    LEFT_LUNG_ALVEOLUS = _Left_Lung_Alveolus()
    LEFT_LUNG_ALVEOLAR_DUCT = _Left_Lung_Alveolar_Duct()
    RIGHT_LUNG_MIDDLE_LOBE_ALVEOLUS = _Right_Lung_Middle_Lobe_Alveolus()
    RIGHT_LUNG_MIDDLE_LOBE_ALVEOLAR_DUCT = _Right_Lung_Middle_Lobe_Alveolar_Duct()
    RIGHT_LUNG_CRANIAL_LOBE_ALVEOLUS = _Right_Lung_Cranial_Lobe_Alveolus()
    RIGHT_LUNG_CRANIAL_LOBE_ALVEOLAR_DUCT = _Right_Lung_Cranial_Lobe_Alveolar_Duct()
    RIGHT_LUNG_CAUDAL_LOBE_ALVEOLUS = _Right_Lung_Caudal_Lobe_Alveolus()
    RIGHT_LUNG_CAUDAL_LOBE_ALVEOLAR_DUCT = _Right_Lung_Caudal_Lobe_Alveolar_Duct()
    RIGHT_LUNG_ACCESSORY_LOBE_ALVEOLUS = _Right_Lung_Accessory_Lobe_Alveolus()
    RIGHT_LUNG_ACCESSORY_LOBE_ALVEOLAR_DUCT = _Right_Lung_Accessory_Lobe_Alveolar_Duct()
    TRACHEA_SMOOTH_MUSCLE = _Trachea_Smooth_Muscle()
    TRACHEALIS = _Trachealis()
    CRANIOPHARYNGEAL_CANAL = _Craniopharyngeal_Canal()
    PITUITARY_FOSSA = _Pituitary_Fossa()
    TEMPORO_MANDIBULAR_JOINT = _Temporo_Mandibular_Joint()
    TYMPANIC_RING = _Tympanic_Ring()
    SUTURE = _Suture()
    ANTERIOR_FONTANELLE = _Anterior_Fontanelle()
    POSTERIOR_FONTANELLE = _Posterior_Fontanelle()
    ETHMOID_BONE_CRIBRIFORM_PLATE = _Ethmoid_Bone_Cribriform_Plate()
    NASAL_BONE = _Nasal_Bone()
    STERNO_CLAVICULAR_JOINT = _Sterno_Clavicular_Joint()
    FORELIMB_JOINT = _Forelimb_Joint()
    RADIO_CARPAL_JOINT = _Radio_Carpal_Joint()
    RADIO_ULNAR_JOINT = _Radio_Ulnar_Joint()
    LIGAMENTUM_NUCHAE = _Ligamentum_Nuchae()
    BROWN_FAT = _Brown_Fat()
    EPICRANIAL_APONEUROSIS = _Epicranial_Aponeurosis()
    CAROTID_BODY = _Carotid_Body()
    CELIAC_TRUNK = _Celiac_Trunk()
    FACIAL_ARTERY = _Facial_Artery()
    MEDIAN_SACRAL_ARTERY = _Median_Sacral_Artery()
    MUSCULO_PHRENIC_ARTERY = _Musculo_Phrenic_Artery()
    SPLENIC_ARTERY = _Splenic_Artery()
    ACCESSORY_HEMIAZYGOS_VEIN = _Accessory_Hemiazygos_Vein()
    DEEP_DORSAL_VEIN_OF_CLITORIS = _Deep_Dorsal_Vein_Of_Clitoris()
    DEEP_DORSAL_VEIN_OF_PENIS = _Deep_Dorsal_Vein_Of_Penis()
    FACIAL_VEIN = _Facial_Vein()
    HEPATIC_VEIN = _Hepatic_Vein()
    MUSCULO_PHRENIC_VEIN = _Musculo_Phrenic_Vein()
    SAGITTAL_SUTURE = _Sagittal_Suture()
    CORONAL_SUTURE = _Coronal_Suture()
    FRONTAL_SUTURE = _Frontal_Suture()
    LAMBDOID_SUTURE = _Lambdoid_Suture()
    SQUAMO_PARIETAL_SUTURE = _Squamo_Parietal_Suture()
    SPHENOIDAL_FONTANELLE = _Sphenoidal_Fontanelle()
    INFERIOR_PETROSAL_SINUS = _Inferior_Petrosal_Sinus()
    PINEAL_VENOUS_PLEXUS = _Pineal_Venous_Plexus()
    ARCUATE_LIGAMENT = _Arcuate_Ligament()
    MEDIAL_ARCUATE_LIGAMENT = _Medial_Arcuate_Ligament()
    LATERAL_ARCUATE_LIGAMENT = _Lateral_Arcuate_Ligament()
    FENESTRA_COCHLEAE = _Fenestra_Cochleae()
    FENESTRA_VESTIBULI = _Fenestra_Vestibuli()
    INFERIOR_OLIVARY_NUCLEUS = _Inferior_Olivary_Nucleus()
    HYALOID_ARTERY = _Hyaloid_Artery()
    LENS_EMBRYONIC_NUCLEUS = _Lens_Embryonic_Nucleus()
    LENS_POSTERIOR_SUTURE = _Lens_Posterior_Suture()
    LACRIMAL_DRAINAGE_SYSTEM = _Lacrimal_Drainage_System()
    PANCREAS_BODY_ISLETS_OF_LANGERHANS = _Pancreas_Body_Islets_Of_Langerhans()
    PANCREAS_HEAD_ISLETS_OF_LANGERHANS = _Pancreas_Head_Islets_Of_Langerhans()
    PANCREAS_TAIL_ISLETS_OF_LANGERHANS = _Pancreas_Tail_Islets_Of_Langerhans()
    PHARYNGEAL_LIGAMENT = _Pharyngeal_Ligament()
    PHARYNGEAL_TUBERCLE = _Pharyngeal_Tubercle()
    PYLORIC_SPHINCTER = _Pyloric_Sphincter()
    LARGE_INTESTINE = _Large_Intestine()
    MIDGUT_DERIVED_LARGE_INTESTINE = _Midgut_Derived_Large_Intestine()
    HINDGUT_DERIVED_LARGE_INTESTINE = _Hindgut_Derived_Large_Intestine()
    MIDGUT_DERIVED_LARGE_INTESTINE_MESENCHYME = _Midgut_Derived_Large_Intestine_Mesenchyme()
    HINDGUT_DERIVED_LARGE_INTESTINE_MESENCHYME = _Hindgut_Derived_Large_Intestine_Mesenchyme()
    MIDGUT_DERIVED_LARGE_INTESTINE_EPITHELIUM = _Midgut_Derived_Large_Intestine_Epithelium()
    MIDGUT_DERIVED_LARGE_INTESTINE_LUMEN = _Midgut_Derived_Large_Intestine_Lumen()
    MIDGUT_DERIVED_LARGE_INTESTINE_MESENTERY = _Midgut_Derived_Large_Intestine_Mesentery()
    MIDGUT_DERIVED_LARGE_INTESTINE_DORSAL_MESENTERY = _Midgut_Derived_Large_Intestine_Dorsal_Mesentery()
    MIDGUT_DERIVED_LARGE_INTESTINE_VASCULAR_ELEMENT = _Midgut_Derived_Large_Intestine_Vascular_Element()
    HINDGUT_DERIVED_LARGE_INTESTINE_EPITHELIUM = _Hindgut_Derived_Large_Intestine_Epithelium()
    HINDGUT_DERIVED_LARGE_INTESTINE_LUMEN = _Hindgut_Derived_Large_Intestine_Lumen()
    HINDGUT_DERIVED_LARGE_INTESTINE_MESENTERY = _Hindgut_Derived_Large_Intestine_Mesentery()
    HINDGUT_DERIVED_LARGE_INTESTINE_DORSAL_MESENTERY = _Hindgut_Derived_Large_Intestine_Dorsal_Mesentery()
    HINDGUT_DERIVED_LARGE_INTESTINE_VASCULAR_ELEMENT = _Hindgut_Derived_Large_Intestine_Vascular_Element()
    TRANSVERSUS_THORACIS = _Transversus_Thoracis()
    INFRAHYOID_MUSCLE = _Infrahyoid_Muscle()
    CRICOTHYROID = _Cricothyroid()
    STERNOHYOID_MUSCLE = _Sternohyoid_Muscle()
    STERNOTHYROID_MUSCLE = _Sternothyroid_Muscle()
    THYROHYOID_MUSCLE = _Thyrohyoid_Muscle()
    SUPERIOR_HYPOGASTRIC_PLEXUS = _Superior_Hypogastric_Plexus()
    INFERIOR_HYPOGASTRIC_PLEXUS = _Inferior_Hypogastric_Plexus()
    SUPERIOR_NASAL_MEATUS = _Superior_Nasal_Meatus()
    MIDDLE_NASAL_MEATUS = _Middle_Nasal_Meatus()
    INFERIOR_NASAL_MEATUS = _Inferior_Nasal_Meatus()
    RENAL_MEDULLA = _Renal_Medulla()
    LOOP_OF_HENLE = _Loop_Of_Henle()
    MALE_ACCESSORY_GLAND = _Male_Accessory_Gland()
    BULBOURETHRAL_GLAND_OF_MALE = _Bulbourethral_Gland_Of_Male()
    PROSTATE_GLAND = _Prostate_Gland()
    TUNICA_ALBUGINEA_OF_TESTIS = _Tunica_Albuginea_Of_Testis()
    EPIDIDYMIS = _Epididymis()
    CAPUT_EPIDIDYMIS = _Caput_Epididymis()
    CAUDA_EPIDIDYMIS = _Cauda_Epididymis()
    CORPUS_EPIDIDYMIS = _Corpus_Epididymis()
    PENILE_BODY = _Penile_Body()
    SCROTUM = _Scrotum()
    SACRO_ILIAC_JOINT = _Sacro_Iliac_Joint()
    METACARPAL_PHALANGEAL_JOINT = _Metacarpal_Phalangeal_Joint()
    SPLEEN_HILUM = _Spleen_Hilum()
    SPLEEN_MEDULLARY_REGION = _Spleen_Medullary_Region()
    THYMUS_MEDULLARY_CORE = _Thymus_Medullary_Core()
    THYMUS_THIN_FIBROUS_CAPSULE = _Thymus_Thin_Fibrous_Capsule()
    THYROID_GLAND_LEFT_LOBE_COLLOID_FILLED_FOLLICLES = _Thyroid_Gland_Left_Lobe_Colloid_Filled_Follicles()
    THYROID_GLAND_RIGHT_LOBE_COLLOID_FILLED_FOLLICLES = _Thyroid_Gland_Right_Lobe_Colloid_Filled_Follicles()
    SUPERIOR_CEREBELLAR_ARTERY = _Superior_Cerebellar_Artery()
    THORACIC_DUCT = _Thoracic_Duct()
    GREAT_CEREBRAL_VEIN_OF_GALEN = _Great_Cerebral_Vein_Of_Galen()
    LINGUAL_VEIN = _Lingual_Vein()
    OPHTHALMIC_VEIN = _Ophthalmic_Vein()
    GREATER_PALATINE_VEIN = _Greater_Palatine_Vein()
    SUPERFICIAL_TEMPORAL_VEIN = _Superficial_Temporal_Vein()
    DISTAL_RADIO_ULNAR_JOINT = _Distal_Radio_Ulnar_Joint()
    PROXIMAL_RADIO_ULNAR_JOINT = _Proximal_Radio_Ulnar_Joint()
    LOWER_LEG_MUSCLE = _Lower_Leg_Muscle()
    FLEXOR_DIGITORUM_PROFUNDUS = _Flexor_Digitorum_Profundus()
    CAROTID_SINUS = _Carotid_Sinus()
    CELIAC_GANGLION = _Celiac_Ganglion()
    ANNULAR_LIGAMENT = _Annular_Ligament()
    C1_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _C1_Vertebral_Pre_Cartilage_Condensation()
    C2_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _C2_Vertebral_Pre_Cartilage_Condensation()
    C3_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _C3_Vertebral_Pre_Cartilage_Condensation()
    C4_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _C4_Vertebral_Pre_Cartilage_Condensation()
    C5_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _C5_Vertebral_Pre_Cartilage_Condensation()
    C6_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _C6_Vertebral_Pre_Cartilage_Condensation()
    C7_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _C7_Vertebral_Pre_Cartilage_Condensation()
    T1_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T1_Vertebral_Pre_Cartilage_Condensation()
    T2_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T2_Vertebral_Pre_Cartilage_Condensation()
    T3_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T3_Vertebral_Pre_Cartilage_Condensation()
    T4_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T4_Vertebral_Pre_Cartilage_Condensation()
    T5_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T5_Vertebral_Pre_Cartilage_Condensation()
    C1_VERTEBRAL_CARTILAGE_CONDENSATION = _C1_Vertebral_Cartilage_Condensation()
    C2_VERTEBRAL_CARTILAGE_CONDENSATION = _C2_Vertebral_Cartilage_Condensation()
    C3_VERTEBRAL_CARTILAGE_CONDENSATION = _C3_Vertebral_Cartilage_Condensation()
    C4_VERTEBRAL_CARTILAGE_CONDENSATION = _C4_Vertebral_Cartilage_Condensation()
    C5_VERTEBRAL_CARTILAGE_CONDENSATION = _C5_Vertebral_Cartilage_Condensation()
    L1_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _L1_Vertebral_Pre_Cartilage_Condensation()
    T6_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T6_Vertebral_Pre_Cartilage_Condensation()
    T7_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T7_Vertebral_Pre_Cartilage_Condensation()
    T8_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T8_Vertebral_Pre_Cartilage_Condensation()
    T9_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T9_Vertebral_Pre_Cartilage_Condensation()
    T10_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T10_Vertebral_Pre_Cartilage_Condensation()
    T11_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T11_Vertebral_Pre_Cartilage_Condensation()
    T12_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T12_Vertebral_Pre_Cartilage_Condensation()
    T13_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _T13_Vertebral_Pre_Cartilage_Condensation()
    C6_VERTEBRAL_CARTILAGE_CONDENSATION = _C6_Vertebral_Cartilage_Condensation()
    C7_VERTEBRAL_CARTILAGE_CONDENSATION = _C7_Vertebral_Cartilage_Condensation()
    L2_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _L2_Vertebral_Pre_Cartilage_Condensation()
    L3_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _L3_Vertebral_Pre_Cartilage_Condensation()
    L4_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _L4_Vertebral_Pre_Cartilage_Condensation()
    L5_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _L5_Vertebral_Pre_Cartilage_Condensation()
    L6_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _L6_Vertebral_Pre_Cartilage_Condensation()
    S1_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _S1_Vertebral_Pre_Cartilage_Condensation()
    S2_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _S2_Vertebral_Pre_Cartilage_Condensation()
    T1_VERTEBRAL_CARTILAGE_CONDENSATION = _T1_Vertebral_Cartilage_Condensation()
    T2_VERTEBRAL_CARTILAGE_CONDENSATION = _T2_Vertebral_Cartilage_Condensation()
    T3_VERTEBRAL_CARTILAGE_CONDENSATION = _T3_Vertebral_Cartilage_Condensation()
    T4_VERTEBRAL_CARTILAGE_CONDENSATION = _T4_Vertebral_Cartilage_Condensation()
    T5_VERTEBRAL_CARTILAGE_CONDENSATION = _T5_Vertebral_Cartilage_Condensation()
    L1_VERTEBRAL_CARTILAGE_CONDENSATION = _L1_Vertebral_Cartilage_Condensation()
    S3_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _S3_Vertebral_Pre_Cartilage_Condensation()
    S4_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _S4_Vertebral_Pre_Cartilage_Condensation()
    TL1_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl1_Vertebral_Pre_Cartilage_Condensation()
    TL2_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl2_Vertebral_Pre_Cartilage_Condensation()
    TL3_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl3_Vertebral_Pre_Cartilage_Condensation()
    T1_RIB_PRE_CARTILAGE_CONDENSATION = _T1_Rib_Pre_Cartilage_Condensation()
    T2_RIB_PRE_CARTILAGE_CONDENSATION = _T2_Rib_Pre_Cartilage_Condensation()
    T3_RIB_PRE_CARTILAGE_CONDENSATION = _T3_Rib_Pre_Cartilage_Condensation()
    T4_RIB_PRE_CARTILAGE_CONDENSATION = _T4_Rib_Pre_Cartilage_Condensation()
    T5_RIB_PRE_CARTILAGE_CONDENSATION = _T5_Rib_Pre_Cartilage_Condensation()
    T6_VERTEBRAL_CARTILAGE_CONDENSATION = _T6_Vertebral_Cartilage_Condensation()
    T7_VERTEBRAL_CARTILAGE_CONDENSATION = _T7_Vertebral_Cartilage_Condensation()
    T8_VERTEBRAL_CARTILAGE_CONDENSATION = _T8_Vertebral_Cartilage_Condensation()
    T9_VERTEBRAL_CARTILAGE_CONDENSATION = _T9_Vertebral_Cartilage_Condensation()
    T10_VERTEBRAL_CARTILAGE_CONDENSATION = _T10_Vertebral_Cartilage_Condensation()
    T11_VERTEBRAL_CARTILAGE_CONDENSATION = _T11_Vertebral_Cartilage_Condensation()
    T12_VERTEBRAL_CARTILAGE_CONDENSATION = _T12_Vertebral_Cartilage_Condensation()
    T13_VERTEBRAL_CARTILAGE_CONDENSATION = _T13_Vertebral_Cartilage_Condensation()
    L2_VERTEBRAL_CARTILAGE_CONDENSATION = _L2_Vertebral_Cartilage_Condensation()
    L3_VERTEBRAL_CARTILAGE_CONDENSATION = _L3_Vertebral_Cartilage_Condensation()
    L4_VERTEBRAL_CARTILAGE_CONDENSATION = _L4_Vertebral_Cartilage_Condensation()
    L5_VERTEBRAL_CARTILAGE_CONDENSATION = _L5_Vertebral_Cartilage_Condensation()
    L6_VERTEBRAL_CARTILAGE_CONDENSATION = _L6_Vertebral_Cartilage_Condensation()
    S1_VERTEBRAL_CARTILAGE_CONDENSATION = _S1_Vertebral_Cartilage_Condensation()
    S2_VERTEBRAL_CARTILAGE_CONDENSATION = _S2_Vertebral_Cartilage_Condensation()
    TL4_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl4_Vertebral_Pre_Cartilage_Condensation()
    TL5_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl5_Vertebral_Pre_Cartilage_Condensation()
    TL6_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl6_Vertebral_Pre_Cartilage_Condensation()
    TL7_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl7_Vertebral_Pre_Cartilage_Condensation()
    TL8_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl8_Vertebral_Pre_Cartilage_Condensation()
    T6_RIB_PRE_CARTILAGE_CONDENSATION = _T6_Rib_Pre_Cartilage_Condensation()
    T7_RIB_PRE_CARTILAGE_CONDENSATION = _T7_Rib_Pre_Cartilage_Condensation()
    T8_RIB_PRE_CARTILAGE_CONDENSATION = _T8_Rib_Pre_Cartilage_Condensation()
    T9_RIB_PRE_CARTILAGE_CONDENSATION = _T9_Rib_Pre_Cartilage_Condensation()
    T10_RIB_PRE_CARTILAGE_CONDENSATION = _T10_Rib_Pre_Cartilage_Condensation()
    T11_RIB_PRE_CARTILAGE_CONDENSATION = _T11_Rib_Pre_Cartilage_Condensation()
    T12_RIB_PRE_CARTILAGE_CONDENSATION = _T12_Rib_Pre_Cartilage_Condensation()
    T13_RIB_PRE_CARTILAGE_CONDENSATION = _T13_Rib_Pre_Cartilage_Condensation()
    S3_VERTEBRAL_CARTILAGE_CONDENSATION = _S3_Vertebral_Cartilage_Condensation()
    S4_VERTEBRAL_CARTILAGE_CONDENSATION = _S4_Vertebral_Cartilage_Condensation()
    TL1_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl1_Vertebral_Cartilage_Condensation()
    TL2_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl2_Vertebral_Cartilage_Condensation()
    TL3_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl3_Vertebral_Cartilage_Condensation()
    TL9_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl9_Vertebral_Pre_Cartilage_Condensation()
    TL10_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl10_Vertebral_Pre_Cartilage_Condensation()
    TL11_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl11_Vertebral_Pre_Cartilage_Condensation()
    T1_RIB_CARTILAGE_CONDENSATION = _T1_Rib_Cartilage_Condensation()
    T2_RIB_CARTILAGE_CONDENSATION = _T2_Rib_Cartilage_Condensation()
    T3_RIB_CARTILAGE_CONDENSATION = _T3_Rib_Cartilage_Condensation()
    T4_RIB_CARTILAGE_CONDENSATION = _T4_Rib_Cartilage_Condensation()
    T5_RIB_CARTILAGE_CONDENSATION = _T5_Rib_Cartilage_Condensation()
    CERVICAL_INTERVERTEBRAL_DISC = _Cervical_Intervertebral_Disc()
    C1_INTERVERTEBRAL_DISC = _C1_Intervertebral_Disc()
    C1_NUCLEUS_PULPOSUS = _C1_Nucleus_Pulposus()
    C1_ANNULUS_FIBROSUS = _C1_Annulus_Fibrosus()
    C2_INTERVERTEBRAL_DISC = _C2_Intervertebral_Disc()
    C2_NUCLEUS_PULPOSUS = _C2_Nucleus_Pulposus()
    C2_ANNULUS_FIBROSUS = _C2_Annulus_Fibrosus()
    C3_INTERVERTEBRAL_DISC = _C3_Intervertebral_Disc()
    C3_NUCLEUS_PULPOSUS = _C3_Nucleus_Pulposus()
    C3_ANNULUS_FIBROSUS = _C3_Annulus_Fibrosus()
    C4_INTERVERTEBRAL_DISC = _C4_Intervertebral_Disc()
    C4_NUCLEUS_PULPOSUS = _C4_Nucleus_Pulposus()
    C4_ANNULUS_FIBROSUS = _C4_Annulus_Fibrosus()
    C5_INTERVERTEBRAL_DISC = _C5_Intervertebral_Disc()
    C5_NUCLEUS_PULPOSUS = _C5_Nucleus_Pulposus()
    C5_ANNULUS_FIBROSUS = _C5_Annulus_Fibrosus()
    C1_VERTEBRA = _C1_Vertebra()
    C2_VERTEBRA = _C2_Vertebra()
    C3_VERTEBRA = _C3_Vertebra()
    C4_VERTEBRA = _C4_Vertebra()
    C5_VERTEBRA = _C5_Vertebra()
    TL4_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl4_Vertebral_Cartilage_Condensation()
    TL5_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl5_Vertebral_Cartilage_Condensation()
    TL6_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl6_Vertebral_Cartilage_Condensation()
    TL7_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl7_Vertebral_Cartilage_Condensation()
    TL8_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl8_Vertebral_Cartilage_Condensation()
    TL9_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl9_Vertebral_Cartilage_Condensation()
    TL10_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl10_Vertebral_Cartilage_Condensation()
    TL11_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl11_Vertebral_Cartilage_Condensation()
    TL12_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl12_Vertebral_Pre_Cartilage_Condensation()
    TL13_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl13_Vertebral_Pre_Cartilage_Condensation()
    TL14_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl14_Vertebral_Pre_Cartilage_Condensation()
    TL15_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl15_Vertebral_Pre_Cartilage_Condensation()
    TL16_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl16_Vertebral_Pre_Cartilage_Condensation()
    TL17_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl17_Vertebral_Pre_Cartilage_Condensation()
    TL18_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl18_Vertebral_Pre_Cartilage_Condensation()
    TL19_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl19_Vertebral_Pre_Cartilage_Condensation()
    T6_RIB_CARTILAGE_CONDENSATION = _T6_Rib_Cartilage_Condensation()
    T7_RIB_CARTILAGE_CONDENSATION = _T7_Rib_Cartilage_Condensation()
    T8_RIB_CARTILAGE_CONDENSATION = _T8_Rib_Cartilage_Condensation()
    T9_RIB_CARTILAGE_CONDENSATION = _T9_Rib_Cartilage_Condensation()
    T10_RIB_CARTILAGE_CONDENSATION = _T10_Rib_Cartilage_Condensation()
    T11_RIB_CARTILAGE_CONDENSATION = _T11_Rib_Cartilage_Condensation()
    T12_RIB_CARTILAGE_CONDENSATION = _T12_Rib_Cartilage_Condensation()
    T13_RIB_CARTILAGE_CONDENSATION = _T13_Rib_Cartilage_Condensation()
    C6_INTERVERTEBRAL_DISC = _C6_Intervertebral_Disc()
    C6_NUCLEUS_PULPOSUS = _C6_Nucleus_Pulposus()
    C6_ANNULUS_FIBROSUS = _C6_Annulus_Fibrosus()
    C7_INTERVERTEBRAL_DISC = _C7_Intervertebral_Disc()
    C7_NUCLEUS_PULPOSUS = _C7_Nucleus_Pulposus()
    C7_ANNULUS_FIBROSUS = _C7_Annulus_Fibrosus()
    C6_VERTEBRA = _C6_Vertebra()
    C7_VERTEBRA = _C7_Vertebra()
    LUMBAR_INTERVERTEBRAL_DISC = _Lumbar_Intervertebral_Disc()
    L1_INTERVERTEBRAL_DISC = _L1_Intervertebral_Disc()
    L1_NUCLEUS_PULPOSUS = _L1_Nucleus_Pulposus()
    L1_ANNULUS_FIBROSUS = _L1_Annulus_Fibrosus()
    L1_VERTEBRA = _L1_Vertebra()
    TL12_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl12_Vertebral_Cartilage_Condensation()
    TL13_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl13_Vertebral_Cartilage_Condensation()
    TL14_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl14_Vertebral_Cartilage_Condensation()
    TL15_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl15_Vertebral_Cartilage_Condensation()
    TL16_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl16_Vertebral_Cartilage_Condensation()
    TL17_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl17_Vertebral_Cartilage_Condensation()
    TL18_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl18_Vertebral_Cartilage_Condensation()
    TL19_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl19_Vertebral_Cartilage_Condensation()
    TL20_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl20_Vertebral_Pre_Cartilage_Condensation()
    TL21_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl21_Vertebral_Pre_Cartilage_Condensation()
    TL22_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl22_Vertebral_Pre_Cartilage_Condensation()
    TL23_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl23_Vertebral_Pre_Cartilage_Condensation()
    TL24_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl24_Vertebral_Pre_Cartilage_Condensation()
    TL25_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl25_Vertebral_Pre_Cartilage_Condensation()
    TL26_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl26_Vertebral_Pre_Cartilage_Condensation()
    TL27_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl27_Vertebral_Pre_Cartilage_Condensation()
    THORACIC_INTERVERTEBRAL_DISC = _Thoracic_Intervertebral_Disc()
    T1_INTERVERTEBRAL_DISC = _T1_Intervertebral_Disc()
    T1_NUCLEUS_PULPOSUS = _T1_Nucleus_Pulposus()
    T1_ANNULUS_FIBROSUS = _T1_Annulus_Fibrosus()
    T2_INTERVERTEBRAL_DISC = _T2_Intervertebral_Disc()
    T2_NUCLEUS_PULPOSUS = _T2_Nucleus_Pulposus()
    T2_ANNULUS_FIBROSUS = _T2_Annulus_Fibrosus()
    T3_INTERVERTEBRAL_DISC = _T3_Intervertebral_Disc()
    T3_NUCLEUS_PULPOSUS = _T3_Nucleus_Pulposus()
    T3_ANNULUS_FIBROSUS = _T3_Annulus_Fibrosus()
    T4_INTERVERTEBRAL_DISC = _T4_Intervertebral_Disc()
    T4_NUCLEUS_PULPOSUS = _T4_Nucleus_Pulposus()
    T4_ANNULUS_FIBROSUS = _T4_Annulus_Fibrosus()
    T5_INTERVERTEBRAL_DISC = _T5_Intervertebral_Disc()
    T5_NUCLEUS_PULPOSUS = _T5_Nucleus_Pulposus()
    T5_ANNULUS_FIBROSUS = _T5_Annulus_Fibrosus()
    T6_INTERVERTEBRAL_DISC = _T6_Intervertebral_Disc()
    T6_NUCLEUS_PULPOSUS = _T6_Nucleus_Pulposus()
    T6_ANNULUS_FIBROSUS = _T6_Annulus_Fibrosus()
    T7_INTERVERTEBRAL_DISC = _T7_Intervertebral_Disc()
    T7_NUCLEUS_PULPOSUS = _T7_Nucleus_Pulposus()
    T7_ANNULUS_FIBROSUS = _T7_Annulus_Fibrosus()
    T8_INTERVERTEBRAL_DISC = _T8_Intervertebral_Disc()
    T8_NUCLEUS_PULPOSUS = _T8_Nucleus_Pulposus()
    T8_ANNULUS_FIBROSUS = _T8_Annulus_Fibrosus()
    T9_INTERVERTEBRAL_DISC = _T9_Intervertebral_Disc()
    T9_NUCLEUS_PULPOSUS = _T9_Nucleus_Pulposus()
    T9_ANNULUS_FIBROSUS = _T9_Annulus_Fibrosus()
    T10_INTERVERTEBRAL_DISC = _T10_Intervertebral_Disc()
    T10_NUCLEUS_PULPOSUS = _T10_Nucleus_Pulposus()
    T10_ANNULUS_FIBROSUS = _T10_Annulus_Fibrosus()
    T11_INTERVERTEBRAL_DISC = _T11_Intervertebral_Disc()
    T11_NUCLEUS_PULPOSUS = _T11_Nucleus_Pulposus()
    T11_ANNULUS_FIBROSUS = _T11_Annulus_Fibrosus()
    T12_INTERVERTEBRAL_DISC = _T12_Intervertebral_Disc()
    T12_NUCLEUS_PULPOSUS = _T12_Nucleus_Pulposus()
    T12_ANNULUS_FIBROSUS = _T12_Annulus_Fibrosus()
    T13_INTERVERTEBRAL_DISC = _T13_Intervertebral_Disc()
    T13_NUCLEUS_PULPOSUS = _T13_Nucleus_Pulposus()
    T13_ANNULUS_FIBROSUS = _T13_Annulus_Fibrosus()
    T1_RIB = _T1_Rib()
    T2_RIB = _T2_Rib()
    T3_RIB = _T3_Rib()
    T4_RIB = _T4_Rib()
    T5_RIB = _T5_Rib()
    T6_RIB = _T6_Rib()
    T7_RIB = _T7_Rib()
    T8_RIB = _T8_Rib()
    T9_RIB = _T9_Rib()
    T10_RIB = _T10_Rib()
    T11_RIB = _T11_Rib()
    T12_RIB = _T12_Rib()
    T13_RIB = _T13_Rib()
    T1_VERTEBRA = _T1_Vertebra()
    T2_VERTEBRA = _T2_Vertebra()
    T3_VERTEBRA = _T3_Vertebra()
    T4_VERTEBRA = _T4_Vertebra()
    T5_VERTEBRA = _T5_Vertebra()
    T6_VERTEBRA = _T6_Vertebra()
    T7_VERTEBRA = _T7_Vertebra()
    T8_VERTEBRA = _T8_Vertebra()
    T9_VERTEBRA = _T9_Vertebra()
    T10_VERTEBRA = _T10_Vertebra()
    T11_VERTEBRA = _T11_Vertebra()
    T12_VERTEBRA = _T12_Vertebra()
    T13_VERTEBRA = _T13_Vertebra()
    L2_INTERVERTEBRAL_DISC = _L2_Intervertebral_Disc()
    L2_NUCLEUS_PULPOSUS = _L2_Nucleus_Pulposus()
    L2_ANNULUS_FIBROSUS = _L2_Annulus_Fibrosus()
    L3_INTERVERTEBRAL_DISC = _L3_Intervertebral_Disc()
    L3_NUCLEUS_PULPOSUS = _L3_Nucleus_Pulposus()
    L3_ANNULUS_FIBROSUS = _L3_Annulus_Fibrosus()
    L4_INTERVERTEBRAL_DISC = _L4_Intervertebral_Disc()
    L4_NUCLEUS_PULPOSUS = _L4_Nucleus_Pulposus()
    L4_ANNULUS_FIBROSUS = _L4_Annulus_Fibrosus()
    L5_INTERVERTEBRAL_DISC = _L5_Intervertebral_Disc()
    L5_NUCLEUS_PULPOSUS = _L5_Nucleus_Pulposus()
    L5_ANNULUS_FIBROSUS = _L5_Annulus_Fibrosus()
    L6_INTERVERTEBRAL_DISC = _L6_Intervertebral_Disc()
    L6_NUCLEUS_PULPOSUS = _L6_Nucleus_Pulposus()
    L6_ANNULUS_FIBROSUS = _L6_Annulus_Fibrosus()
    L2_VERTEBRA = _L2_Vertebra()
    L3_VERTEBRA = _L3_Vertebra()
    L4_VERTEBRA = _L4_Vertebra()
    L5_VERTEBRA = _L5_Vertebra()
    L6_VERTEBRA = _L6_Vertebra()
    SACRAL_INTERVERTEBRAL_DISC = _Sacral_Intervertebral_Disc()
    S1_INTERVERTEBRAL_DISC = _S1_Intervertebral_Disc()
    S1_NUCLEUS_PULPOSUS = _S1_Nucleus_Pulposus()
    S1_ANNULUS_FIBROSUS = _S1_Annulus_Fibrosus()
    S2_INTERVERTEBRAL_DISC = _S2_Intervertebral_Disc()
    S2_NUCLEUS_PULPOSUS = _S2_Nucleus_Pulposus()
    S2_ANNULUS_FIBROSUS = _S2_Annulus_Fibrosus()
    S3_INTERVERTEBRAL_DISC = _S3_Intervertebral_Disc()
    S3_NUCLEUS_PULPOSUS = _S3_Nucleus_Pulposus()
    S3_ANNULUS_FIBROSUS = _S3_Annulus_Fibrosus()
    S4_INTERVERTEBRAL_DISC = _S4_Intervertebral_Disc()
    S4_NUCLEUS_PULPOSUS = _S4_Nucleus_Pulposus()
    S4_ANNULUS_FIBROSUS = _S4_Annulus_Fibrosus()
    S1_VERTEBRA = _S1_Vertebra()
    S2_VERTEBRA = _S2_Vertebra()
    S3_VERTEBRA = _S3_Vertebra()
    S4_VERTEBRA = _S4_Vertebra()
    TAIL_INTERVERTEBRAL_DISC = _Tail_Intervertebral_Disc()
    TL1_INTERVERTEBRAL_DISC = _Tl1_Intervertebral_Disc()
    TL1_NUCLEUS_PULPOSUS = _Tl1_Nucleus_Pulposus()
    TL1_ANNULUS_FIBROSUS = _Tl1_Annulus_Fibrosus()
    TL2_INTERVERTEBRAL_DISC = _Tl2_Intervertebral_Disc()
    TL2_NUCLEUS_PULPOSUS = _Tl2_Nucleus_Pulposus()
    TL2_ANNULUS_FIBROSUS = _Tl2_Annulus_Fibrosus()
    TL3_INTERVERTEBRAL_DISC = _Tl3_Intervertebral_Disc()
    TL3_NUCLEUS_PULPOSUS = _Tl3_Nucleus_Pulposus()
    TL3_ANNULUS_FIBROSUS = _Tl3_Annulus_Fibrosus()
    TL1_VERTEBRA = _Tl1_Vertebra()
    TL2_VERTEBRA = _Tl2_Vertebra()
    TL3_VERTEBRA = _Tl3_Vertebra()
    TL20_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl20_Vertebral_Cartilage_Condensation()
    TL21_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl21_Vertebral_Cartilage_Condensation()
    TL22_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl22_Vertebral_Cartilage_Condensation()
    TL23_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl23_Vertebral_Cartilage_Condensation()
    TL24_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl24_Vertebral_Cartilage_Condensation()
    TL25_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl25_Vertebral_Cartilage_Condensation()
    TL26_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl26_Vertebral_Cartilage_Condensation()
    TL27_VERTEBRAL_CARTILAGE_CONDENSATION = _Tl27_Vertebral_Cartilage_Condensation()
    TL28_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl28_Vertebral_Pre_Cartilage_Condensation()
    TL29_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl29_Vertebral_Pre_Cartilage_Condensation()
    TL30_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl30_Vertebral_Pre_Cartilage_Condensation()
    TL31_VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Tl31_Vertebral_Pre_Cartilage_Condensation()
    TL4_INTERVERTEBRAL_DISC = _Tl4_Intervertebral_Disc()
    TL4_NUCLEUS_PULPOSUS = _Tl4_Nucleus_Pulposus()
    TL4_ANNULUS_FIBROSUS = _Tl4_Annulus_Fibrosus()
    TL5_INTERVERTEBRAL_DISC = _Tl5_Intervertebral_Disc()
    TL5_NUCLEUS_PULPOSUS = _Tl5_Nucleus_Pulposus()
    TL5_ANNULUS_FIBROSUS = _Tl5_Annulus_Fibrosus()
    TL6_INTERVERTEBRAL_DISC = _Tl6_Intervertebral_Disc()
    TL6_NUCLEUS_PULPOSUS = _Tl6_Nucleus_Pulposus()
    TL6_ANNULUS_FIBROSUS = _Tl6_Annulus_Fibrosus()
    TL7_INTERVERTEBRAL_DISC = _Tl7_Intervertebral_Disc()
    TL7_NUCLEUS_PULPOSUS = _Tl7_Nucleus_Pulposus()
    TL7_ANNULUS_FIBROSUS = _Tl7_Annulus_Fibrosus()
    TL8_INTERVERTEBRAL_DISC = _Tl8_Intervertebral_Disc()
    TL8_NUCLEUS_PULPOSUS = _Tl8_Nucleus_Pulposus()
    TL8_ANNULUS_FIBROSUS = _Tl8_Annulus_Fibrosus()
    TL9_INTERVERTEBRAL_DISC = _Tl9_Intervertebral_Disc()
    TL9_NUCLEUS_PULPOSUS = _Tl9_Nucleus_Pulposus()
    TL9_ANNULUS_FIBROSUS = _Tl9_Annulus_Fibrosus()
    TL10_INTERVERTEBRAL_DISC = _Tl10_Intervertebral_Disc()
    TL10_NUCLEUS_PULPOSUS = _Tl10_Nucleus_Pulposus()
    TL10_ANNULUS_FIBROSUS = _Tl10_Annulus_Fibrosus()
    TL11_INTERVERTEBRAL_DISC = _Tl11_Intervertebral_Disc()
    TL11_NUCLEUS_PULPOSUS = _Tl11_Nucleus_Pulposus()
    TL11_ANNULUS_FIBROSUS = _Tl11_Annulus_Fibrosus()
    TL4_VERTEBRA = _Tl4_Vertebra()
    TL5_VERTEBRA = _Tl5_Vertebra()
    TL6_VERTEBRA = _Tl6_Vertebra()
    TL7_VERTEBRA = _Tl7_Vertebra()
    TL8_VERTEBRA = _Tl8_Vertebra()
    TL9_VERTEBRA = _Tl9_Vertebra()
    TL10_VERTEBRA = _Tl10_Vertebra()
    TL11_VERTEBRA = _Tl11_Vertebra()
    TL12_INTERVERTEBRAL_DISC = _Tl12_Intervertebral_Disc()
    TL12_NUCLEUS_PULPOSUS = _Tl12_Nucleus_Pulposus()
    TL12_ANNULUS_FIBROSUS = _Tl12_Annulus_Fibrosus()
    TL13_INTERVERTEBRAL_DISC = _Tl13_Intervertebral_Disc()
    TL13_NUCLEUS_PULPOSUS = _Tl13_Nucleus_Pulposus()
    TL13_ANNULUS_FIBROSUS = _Tl13_Annulus_Fibrosus()
    TL14_INTERVERTEBRAL_DISC = _Tl14_Intervertebral_Disc()
    TL14_NUCLEUS_PULPOSUS = _Tl14_Nucleus_Pulposus()
    TL14_ANNULUS_FIBROSUS = _Tl14_Annulus_Fibrosus()
    TL15_INTERVERTEBRAL_DISC = _Tl15_Intervertebral_Disc()
    TL15_NUCLEUS_PULPOSUS = _Tl15_Nucleus_Pulposus()
    TL15_ANNULUS_FIBROSUS = _Tl15_Annulus_Fibrosus()
    TL16_INTERVERTEBRAL_DISC = _Tl16_Intervertebral_Disc()
    TL16_NUCLEUS_PULPOSUS = _Tl16_Nucleus_Pulposus()
    TL16_ANNULUS_FIBROSUS = _Tl16_Annulus_Fibrosus()
    TL17_INTERVERTEBRAL_DISC = _Tl17_Intervertebral_Disc()
    TL17_NUCLEUS_PULPOSUS = _Tl17_Nucleus_Pulposus()
    TL17_ANNULUS_FIBROSUS = _Tl17_Annulus_Fibrosus()
    TL18_INTERVERTEBRAL_DISC = _Tl18_Intervertebral_Disc()
    TL18_NUCLEUS_PULPOSUS = _Tl18_Nucleus_Pulposus()
    TL18_ANNULUS_FIBROSUS = _Tl18_Annulus_Fibrosus()
    TL19_INTERVERTEBRAL_DISC = _Tl19_Intervertebral_Disc()
    TL19_NUCLEUS_PULPOSUS = _Tl19_Nucleus_Pulposus()
    TL19_ANNULUS_FIBROSUS = _Tl19_Annulus_Fibrosus()
    TL12_VERTEBRA = _Tl12_Vertebra()
    TL13_VERTEBRA = _Tl13_Vertebra()
    TL14_VERTEBRA = _Tl14_Vertebra()
    TL15_VERTEBRA = _Tl15_Vertebra()
    TL16_VERTEBRA = _Tl16_Vertebra()
    TL17_VERTEBRA = _Tl17_Vertebra()
    TL18_VERTEBRA = _Tl18_Vertebra()
    TL19_VERTEBRA = _Tl19_Vertebra()
    PLEURO_PERITONEAL_CANAL_MESOTHELIUM = _Pleuro_Peritoneal_Canal_Mesothelium()
    PLEURO_PERITONEAL_CANAL_PARIETAL_MESOTHELIUM = _Pleuro_Peritoneal_Canal_Parietal_Mesothelium()
    PLEURO_PERITONEAL_CANAL_CAVITY = _Pleuro_Peritoneal_Canal_Cavity()
    FUTURE_CENTRAL_TENDON = _Future_Central_Tendon()
    RATHKE_S_POUCH_WALL = _Rathke_S_Pouch_Wall()
    RATHKE_S_POUCH_LUMEN = _Rathke_S_Pouch_Lumen()
    PROCTODEUM = _Proctodeum()
    CAUDAL_ONE_THIRD_OF_ANAL_CANAL = _Caudal_One_Third_Of_Anal_Canal()
    ECTODERM_COMPONENT_OF_ANAL_MEMBRANE = _Ectoderm_Component_Of_Anal_Membrane()
    FUTURE_DOME = _Future_Dome()
    SPINAL_CORD_LUMEN = _Spinal_Cord_Lumen()
    DIAPHRAGM_LEFT_DOME = _Diaphragm_Left_Dome()
    DIAPHRAGM_RIGHT_DOME = _Diaphragm_Right_Dome()
    HUMERUS_CREST = _Humerus_Crest()
    HEAD_OF_HUMERUS = _Head_Of_Humerus()
    HUMERUS_SHAFT = _Humerus_Shaft()
    HUMERUS_DELTOID_TUBEROSITY = _Humerus_Deltoid_Tuberosity()
    TENDON_OF_BICEPS_BRACHII = _Tendon_Of_Biceps_Brachii()
    LONG_HEAD_OF_BICEPS_BRACHII = _Long_Head_Of_Biceps_Brachii()
    SHORT_HEAD_OF_BICEPS_BRACHII = _Short_Head_Of_Biceps_Brachii()
    CARPAL_BONE = _Carpal_Bone()
    FORELIMB_DIGIT_1_METACARPAL_PHALANGEAL_JOINT = _Forelimb_Digit_1_Metacarpal_Phalangeal_Joint()
    FORELIMB_DIGIT_1_INTERPHALANGEAL_JOINT = _Forelimb_Digit_1_Interphalangeal_Joint()
    FORELIMB_DIGIT_1_EPIPHYSEAL_PLATE = _Forelimb_Digit_1_Epiphyseal_Plate()
    FORELIMB_DIGIT_2_METACARPAL_PHALANGEAL_JOINT = _Forelimb_Digit_2_Metacarpal_Phalangeal_Joint()
    FORELIMB_DIGIT_2_INTERPHALANGEAL_JOINT = _Forelimb_Digit_2_Interphalangeal_Joint()
    FORELIMB_DIGIT_2_EPIPHYSEAL_PLATE = _Forelimb_Digit_2_Epiphyseal_Plate()
    FORELIMB_DIGIT_3_METACARPAL_PHALANGEAL_JOINT = _Forelimb_Digit_3_Metacarpal_Phalangeal_Joint()
    FORELIMB_DIGIT_3_INTERPHALANGEAL_JOINT = _Forelimb_Digit_3_Interphalangeal_Joint()
    FORELIMB_DIGIT_3_EPIPHYSEAL_PLATE = _Forelimb_Digit_3_Epiphyseal_Plate()
    FORELIMB_DIGIT_4_METACARPAL_PHALANGEAL_JOINT = _Forelimb_Digit_4_Metacarpal_Phalangeal_Joint()
    FORELIMB_DIGIT_4_INTERPHALANGEAL_JOINT = _Forelimb_Digit_4_Interphalangeal_Joint()
    FORELIMB_DIGIT_4_EPIPHYSEAL_PLATE = _Forelimb_Digit_4_Epiphyseal_Plate()
    FORELIMB_DIGIT_5_METACARPAL_PHALANGEAL_JOINT = _Forelimb_Digit_5_Metacarpal_Phalangeal_Joint()
    FORELIMB_DIGIT_5_INTERPHALANGEAL_JOINT = _Forelimb_Digit_5_Interphalangeal_Joint()
    FORELIMB_DIGIT_5_EPIPHYSEAL_PLATE = _Forelimb_Digit_5_Epiphyseal_Plate()
    TARSAL_BONE = _Tarsal_Bone()
    CEPHALIC_VEIN = _Cephalic_Vein()
    CEREBELLUM_LATERAL_PART = _Cerebellum_Lateral_Part()
    CEREBELLUM_LATERAL_PART_MANTLE_LAYER = _Cerebellum_Lateral_Part_Mantle_Layer()
    CEREBELLUM_LATERAL_PART_MARGINAL_LAYER = _Cerebellum_Lateral_Part_Marginal_Layer()
    CEREBELLUM_LATERAL_PART_VENTRICULAR_LAYER = _Cerebellum_Lateral_Part_Ventricular_Layer()
    CHOROID_LAYER = _Choroid_Layer()
    SEROUS_GLAND_EPITHELIAL_COMPONENT = _Serous_Gland_Epithelial_Component()
    NASAL_SEPTUM_CARTILAGE = _Nasal_Septum_Cartilage()
    TURBINATE_BONE = _Turbinate_Bone()
    OROPHARYNX = _Oropharynx()
    OROPHARYNX_GLAND = _Oropharynx_Gland()
    OROPHARYNX_GLAND_DUCT = _Oropharynx_Gland_Duct()
    TONGUE_GLAND = _Tongue_Gland()
    TONGUE_GLAND_DUCT = _Tongue_Gland_Duct()
    LOWER_JAW_ALVEOLAR_CANAL = _Lower_Jaw_Alveolar_Canal()
    MANDIBLE_RAMUS = _Mandible_Ramus()
    L1_VERTEBRA_CENTRUM = _L1_Vertebra_Centrum()
    L1_VERTEBRA_NEURAL_ARCH = _L1_Vertebra_Neural_Arch()
    L1_FUTURE_VERTEBRAL_CANAL = _L1_Future_Vertebral_Canal()
    L1_NEURAL_ARCH_LAMINA = _L1_Neural_Arch_Lamina()
    L1_NEURAL_ARCH_PEDICLE = _L1_Neural_Arch_Pedicle()
    L1_NEURAL_ARCH_TRANSVERSE_PROCESS = _L1_Neural_Arch_Transverse_Process()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_L1_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_L1_Spinous_Process()
    ZYGOMATIC_BONE = _Zygomatic_Bone()
    OCCIPITAL_BONE = _Occipital_Bone()
    OCCIPITAL_BONE_SQUAMOUS_PART = _Occipital_Bone_Squamous_Part()
    ETHMOID_BONE_PERPENDICULAR_PLATE = _Ethmoid_Bone_Perpendicular_Plate()
    T1_RIB_COSTAL_CARTILAGE = _T1_Rib_Costal_Cartilage()
    T1_RIB_HEAD_CARTILAGE = _T1_Rib_Head_Cartilage()
    T1_RIB_NECK_CARTILAGE = _T1_Rib_Neck_Cartilage()
    ACROMION = _Acromion()
    BLADE_OF_SCAPULA = _Blade_Of_Scapula()
    CORACOID_PROCESS = _Coracoid_Process()
    GLENOID_FOSSA_OF_SCAPULA = _Glenoid_Fossa_Of_Scapula()
    SCAPULA_SPINE = _Scapula_Spine()
    SCAPULA_BORDER = _Scapula_Border()
    SCAPULA_ANGLE = _Scapula_Angle()
    SCAPULA_LATERAL_BORDER = _Scapula_Lateral_Border()
    SCAPULA_MEDIAL_BORDER = _Scapula_Medial_Border()
    SCAPULA_INFERIOR_ANGLE = _Scapula_Inferior_Angle()
    SCAPULA_SUPERIOR_ANGLE = _Scapula_Superior_Angle()
    PRE_VERTEBRAL_MUSCLE_OF_NECK = _Pre_Vertebral_Muscle_Of_Neck()
    LONGUS_CAPITIS = _Longus_Capitis()
    LONGUS_CERVICIS = _Longus_Cervicis()
    FACIAL_MUSCLE = _Facial_Muscle()
    DIGASTRIC = _Digastric()
    MASSETER = _Masseter()
    MYLOHYOID = _Mylohyoid()
    STERNO_MASTOID = _Sterno_Mastoid()
    TEMPORALIS = _Temporalis()
    PTERYGOID = _Pterygoid()
    LATERAL_PTERYGOID = _Lateral_Pterygoid()
    MEDIAL_PTERYGOID = _Medial_Pterygoid()
    C1_DORSAL_ROOT_GANGLION = _C1_Dorsal_Root_Ganglion()
    C1_SEGMENTAL_SPINAL_NERVE = _C1_Segmental_Spinal_Nerve()
    C1_DORSAL_ROOT = _C1_Dorsal_Root()
    C1_VENTRAL_ROOT = _C1_Ventral_Root()
    TAIL_NERVE = _Tail_Nerve()
    TAIL_SEGMENTAL_SPINAL_NERVE = _Tail_Segmental_Spinal_Nerve()
    TL1_SEGMENTAL_SPINAL_NERVE = _Tl1_Segmental_Spinal_Nerve()
    TL1_DORSAL_ROOT = _Tl1_Dorsal_Root()
    TL1_VENTRAL_ROOT = _Tl1_Ventral_Root()
    TL1_DORSAL_ROOT_GANGLION = _Tl1_Dorsal_Root_Ganglion()
    C2_DORSAL_ROOT_GANGLION = _C2_Dorsal_Root_Ganglion()
    C3_DORSAL_ROOT_GANGLION = _C3_Dorsal_Root_Ganglion()
    C4_DORSAL_ROOT_GANGLION = _C4_Dorsal_Root_Ganglion()
    C5_DORSAL_ROOT_GANGLION = _C5_Dorsal_Root_Ganglion()
    C6_DORSAL_ROOT_GANGLION = _C6_Dorsal_Root_Ganglion()
    C7_DORSAL_ROOT_GANGLION = _C7_Dorsal_Root_Ganglion()
    L1_DORSAL_ROOT_GANGLION = _L1_Dorsal_Root_Ganglion()
    L2_DORSAL_ROOT_GANGLION = _L2_Dorsal_Root_Ganglion()
    L3_DORSAL_ROOT_GANGLION = _L3_Dorsal_Root_Ganglion()
    L4_DORSAL_ROOT_GANGLION = _L4_Dorsal_Root_Ganglion()
    L5_DORSAL_ROOT_GANGLION = _L5_Dorsal_Root_Ganglion()
    L6_DORSAL_ROOT_GANGLION = _L6_Dorsal_Root_Ganglion()
    S1_DORSAL_ROOT_GANGLION = _S1_Dorsal_Root_Ganglion()
    S2_DORSAL_ROOT_GANGLION = _S2_Dorsal_Root_Ganglion()
    S3_DORSAL_ROOT_GANGLION = _S3_Dorsal_Root_Ganglion()
    S4_DORSAL_ROOT_GANGLION = _S4_Dorsal_Root_Ganglion()
    T1_DORSAL_ROOT_GANGLION = _T1_Dorsal_Root_Ganglion()
    T2_DORSAL_ROOT_GANGLION = _T2_Dorsal_Root_Ganglion()
    T3_DORSAL_ROOT_GANGLION = _T3_Dorsal_Root_Ganglion()
    T4_DORSAL_ROOT_GANGLION = _T4_Dorsal_Root_Ganglion()
    T6_DORSAL_ROOT_GANGLION = _T6_Dorsal_Root_Ganglion()
    T5_DORSAL_ROOT_GANGLION = _T5_Dorsal_Root_Ganglion()
    T7_DORSAL_ROOT_GANGLION = _T7_Dorsal_Root_Ganglion()
    T8_DORSAL_ROOT_GANGLION = _T8_Dorsal_Root_Ganglion()
    T9_DORSAL_ROOT_GANGLION = _T9_Dorsal_Root_Ganglion()
    T10_DORSAL_ROOT_GANGLION = _T10_Dorsal_Root_Ganglion()
    T11_DORSAL_ROOT_GANGLION = _T11_Dorsal_Root_Ganglion()
    T12_DORSAL_ROOT_GANGLION = _T12_Dorsal_Root_Ganglion()
    T13_DORSAL_ROOT_GANGLION = _T13_Dorsal_Root_Ganglion()
    TL2_DORSAL_ROOT_GANGLION = _Tl2_Dorsal_Root_Ganglion()
    TL3_DORSAL_ROOT_GANGLION = _Tl3_Dorsal_Root_Ganglion()
    TL4_DORSAL_ROOT_GANGLION = _Tl4_Dorsal_Root_Ganglion()
    TL5_DORSAL_ROOT_GANGLION = _Tl5_Dorsal_Root_Ganglion()
    TL6_DORSAL_ROOT_GANGLION = _Tl6_Dorsal_Root_Ganglion()
    TL7_DORSAL_ROOT_GANGLION = _Tl7_Dorsal_Root_Ganglion()
    TL8_DORSAL_ROOT_GANGLION = _Tl8_Dorsal_Root_Ganglion()
    TL9_DORSAL_ROOT_GANGLION = _Tl9_Dorsal_Root_Ganglion()
    TL10_DORSAL_ROOT_GANGLION = _Tl10_Dorsal_Root_Ganglion()
    TL11_DORSAL_ROOT_GANGLION = _Tl11_Dorsal_Root_Ganglion()
    TL12_DORSAL_ROOT_GANGLION = _Tl12_Dorsal_Root_Ganglion()
    TL13_DORSAL_ROOT_GANGLION = _Tl13_Dorsal_Root_Ganglion()
    TL14_DORSAL_ROOT_GANGLION = _Tl14_Dorsal_Root_Ganglion()
    TL15_DORSAL_ROOT_GANGLION = _Tl15_Dorsal_Root_Ganglion()
    TL16_DORSAL_ROOT_GANGLION = _Tl16_Dorsal_Root_Ganglion()
    TL17_DORSAL_ROOT_GANGLION = _Tl17_Dorsal_Root_Ganglion()
    TL18_DORSAL_ROOT_GANGLION = _Tl18_Dorsal_Root_Ganglion()
    TL19_DORSAL_ROOT_GANGLION = _Tl19_Dorsal_Root_Ganglion()
    TL2_SEGMENTAL_SPINAL_NERVE = _Tl2_Segmental_Spinal_Nerve()
    TL3_SEGMENTAL_SPINAL_NERVE = _Tl3_Segmental_Spinal_Nerve()
    TL4_SEGMENTAL_SPINAL_NERVE = _Tl4_Segmental_Spinal_Nerve()
    TL5_SEGMENTAL_SPINAL_NERVE = _Tl5_Segmental_Spinal_Nerve()
    TL6_SEGMENTAL_SPINAL_NERVE = _Tl6_Segmental_Spinal_Nerve()
    TL7_SEGMENTAL_SPINAL_NERVE = _Tl7_Segmental_Spinal_Nerve()
    TL8_SEGMENTAL_SPINAL_NERVE = _Tl8_Segmental_Spinal_Nerve()
    TL9_SEGMENTAL_SPINAL_NERVE = _Tl9_Segmental_Spinal_Nerve()
    TL10_SEGMENTAL_SPINAL_NERVE = _Tl10_Segmental_Spinal_Nerve()
    TL11_SEGMENTAL_SPINAL_NERVE = _Tl11_Segmental_Spinal_Nerve()
    TL12_SEGMENTAL_SPINAL_NERVE = _Tl12_Segmental_Spinal_Nerve()
    TL13_SEGMENTAL_SPINAL_NERVE = _Tl13_Segmental_Spinal_Nerve()
    TL14_SEGMENTAL_SPINAL_NERVE = _Tl14_Segmental_Spinal_Nerve()
    TL15_SEGMENTAL_SPINAL_NERVE = _Tl15_Segmental_Spinal_Nerve()
    TL16_SEGMENTAL_SPINAL_NERVE = _Tl16_Segmental_Spinal_Nerve()
    TL17_SEGMENTAL_SPINAL_NERVE = _Tl17_Segmental_Spinal_Nerve()
    TL18_SEGMENTAL_SPINAL_NERVE = _Tl18_Segmental_Spinal_Nerve()
    TL19_SEGMENTAL_SPINAL_NERVE = _Tl19_Segmental_Spinal_Nerve()
    C2_SEGMENTAL_SPINAL_NERVE = _C2_Segmental_Spinal_Nerve()
    C3_SEGMENTAL_SPINAL_NERVE = _C3_Segmental_Spinal_Nerve()
    C4_SEGMENTAL_SPINAL_NERVE = _C4_Segmental_Spinal_Nerve()
    C5_SEGMENTAL_SPINAL_NERVE = _C5_Segmental_Spinal_Nerve()
    C6_SEGMENTAL_SPINAL_NERVE = _C6_Segmental_Spinal_Nerve()
    C7_SEGMENTAL_SPINAL_NERVE = _C7_Segmental_Spinal_Nerve()
    L1_SEGMENTAL_SPINAL_NERVE = _L1_Segmental_Spinal_Nerve()
    L2_SEGMENTAL_SPINAL_NERVE = _L2_Segmental_Spinal_Nerve()
    L3_SEGMENTAL_SPINAL_NERVE = _L3_Segmental_Spinal_Nerve()
    L4_SEGMENTAL_SPINAL_NERVE = _L4_Segmental_Spinal_Nerve()
    L5_SEGMENTAL_SPINAL_NERVE = _L5_Segmental_Spinal_Nerve()
    L6_SEGMENTAL_SPINAL_NERVE = _L6_Segmental_Spinal_Nerve()
    S1_SEGMENTAL_SPINAL_NERVE = _S1_Segmental_Spinal_Nerve()
    S2_SEGMENTAL_SPINAL_NERVE = _S2_Segmental_Spinal_Nerve()
    S3_SEGMENTAL_SPINAL_NERVE = _S3_Segmental_Spinal_Nerve()
    S4_SEGMENTAL_SPINAL_NERVE = _S4_Segmental_Spinal_Nerve()
    T1_SEGMENTAL_SPINAL_NERVE = _T1_Segmental_Spinal_Nerve()
    T2_SEGMENTAL_SPINAL_NERVE = _T2_Segmental_Spinal_Nerve()
    T3_SEGMENTAL_SPINAL_NERVE = _T3_Segmental_Spinal_Nerve()
    T4_SEGMENTAL_SPINAL_NERVE = _T4_Segmental_Spinal_Nerve()
    T5_SEGMENTAL_SPINAL_NERVE = _T5_Segmental_Spinal_Nerve()
    T6_SEGMENTAL_SPINAL_NERVE = _T6_Segmental_Spinal_Nerve()
    T7_SEGMENTAL_SPINAL_NERVE = _T7_Segmental_Spinal_Nerve()
    T8_SEGMENTAL_SPINAL_NERVE = _T8_Segmental_Spinal_Nerve()
    T9_SEGMENTAL_SPINAL_NERVE = _T9_Segmental_Spinal_Nerve()
    T10_SEGMENTAL_SPINAL_NERVE = _T10_Segmental_Spinal_Nerve()
    T11_SEGMENTAL_SPINAL_NERVE = _T11_Segmental_Spinal_Nerve()
    T12_SEGMENTAL_SPINAL_NERVE = _T12_Segmental_Spinal_Nerve()
    T13_SEGMENTAL_SPINAL_NERVE = _T13_Segmental_Spinal_Nerve()
    C2_DORSAL_ROOT = _C2_Dorsal_Root()
    C2_VENTRAL_ROOT = _C2_Ventral_Root()
    C3_DORSAL_ROOT = _C3_Dorsal_Root()
    C3_VENTRAL_ROOT = _C3_Ventral_Root()
    C4_DORSAL_ROOT = _C4_Dorsal_Root()
    C4_VENTRAL_ROOT = _C4_Ventral_Root()
    C5_DORSAL_ROOT = _C5_Dorsal_Root()
    C5_VENTRAL_ROOT = _C5_Ventral_Root()
    C6_DORSAL_ROOT = _C6_Dorsal_Root()
    C6_VENTRAL_ROOT = _C6_Ventral_Root()
    C7_DORSAL_ROOT = _C7_Dorsal_Root()
    C7_VENTRAL_ROOT = _C7_Ventral_Root()
    L1_DORSAL_ROOT = _L1_Dorsal_Root()
    L1_VENTRAL_ROOT = _L1_Ventral_Root()
    L2_DORSAL_ROOT = _L2_Dorsal_Root()
    L2_VENTRAL_ROOT = _L2_Ventral_Root()
    L3_DORSAL_ROOT = _L3_Dorsal_Root()
    L3_VENTRAL_ROOT = _L3_Ventral_Root()
    L4_DORSAL_ROOT = _L4_Dorsal_Root()
    L4_VENTRAL_ROOT = _L4_Ventral_Root()
    L5_DORSAL_ROOT = _L5_Dorsal_Root()
    L5_VENTRAL_ROOT = _L5_Ventral_Root()
    L6_DORSAL_ROOT = _L6_Dorsal_Root()
    L6_VENTRAL_ROOT = _L6_Ventral_Root()
    S1_DORSAL_ROOT = _S1_Dorsal_Root()
    S1_VENTRAL_ROOT = _S1_Ventral_Root()
    S2_DORSAL_ROOT = _S2_Dorsal_Root()
    S2_VENTRAL_ROOT = _S2_Ventral_Root()
    S3_DORSAL_ROOT = _S3_Dorsal_Root()
    S3_VENTRAL_ROOT = _S3_Ventral_Root()
    S4_DORSAL_ROOT = _S4_Dorsal_Root()
    S4_VENTRAL_ROOT = _S4_Ventral_Root()
    T1_DORSAL_ROOT = _T1_Dorsal_Root()
    T1_VENTRAL_ROOT = _T1_Ventral_Root()
    T10_DORSAL_ROOT = _T10_Dorsal_Root()
    T11_DORSAL_ROOT = _T11_Dorsal_Root()
    T11_VENTRAL_ROOT = _T11_Ventral_Root()
    T10_VENTRAL_ROOT = _T10_Ventral_Root()
    T12_DORSAL_ROOT = _T12_Dorsal_Root()
    T12_VENTRAL_ROOT = _T12_Ventral_Root()
    T13_DORSAL_ROOT = _T13_Dorsal_Root()
    T2_DORSAL_ROOT = _T2_Dorsal_Root()
    T2_VENTRAL_ROOT = _T2_Ventral_Root()
    T3_DORSAL_ROOT = _T3_Dorsal_Root()
    T3_VENTRAL_ROOT = _T3_Ventral_Root()
    T4_DORSAL_ROOT = _T4_Dorsal_Root()
    T4_VENTRAL_ROOT = _T4_Ventral_Root()
    T5_DORSAL_ROOT = _T5_Dorsal_Root()
    T5_VENTRAL_ROOT = _T5_Ventral_Root()
    T6_DORSAL_ROOT = _T6_Dorsal_Root()
    T6_VENTRAL_ROOT = _T6_Ventral_Root()
    T7_DORSAL_ROOT = _T7_Dorsal_Root()
    T7_VENTRAL_ROOT = _T7_Ventral_Root()
    T8_DORSAL_ROOT = _T8_Dorsal_Root()
    T8_VENTRAL_ROOT = _T8_Ventral_Root()
    T9_DORSAL_ROOT = _T9_Dorsal_Root()
    T9_VENTRAL_ROOT = _T9_Ventral_Root()
    T13_VENTRAL_ROOT = _T13_Ventral_Root()
    TL10_DORSAL_ROOT = _Tl10_Dorsal_Root()
    TL10_VENTRAL_ROOT = _Tl10_Ventral_Root()
    TL11_DORSAL_ROOT = _Tl11_Dorsal_Root()
    TL11_VENTRAL_ROOT = _Tl11_Ventral_Root()
    TL12_DORSAL_ROOT = _Tl12_Dorsal_Root()
    TL12_VENTRAL_ROOT = _Tl12_Ventral_Root()
    TL13_DORSAL_ROOT = _Tl13_Dorsal_Root()
    TL13_VENTRAL_ROOT = _Tl13_Ventral_Root()
    TL14_DORSAL_ROOT = _Tl14_Dorsal_Root()
    TL14_VENTRAL_ROOT = _Tl14_Ventral_Root()
    TL15_DORSAL_ROOT = _Tl15_Dorsal_Root()
    TL15_VENTRAL_ROOT = _Tl15_Ventral_Root()
    TL16_DORSAL_ROOT = _Tl16_Dorsal_Root()
    TL16_VENTRAL_ROOT = _Tl16_Ventral_Root()
    TL17_DORSAL_ROOT = _Tl17_Dorsal_Root()
    TL17_VENTRAL_ROOT = _Tl17_Ventral_Root()
    TL18_DORSAL_ROOT = _Tl18_Dorsal_Root()
    TL18_VENTRAL_ROOT = _Tl18_Ventral_Root()
    TL19_DORSAL_ROOT = _Tl19_Dorsal_Root()
    TL19_VENTRAL_ROOT = _Tl19_Ventral_Root()
    TL2_DORSAL_ROOT = _Tl2_Dorsal_Root()
    TL2_VENTRAL_ROOT = _Tl2_Ventral_Root()
    TL3_DORSAL_ROOT = _Tl3_Dorsal_Root()
    TL3_VENTRAL_ROOT = _Tl3_Ventral_Root()
    TL4_DORSAL_ROOT = _Tl4_Dorsal_Root()
    TL4_VENTRAL_ROOT = _Tl4_Ventral_Root()
    TL5_DORSAL_ROOT = _Tl5_Dorsal_Root()
    TL5_VENTRAL_ROOT = _Tl5_Ventral_Root()
    TL6_DORSAL_ROOT = _Tl6_Dorsal_Root()
    TL6_VENTRAL_ROOT = _Tl6_Ventral_Root()
    TL7_DORSAL_ROOT = _Tl7_Dorsal_Root()
    TL7_VENTRAL_ROOT = _Tl7_Ventral_Root()
    TL8_DORSAL_ROOT = _Tl8_Dorsal_Root()
    TL8_VENTRAL_ROOT = _Tl8_Ventral_Root()
    TL9_DORSAL_ROOT = _Tl9_Dorsal_Root()
    TL9_VENTRAL_ROOT = _Tl9_Ventral_Root()
    VAGUS_NERVE_LEFT_RECURRENT_LARYNGEAL_BRANCH = _Vagus_Nerve_Left_Recurrent_Laryngeal_Branch()
    PINNA_MESENCHYME_CONDENSATION = _Pinna_Mesenchyme_Condensation()
    PINNA_REST_OF_MESENCHYME = _Pinna_Rest_Of_Mesenchyme()
    PINNA_CARTILAGE_CONDENSATION = _Pinna_Cartilage_Condensation()
    SUBCUTANEOUS_VEIN = _Subcutaneous_Vein()
    TRUNK_MESENCHYME_DERIVED_FROM_NEURAL_CREST_NON_MIGRATING_CELLS = (
        _Trunk_Mesenchyme_Derived_From_Neural_Crest_Non_Migrating_Cells()
    )
    MESENCHYME_DERIVED_FROM_SOMITES_01_04 = _Mesenchyme_Derived_From_Somites_01_04()
    THYROID_PRIMORDIUM_ENDODERM = _Thyroid_Primordium_Endoderm()
    RHOMBOMERE_1_REST_OF_NEURAL_FOLD = _Rhombomere_1_Rest_Of_Neural_Fold()
    RHOMBOMERE_2_REST_OF_NEURAL_FOLD = _Rhombomere_2_Rest_Of_Neural_Fold()
    RHOMBOMERE_3_REST_OF_NEURAL_FOLD = _Rhombomere_3_Rest_Of_Neural_Fold()
    RHOMBOMERE_4_REST_OF_NEURAL_FOLD = _Rhombomere_4_Rest_Of_Neural_Fold()
    RHOMBOMERE_5_REST_OF_NEURAL_FOLD = _Rhombomere_5_Rest_Of_Neural_Fold()
    OTOCYST_LUMEN = _Otocyst_Lumen()
    L2_VERTEBRA_CENTRUM = _L2_Vertebra_Centrum()
    L2_FUTURE_VERTEBRAL_CANAL = _L2_Future_Vertebral_Canal()
    L2_VERTEBRA_NEURAL_ARCH = _L2_Vertebra_Neural_Arch()
    L2_NEURAL_ARCH_LAMINA = _L2_Neural_Arch_Lamina()
    L2_NEURAL_ARCH_PEDICLE = _L2_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_L2_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_L2_Spinous_Process()
    L2_NEURAL_ARCH_TRANSVERSE_PROCESS = _L2_Neural_Arch_Transverse_Process()
    L3_VERTEBRA_CENTRUM = _L3_Vertebra_Centrum()
    L3_FUTURE_VERTEBRAL_CANAL = _L3_Future_Vertebral_Canal()
    L3_VERTEBRA_NEURAL_ARCH = _L3_Vertebra_Neural_Arch()
    L3_NEURAL_ARCH_LAMINA = _L3_Neural_Arch_Lamina()
    L3_NEURAL_ARCH_PEDICLE = _L3_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_L3_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_L3_Spinous_Process()
    L3_NEURAL_ARCH_TRANSVERSE_PROCESS = _L3_Neural_Arch_Transverse_Process()
    L4_VERTEBRA_CENTRUM = _L4_Vertebra_Centrum()
    L4_FUTURE_VERTEBRAL_CANAL = _L4_Future_Vertebral_Canal()
    L4_VERTEBRA_NEURAL_ARCH = _L4_Vertebra_Neural_Arch()
    L4_NEURAL_ARCH_LAMINA = _L4_Neural_Arch_Lamina()
    L4_NEURAL_ARCH_PEDICLE = _L4_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_L4_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_L4_Spinous_Process()
    L4_NEURAL_ARCH_TRANSVERSE_PROCESS = _L4_Neural_Arch_Transverse_Process()
    L5_VERTEBRA_CENTRUM = _L5_Vertebra_Centrum()
    L5_FUTURE_VERTEBRAL_CANAL = _L5_Future_Vertebral_Canal()
    L5_VERTEBRA_NEURAL_ARCH = _L5_Vertebra_Neural_Arch()
    L5_NEURAL_ARCH_LAMINA = _L5_Neural_Arch_Lamina()
    L5_NEURAL_ARCH_PEDICLE = _L5_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_L5_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_L5_Spinous_Process()
    L5_NEURAL_ARCH_TRANSVERSE_PROCESS = _L5_Neural_Arch_Transverse_Process()
    L6_VERTEBRA_CENTRUM = _L6_Vertebra_Centrum()
    L6_FUTURE_VERTEBRAL_CANAL = _L6_Future_Vertebral_Canal()
    L6_VERTEBRA_NEURAL_ARCH = _L6_Vertebra_Neural_Arch()
    L6_NEURAL_ARCH_LAMINA = _L6_Neural_Arch_Lamina()
    L6_NEURAL_ARCH_PEDICLE = _L6_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_L6_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_L6_Spinous_Process()
    L6_NEURAL_ARCH_TRANSVERSE_PROCESS = _L6_Neural_Arch_Transverse_Process()
    S1_VERTEBRA_CENTRUM = _S1_Vertebra_Centrum()
    S1_FUTURE_VERTEBRAL_CANAL = _S1_Future_Vertebral_Canal()
    S1_VERTEBRA_NEURAL_ARCH = _S1_Vertebra_Neural_Arch()
    S1_NEURAL_ARCH_LAMINA = _S1_Neural_Arch_Lamina()
    S1_NEURAL_ARCH_PEDICLE = _S1_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_S1_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_S1_Spinous_Process()
    S1_NEURAL_ARCH_TRANSVERSE_PROCESS = _S1_Neural_Arch_Transverse_Process()
    S2_VERTEBRA_CENTRUM = _S2_Vertebra_Centrum()
    S2_FUTURE_VERTEBRAL_CANAL = _S2_Future_Vertebral_Canal()
    S2_VERTEBRA_NEURAL_ARCH = _S2_Vertebra_Neural_Arch()
    S2_NEURAL_ARCH_LAMINA = _S2_Neural_Arch_Lamina()
    S2_NEURAL_ARCH_PEDICLE = _S2_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_S2_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_S2_Spinous_Process()
    S2_NEURAL_ARCH_TRANSVERSE_PROCESS = _S2_Neural_Arch_Transverse_Process()
    S3_VERTEBRA_CENTRUM = _S3_Vertebra_Centrum()
    S3_FUTURE_VERTEBRAL_CANAL = _S3_Future_Vertebral_Canal()
    S3_VERTEBRA_NEURAL_ARCH = _S3_Vertebra_Neural_Arch()
    S3_NEURAL_ARCH_LAMINA = _S3_Neural_Arch_Lamina()
    S3_NEURAL_ARCH_PEDICLE = _S3_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_S3_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_S3_Spinous_Process()
    S3_NEURAL_ARCH_TRANSVERSE_PROCESS = _S3_Neural_Arch_Transverse_Process()
    S4_VERTEBRA_CENTRUM = _S4_Vertebra_Centrum()
    S4_FUTURE_VERTEBRAL_CANAL = _S4_Future_Vertebral_Canal()
    S4_VERTEBRA_NEURAL_ARCH = _S4_Vertebra_Neural_Arch()
    S4_NEURAL_ARCH_LAMINA = _S4_Neural_Arch_Lamina()
    S4_NEURAL_ARCH_PEDICLE = _S4_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_S4_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_S4_Spinous_Process()
    S4_NEURAL_ARCH_TRANSVERSE_PROCESS = _S4_Neural_Arch_Transverse_Process()
    T1_VERTEBRA_CENTRUM = _T1_Vertebra_Centrum()
    T1_VERTEBRAL_CANAL = _T1_Vertebral_Canal()
    T1_VERTEBRA_NEURAL_ARCH = _T1_Vertebra_Neural_Arch()
    T1_NEURAL_ARCH_LAMINA = _T1_Neural_Arch_Lamina()
    T1_NEURAL_ARCH_PEDICLE = _T1_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T1_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T1_Spinous_Process()
    T1_NEURAL_ARCH_TRANSVERSE_PROCESS = _T1_Neural_Arch_Transverse_Process()
    T10_VERTEBRA_CENTRUM = _T10_Vertebra_Centrum()
    T10_VERTEBRAL_CANAL = _T10_Vertebral_Canal()
    T10_VERTEBRA_NEURAL_ARCH = _T10_Vertebra_Neural_Arch()
    T10_NEURAL_ARCH_LAMINA = _T10_Neural_Arch_Lamina()
    T10_NEURAL_ARCH_PEDICLE = _T10_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T10_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T10_Spinous_Process()
    T10_NEURAL_ARCH_TRANSVERSE_PROCESS = _T10_Neural_Arch_Transverse_Process()
    T11_VERTEBRA_CENTRUM = _T11_Vertebra_Centrum()
    T11_VERTEBRAL_CANAL = _T11_Vertebral_Canal()
    T11_VERTEBRA_NEURAL_ARCH = _T11_Vertebra_Neural_Arch()
    T11_NEURAL_ARCH_LAMINA = _T11_Neural_Arch_Lamina()
    T11_NEURAL_ARCH_PEDICLE = _T11_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T11_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T11_Spinous_Process()
    T11_NEURAL_ARCH_TRANSVERSE_PROCESS = _T11_Neural_Arch_Transverse_Process()
    T12_VERTEBRA_CENTRUM = _T12_Vertebra_Centrum()
    T12_VERTEBRAL_CANAL = _T12_Vertebral_Canal()
    T12_VERTEBRA_NEURAL_ARCH = _T12_Vertebra_Neural_Arch()
    T12_NEURAL_ARCH_LAMINA = _T12_Neural_Arch_Lamina()
    T12_NEURAL_ARCH_PEDICLE = _T12_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T12_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T12_Spinous_Process()
    T12_NEURAL_ARCH_TRANSVERSE_PROCESS = _T12_Neural_Arch_Transverse_Process()
    T13_VERTEBRA_CENTRUM = _T13_Vertebra_Centrum()
    T13_VERTEBRAL_CANAL = _T13_Vertebral_Canal()
    T13_VERTEBRA_NEURAL_ARCH = _T13_Vertebra_Neural_Arch()
    T13_NEURAL_ARCH_LAMINA = _T13_Neural_Arch_Lamina()
    T13_NEURAL_ARCH_PEDICLE = _T13_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T13_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T13_Spinous_Process()
    T13_NEURAL_ARCH_TRANSVERSE_PROCESS = _T13_Neural_Arch_Transverse_Process()
    T2_VERTEBRA_CENTRUM = _T2_Vertebra_Centrum()
    T2_VERTEBRAL_CANAL = _T2_Vertebral_Canal()
    T2_VERTEBRA_NEURAL_ARCH = _T2_Vertebra_Neural_Arch()
    T2_NEURAL_ARCH_LAMINA = _T2_Neural_Arch_Lamina()
    T2_NEURAL_ARCH_PEDICLE = _T2_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T2_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T2_Spinous_Process()
    T2_NEURAL_ARCH_TRANSVERSE_PROCESS = _T2_Neural_Arch_Transverse_Process()
    T3_VERTEBRA_CENTRUM = _T3_Vertebra_Centrum()
    T3_VERTEBRAL_CANAL = _T3_Vertebral_Canal()
    T3_VERTEBRA_NEURAL_ARCH = _T3_Vertebra_Neural_Arch()
    T3_NEURAL_ARCH_LAMINA = _T3_Neural_Arch_Lamina()
    T3_NEURAL_ARCH_PEDICLE = _T3_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T3_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T3_Spinous_Process()
    T3_NEURAL_ARCH_TRANSVERSE_PROCESS = _T3_Neural_Arch_Transverse_Process()
    T4_VERTEBRA_CENTRUM = _T4_Vertebra_Centrum()
    T4_VERTEBRAL_CANAL = _T4_Vertebral_Canal()
    T4_VERTEBRA_NEURAL_ARCH = _T4_Vertebra_Neural_Arch()
    T4_NEURAL_ARCH_LAMINA = _T4_Neural_Arch_Lamina()
    T4_NEURAL_ARCH_PEDICLE = _T4_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T4_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T4_Spinous_Process()
    T4_NEURAL_ARCH_TRANSVERSE_PROCESS = _T4_Neural_Arch_Transverse_Process()
    T5_VERTEBRA_CENTRUM = _T5_Vertebra_Centrum()
    T5_VERTEBRAL_CANAL = _T5_Vertebral_Canal()
    T5_VERTEBRA_NEURAL_ARCH = _T5_Vertebra_Neural_Arch()
    T5_NEURAL_ARCH_LAMINA = _T5_Neural_Arch_Lamina()
    T5_NEURAL_ARCH_PEDICLE = _T5_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T5_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T5_Spinous_Process()
    T5_NEURAL_ARCH_TRANSVERSE_PROCESS = _T5_Neural_Arch_Transverse_Process()
    T6_VERTEBRA_CENTRUM = _T6_Vertebra_Centrum()
    T6_VERTEBRAL_CANAL = _T6_Vertebral_Canal()
    T6_VERTEBRA_NEURAL_ARCH = _T6_Vertebra_Neural_Arch()
    T6_NEURAL_ARCH_LAMINA = _T6_Neural_Arch_Lamina()
    T6_NEURAL_ARCH_PEDICLE = _T6_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T6_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T6_Spinous_Process()
    T6_NEURAL_ARCH_TRANSVERSE_PROCESS = _T6_Neural_Arch_Transverse_Process()
    T7_VERTEBRA_CENTRUM = _T7_Vertebra_Centrum()
    T7_VERTEBRAL_CANAL = _T7_Vertebral_Canal()
    T7_VERTEBRA_NEURAL_ARCH = _T7_Vertebra_Neural_Arch()
    T7_NEURAL_ARCH_LAMINA = _T7_Neural_Arch_Lamina()
    T7_NEURAL_ARCH_PEDICLE = _T7_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T7_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T7_Spinous_Process()
    T7_NEURAL_ARCH_TRANSVERSE_PROCESS = _T7_Neural_Arch_Transverse_Process()
    T8_VERTEBRA_CENTRUM = _T8_Vertebra_Centrum()
    T8_VERTEBRAL_CANAL = _T8_Vertebral_Canal()
    T8_VERTEBRA_NEURAL_ARCH = _T8_Vertebra_Neural_Arch()
    T8_NEURAL_ARCH_LAMINA = _T8_Neural_Arch_Lamina()
    T8_NEURAL_ARCH_PEDICLE = _T8_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T8_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T8_Spinous_Process()
    T8_NEURAL_ARCH_TRANSVERSE_PROCESS = _T8_Neural_Arch_Transverse_Process()
    T9_VERTEBRA_CENTRUM = _T9_Vertebra_Centrum()
    T9_VERTEBRAL_CANAL = _T9_Vertebral_Canal()
    T9_VERTEBRA_NEURAL_ARCH = _T9_Vertebra_Neural_Arch()
    T9_NEURAL_ARCH_LAMINA = _T9_Neural_Arch_Lamina()
    T9_NEURAL_ARCH_PEDICLE = _T9_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_T9_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_T9_Spinous_Process()
    T9_NEURAL_ARCH_TRANSVERSE_PROCESS = _T9_Neural_Arch_Transverse_Process()
    TL1_VERTEBRA_CENTRUM = _Tl1_Vertebra_Centrum()
    TL1_VERTEBRAL_CANAL = _Tl1_Vertebral_Canal()
    TL1_VERTEBRA_NEURAL_ARCH = _Tl1_Vertebra_Neural_Arch()
    TL1_NEURAL_ARCH_LAMINA = _Tl1_Neural_Arch_Lamina()
    TL1_NEURAL_ARCH_PEDICLE = _Tl1_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL1_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl1_Spinous_Process()
    TL1_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl1_Neural_Arch_Transverse_Process()
    TL10_VERTEBRA_CENTRUM = _Tl10_Vertebra_Centrum()
    TL10_VERTEBRAL_CANAL = _Tl10_Vertebral_Canal()
    TL10_VERTEBRA_NEURAL_ARCH = _Tl10_Vertebra_Neural_Arch()
    TL10_NEURAL_ARCH_LAMINA = _Tl10_Neural_Arch_Lamina()
    TL10_NEURAL_ARCH_PEDICLE = _Tl10_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL10_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl10_Spinous_Process()
    TL10_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl10_Neural_Arch_Transverse_Process()
    TL11_VERTEBRA_CENTRUM = _Tl11_Vertebra_Centrum()
    TL11_VERTEBRAL_CANAL = _Tl11_Vertebral_Canal()
    TL11_VERTEBRA_NEURAL_ARCH = _Tl11_Vertebra_Neural_Arch()
    TL11_NEURAL_ARCH_LAMINA = _Tl11_Neural_Arch_Lamina()
    TL11_NEURAL_ARCH_PEDICLE = _Tl11_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL11_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl11_Spinous_Process()
    TL11_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl11_Neural_Arch_Transverse_Process()
    TL12_VERTEBRA_CENTRUM = _Tl12_Vertebra_Centrum()
    TL12_VERTEBRAL_CANAL = _Tl12_Vertebral_Canal()
    TL12_VERTEBRA_NEURAL_ARCH = _Tl12_Vertebra_Neural_Arch()
    TL12_NEURAL_ARCH_LAMINA = _Tl12_Neural_Arch_Lamina()
    TL12_NEURAL_ARCH_PEDICLE = _Tl12_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL12_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl12_Spinous_Process()
    TL12_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl12_Neural_Arch_Transverse_Process()
    TL13_VERTEBRA_CENTRUM = _Tl13_Vertebra_Centrum()
    TL13_VERTEBRAL_CANAL = _Tl13_Vertebral_Canal()
    TL13_VERTEBRA_NEURAL_ARCH = _Tl13_Vertebra_Neural_Arch()
    TL13_NEURAL_ARCH_LAMINA = _Tl13_Neural_Arch_Lamina()
    TL13_NEURAL_ARCH_PEDICLE = _Tl13_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL13_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl13_Spinous_Process()
    TL13_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl13_Neural_Arch_Transverse_Process()
    TL14_VERTEBRA_CENTRUM = _Tl14_Vertebra_Centrum()
    TL14_VERTEBRAL_CANAL = _Tl14_Vertebral_Canal()
    TL14_VERTEBRA_NEURAL_ARCH = _Tl14_Vertebra_Neural_Arch()
    TL14_NEURAL_ARCH_LAMINA = _Tl14_Neural_Arch_Lamina()
    TL14_NEURAL_ARCH_PEDICLE = _Tl14_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL14_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl14_Spinous_Process()
    TL14_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl14_Neural_Arch_Transverse_Process()
    TL15_VERTEBRA_CENTRUM = _Tl15_Vertebra_Centrum()
    TL15_VERTEBRAL_CANAL = _Tl15_Vertebral_Canal()
    TL15_VERTEBRA_NEURAL_ARCH = _Tl15_Vertebra_Neural_Arch()
    TL15_NEURAL_ARCH_LAMINA = _Tl15_Neural_Arch_Lamina()
    TL15_NEURAL_ARCH_PEDICLE = _Tl15_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL15_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl15_Spinous_Process()
    TL15_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl15_Neural_Arch_Transverse_Process()
    TL16_VERTEBRA_CENTRUM = _Tl16_Vertebra_Centrum()
    TL16_VERTEBRAL_CANAL = _Tl16_Vertebral_Canal()
    TL16_VERTEBRA_NEURAL_ARCH = _Tl16_Vertebra_Neural_Arch()
    TL16_NEURAL_ARCH_LAMINA = _Tl16_Neural_Arch_Lamina()
    TL16_NEURAL_ARCH_PEDICLE = _Tl16_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL16_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl16_Spinous_Process()
    TL16_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl16_Neural_Arch_Transverse_Process()
    TL17_VERTEBRA_CENTRUM = _Tl17_Vertebra_Centrum()
    TL17_VERTEBRAL_CANAL = _Tl17_Vertebral_Canal()
    TL17_VERTEBRA_NEURAL_ARCH = _Tl17_Vertebra_Neural_Arch()
    TL17_NEURAL_ARCH_LAMINA = _Tl17_Neural_Arch_Lamina()
    TL17_NEURAL_ARCH_PEDICLE = _Tl17_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL17_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl17_Spinous_Process()
    TL17_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl17_Neural_Arch_Transverse_Process()
    TL18_VERTEBRA_CENTRUM = _Tl18_Vertebra_Centrum()
    TL18_VERTEBRAL_CANAL = _Tl18_Vertebral_Canal()
    TL18_VERTEBRA_NEURAL_ARCH = _Tl18_Vertebra_Neural_Arch()
    TL18_NEURAL_ARCH_LAMINA = _Tl18_Neural_Arch_Lamina()
    TL18_NEURAL_ARCH_PEDICLE = _Tl18_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL18_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl18_Spinous_Process()
    TL18_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl18_Neural_Arch_Transverse_Process()
    TL19_VERTEBRA_CENTRUM = _Tl19_Vertebra_Centrum()
    TL19_VERTEBRAL_CANAL = _Tl19_Vertebral_Canal()
    TL19_VERTEBRA_NEURAL_ARCH = _Tl19_Vertebra_Neural_Arch()
    TL19_NEURAL_ARCH_LAMINA = _Tl19_Neural_Arch_Lamina()
    TL19_NEURAL_ARCH_PEDICLE = _Tl19_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL19_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl19_Spinous_Process()
    TL19_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl19_Neural_Arch_Transverse_Process()
    TL2_VERTEBRA_CENTRUM = _Tl2_Vertebra_Centrum()
    TL2_VERTEBRAL_CANAL = _Tl2_Vertebral_Canal()
    TL2_VERTEBRA_NEURAL_ARCH = _Tl2_Vertebra_Neural_Arch()
    TL2_NEURAL_ARCH_LAMINA = _Tl2_Neural_Arch_Lamina()
    TL2_NEURAL_ARCH_PEDICLE = _Tl2_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL2_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl2_Spinous_Process()
    TL2_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl2_Neural_Arch_Transverse_Process()
    TL3_VERTEBRA_CENTRUM = _Tl3_Vertebra_Centrum()
    TL3_VERTEBRAL_CANAL = _Tl3_Vertebral_Canal()
    TL3_VERTEBRA_NEURAL_ARCH = _Tl3_Vertebra_Neural_Arch()
    TL3_NEURAL_ARCH_LAMINA = _Tl3_Neural_Arch_Lamina()
    TL3_NEURAL_ARCH_PEDICLE = _Tl3_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL3_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl3_Spinous_Process()
    TL3_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl3_Neural_Arch_Transverse_Process()
    TL4_VERTEBRA_CENTRUM = _Tl4_Vertebra_Centrum()
    TL4_VERTEBRAL_CANAL = _Tl4_Vertebral_Canal()
    TL4_VERTEBRA_NEURAL_ARCH = _Tl4_Vertebra_Neural_Arch()
    TL4_NEURAL_ARCH_LAMINA = _Tl4_Neural_Arch_Lamina()
    TL4_NEURAL_ARCH_PEDICLE = _Tl4_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL4_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl4_Spinous_Process()
    TL4_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl4_Neural_Arch_Transverse_Process()
    TL5_VERTEBRA_CENTRUM = _Tl5_Vertebra_Centrum()
    TL5_VERTEBRAL_CANAL = _Tl5_Vertebral_Canal()
    TL5_VERTEBRA_NEURAL_ARCH = _Tl5_Vertebra_Neural_Arch()
    TL5_NEURAL_ARCH_LAMINA = _Tl5_Neural_Arch_Lamina()
    TL5_NEURAL_ARCH_PEDICLE = _Tl5_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL5_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl5_Spinous_Process()
    TL5_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl5_Neural_Arch_Transverse_Process()
    TL6_VERTEBRA_CENTRUM = _Tl6_Vertebra_Centrum()
    TL6_VERTEBRAL_CANAL = _Tl6_Vertebral_Canal()
    TL6_VERTEBRA_NEURAL_ARCH = _Tl6_Vertebra_Neural_Arch()
    TL6_NEURAL_ARCH_LAMINA = _Tl6_Neural_Arch_Lamina()
    TL6_NEURAL_ARCH_PEDICLE = _Tl6_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL6_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl6_Spinous_Process()
    TL6_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl6_Neural_Arch_Transverse_Process()
    TL7_VERTEBRA_CENTRUM = _Tl7_Vertebra_Centrum()
    TL7_VERTEBRAL_CANAL = _Tl7_Vertebral_Canal()
    TL7_VERTEBRA_NEURAL_ARCH = _Tl7_Vertebra_Neural_Arch()
    TL7_NEURAL_ARCH_LAMINA = _Tl7_Neural_Arch_Lamina()
    TL7_NEURAL_ARCH_PEDICLE = _Tl7_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL7_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl7_Spinous_Process()
    TL7_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl7_Neural_Arch_Transverse_Process()
    TL8_VERTEBRA_CENTRUM = _Tl8_Vertebra_Centrum()
    TL8_VERTEBRAL_CANAL = _Tl8_Vertebral_Canal()
    TL8_VERTEBRA_NEURAL_ARCH = _Tl8_Vertebra_Neural_Arch()
    TL8_NEURAL_ARCH_LAMINA = _Tl8_Neural_Arch_Lamina()
    TL8_NEURAL_ARCH_PEDICLE = _Tl8_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL8_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl8_Spinous_Process()
    TL8_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl8_Neural_Arch_Transverse_Process()
    TL9_VERTEBRA_CENTRUM = _Tl9_Vertebra_Centrum()
    TL9_VERTEBRAL_CANAL = _Tl9_Vertebral_Canal()
    TL9_VERTEBRA_NEURAL_ARCH = _Tl9_Vertebra_Neural_Arch()
    TL9_NEURAL_ARCH_LAMINA = _Tl9_Neural_Arch_Lamina()
    TL9_NEURAL_ARCH_PEDICLE = _Tl9_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_TL9_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Tl9_Spinous_Process()
    TL9_NEURAL_ARCH_TRANSVERSE_PROCESS = _Tl9_Neural_Arch_Transverse_Process()
    T10_RIB_COSTAL_CARTILAGE = _T10_Rib_Costal_Cartilage()
    T10_RIB_HEAD_CARTILAGE = _T10_Rib_Head_Cartilage()
    T10_RIB_NECK_CARTILAGE = _T10_Rib_Neck_Cartilage()
    T11_RIB_COSTAL_CARTILAGE = _T11_Rib_Costal_Cartilage()
    T11_RIB_HEAD_CARTILAGE = _T11_Rib_Head_Cartilage()
    T11_RIB_NECK_CARTILAGE = _T11_Rib_Neck_Cartilage()
    T12_RIB_COSTAL_CARTILAGE = _T12_Rib_Costal_Cartilage()
    T12_RIB_HEAD_CARTILAGE = _T12_Rib_Head_Cartilage()
    T12_RIB_NECK_CARTILAGE = _T12_Rib_Neck_Cartilage()
    T13_RIB_COSTAL_CARTILAGE = _T13_Rib_Costal_Cartilage()
    T13_RIB_HEAD_CARTILAGE = _T13_Rib_Head_Cartilage()
    T13_RIB_NECK_CARTILAGE = _T13_Rib_Neck_Cartilage()
    T2_RIB_COSTAL_CARTILAGE = _T2_Rib_Costal_Cartilage()
    T2_RIB_HEAD_CARTILAGE = _T2_Rib_Head_Cartilage()
    T2_RIB_NECK_CARTILAGE = _T2_Rib_Neck_Cartilage()
    T3_RIB_COSTAL_CARTILAGE = _T3_Rib_Costal_Cartilage()
    T3_RIB_HEAD_CARTILAGE = _T3_Rib_Head_Cartilage()
    T3_RIB_NECK_CARTILAGE = _T3_Rib_Neck_Cartilage()
    T4_RIB_COSTAL_CARTILAGE = _T4_Rib_Costal_Cartilage()
    T4_RIB_HEAD_CARTILAGE = _T4_Rib_Head_Cartilage()
    T4_RIB_NECK_CARTILAGE = _T4_Rib_Neck_Cartilage()
    T5_RIB_COSTAL_CARTILAGE = _T5_Rib_Costal_Cartilage()
    T5_RIB_HEAD_CARTILAGE = _T5_Rib_Head_Cartilage()
    T5_RIB_NECK_CARTILAGE = _T5_Rib_Neck_Cartilage()
    T6_RIB_COSTAL_CARTILAGE = _T6_Rib_Costal_Cartilage()
    T6_RIB_HEAD_CARTILAGE = _T6_Rib_Head_Cartilage()
    T6_RIB_NECK_CARTILAGE = _T6_Rib_Neck_Cartilage()
    T7_RIB_COSTAL_CARTILAGE = _T7_Rib_Costal_Cartilage()
    T7_RIB_HEAD_CARTILAGE = _T7_Rib_Head_Cartilage()
    T7_RIB_NECK_CARTILAGE = _T7_Rib_Neck_Cartilage()
    T8_RIB_COSTAL_CARTILAGE = _T8_Rib_Costal_Cartilage()
    T8_RIB_HEAD_CARTILAGE = _T8_Rib_Head_Cartilage()
    T8_RIB_NECK_CARTILAGE = _T8_Rib_Neck_Cartilage()
    T9_RIB_COSTAL_CARTILAGE = _T9_Rib_Costal_Cartilage()
    T9_RIB_HEAD_CARTILAGE = _T9_Rib_Head_Cartilage()
    T9_RIB_NECK_CARTILAGE = _T9_Rib_Neck_Cartilage()
    C3_VERTEBRA_CENTRUM = _C3_Vertebra_Centrum()
    C3_VERTEBRAL_CANAL = _C3_Vertebral_Canal()
    C3_VERTEBRA_NEURAL_ARCH = _C3_Vertebra_Neural_Arch()
    C3_NEURAL_ARCH_LAMINA = _C3_Neural_Arch_Lamina()
    C3_NEURAL_ARCH_PEDICLE = _C3_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_C3_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_C3_Spinous_Process()
    C3_NEURAL_ARCH_TRANSVERSE_PROCESS = _C3_Neural_Arch_Transverse_Process()
    C4_VERTEBRA_CENTRUM = _C4_Vertebra_Centrum()
    C4_VERTEBRAL_CANAL = _C4_Vertebral_Canal()
    C4_VERTEBRA_NEURAL_ARCH = _C4_Vertebra_Neural_Arch()
    C4_NEURAL_ARCH_LAMINA = _C4_Neural_Arch_Lamina()
    C4_NEURAL_ARCH_PEDICLE = _C4_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_C4_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_C4_Spinous_Process()
    C4_NEURAL_ARCH_TRANSVERSE_PROCESS = _C4_Neural_Arch_Transverse_Process()
    C5_VERTEBRA_CENTRUM = _C5_Vertebra_Centrum()
    C5_VERTEBRAL_CANAL = _C5_Vertebral_Canal()
    C5_VERTEBRA_NEURAL_ARCH = _C5_Vertebra_Neural_Arch()
    C5_NEURAL_ARCH_LAMINA = _C5_Neural_Arch_Lamina()
    C5_NEURAL_ARCH_PEDICLE = _C5_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_C5_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_C5_Spinous_Process()
    C5_NEURAL_ARCH_TRANSVERSE_PROCESS = _C5_Neural_Arch_Transverse_Process()
    C6_VERTEBRA_CENTRUM = _C6_Vertebra_Centrum()
    C6_VERTEBRAL_CANAL = _C6_Vertebral_Canal()
    C6_VERTEBRA_NEURAL_ARCH = _C6_Vertebra_Neural_Arch()
    C6_NEURAL_ARCH_LAMINA = _C6_Neural_Arch_Lamina()
    C6_NEURAL_ARCH_PEDICLE = _C6_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_C6_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_C6_Spinous_Process()
    C6_NEURAL_ARCH_TRANSVERSE_PROCESS = _C6_Neural_Arch_Transverse_Process()
    C7_VERTEBRA_CENTRUM = _C7_Vertebra_Centrum()
    C7_VERTEBRAL_CANAL = _C7_Vertebral_Canal()
    C7_VERTEBRA_NEURAL_ARCH = _C7_Vertebra_Neural_Arch()
    C7_NEURAL_ARCH_LAMINA = _C7_Neural_Arch_Lamina()
    C7_NEURAL_ARCH_PEDICLE = _C7_Neural_Arch_Pedicle()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_C7_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_C7_Spinous_Process()
    C7_NEURAL_ARCH_TRANSVERSE_PROCESS = _C7_Neural_Arch_Transverse_Process()
    MOUSE = _Mouse()
    LEFT_ATRIUM_LUMEN = _Left_Atrium_Lumen()
    RIGHT_ATRIUM_LUMEN = _Right_Atrium_Lumen()
    INTERVENTRICULAR_CANAL = _Interventricular_Canal()
    LEFT_VENTRICLE_LUMEN = _Left_Ventricle_Lumen()
    RIGHT_VENTRICLE_LUMEN = _Right_Ventricle_Lumen()
    INTERSEGMENTAL_VEIN = _Intersegmental_Vein()
    MEDIAN_SACRAL_VEIN = _Median_Sacral_Vein()
    INFERIOR_VENA_CAVA_INTRAHEPATIC_PART = _Inferior_Vena_Cava_Intrahepatic_Part()
    COMMUNICATION_DUCTUS_VENOSUS_TO_PORTAL_VEIN = _Communication_Ductus_Venosus_To_Portal_Vein()
    PHYSIOLOGICAL_UMBILICAL_HERNIA_MESENCHYME = _Physiological_Umbilical_Hernia_Mesenchyme()
    PHYSIOLOGICAL_UMBILICAL_HERNIA_MESOTHELIUM = _Physiological_Umbilical_Hernia_Mesothelium()
    UMBILICAL_CORD = _Umbilical_Cord()
    UMBILICAL_CORD_MESENCHYME = _Umbilical_Cord_Mesenchyme()
    VITELLINE_DUCT = _Vitelline_Duct()
    VITELLINE_VEIN_VITELLINE_DUCT_PART = _Vitelline_Vein_Vitelline_Duct_Part()
    CAVITY_OF_PHYSIOLOGICAL_UMBILICAL_HERNIA = _Cavity_Of_Physiological_Umbilical_Hernia()
    CAVITY_OF_PHYSIOLOGICAL_UMBILICAL_HERNIA_MESOTHELIUM = _Cavity_Of_Physiological_Umbilical_Hernia_Mesothelium()
    PANCREAS_MESENCHYME = _Pancreas_Mesenchyme()
    HINDLIMB_DIGIT_1_INTERPHALANGEAL_JOINT = _Hindlimb_Digit_1_Interphalangeal_Joint()
    HINDLIMB_DIGIT_1_METATARSAL_PHALANGEAL_JOINT = _Hindlimb_Digit_1_Metatarsal_Phalangeal_Joint()
    HINDLIMB_DIGIT_2_METATARSAL_PHALANGEAL_JOINT = _Hindlimb_Digit_2_Metatarsal_Phalangeal_Joint()
    HINDLIMB_DIGIT_2_INTERPHALANGEAL_JOINT = _Hindlimb_Digit_2_Interphalangeal_Joint()
    HINDLIMB_DIGIT_3_INTERPHALANGEAL_JOINT = _Hindlimb_Digit_3_Interphalangeal_Joint()
    HINDLIMB_DIGIT_3_METATARSAL_PHALANGEAL_JOINT = _Hindlimb_Digit_3_Metatarsal_Phalangeal_Joint()
    HINDLIMB_DIGIT_4_INTERPHALANGEAL_JOINT = _Hindlimb_Digit_4_Interphalangeal_Joint()
    HINDLIMB_DIGIT_4_METATARSAL_PHALANGEAL_JOINT = _Hindlimb_Digit_4_Metatarsal_Phalangeal_Joint()
    HINDLIMB_DIGIT_5_INTERPHALANGEAL_JOINT = _Hindlimb_Digit_5_Interphalangeal_Joint()
    HINDLIMB_DIGIT_5_METATARSAL_PHALANGEAL_JOINT = _Hindlimb_Digit_5_Metatarsal_Phalangeal_Joint()
    C1_VERTEBRAL_CANAL = _C1_Vertebral_Canal()
    C1_VERTEBRA_NEURAL_ARCH = _C1_Vertebra_Neural_Arch()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_C1_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_C1_Spinous_Process()
    C1_NEURAL_ARCH_LAMINA = _C1_Neural_Arch_Lamina()
    C1_NEURAL_ARCH_PEDICLE = _C1_Neural_Arch_Pedicle()
    C2_VERTEBRA_CENTRUM = _C2_Vertebra_Centrum()
    ODONTOID_PROCESS = _Odontoid_Process()
    C2_VERTEBRAL_CANAL = _C2_Vertebral_Canal()
    C2_VERTEBRA_NEURAL_ARCH = _C2_Vertebra_Neural_Arch()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_C2_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_C2_Spinous_Process()
    C2_NEURAL_ARCH_LAMINA = _C2_Neural_Arch_Lamina()
    C2_NEURAL_ARCH_PEDICLE = _C2_Neural_Arch_Pedicle()
    C3_FORAMEN_TRANSVERSARIUM = _C3_Foramen_Transversarium()
    C4_FORAMEN_TRANSVERSARIUM = _C4_Foramen_Transversarium()
    C5_FORAMEN_TRANSVERSARIUM = _C5_Foramen_Transversarium()
    C6_FORAMEN_TRANSVERSARIUM = _C6_Foramen_Transversarium()
    C7_FORAMEN_TRANSVERSARIUM = _C7_Foramen_Transversarium()
    C1_MIXED_SPINAL_NERVE = _C1_Mixed_Spinal_Nerve()
    C2_MIXED_SPINAL_NERVE = _C2_Mixed_Spinal_Nerve()
    C3_MIXED_SPINAL_NERVE = _C3_Mixed_Spinal_Nerve()
    C4_MIXED_SPINAL_NERVE = _C4_Mixed_Spinal_Nerve()
    C5_MIXED_SPINAL_NERVE = _C5_Mixed_Spinal_Nerve()
    C6_MIXED_SPINAL_NERVE = _C6_Mixed_Spinal_Nerve()
    C7_MIXED_SPINAL_NERVE = _C7_Mixed_Spinal_Nerve()
    L1_MIXED_SPINAL_NERVE = _L1_Mixed_Spinal_Nerve()
    L2_MIXED_SPINAL_NERVE = _L2_Mixed_Spinal_Nerve()
    L3_MIXED_SPINAL_NERVE = _L3_Mixed_Spinal_Nerve()
    L4_MIXED_SPINAL_NERVE = _L4_Mixed_Spinal_Nerve()
    L5_MIXED_SPINAL_NERVE = _L5_Mixed_Spinal_Nerve()
    L6_MIXED_SPINAL_NERVE = _L6_Mixed_Spinal_Nerve()
    S1_MIXED_SPINAL_NERVE = _S1_Mixed_Spinal_Nerve()
    S2_MIXED_SPINAL_NERVE = _S2_Mixed_Spinal_Nerve()
    S3_MIXED_SPINAL_NERVE = _S3_Mixed_Spinal_Nerve()
    S4_MIXED_SPINAL_NERVE = _S4_Mixed_Spinal_Nerve()
    T1_MIXED_SPINAL_NERVE = _T1_Mixed_Spinal_Nerve()
    T2_MIXED_SPINAL_NERVE = _T2_Mixed_Spinal_Nerve()
    T3_MIXED_SPINAL_NERVE = _T3_Mixed_Spinal_Nerve()
    T4_MIXED_SPINAL_NERVE = _T4_Mixed_Spinal_Nerve()
    T5_MIXED_SPINAL_NERVE = _T5_Mixed_Spinal_Nerve()
    T6_MIXED_SPINAL_NERVE = _T6_Mixed_Spinal_Nerve()
    T7_MIXED_SPINAL_NERVE = _T7_Mixed_Spinal_Nerve()
    T8_MIXED_SPINAL_NERVE = _T8_Mixed_Spinal_Nerve()
    T9_MIXED_SPINAL_NERVE = _T9_Mixed_Spinal_Nerve()
    T10_MIXED_SPINAL_NERVE = _T10_Mixed_Spinal_Nerve()
    T11_MIXED_SPINAL_NERVE = _T11_Mixed_Spinal_Nerve()
    T12_MIXED_SPINAL_NERVE = _T12_Mixed_Spinal_Nerve()
    T13_MIXED_SPINAL_NERVE = _T13_Mixed_Spinal_Nerve()
    T1_RIB_SHAFT_OSSIFIED_REGION = _T1_Rib_Shaft_Ossified_Region()
    T1_RIB_SHAFT_NON_OSSIFIED_REGION = _T1_Rib_Shaft_Non_Ossified_Region()
    T2_RIB_SHAFT_OSSIFIED_REGION = _T2_Rib_Shaft_Ossified_Region()
    T2_RIB_SHAFT_NON_OSSIFIED_REGION = _T2_Rib_Shaft_Non_Ossified_Region()
    T3_RIB_SHAFT_OSSIFIED_REGION = _T3_Rib_Shaft_Ossified_Region()
    T3_RIB_SHAFT_NON_OSSIFIED_REGION = _T3_Rib_Shaft_Non_Ossified_Region()
    T4_RIB_SHAFT_OSSIFIED_REGION = _T4_Rib_Shaft_Ossified_Region()
    T4_RIB_SHAFT_NON_OSSIFIED_REGION = _T4_Rib_Shaft_Non_Ossified_Region()
    T5_RIB_SHAFT_OSSIFIED_REGION = _T5_Rib_Shaft_Ossified_Region()
    T5_RIB_SHAFT_NON_OSSIFIED_REGION = _T5_Rib_Shaft_Non_Ossified_Region()
    T6_RIB_SHAFT_OSSIFIED_REGION = _T6_Rib_Shaft_Ossified_Region()
    T6_RIB_SHAFT_NON_OSSIFIED_REGION = _T6_Rib_Shaft_Non_Ossified_Region()
    T7_RIB_SHAFT_OSSIFIED_REGION = _T7_Rib_Shaft_Ossified_Region()
    T7_RIB_SHAFT_NON_OSSIFIED_REGION = _T7_Rib_Shaft_Non_Ossified_Region()
    T8_RIB_SHAFT_OSSIFIED_REGION = _T8_Rib_Shaft_Ossified_Region()
    T8_RIB_SHAFT_NON_OSSIFIED_REGION = _T8_Rib_Shaft_Non_Ossified_Region()
    T9_RIB_SHAFT_OSSIFIED_REGION = _T9_Rib_Shaft_Ossified_Region()
    T9_RIB_SHAFT_NON_OSSIFIED_REGION = _T9_Rib_Shaft_Non_Ossified_Region()
    T10_RIB_SHAFT_OSSIFIED_REGION = _T10_Rib_Shaft_Ossified_Region()
    T10_RIB_SHAFT_NON_OSSIFIED_REGION = _T10_Rib_Shaft_Non_Ossified_Region()
    T11_RIB_SHAFT_OSSIFIED_REGION = _T11_Rib_Shaft_Ossified_Region()
    T11_RIB_SHAFT_NON_OSSIFIED_REGION = _T11_Rib_Shaft_Non_Ossified_Region()
    T12_RIB_SHAFT_NON_OSSIFIED_REGION = _T12_Rib_Shaft_Non_Ossified_Region()
    T12_RIB_SHAFT_OSSIFIED_REGION = _T12_Rib_Shaft_Ossified_Region()
    T13_RIB_SHAFT_OSSIFIED_REGION = _T13_Rib_Shaft_Ossified_Region()
    T13_RIB_SHAFT_NON_OSSIFIED_REGION = _T13_Rib_Shaft_Non_Ossified_Region()
    C1_NEURAL_ARCH_TRANSVERSE_PROCESS = _C1_Neural_Arch_Transverse_Process()
    C1_FORAMEN_TRANSVERSARIUM = _C1_Foramen_Transversarium()
    C2_NEURAL_ARCH_TRANSVERSE_PROCESS = _C2_Neural_Arch_Transverse_Process()
    C2_FORAMEN_TRANSVERSARIUM = _C2_Foramen_Transversarium()
    VIBRISSA_BULB = _Vibrissa_Bulb()
    VIBRISSA_FOLLICLE = _Vibrissa_Follicle()
    VIBRISSA_ROOT_SHEATH = _Vibrissa_Root_Sheath()
    VIBRISSA_HAIR = _Vibrissa_Hair()
    VIBRISSA_ARRECTOR_PILI_MUSCLE = _Vibrissa_Arrector_Pili_Muscle()
    HAIR_ARRECTOR_PILI_MUSCLE = _Hair_Arrector_Pili_Muscle()
    MALE_INGUINAL_CANAL = _Male_Inguinal_Canal()
    ENTERIC_NERVOUS_SYSTEM = _Enteric_Nervous_System()
    PUBIS_CARTILAGE_CONDENSATION = _Pubis_Cartilage_Condensation()
    ISCHIUM_CARTILAGE_CONDENSATION = _Ischium_Cartilage_Condensation()
    ORAL_MUCOSA = _Oral_Mucosa()
    ORAL_EPITHELIUM = _Oral_Epithelium()
    ORAL_LAMINA_PROPRIA = _Oral_Lamina_Propria()
    ORAL_REGION_MUSCULARIS = _Oral_Region_Muscularis()
    PHARYNX_MUCOSA = _Pharynx_Mucosa()
    PHARYNX_MUSCULARIS = _Pharynx_Muscularis()
    PHARYNX_LAMINA_PROPRIA = _Pharynx_Lamina_Propria()
    ESOPHAGUS_MUCOSA = _Esophagus_Mucosa()
    ESOPHAGUS_MUSCULARIS = _Esophagus_Muscularis()
    ESOPHAGUS_LAMINA_PROPRIA = _Esophagus_Lamina_Propria()
    ESOPHAGUS_MUSCULARIS_MUCOSA = _Esophagus_Muscularis_Mucosa()
    FOREGUT_MIDGUT_JUNCTION_MUCOSA = _Foregut_Midgut_Junction_Mucosa()
    FOREGUT_MIDGUT_JUNCTION_SUBMUCOSA = _Foregut_Midgut_Junction_Submucosa()
    FOREGUT_MIDGUT_JUNCTION_MUSCULARIS = _Foregut_Midgut_Junction_Muscularis()
    FOREGUT_MIDGUT_JUNCTION_SEROSA = _Foregut_Midgut_Junction_Serosa()
    FOREGUT_MIDGUT_JUNCTION_LAMINA_PROPRIA = _Foregut_Midgut_Junction_Lamina_Propria()
    FOREGUT_MIDGUT_JUNCTION_MUSCULARIS_MUCOSA = _Foregut_Midgut_Junction_Muscularis_Mucosa()
    DUODENUM_ROSTRAL_PART_MUCOSA = _Duodenum_Rostral_Part_Mucosa()
    DUODENUM_ROSTRAL_PART_SUBMUCOSA = _Duodenum_Rostral_Part_Submucosa()
    DUODENUM_ROSTRAL_PART_MUSCULARIS = _Duodenum_Rostral_Part_Muscularis()
    DUODENUM_ROSTRAL_PART_SEROSA = _Duodenum_Rostral_Part_Serosa()
    DUODENUM_ROSTRAL_PART_LAMINA_PROPRIA = _Duodenum_Rostral_Part_Lamina_Propria()
    DUODENUM_ROSTRAL_PART_MUSCULARIS_MUCOSA = _Duodenum_Rostral_Part_Muscularis_Mucosa()
    GASTRO_ESOPHAGEAL_JUNCTION_MUCOSA = _Gastro_Esophageal_Junction_Mucosa()
    GASTRO_ESOPHAGEAL_JUNCTION_SUBMUCOSA = _Gastro_Esophageal_Junction_Submucosa()
    GASTRO_ESOPHAGEAL_JUNCTION_MUSCULARIS = _Gastro_Esophageal_Junction_Muscularis()
    GASTRO_ESOPHAGEAL_JUNCTION_SEROSA = _Gastro_Esophageal_Junction_Serosa()
    GASTRO_ESOPHAGEAL_JUNCTION_LAMINA_PROPRIA = _Gastro_Esophageal_Junction_Lamina_Propria()
    GASTRO_ESOPHAGEAL_JUNCTION_MUSCULARIS_MUCOSA = _Gastro_Esophageal_Junction_Muscularis_Mucosa()
    PERINEAL_BODY_MUCOSA = _Perineal_Body_Mucosa()
    PERINEAL_BODY_SUBMUCOSA = _Perineal_Body_Submucosa()
    PERINEAL_BODY_MUSCULARIS = _Perineal_Body_Muscularis()
    PERINEAL_BODY_SEROSA = _Perineal_Body_Serosa()
    PERINEAL_BODY_LAMINA_PROPRIA = _Perineal_Body_Lamina_Propria()
    PERINEAL_BODY_MUSCULARIS_MUCOSA = _Perineal_Body_Muscularis_Mucosa()
    HINDGUT_MUCOSA = _Hindgut_Mucosa()
    HINDGUT_SUBMUCOSA = _Hindgut_Submucosa()
    HINDGUT_MUSCULARIS = _Hindgut_Muscularis()
    HINDGUT_SEROSA = _Hindgut_Serosa()
    HINDGUT_LAMINA_PROPRIA = _Hindgut_Lamina_Propria()
    HINDGUT_MUSCULARIS_MUCOSA = _Hindgut_Muscularis_Mucosa()
    RECTUM_MUCOSA = _Rectum_Mucosa()
    RECTUM_SUBMUCOSA = _Rectum_Submucosa()
    RECTUM_MUSCULARIS = _Rectum_Muscularis()
    RECTUM_SEROSA = _Rectum_Serosa()
    RECTUM_LAMINA_PROPRIA = _Rectum_Lamina_Propria()
    RECTUM_MUSCULARIS_MUCOSA = _Rectum_Muscularis_Mucosa()
    DUODENUM_CAUDAL_PART_MUCOSA = _Duodenum_Caudal_Part_Mucosa()
    DUODENUM_CAUDAL_PART_SUBMUCOSA = _Duodenum_Caudal_Part_Submucosa()
    DUODENUM_CAUDAL_PART_MUSCULARIS = _Duodenum_Caudal_Part_Muscularis()
    DUODENUM_CAUDAL_PART_SEROSA = _Duodenum_Caudal_Part_Serosa()
    DUODENUM_CAUDAL_PART_LAMINA_PROPRIA = _Duodenum_Caudal_Part_Lamina_Propria()
    DUODENUM_CAUDAL_PART_MUSCULARIS_MUCOSA = _Duodenum_Caudal_Part_Muscularis_Mucosa()
    JEJUNUM_MUCOSA = _Jejunum_Mucosa()
    JEJUNUM_SUBMUCOSA = _Jejunum_Submucosa()
    JEJUNUM_MUSCULARIS = _Jejunum_Muscularis()
    JEJUNUM_SEROSA = _Jejunum_Serosa()
    JEJUNUM_LAMINA_PROPRIA = _Jejunum_Lamina_Propria()
    JEJUNUM_MUSCULARIS_MUCOSA = _Jejunum_Muscularis_Mucosa()
    MIDGUT_LOOP_MUCOSA = _Midgut_Loop_Mucosa()
    MIDGUT_LOOP_SUBMUCOSA = _Midgut_Loop_Submucosa()
    MIDGUT_LOOP_MUSCULARIS = _Midgut_Loop_Muscularis()
    MIDGUT_LOOP_SEROSA = _Midgut_Loop_Serosa()
    MIDGUT_LOOP_LAMINA_PROPRIA = _Midgut_Loop_Lamina_Propria()
    MIDGUT_LOOP_MUSCULARIS_MUCOSA = _Midgut_Loop_Muscularis_Mucosa()
    MIDGUT_MUCOSA = _Midgut_Mucosa()
    MIDGUT_SUBMUCOSA = _Midgut_Submucosa()
    MIDGUT_MUSCULARIS = _Midgut_Muscularis()
    MIDGUT_SEROSA = _Midgut_Serosa()
    MIDGUT_LAMINA_PROPRIA = _Midgut_Lamina_Propria()
    MIDGUT_MUSCULARIS_MUCOSA = _Midgut_Muscularis_Mucosa()
    STOMACH_FUNDUS_MUCOSA = _Stomach_Fundus_Mucosa()
    STOMACH_FUNDUS_SUBMUCOSA = _Stomach_Fundus_Submucosa()
    STOMACH_FUNDUS_MUSCULARIS = _Stomach_Fundus_Muscularis()
    STOMACH_FUNDUS_SEROSA = _Stomach_Fundus_Serosa()
    STOMACH_FUNDUS_GASTRIC_GLAND = _Stomach_Fundus_Gastric_Gland()
    STOMACH_FUNDUS_LAMINA_PROPRIA = _Stomach_Fundus_Lamina_Propria()
    STOMACH_FUNDUS_MUSCULARIS_MUCOSA = _Stomach_Fundus_Muscularis_Mucosa()
    STOMACH_GLANDULAR_REGION_MUCOSA = _Stomach_Glandular_Region_Mucosa()
    STOMACH_GLANDULAR_REGION_SUBMUCOSA = _Stomach_Glandular_Region_Submucosa()
    STOMACH_GLANDULAR_REGION_MUSCULARIS = _Stomach_Glandular_Region_Muscularis()
    STOMACH_GLANDULAR_REGION_SEROSA = _Stomach_Glandular_Region_Serosa()
    STOMACH_GLANDULAR_REGION_LAMINA_PROPRIA = _Stomach_Glandular_Region_Lamina_Propria()
    STOMACH_GLANDULAR_REGION_MUSCULARIS_MUCOSA = _Stomach_Glandular_Region_Muscularis_Mucosa()
    STOMACH_GLANDULAR_REGION_GASTRIC_GLAND = _Stomach_Glandular_Region_Gastric_Gland()
    STOMACH_PROVENTRICULAR_REGION_MUCOSA = _Stomach_Proventricular_Region_Mucosa()
    STOMACH_PROVENTRICULAR_REGION_SUBMUCOSA = _Stomach_Proventricular_Region_Submucosa()
    STOMACH_PROVENTRICULAR_REGION_MUSCULARIS = _Stomach_Proventricular_Region_Muscularis()
    STOMACH_PROVENTRICULAR_REGION_SEROSA = _Stomach_Proventricular_Region_Serosa()
    STOMACH_PROVENTRICULAR_REGION_LAMINA_PROPRIA = _Stomach_Proventricular_Region_Lamina_Propria()
    STOMACH_PROVENTRICULAR_REGION_GASTRIC_GLAND = _Stomach_Proventricular_Region_Gastric_Gland()
    STOMACH_PROVENTRICULAR_REGION_MUSCULARIS_MUCOSA = _Stomach_Proventricular_Region_Muscularis_Mucosa()
    STOMACH_PYLORIC_REGION_MUCOSA = _Stomach_Pyloric_Region_Mucosa()
    STOMACH_PYLORIC_REGION_SUBMUCOSA = _Stomach_Pyloric_Region_Submucosa()
    STOMACH_PYLORIC_REGION_SEROSA = _Stomach_Pyloric_Region_Serosa()
    STOMACH_PYLORIC_REGION_LAMINA_PROPRIA = _Stomach_Pyloric_Region_Lamina_Propria()
    STOMACH_PYLORIC_REGION_GASTRIC_GLAND = _Stomach_Pyloric_Region_Gastric_Gland()
    STOMACH_PYLORIC_REGION_MUSCULARIS_MUCOSA = _Stomach_Pyloric_Region_Muscularis_Mucosa()
    ANAL_CANAL_CAUDAL_PART_MUCOSA = _Anal_Canal_Caudal_Part_Mucosa()
    ANAL_CANAL_CAUDAL_PART_SUBMUCOSA = _Anal_Canal_Caudal_Part_Submucosa()
    ANAL_CANAL_CAUDAL_PART_GLAND = _Anal_Canal_Caudal_Part_Gland()
    ANAL_CANAL_CAUDAL_PART_LAMINA_PROPRIA = _Anal_Canal_Caudal_Part_Lamina_Propria()
    ANAL_CANAL_ROSTRAL_PART_MUCOSA = _Anal_Canal_Rostral_Part_Mucosa()
    ANAL_CANAL_ROSTRAL_PART_SUBMUCOSA = _Anal_Canal_Rostral_Part_Submucosa()
    ANAL_CANAL_ROSTRAL_PART_LAMINA_PROPRIA = _Anal_Canal_Rostral_Part_Lamina_Propria()
    ANAL_CANAL_ROSTRAL_PART_GLAND = _Anal_Canal_Rostral_Part_Gland()
    DUODENUM_MUCOSA = _Duodenum_Mucosa()
    DUODENUM_SUBMUCOSA = _Duodenum_Submucosa()
    DUODENUM_MUSCULARIS = _Duodenum_Muscularis()
    DUODENUM_SEROSA = _Duodenum_Serosa()
    DUODENUM_LAMINA_PROPRIA = _Duodenum_Lamina_Propria()
    DUODENUM_MUSCULARIS_MUCOSA = _Duodenum_Muscularis_Mucosa()
    COLON_MUCOSA = _Colon_Mucosa()
    COLON_SUBMUCOSA = _Colon_Submucosa()
    COLON_MUSCULARIS = _Colon_Muscularis()
    COLON_SEROSA = _Colon_Serosa()
    COLON_LAMINA_PROPRIA = _Colon_Lamina_Propria()
    COLON_MUSCULARIS_MUCOSA = _Colon_Muscularis_Mucosa()
    ANAL_CANAL_MUCOSA = _Anal_Canal_Mucosa()
    ANAL_CANAL_SUBMUCOSA = _Anal_Canal_Submucosa()
    ANAL_CANAL_GLAND = _Anal_Canal_Gland()
    ANAL_CANAL_LAMINA_PROPRIA = _Anal_Canal_Lamina_Propria()
    COELOMIC_EPITHELIUM_OF_GONAD_PRIMORDIUM = _Coelomic_Epithelium_Of_Gonad_Primordium()
    ANTERIOR_GONAD_PRIMORDIUM_MESENCHYME = _Anterior_Gonad_Primordium_Mesenchyme()
    CENTRAL_GONAD_PRIMORDIUM_MESENCHYME = _Central_Gonad_Primordium_Mesenchyme()
    POSTERIOR_GONAD_PRIMORDIUM_MESENCHYME = _Posterior_Gonad_Primordium_Mesenchyme()
    CLOACA = _Cloaca()
    CLOACAL_EPITHELIUM = _Cloacal_Epithelium()
    CLOACA_ASSOCIATED_MESENCHYME = _Cloaca_Associated_Mesenchyme()
    NEPHRIC_DUCT__MESONEPHRIC_PORTION = _Nephric_Duct_Mesonephric_Portion()
    NEPHRIC_DUCT__METANEPHRIC_PORTION = _Nephric_Duct_Metanephric_Portion()
    NEPHRIC_DUCT__PRONEPHRIC_PORTION = _Nephric_Duct_Pronephric_Portion()
    URETERIC_TIP = _Ureteric_Tip()
    URETERIC_STALK = _Ureteric_Stalk()
    PARAMETANEPHRIC_MESENCHYME = _Parametanephric_Mesenchyme()
    ROSTRAL_PARAMETANEPHRIC_MESENCHYME = _Rostral_Parametanephric_Mesenchyme()
    CAUDAL_PARAMESONEPHRIC_MESENCHYME = _Caudal_Paramesonephric_Mesenchyme()
    CAP_MESENCHYME = _Cap_Mesenchyme()
    PERIPHERAL_BLASTEMA = _Peripheral_Blastema()
    ANTERIOR_GONADAL_MESENCHYME = _Anterior_Gonadal_Mesenchyme()
    CENTRAL_GONADAL_MESENCHYME = _Central_Gonadal_Mesenchyme()
    POSTERIOR_GONADAL_MESENCHYME = _Posterior_Gonadal_Mesenchyme()
    PARAMESONEPHRIC_DUCT = _Paramesonephric_Duct()
    PRETUBULAR_AGGREGATE = _Pretubular_Aggregate()
    RENAL_VESICLE = _Renal_Vesicle()
    COMMA_SHAPED_BODY = _Comma_Shaped_Body()
    UPPER_LIMB_OF_COMMA_SHAPED_BODY = _Upper_Limb_Of_Comma_Shaped_Body()
    URETERIC_TRUNK = _Ureteric_Trunk()
    EPITHELIAL_LAYER_OF_URETER = _Epithelial_Layer_Of_Ureter()
    URETERAL_MESENCHYME = _Ureteral_Mesenchyme()
    NEPHROGENIC_ZONE = _Nephrogenic_Zone()
    S_SHAPED_BODY = _S_Shaped_Body()
    RENAL_CONNECTING_TUBULE_OF_S_SHAPED_BODY = _Renal_Connecting_Tubule_Of_S_Shaped_Body()
    DISTAL_SEGMENT_OF_S_SHAPED_BODY = _Distal_Segment_Of_S_Shaped_Body()
    MEDIAL_SEGMENT_OF_S_SHAPED_BODY = _Medial_Segment_Of_S_Shaped_Body()
    PROXIMAL_SEGMENT_OF_S_SHAPED_BODY = _Proximal_Segment_Of_S_Shaped_Body()
    VISCERAL_EPITHELIUM_OF_S_SHAPED_BODY = _Visceral_Epithelium_Of_S_Shaped_Body()
    PARIETAL_EPITHELIUM_OF_S_SHAPED_BODY = _Parietal_Epithelium_Of_S_Shaped_Body()
    CAPILLARY_LOOP_RENAL_CORPUSCLE = _Capillary_Loop_Renal_Corpuscle()
    VISCERAL_EPITHELIUM_OF_CAPILLARY_LOOP_RENAL_CORPUSCLE = _Visceral_Epithelium_Of_Capillary_Loop_Renal_Corpuscle()
    PARIETAL_EPITHELIUM_OF_CAPILLARY_LOOP_RENAL_CORPUSCLE = _Parietal_Epithelium_Of_Capillary_Loop_Renal_Corpuscle()
    ASSOCIATED_INTERSTITIUM_OF_CAPILLARY_LOOP_RENAL_CORPUSCLE = (
        _Associated_Interstitium_Of_Capillary_Loop_Renal_Corpuscle()
    )
    PRESUMPTIVE_MESANGIUM_OF_CAPILLARY_LOOP_RENAL_CORPUSCLE = _Presumptive_Mesangium_Of_Capillary_Loop_Renal_Corpuscle()
    PRESUMPTIVE_ENDOTHELIUM_OF_CAPILLARY_LOOP_RENAL_CORPUSCLE = (
        _Presumptive_Endothelium_Of_Capillary_Loop_Renal_Corpuscle()
    )
    RENAL_TUBULE = _Renal_Tubule()
    EARLY_PROXIMAL_TUBULE = _Early_Proximal_Tubule()
    ANLAGE_OF_LOOP_OF_HENLE = _Anlage_Of_Loop_Of_Henle()
    EARLY_DISTAL_TUBULE = _Early_Distal_Tubule()
    RENAL_CONNECTING_TUBULE_OF_CAPILLARY_LOOP_NEPHRON = _Renal_Connecting_Tubule_Of_Capillary_Loop_Nephron()
    DEVELOPING_VASCULATURE_OF_METANEPHROS = _Developing_Vasculature_Of_Metanephros()
    LOWER_LIMB_OF_COMMA_SHAPED_BODY = _Lower_Limb_Of_Comma_Shaped_Body()
    MATURING_RENAL_CORPUSCLE = _Maturing_Renal_Corpuscle()
    MATURING_GLOMERULAR_TUFT = _Maturing_Glomerular_Tuft()
    GLOMERULAR_CAPILLARY_SYSTEM_OF_MATURING_GLOMERULAR_TUFT = _Glomerular_Capillary_System_Of_Maturing_Glomerular_Tuft()
    GLOMERULAR_MESANGIUM_OF_MATURING_GLOMERULAR_TUFT = _Glomerular_Mesangium_Of_Maturing_Glomerular_Tuft()
    VISCERAL_EPITHELIUM_OF_MATURING_RENAL_CORPUSCLE = _Visceral_Epithelium_Of_Maturing_Renal_Corpuscle()
    BOWMAN_S_CAPSULE_OF_MATURING_RENAL_CORPUSCLE = _Bowman_S_Capsule_Of_Maturing_Renal_Corpuscle()
    PARIETAL_EPITHELIUM_OF_MATURING_RENAL_CORPUSCLE = _Parietal_Epithelium_Of_Maturing_Renal_Corpuscle()
    URINARY_SPACE_OF_MATURING_RENAL_CORPUSCLE = _Urinary_Space_Of_Maturing_Renal_Corpuscle()
    JUXTAGLOMERULAR_ARTERIOLE = _Juxtaglomerular_Arteriole()
    CORTICAL_EARLY_PROXIMAL_TUBULE = _Cortical_Early_Proximal_Tubule()
    CORTICAL_EARLY_DISTAL_TUBULE = _Cortical_Early_Distal_Tubule()
    RENAL_CONNECTING_TUBULE = _Renal_Connecting_Tubule()
    DEVELOPING_VASCULATURE_OF_RENAL_CORTEX = _Developing_Vasculature_Of_Renal_Cortex()
    DEVELOPING_ARTERIAL_VASCULATURE_OF_RENAL_CORTEX = _Developing_Arterial_Vasculature_Of_Renal_Cortex()
    DEVELOPING_VENOUS_VASCULATURE_OF_RENAL_CORTEX = _Developing_Venous_Vasculature_Of_Renal_Cortex()
    DEVELOPING_CAPILLARY_OF_RENAL_CORTEX = _Developing_Capillary_Of_Renal_Cortex()
    IMMATURE_LOOP_OF_HENLE = _Immature_Loop_Of_Henle()
    MEDULLARY_COLLECTING_DUCT = _Medullary_Collecting_Duct()
    DEVELOPING_VASCULATURE_OF_RENAL_MEDULLA = _Developing_Vasculature_Of_Renal_Medulla()
    DEVELOPING_ARTERIAL_VASCULATURE_OF_RENAL_MEDULLA = _Developing_Arterial_Vasculature_Of_Renal_Medulla()
    DEVELOPING_VENOUS_VASCULATURE_OF_RENAL_MEDULLA = _Developing_Venous_Vasculature_Of_Renal_Medulla()
    DEVELOPING_CAPILLARY_OF_RENAL_MEDULLA = _Developing_Capillary_Of_Renal_Medulla()
    PELVIC_UROTHELIAL_LINING = _Pelvic_Urothelial_Lining()
    PERIHILAR_INTERSTITIUM = _Perihilar_Interstitium()
    UROTHELIUM_OF_URETER = _Urothelium_Of_Ureter()
    ADVENTITIA_OF_URETER = _Adventitia_Of_Ureter()
    PELVIC_SMOOTH_MUSCLE = _Pelvic_Smooth_Muscle()
    CORTICAL_COLLECTING_DUCT = _Cortical_Collecting_Duct()
    RENAL_CORTICAL_INTERSTITIUM = _Renal_Cortical_Interstitium()
    RENAL_CORTICAL_VASCULATURE = _Renal_Cortical_Vasculature()
    RENAL_CORTICAL_ARTERIAL_SYSTEM = _Renal_Cortical_Arterial_System()
    RENAL_CORTICAL_VENOUS_SYSTEM = _Renal_Cortical_Venous_System()
    RENAL_MEDULLARY_VASCULATURE = _Renal_Medullary_Vasculature()
    RENAL_MEDULLARY_ARTERIAL_SYSTEM = _Renal_Medullary_Arterial_System()
    RENAL_MEDULLARY_VENOUS_SYSTEM = _Renal_Medullary_Venous_System()
    INTERLOBULAR_ARTERY = _Interlobular_Artery()
    ARCUATE_ARTERY = _Arcuate_Artery()
    INTERLOBULAR_VEIN = _Interlobular_Vein()
    ARCUATE_VEIN = _Arcuate_Vein()
    AFFERENT_ARTERIOLE_OF_MATURING_RENAL_CORPUSCLE = _Afferent_Arteriole_Of_Maturing_Renal_Corpuscle()
    EFFERENT_ARTERIOLE_OF_MATURING_RENAL_CORPUSCLE = _Efferent_Arteriole_Of_Maturing_Renal_Corpuscle()
    MATURE_RENAL_CORPUSCLE = _Mature_Renal_Corpuscle()
    GLOMERULAR_TUFT = _Glomerular_Tuft()
    GLOMERULAR_CAPILLARY_SYSTEM = _Glomerular_Capillary_System()
    GLOMERULAR_MESANGIUM_OF_GLOMERULAR_TUFT = _Glomerular_Mesangium_Of_Glomerular_Tuft()
    GLOMERULAR_BASEMENT_MEMBRANE_OF_MATURE_RENAL_CORPUSCLE = _Glomerular_Basement_Membrane_Of_Mature_Renal_Corpuscle()
    VISCERAL_EPITHELIUM_OF_MATURE_RENAL_CORPUSCLE = _Visceral_Epithelium_Of_Mature_Renal_Corpuscle()
    BOWMAN_S_CAPSULE_OF_MATURE_RENAL_CORPUSCLE = _Bowman_S_Capsule_Of_Mature_Renal_Corpuscle()
    PARIETAL_EPITHELIUM_OF_MATURE_RENAL_CORPUSCLE = _Parietal_Epithelium_Of_Mature_Renal_Corpuscle()
    URINARY_SPACE_OF_MATURE_RENAL_CORPUSCLE = _Urinary_Space_Of_Mature_Renal_Corpuscle()
    AFFERENT_ARTERIOLE_OF_MATURE_RENAL_CORPUSCLE = _Afferent_Arteriole_Of_Mature_Renal_Corpuscle()
    PART_OF_AFFERENT_ARTERIOLE_FORMING_THE_JUXTAGLOMERULAR_COMPLEX = (
        _Part_Of_Afferent_Arteriole_Forming_The_Juxtaglomerular_Complex()
    )
    REST_OF_AFFERENT_ARTERIOLE = _Rest_Of_Afferent_Arteriole()
    EFFERENT_ARTERIOLE_OF_MATURE_RENAL_CORPUSCLE = _Efferent_Arteriole_Of_Mature_Renal_Corpuscle()
    EXTRAGLOMERULAR_MESANGIUM = _Extraglomerular_Mesangium()
    RENAL_PROXIMAL_TUBULE = _Renal_Proximal_Tubule()
    RENAL_PROXIMAL_CONVOLUTED_TUBULE = _Renal_Proximal_Convoluted_Tubule()
    OUTER_RENAL_MEDULLA = _Outer_Renal_Medulla()
    LOOP_OF_HENLE__OUTER_MEDULLARY_PORTION = _Loop_Of_Henle_Outer_Medullary_Portion()
    THIN_DESCENDING_LIMB_OF_OUTER_MEDULLA = _Thin_Descending_Limb_Of_Outer_Medulla()
    THIN_ASCENDING_LIMB_OF_OUTER_MEDULLA = _Thin_Ascending_Limb_Of_Outer_Medulla()
    PREMACULA_SEGMENT_OF_DISTAL_STRAIGHT_TUBULE_OF_OUTER_MEDULLA = (
        _Premacula_Segment_Of_Distal_Straight_Tubule_Of_Outer_Medulla()
    )
    OUTER_MEDULLARY_INTERSTITIUM = _Outer_Medullary_Interstitium()
    OUTER_MEDULLARY_COLLECTING_DUCT = _Outer_Medullary_Collecting_Duct()
    INNER_RENAL_MEDULLA = _Inner_Renal_Medulla()
    LOOP_OF_HENLE__INNER_MEDULLARY_PORTION = _Loop_Of_Henle_Inner_Medullary_Portion()
    THIN_DESCENDING_LIMB_OF_INNER_MEDULLA = _Thin_Descending_Limb_Of_Inner_Medulla()
    BEND_OF_LOOP_OF_HENLE_INNER_MEDULLARY_PORTION = _Bend_Of_Loop_Of_Henle_Inner_Medullary_Portion()
    THIN_ASCENDING_LIMB_OF_INNER_MEDULLA = _Thin_Ascending_Limb_Of_Inner_Medulla()
    INNER_MEDULLARY_INTERSTITIUM = _Inner_Medullary_Interstitium()
    INNER_MEDULLARY_COLLECTING_DUCT = _Inner_Medullary_Collecting_Duct()
    RENAL_ARTERY = _Renal_Artery()
    RENAL_VEIN = _Renal_Vein()
    RENAL_DISTAL_TUBULE = _Renal_Distal_Tubule()
    DISTAL_CONVOLUTED_TUBULE = _Distal_Convoluted_Tubule()
    DISTAL_STRAIGHT_TUBULE_OF_RENAL_CORTEX = _Distal_Straight_Tubule_Of_Renal_Cortex()
    MACULA_DENSA = _Macula_Densa()
    POSTMACULA_SEGMENT_OF_DISTAL_STRAIGHT_TUBULE = _Postmacula_Segment_Of_Distal_Straight_Tubule()
    COLLECTING_DUCT = _Collecting_Duct()
    STAGE_IV_IMMATURE_NEPHRON = _Stage_Iv_Immature_Nephron()
    RENAL_VASCULATURE = _Renal_Vasculature()
    MATURING_NEPHRON = _Maturing_Nephron()
    MATURE_NEPHRON = _Mature_Nephron()
    EARLY_TUBULE = _Early_Tubule()
    DEVELOPING_CAPILLARY_LOOP_STAGE_NEPHRON_GROUP = _Developing_Capillary_Loop_Stage_Nephron_Group()
    RENAL_INTERSTITIUM = _Renal_Interstitium()
    LATE_TUBULE = _Late_Tubule()
    MALE_ASSOCIATED_REPRODUCTIVE_STRUCTURE = _Male_Associated_Reproductive_Structure()
    FEMALE_ASSOCIATED_REPRODUCTIVE_STRUCTURE = _Female_Associated_Reproductive_Structure()
    ALLANTOIS_OF_EMBRYONIC_URINARY_SYSTEM = _Allantois_Of_Embryonic_Urinary_System()
    URETHRAL_PLATE = _Urethral_Plate()
    URETERAL_MESENCHYME_SUBEPITHELIAL_LAYER = _Ureteral_Mesenchyme_Subepithelial_Layer()
    URETERAL_MESENCHYME_MIDDLE_LAYER = _Ureteral_Mesenchyme_Middle_Layer()
    URETERAL_MESENCHYME_OUTER_LAYER = _Ureteral_Mesenchyme_Outer_Layer()
    SUPERFICIAL_CELL_LAYER_OF_URETER = _Superficial_Cell_Layer_Of_Ureter()
    UROTHELIUM_OF_BLADDER = _Urothelium_Of_Bladder()
    UROTHELIUM_OF_BLADDER_FUNDUS = _Urothelium_Of_Bladder_Fundus()
    UROTHELIUM_OF_BLADDER_TRIGONE = _Urothelium_Of_Bladder_Trigone()
    MUSCULARIS_MUCOSA_OF_BLADDER = _Muscularis_Mucosa_Of_Bladder()
    MUSCULARIS_MUCOSA_OF_FUNDUS = _Muscularis_Mucosa_Of_Fundus()
    MUSCULARIS_MUCOSA_OF_TRIGONE = _Muscularis_Mucosa_Of_Trigone()
    DETRUSOR_MUSCLE_OF_BLADDER = _Detrusor_Muscle_Of_Bladder()
    DETRUSOR_MUSCLE_OF_BLADDER_FUNDUS = _Detrusor_Muscle_Of_Bladder_Fundus()
    DETRUSOR_MUSCLE_OF_BLADDER_TRIGONE = _Detrusor_Muscle_Of_Bladder_Trigone()
    SEROSA_OF_BLADDER = _Serosa_Of_Bladder()
    SEROSA_OF_BLADDER_FUNDUS = _Serosa_Of_Bladder_Fundus()
    SEROSA_OF_TRIGONE = _Serosa_Of_Trigone()
    VASCULATURE_OF_BLADDER = _Vasculature_Of_Bladder()
    EPITHELIUM_OF_PELVIC_URETHRA_OF_MALE = _Epithelium_Of_Pelvic_Urethra_Of_Male()
    MESENCHYMAL_LAYER_OF_PELVIC_URETHRA_OF_MALE = _Mesenchymal_Layer_Of_Pelvic_Urethra_Of_Male()
    MUSCLE_LAYER_OF_PELVIC_URETHRA_OF_MALE = _Muscle_Layer_Of_Pelvic_Urethra_Of_Male()
    URETHRA_OF_FEMALE = _Urethra_Of_Female()
    PELVIC_URETHRA_OF_FEMALE = _Pelvic_Urethra_Of_Female()
    EPITHELIUM_OF_PELVIC_URETHRA_OF_FEMALE = _Epithelium_Of_Pelvic_Urethra_Of_Female()
    MESENCHYMAL_LAYER_OF_PELVIC_URETHRA_OF_FEMALE = _Mesenchymal_Layer_Of_Pelvic_Urethra_Of_Female()
    MUSCLE_LAYER_OF_PELVIC_URETHRA_OF_FEMALE = _Muscle_Layer_Of_Pelvic_Urethra_Of_Female()
    INTERMEDIATE_CELL_LAYER_OF_URETER = _Intermediate_Cell_Layer_Of_Ureter()
    BASAL_CELL_LAYER_OF_URETER = _Basal_Cell_Layer_Of_Ureter()
    URETERAL_SMOOTH_MUSCLE_LAYER = _Ureteral_Smooth_Muscle_Layer()
    URETERAL_SMOOTH_MUSCLE_LAYER_SMOOTH_MUSCLE_COMPONENT = _Ureteral_Smooth_Muscle_Layer_Smooth_Muscle_Component()
    ADVENTITIA_OF_BLADDER = _Adventitia_Of_Bladder()
    ADVENTITIA_OF_FUNDUS = _Adventitia_Of_Fundus()
    ADVENTITIA_OF_BLADDER_TRIGONE = _Adventitia_Of_Bladder_Trigone()
    LAMINA_PROPRIA_OF_URETER = _Lamina_Propria_Of_Ureter()
    MESENCHYMAL_LAYER_OF_PHALLIC_URETHRA_OF_MALE = _Mesenchymal_Layer_Of_Phallic_Urethra_Of_Male()
    MUSCLE_LAYER_OF_PHALLIC_URETHRA_OF_MALE = _Muscle_Layer_Of_Phallic_Urethra_Of_Male()
    PROXIMAL_STRAIGHT_TUBULE__OUTER_MEDULLARY_PORTION = _Proximal_Straight_Tubule_Outer_Medullary_Portion()
    MESENCHYMAL_STROMA_OF_OVARY = _Mesenchymal_Stroma_Of_Ovary()
    DEVELOPING_VASCULATURE_OF_OVARY = _Developing_Vasculature_Of_Ovary()
    MESONEPHROS_OF_FEMALE = _Mesonephros_Of_Female()
    MESONEPHRIC_MESENCHYME_OF_FEMALE = _Mesonephric_Mesenchyme_Of_Female()
    MESONEPHRIC_TUBULE_OF_FEMALE = _Mesonephric_Tubule_Of_Female()
    NEPHRIC_DUCT_OF_FEMALE__MESONEPHRIC_PORTION = _Nephric_Duct_Of_Female_Mesonephric_Portion()
    RETE_OVARII_OF_MESONEPHROS = _Rete_Ovarii_Of_Mesonephros()
    COELOMIC_EPITHELIUM_OF_FEMALE_MESONEPHROS = _Coelomic_Epithelium_Of_Female_Mesonephros()
    PARAMESONEPHRIC_DUCT_OF_FEMALE__MESONEPHRIC_PORTION = _Paramesonephric_Duct_Of_Female_Mesonephric_Portion()
    PARAMESONEPHRIC_DUCT_OF_FEMALE__REST_OF = _Paramesonephric_Duct_Of_Female_Rest_Of()
    NEPHRIC_DUCT_OF_FEMALE__REST_OF = _Nephric_Duct_Of_Female_Rest_Of()
    EPITHELIUM_OF_NEPHRIC_DUCT_OF_FEMALE = _Epithelium_Of_Nephric_Duct_Of_Female()
    MESENCHYME_OF_NEPHRIC_DUCT_OF_FEMALE = _Mesenchyme_Of_Nephric_Duct_Of_Female()
    EPITHELIUM_OF_REST_OF_PARAMESONEPHRIC_DUCT_OF_FEMALE = _Epithelium_Of_Rest_Of_Paramesonephric_Duct_Of_Female()
    MESENCHYME_OF_REST_OF_PARAMESONEPHRIC_DUCT_OF_FEMALE = _Mesenchyme_Of_Rest_Of_Paramesonephric_Duct_Of_Female()
    MEIOTIC_GERM_CELL_OF_OVARY = _Meiotic_Germ_Cell_Of_Ovary()
    PREMEIOTIC_GERM_CELL_OF_OVARY = _Premeiotic_Germ_Cell_Of_Ovary()
    DEGENERATING_MESONEPHRIC_TUBULE_OF_FEMALE = _Degenerating_Mesonephric_Tubule_Of_Female()
    DEGENERATING_MESONEPHRIC_PORTION_OF_NEPHRIC_DUCT_OF_FEMALE = (
        _Degenerating_Mesonephric_Portion_Of_Nephric_Duct_Of_Female()
    )
    CORTICAL_COMPONENT_OF_MESENCHYMAL_STROMA = _Cortical_Component_Of_Mesenchymal_Stroma()
    MEDULLARY_COMPONENT_OF_MESENCHYMAL_STROMA = _Medullary_Component_Of_Mesenchymal_Stroma()
    UTERINE_HORN_EPITHELIUM = _Uterine_Horn_Epithelium()
    UTERINE_HORN_MUSCULAR_LAYER = _Uterine_Horn_Muscular_Layer()
    EPITHELIAL_LAYER_OF_OVIDUCT = _Epithelial_Layer_Of_Oviduct()
    MUSCLE_LAYER_OF_OVIDUCT = _Muscle_Layer_Of_Oviduct()
    OUTER_LAYER_OF_OVIDUCT = _Outer_Layer_Of_Oviduct()
    EPITHELIUM_OF_UPPER_VAGINA = _Epithelium_Of_Upper_Vagina()
    MUSCLE_OF_UPPER_VAGINA = _Muscle_Of_Upper_Vagina()
    EPITHELIUM_OF_SINOVAGINAL_BULB = _Epithelium_Of_Sinovaginal_Bulb()
    MUSCLE_OF_SINOVAGINAL_BULB = _Muscle_Of_Sinovaginal_Bulb()
    OOCYTE_OF_PRIMARY_FOLLICLE = _Oocyte_Of_Primary_Follicle()
    FOLLICLE_CELL_OF_PRIMARY_FOLLICLE = _Follicle_Cell_Of_Primary_Follicle()
    PRIMARY_SEX_CORD = _Primary_Sex_Cord()
    SERTOLI_CELL = _Sertoli_Cell()
    PERITUBULAR_MYOID_CELL = _Peritubular_Myoid_Cell()
    DEVELOPING_VASCULATURE_OF_TESTIS = _Developing_Vasculature_Of_Testis()
    COELOMIC_VESSEL = _Coelomic_Vessel()
    INTERSTITIAL_VESSEL = _Interstitial_Vessel()
    MESONEPHROS_OF_MALE = _Mesonephros_Of_Male()
    MESONEPHRIC_MESENCHYME_OF_MALE = _Mesonephric_Mesenchyme_Of_Male()
    MESONEPHRIC_TUBULE_OF_MALE = _Mesonephric_Tubule_Of_Male()
    PARAMESONEPHRIC_DUCT_OF_MALE__MESONEPHRIC_PORTION = _Paramesonephric_Duct_Of_Male_Mesonephric_Portion()
    DEGENERATING_MESONEPHRIC_PORTION_OF_MALE_PARAMESONEPHRIC_DUCT = (
        _Degenerating_Mesonephric_Portion_Of_Male_Paramesonephric_Duct()
    )
    GENITAL_TUBERCLE_MESENCHYME_OF_MALE = _Genital_Tubercle_Mesenchyme_Of_Male()
    GENITAL_TUBERCLE_SKIN_OF_MALE = _Genital_Tubercle_Skin_Of_Male()
    NEPHRIC_DUCT_OF_MALE__REST_OF = _Nephric_Duct_Of_Male_Rest_Of()
    MESENCHYME_OF_NEPHRIC_DUCT_OF_MALE = _Mesenchyme_Of_Nephric_Duct_Of_Male()
    EPITHELIUM_OF_NEPHRIC_DUCT_OF_MALE = _Epithelium_Of_Nephric_Duct_Of_Male()
    PARAMESONEPHRIC_DUCT_OF_MALE__REST_OF = _Paramesonephric_Duct_Of_Male_Rest_Of()
    EPITHELIUM_OF_REST_OF_PARAMESONEPHRIC_DUCT_OF_MALE = _Epithelium_Of_Rest_Of_Paramesonephric_Duct_Of_Male()
    MESENCHYME_OF_REST_OF_PARAMESONEPHRIC_DUCT_OF_MALE = _Mesenchyme_Of_Rest_Of_Paramesonephric_Duct_Of_Male()
    DEGENERATING_REST_OF_PARAMESONEPHRIC_DUCT_OF_MALE = _Degenerating_Rest_Of_Paramesonephric_Duct_Of_Male()
    EPITHELIUM_OF_DEGENERATING_REST_OF_PARAMESONEPHRIC_DUCT_OF_MALE = (
        _Epithelium_Of_Degenerating_Rest_Of_Paramesonephric_Duct_Of_Male()
    )
    MESENCHYME_OF_DEGENERATING_REST_OF_PARAMESONEPHRIC_DUCT_OF_MALE = (
        _Mesenchyme_Of_Degenerating_Rest_Of_Paramesonephric_Duct_Of_Male()
    )
    DISTAL_GENITAL_TUBERCLE_OF_MALE = _Distal_Genital_Tubercle_Of_Male()
    MESENCHYME_OF_DISTAL_GENITAL_TUBERCLE_OF_MALE = _Mesenchyme_Of_Distal_Genital_Tubercle_Of_Male()
    SKIN_OF_DISTAL_GENITAL_TUBERCLE_OF_MALE = _Skin_Of_Distal_Genital_Tubercle_Of_Male()
    PREPUTIAL_SWELLING_OF_MALE = _Preputial_Swelling_Of_Male()
    SKIN_OF_MALE_PREPUTIAL_SWELLING = _Skin_Of_Male_Preputial_Swelling()
    MESENCHYME_OF_MALE_PREPUTIAL_SWELLING = _Mesenchyme_Of_Male_Preputial_Swelling()
    GLANS_OF_MALE_GENITAL_TUBERCLE = _Glans_Of_Male_Genital_Tubercle()
    MESENCHYME_OF_GLANS_OF_MALE_GENITAL_TUBERCLE = _Mesenchyme_Of_Glans_Of_Male_Genital_Tubercle()
    SKIN_OF_GLANS_OF_MALE_GENITAL_TUBERCLE = _Skin_Of_Glans_Of_Male_Genital_Tubercle()
    MUSCLE_OF_DUCTUS_DEFERENS = _Muscle_Of_Ductus_Deferens()
    EPITHELIUM_OF_DUCTUS_DEFERENS = _Epithelium_Of_Ductus_Deferens()
    MALE_CYSTIC_VESICULAR_APPENDAGE = _Male_Cystic_Vesicular_Appendage()
    MALE_INGUINAL_RING = _Male_Inguinal_Ring()
    MALE_EXTERNAL_INGUINAL_RING = _Male_External_Inguinal_Ring()
    MALE_INTERNAL_INGUINAL_RING = _Male_Internal_Inguinal_Ring()
    SCROTAL_FOLD = _Scrotal_Fold()
    VASCULATURE_OF_TESTIS = _Vasculature_Of_Testis()
    REST_OF_MESENTERY = _Rest_Of_Mesentery()
    GENITAL_TUBERCLE_MESENCHYME_OF_FEMALE = _Genital_Tubercle_Mesenchyme_Of_Female()
    GENITAL_TUBERCLE_SKIN_OF_FEMALE = _Genital_Tubercle_Skin_Of_Female()
    VASCULATURE_OF_OVARY = _Vasculature_Of_Ovary()
    URETERAL_SMOOTH_MUSCLE_LAYER_INNER_LONGITUDINAL_MUSCLE = _Ureteral_Smooth_Muscle_Layer_Inner_Longitudinal_Muscle()
    URETERAL_SMOOTH_MUSCLE_LAYER_OUTER_CIRCULAR_MUSCLE = _Ureteral_Smooth_Muscle_Layer_Outer_Circular_Muscle()
    MEDIAN_UMBILICAL_LIGAMENT = _Median_Umbilical_Ligament()
    BULBAR_PART_OF_URETHRA_OF_MALE = _Bulbar_Part_Of_Urethra_Of_Male()
    MALE_URETHRAL_GLAND = _Male_Urethral_Gland()
    FEMALE_URETHRAL_GLAND = _Female_Urethral_Gland()
    LEYDIG_CELL = _Leydig_Cell()
    SEGMENT_1_OF_PROXIMAL_TUBULE = _Segment_1_Of_Proximal_Tubule()
    SEGMENT_2_OF_PROXIMAL_TUBULE = _Segment_2_Of_Proximal_Tubule()
    PROXIMAL_STRAIGHT_TUBULE__CORTICAL_PORTION = _Proximal_Straight_Tubule_Cortical_Portion()
    OUTER_STRIPE_OF_OUTER_MEDULLA = _Outer_Stripe_Of_Outer_Medulla()
    LOOP_OF_HENLE_OF_OUTER_STRIPE_OF_OUTER_MEDULLA = _Loop_Of_Henle_Of_Outer_Stripe_Of_Outer_Medulla()
    PROXIMAL_STRAIGHT_TUBULE_OF_OUTER_STRIPE_OF_OUTER_MEDULLA = (
        _Proximal_Straight_Tubule_Of_Outer_Stripe_Of_Outer_Medulla()
    )
    DISTAL_STRAIGHT_TUBULE_OF_OUTER_STRIPE_OF_OUTER_MEDULLA = _Distal_Straight_Tubule_Of_Outer_Stripe_Of_Outer_Medulla()
    INNER_STRIPE_OF_OUTER_MEDULLA = _Inner_Stripe_Of_Outer_Medulla()
    LOOP_OF_HENLE_OF_INNER_STRIPE_OF_OUTER_MEDULLA = _Loop_Of_Henle_Of_Inner_Stripe_Of_Outer_Medulla()
    THIN_DESCENDING_LIMB_OF_INNER_STRIPE_OF_OUTER_MEDULLA = _Thin_Descending_Limb_Of_Inner_Stripe_Of_Outer_Medulla()
    PREMACULA_SEGMENT_OF_DISTAL_STRAIGHT_TUBULE_OF_INNER_STRIPE_OF_INNER_MEDULLA = (
        _Premacula_Segment_Of_Distal_Straight_Tubule_Of_Inner_Stripe_Of_Inner_Medulla()
    )
    RENAL_NERVE = _Renal_Nerve()
    EPITHELIUM_OF_CAUDA_OF_EPIDIDYMIS = _Epithelium_Of_Cauda_Of_Epididymis()
    TRUNK_DERMOMYOTOME = _Trunk_Dermomyotome()
    TAIL_DERMOMYOTOME = _Tail_Dermomyotome()
    TESTICULAR_BRANCH_OF_GENITAL_NERVE = _Testicular_Branch_Of_Genital_Nerve()
    EPIDERMAL_LAYER_OF_SCROTUM = _Epidermal_Layer_Of_Scrotum()
    BASAL_EPIDERMAL_LAYER_OF_SCROTUM = _Basal_Epidermal_Layer_Of_Scrotum()
    STRATIFIED_EPIDERMAL_LAYER_OF_SCROTUM = _Stratified_Epidermal_Layer_Of_Scrotum()
    DERMAL_LAYER_OF_SCROTUM = _Dermal_Layer_Of_Scrotum()
    HAIR_FOLLICLE_OF_SCROTUM_DERMAL_LAYER = _Hair_Follicle_Of_Scrotum_Dermal_Layer()
    SWEAT_GLAND_OF_SCROTUM_DERMAL_LAYER = _Sweat_Gland_Of_Scrotum_Dermal_Layer()
    SEPTUM_OF_SCROTUM = _Septum_Of_Scrotum()
    EPITHELIAL_LAYER_OF_EFFERENT_DUCT = _Epithelial_Layer_Of_Efferent_Duct()
    REST_OF_EFFERENT_DUCT = _Rest_Of_Efferent_Duct()
    MUSCLE_LAYER_OF_CAUDA_OF_EPIDIDYMIS = _Muscle_Layer_Of_Cauda_Of_Epididymis()
    ADVENTITIA_OF_CAUDA_OF_EPIDIDYMIS = _Adventitia_Of_Cauda_Of_Epididymis()
    EPITHELIUM_OF_CORPUS_EPIDIDYMIS = _Epithelium_Of_Corpus_Epididymis()
    MUSCLE_LAYER_OF_CORPUS_OF_EPIDIDYMIS = _Muscle_Layer_Of_Corpus_Of_Epididymis()
    ADVENTITIA_OF_CORPUS_OF_EPIDIDYMIS = _Adventitia_Of_Corpus_Of_Epididymis()
    EPITHELIUM_OF_CAPUT_OF_EPIDIDYMIS = _Epithelium_Of_Caput_Of_Epididymis()
    MUSCLE_LAYER_OF_CAPUT_OF_EPIDIDYMIS = _Muscle_Layer_Of_Caput_Of_Epididymis()
    ADVENTITIA_OF_CAPUT_OF_EPIDIDYMIS = _Adventitia_Of_Caput_Of_Epididymis()
    SEROSA_OF_DUCTUS_DEFERENS = _Serosa_Of_Ductus_Deferens()
    OS_PENIS = _Os_Penis()
    EPITHELIUM_OF_SEMINAL_VESICLE = _Epithelium_Of_Seminal_Vesicle()
    MUSCLE_OF_SEMINAL_VESICLE = _Muscle_Of_Seminal_Vesicle()
    SEROSA_OF_SEMINAL_VESICLE = _Serosa_Of_Seminal_Vesicle()
    EPITHELIUM_OF_EJACULATORY_DUCT = _Epithelium_Of_Ejaculatory_Duct()
    EPITHELIUM_OF_BULBOURETHRAL_GLAND_OF_MALE = _Epithelium_Of_Bulbourethral_Gland_Of_Male()
    LAMINA_PROPRIA_OF_BULBOURETHRAL_GLAND_OF_MALE = _Lamina_Propria_Of_Bulbourethral_Gland_Of_Male()
    ANTERIOR_PROSTATE_GLAND = _Anterior_Prostate_Gland()
    ANTERIOR_PROSTATIC_EPITHELIUM = _Anterior_Prostatic_Epithelium()
    GLANDULAR_EPITHELIUM_OF_ANTERIOR_PROSTATE = _Glandular_Epithelium_Of_Anterior_Prostate()
    BASAL_EPITHELIUM_OF_ANTERIOR_PROSTATE = _Basal_Epithelium_Of_Anterior_Prostate()
    ANTERIOR_PROSTATIC_INTERSTITIUM = _Anterior_Prostatic_Interstitium()
    SMOOTH_MUSCLE_OF_ANTERIOR_PROSTATE = _Smooth_Muscle_Of_Anterior_Prostate()
    REST_OF_INTERSTITIUM_OF_ANTERIOR_PROSTATE = _Rest_Of_Interstitium_Of_Anterior_Prostate()
    DORSAL_PROSTATE_GLAND = _Dorsal_Prostate_Gland()
    DORSAL_PROSTATIC_EPITHELIUM = _Dorsal_Prostatic_Epithelium()
    GLANDULAR_EPITHELIUM_OF_DORSAL_PROSTATE = _Glandular_Epithelium_Of_Dorsal_Prostate()
    BASAL_EPITHELIUM_OF_DORSAL_PROSTATE = _Basal_Epithelium_Of_Dorsal_Prostate()
    DORSAL_PROSTATIC_INTERSTITIUM = _Dorsal_Prostatic_Interstitium()
    SMOOTH_MUSCLE_OF_DORSAL_PROSTATE = _Smooth_Muscle_Of_Dorsal_Prostate()
    REST_OF_INTERSTITIUM_OF_DORSAL_PROSTATE = _Rest_Of_Interstitium_Of_Dorsal_Prostate()
    LATERAL_PROSTATE_GLAND = _Lateral_Prostate_Gland()
    LATERAL_PROSTATIC_EPITHELIUM = _Lateral_Prostatic_Epithelium()
    GLANDULAR_EPITHELIUM_OF_LATERAL_PROSTATE = _Glandular_Epithelium_Of_Lateral_Prostate()
    BASAL_EPITHELIUM_OF_LATERAL_PROSTATE = _Basal_Epithelium_Of_Lateral_Prostate()
    LATERAL_PROSTATIC_INTERSTITIUM = _Lateral_Prostatic_Interstitium()
    SMOOTH_MUSCLE_OF_LATERAL_PROSTATE = _Smooth_Muscle_Of_Lateral_Prostate()
    REST_OF_INTERSTITIUM_OF_LATERAL_PROSTATE = _Rest_Of_Interstitium_Of_Lateral_Prostate()
    VENTRAL_PROSTATE_GLAND = _Ventral_Prostate_Gland()
    VENTRAL_PROSTATIC_EPITHELIUM = _Ventral_Prostatic_Epithelium()
    GLANDULAR_EPITHELIUM_OF_VENTRAL_PROSTATE = _Glandular_Epithelium_Of_Ventral_Prostate()
    BASAL_EPITHELIUM_OF_VENTRAL_PROSTATE = _Basal_Epithelium_Of_Ventral_Prostate()
    VENTRAL_PROSTATIC_INTERSTITIUM = _Ventral_Prostatic_Interstitium()
    SMOOTH_MUSCLE_OF_VENTRAL_PROSTATE = _Smooth_Muscle_Of_Ventral_Prostate()
    REST_OF_INTERSTITIUM_OF_VENTRAL_PROSTATE = _Rest_Of_Interstitium_Of_Ventral_Prostate()
    CORPUS_CAVERNOSUM_OF_PENILE_BODY = _Corpus_Cavernosum_Of_Penile_Body()
    LAMINA_PROPRIA_OF_PENILE_BODY = _Lamina_Propria_Of_Penile_Body()
    CORPUS_CAVERNOSUM_OF_GLANS_PENIS = _Corpus_Cavernosum_Of_Glans_Penis()
    LAMINA_PROPRIA_OF_GLANS_PENIS = _Lamina_Propria_Of_Glans_Penis()
    OOCYTE_OF_SECONDARY_FOLLICLE = _Oocyte_Of_Secondary_Follicle()
    FOLLICLE_CELL_OF_SECONDARY_FOLLICLE = _Follicle_Cell_Of_Secondary_Follicle()
    CUMULUS_OF_SECONDARY_FOLLICLE = _Cumulus_Of_Secondary_Follicle()
    MURAL_OF_SECONDARY_FOLLICLE = _Mural_Of_Secondary_Follicle()
    THECA_OF_SECONDARY_FOLLICLE = _Theca_Of_Secondary_Follicle()
    OVARY_ATRETIC_FOLLICLE = _Ovary_Atretic_Follicle()
    OOCYTE_OF_ATRETIC_FOLLICLE = _Oocyte_Of_Atretic_Follicle()
    APOPTOTIC_GERMINAL_CELL = _Apoptotic_Germinal_Cell()
    OVARY_RUPTURED_FOLLICLE = _Ovary_Ruptured_Follicle()
    THECA_OF_RUPTURED_FOLLICLE = _Theca_Of_Ruptured_Follicle()
    GERMINAL_CELL_OF_RUPTURED_FOLLICLE = _Germinal_Cell_Of_Ruptured_Follicle()
    CORPUS_LUTEUM = _Corpus_Luteum()
    CORPUS_ALBICANS = _Corpus_Albicans()
    OVIDUCT_INFUNDIBULUM = _Oviduct_Infundibulum()
    EPITHELIAL_LAYER_OF_INFUNDIBULUM = _Epithelial_Layer_Of_Infundibulum()
    SEROSA_OF_INFUNDIBULUM = _Serosa_Of_Infundibulum()
    REST_OF_OVIDUCT = _Rest_Of_Oviduct()
    EPITHELIAL_LAYER_OF_REST_OF_OVIDUCT = _Epithelial_Layer_Of_Rest_Of_Oviduct()
    SEROSA_OF_REST_OF_OVIDUCT = _Serosa_Of_Rest_Of_Oviduct()
    UTERUS = _Uterus()
    ENDOMETRIUM = _Endometrium()
    UTERINE_GLAND = _Uterine_Gland()
    REST_OF_ENDOMETRIUM = _Rest_Of_Endometrium()
    MYOMETRIUM = _Myometrium()
    ADVENTITIA_OF_UTERUS = _Adventitia_Of_Uterus()
    CERVIX_UTERI = _Cervix_Uteri()
    EPITHELIAL_LAYER_OF_CERVIX_UTERI = _Epithelial_Layer_Of_Cervix_Uteri()
    MUSCLE_LAYER_OF_CERVIX_UTERI = _Muscle_Layer_Of_Cervix_Uteri()
    ADVENTITIA_OF_CERVIX_UTERI = _Adventitia_Of_Cervix_Uteri()
    GLAND_OF_LOWER_VAGINAL_EPITHELIUM = _Gland_Of_Lower_Vaginal_Epithelium()
    REST_OF_EPITHELIAL_LAYER_OF_LOWER_VAGINA = _Rest_Of_Epithelial_Layer_Of_Lower_Vagina()
    ADVENTITIA_OF_SINOVAGINAL_BULB = _Adventitia_Of_Sinovaginal_Bulb()
    GLAND_OF_UPPER_VAGINAL_EPITHELIUM = _Gland_Of_Upper_Vaginal_Epithelium()
    REST_OF_EPITHELIUM_OF_UPPER_VAGINA = _Rest_Of_Epithelium_Of_Upper_Vagina()
    ADVENTITIA_OF_UPPER_VAGINA = _Adventitia_Of_Upper_Vagina()
    URETERAL_MESENCHYME__REST_OF = _Ureteral_Mesenchyme_Rest_Of()
    ENDOTHELIUM_OF_RENAL_ARTERY = _Endothelium_Of_Renal_Artery()
    SMOOTH_MUSCLE_LAYER_OF_RENAL_ARTERY = _Smooth_Muscle_Layer_Of_Renal_Artery()
    ENDOTHELIUM_OF_RENAL_VEIN = _Endothelium_Of_Renal_Vein()
    SMOOTH_MUSCLE_LAYER_OF_RENAL_VEIN = _Smooth_Muscle_Layer_Of_Renal_Vein()
    GLOMERULAR_MESANGIUM_OF_MATURING_RENAL_CORPUSCLE = _Glomerular_Mesangium_Of_Maturing_Renal_Corpuscle()
    RENAL_CORTICAL_CAPILLARY = _Renal_Cortical_Capillary()
    RENAL_MEDULLARY_CAPILLARY = _Renal_Medullary_Capillary()
    MUSCLE_LAYER_OF_REST_OF_OVIDUCT = _Muscle_Layer_Of_Rest_Of_Oviduct()
    CIRCULAR_MUSCLE_LAYER_OF_REST_OF_OVIDUCT = _Circular_Muscle_Layer_Of_Rest_Of_Oviduct()
    LONGITUDINAL_MUSCLE_LAYER_OF_REST_OF_OVIDUCT = _Longitudinal_Muscle_Layer_Of_Rest_Of_Oviduct()
    CIRCULAR_MUSCLE_OF_DUCTUS_DEFERENS = _Circular_Muscle_Of_Ductus_Deferens()
    LONGITUDINAL_MUSCLE_OF_DUCTUS_DEFERENS = _Longitudinal_Muscle_Of_Ductus_Deferens()
    CRANIAL_SUSPENSORY_LIGAMENT = _Cranial_Suspensory_Ligament()
    EPITHELIUM_OF_PARAMESONEPHRIC_DUCT_OF_FEMALE__MESONEPHRIC_PORTION = (
        _Epithelium_Of_Paramesonephric_Duct_Of_Female_Mesonephric_Portion()
    )
    MESENCHYME_OF_PARAMESONEPHRIC_DUCT_OF_FEMALE__MESONEPHRIC_PORTION = (
        _Mesenchyme_Of_Paramesonephric_Duct_Of_Female_Mesonephric_Portion()
    )
    GENITAL_SWELLING = _Genital_Swelling()
    DORSAL_GENITAL_SWELLING = _Dorsal_Genital_Swelling()
    VENTROLATERAL_GENITAL_SWELLING = _Ventrolateral_Genital_Swelling()
    UROTHELIUM_OF_VENTRAL_BLADDER_NECK = _Urothelium_Of_Ventral_Bladder_Neck()
    LAMINA_PROPRIA_OF_BLADDER = _Lamina_Propria_Of_Bladder()
    LAMINA_PROPRIA_OF_BLADDER_FUNDUS = _Lamina_Propria_Of_Bladder_Fundus()
    LAMINA_PROPRIA_OF_BLADDER_TRIGONE = _Lamina_Propria_Of_Bladder_Trigone()
    LAMINA_PROPRIA_OF_VENTRAL_BLADDER_NECK = _Lamina_Propria_Of_Ventral_Bladder_Neck()
    DETRUSOR_MUSCLE_OF_VENTRAL_BLADDER_NECK = _Detrusor_Muscle_Of_Ventral_Bladder_Neck()
    SEROSA_OF_NECK = _Serosa_Of_Neck()
    MUSCULARIS_MUCOSA_OF_NECK = _Muscularis_Mucosa_Of_Neck()
    ADVENTITIA_OF_VENTRAL_BLADDER_NECK = _Adventitia_Of_Ventral_Bladder_Neck()
    URETERAL_SMOOTH_MUSCLE_LAYER_INTERSTITIUM = _Ureteral_Smooth_Muscle_Layer_Interstitium()
    LABIAL_SWELLING = _Labial_Swelling()
    MESENCHYME_OF_LABIAL_SWELLING = _Mesenchyme_Of_Labial_Swelling()
    LABIAL_SWELLING_SKIN = _Labial_Swelling_Skin()
    MESENCHYME_OF_LABIAL_FOLD = _Mesenchyme_Of_Labial_Fold()
    LABIAL_FOLD_SKIN = _Labial_Fold_Skin()
    ADVENTITIA_OF_EPIDIDYMIS = _Adventitia_Of_Epididymis()
    EPITHELIUM_OF_EPIDIDYMIS = _Epithelium_Of_Epididymis()
    JUXTAGLOMERULAR_COMPLEX = _Juxtaglomerular_Complex()
    COELOMIC_EPITHELIUM_OF_MALE_MESONEPHROS = _Coelomic_Epithelium_Of_Male_Mesonephros()
    EPITHELIUM_OF_PHALLIC_URETHRA_OF_MALE = _Epithelium_Of_Phallic_Urethra_Of_Male()
    EPITHELIUM_OF_PHALLIC_URETHRA_OF_FEMALE = _Epithelium_Of_Phallic_Urethra_Of_Female()
    PREPUTIAL_SWELLING_OF_FEMALE = _Preputial_Swelling_Of_Female()
    DISTAL_GENITAL_TUBERCLE_OF_FEMALE = _Distal_Genital_Tubercle_Of_Female()
    MESENCHYME_OF_DISTAL_GENITAL_TUBERCLE_OF_FEMALE = _Mesenchyme_Of_Distal_Genital_Tubercle_Of_Female()
    SKIN_OF_DISTAL_GENITAL_TUBERCLE_OF_FEMALE = _Skin_Of_Distal_Genital_Tubercle_Of_Female()
    MESENCHYME_OF_FEMALE_PREPUTIAL_SWELLING = _Mesenchyme_Of_Female_Preputial_Swelling()
    SKIN_OF_FEMALE_PREPUTIAL_SWELLING = _Skin_Of_Female_Preputial_Swelling()
    SCROTAL_SWELLING = _Scrotal_Swelling()
    MESENCHYME_OF_SCROTAL_SWELLING = _Mesenchyme_Of_Scrotal_Swelling()
    SCROTAL_SWELLING_SKIN = _Scrotal_Swelling_Skin()
    TUNICA_ALBUGINEA_OF_OVARY = _Tunica_Albuginea_Of_Ovary()
    CRANIAL_MESONEPHRIC_TUBULE_OF_MALE = _Cranial_Mesonephric_Tubule_Of_Male()
    MESONEPHRIC_GLOMERULUS_OF_MALE = _Mesonephric_Glomerulus_Of_Male()
    REST_OF_CRANIAL_MESONEPHRIC_TUBULE_OF_MALE = _Rest_Of_Cranial_Mesonephric_Tubule_Of_Male()
    CAUDAL_MESONEPHRIC_TUBULE_OF_MALE = _Caudal_Mesonephric_Tubule_Of_Male()
    CRANIAL_MESONEPHRIC_TUBULE_OF_FEMALE = _Cranial_Mesonephric_Tubule_Of_Female()
    MESONEPHRIC_GLOMERULUS_OF_FEMALE = _Mesonephric_Glomerulus_Of_Female()
    REST_OF_CRANIAL_MESONEPHRIC_TUBULE_OF_FEMALE = _Rest_Of_Cranial_Mesonephric_Tubule_Of_Female()
    CAUDAL_MESONEPHRIC_TUBULE_OF_FEMALE = _Caudal_Mesonephric_Tubule_Of_Female()
    CRANIAL_MESONEPHRIC_TUBULE = _Cranial_Mesonephric_Tubule()
    REST_OF_CRANIAL_MESONEPHRIC_TUBULE = _Rest_Of_Cranial_Mesonephric_Tubule()
    MESONEPHRIC_GLOMERULUS = _Mesonephric_Glomerulus()
    CAUDAL_MESONEPHRIC_TUBULE = _Caudal_Mesonephric_Tubule()
    MESENCHYME_OF_SCROTAL_FOLD = _Mesenchyme_Of_Scrotal_Fold()
    SCROTAL_FOLD_SKIN = _Scrotal_Fold_Skin()
    MESENCHYME_OF_GLANS_PENIS = _Mesenchyme_Of_Glans_Penis()
    GLANS_PENIS_SKIN = _Glans_Penis_Skin()
    PREPUCE_MESENCHYME_OF_MALE = _Prepuce_Mesenchyme_Of_Male()
    MALE_PREPUCE_SKIN = _Male_Prepuce_Skin()
    PREPUTIAL_GLAND_OF_MALE = _Preputial_Gland_Of_Male()
    MESENCHYME_OF_PENILE_BODY = _Mesenchyme_Of_Penile_Body()
    PENILE_BODY_SKIN = _Penile_Body_Skin()
    OUTER_LAYER_OF_UTERINE_HORN = _Outer_Layer_Of_Uterine_Horn()
    PREPUCE_OF_FEMALE = _Prepuce_Of_Female()
    FEMALE_PREPUCE_MESENCHYME = _Female_Prepuce_Mesenchyme()
    FEMALE_PREPUCE_SKIN = _Female_Prepuce_Skin()
    PREPUTIAL_GLAND_OF_FEMALE = _Preputial_Gland_Of_Female()
    MESENCHYME_OF_GLANS_CLITORIS = _Mesenchyme_Of_Glans_Clitoris()
    SKIN_OF_GLANS_OF_FEMALE_GENITAL_TUBERCLE = _Skin_Of_Glans_Of_Female_Genital_Tubercle()
    MUSCLE_LAYER_OF_EPIDIDYMIS = _Muscle_Layer_Of_Epididymis()
    OVARY_PRIMORDIAL_FOLLICLE = _Ovary_Primordial_Follicle()
    OOCYTE_OF_PRIMORDIAL_FOLLICLE = _Oocyte_Of_Primordial_Follicle()
    OVARY_TERTIARY_FOLLICLE = _Ovary_Tertiary_Follicle()
    OOCYTE_OF_TERTIARY_FOLLICLE = _Oocyte_Of_Tertiary_Follicle()
    FOLLICLE_CELL_OF_TERTIARY_FOLLICLE = _Follicle_Cell_Of_Tertiary_Follicle()
    THECA_OF_TERTIARY_FOLLICLE = _Theca_Of_Tertiary_Follicle()
    ANTRUM_OF_TERTIARY_FOLLICLE = _Antrum_Of_Tertiary_Follicle()
    CUMULUS_OF_TERTIARY_FOLLICLE = _Cumulus_Of_Tertiary_Follicle()
    MURAL_OF_TERTIARY_FOLLICLE = _Mural_Of_Tertiary_Follicle()
    OVARY_MATURE_FOLLICLE = _Ovary_Mature_Follicle()
    OOCYTE_OF_MATURE_FOLLICLE = _Oocyte_Of_Mature_Follicle()
    GERMINAL_CELL_OF_MATURE_FOLLICLE = _Germinal_Cell_Of_Mature_Follicle()
    CUMULUS_OF_MATURE_FOLLICLE = _Cumulus_Of_Mature_Follicle()
    MURAL_OF_MATURE_FOLLICLE = _Mural_Of_Mature_Follicle()
    THECA_OF_MATURE_FOLLICLE = _Theca_Of_Mature_Follicle()
    ANTRUM_OF_MATURE_FOLLICLE = _Antrum_Of_Mature_Follicle()
    VASCULATURE_OF_SCROTUM = _Vasculature_Of_Scrotum()
    VASCULATURE_OF_DUCTUS_DEFERENS = _Vasculature_Of_Ductus_Deferens()
    VASCULATURE_OF_EPIDIDYMIS = _Vasculature_Of_Epididymis()
    VASCULATURE_OF_SEMINAL_VESICLE = _Vasculature_Of_Seminal_Vesicle()
    VASCULATURE_OF_EJACULATORY_DUCT = _Vasculature_Of_Ejaculatory_Duct()
    VASCULATURE_OF_BULBOURETHRAL_GLAND_OF_MALE = _Vasculature_Of_Bulbourethral_Gland_Of_Male()
    VASCULATURE_OF_PROSTATE_GLAND = _Vasculature_Of_Prostate_Gland()
    VASCULATURE_OF_PENIS = _Vasculature_Of_Penis()
    VASCULATURE_OF_OVIDUCT = _Vasculature_Of_Oviduct()
    VASCULATURE_OF_UTERUS = _Vasculature_Of_Uterus()
    VASCULATURE_OF_VAGINA = _Vasculature_Of_Vagina()
    CLITORIS = _Clitoris()
    BODY_OF_CLITORIS = _Body_Of_Clitoris()
    OS_CLITORIDIS = _Os_Clitoridis()
    EPITHELIUM_OF_BODY_OF_CLITORIS = _Epithelium_Of_Body_Of_Clitoris()
    LAMINA_PROPRIA_OF_BODY_OF_CLITORIS = _Lamina_Propria_Of_Body_Of_Clitoris()
    GLANS_CLITORIS = _Glans_Clitoris()
    EPITHELIUM_OF_GLANS_CLITORIS = _Epithelium_Of_Glans_Clitoris()
    LAMINA_PROPRIA_OF_GLANS_CLITORIS = _Lamina_Propria_Of_Glans_Clitoris()
    VASCULATURE_OF_CLITORIS = _Vasculature_Of_Clitoris()
    LABIA = _Labia()
    LABIA_SKIN = _Labia_Skin()
    LAMINA_PROPRIA_OF_LABIA = _Lamina_Propria_Of_Labia()
    GLAND_OF_LABIA = _Gland_Of_Labia()
    VASCULATURE_OF_LABIA = _Vasculature_Of_Labia()
    URETERAL_VASCULATURE = _Ureteral_Vasculature()
    PRIMITIVE_BLADDER = _Primitive_Bladder()
    UROTHELIUM_OF_PRIMITIVE_BLADDER = _Urothelium_Of_Primitive_Bladder()
    MESENCHYMAL_LAYER_OF_PRIMITIVE_BLADDER = _Mesenchymal_Layer_Of_Primitive_Bladder()
    CAUDAL_UROGENITAL_SINUS = _Caudal_Urogenital_Sinus()
    CAUDAL_UROGENITAL_SINUS_EPITHELIUM = _Caudal_Urogenital_Sinus_Epithelium()
    CAUDAL_UROGENITAL_SINUS_MESENCHYME = _Caudal_Urogenital_Sinus_Mesenchyme()
    URETHRAL_FOLD = _Urethral_Fold()
    URETHRA = _Urethra()
    PELVIC_URETHRA = _Pelvic_Urethra()
    EPITHELIUM_OF_PELVIC_URETHRA = _Epithelium_Of_Pelvic_Urethra()
    MESENCHYMAL_LAYER_OF_PELVIC_URETHRA = _Mesenchymal_Layer_Of_Pelvic_Urethra()
    MUSCLE_LAYER_OF_PELVIC_URETHRA = _Muscle_Layer_Of_Pelvic_Urethra()
    PHALLIC_URETHRA = _Phallic_Urethra()
    URETHRAL_PLATE_OF_PHALLIC_URETHRA = _Urethral_Plate_Of_Phallic_Urethra()
    CLITORAL_URETHRA = _Clitoral_Urethra()
    URETHRAL_PLATE_EPITHELIUM_OF_CLITORAL_URETHRA = _Urethral_Plate_Epithelium_Of_Clitoral_Urethra()
    URETHRAL_FOLD_OF_FEMALE = _Urethral_Fold_Of_Female()
    EPITHELIUM_OF_CLITORAL_URETHRA = _Epithelium_Of_Clitoral_Urethra()
    MESENCHYMAL_LAYER_OF_PHALLIC_URETHRA_OF_FEMALE = _Mesenchymal_Layer_Of_Phallic_Urethra_Of_Female()
    MUSCLE_LAYER_OF_PHALLIC_URETHRA_OF_FEMALE = _Muscle_Layer_Of_Phallic_Urethra_Of_Female()
    PROSTATIC_URETHRA = _Prostatic_Urethra()
    PENILE_URETHRA = _Penile_Urethra()
    EPITHELIUM_OF_PENILE_URETHRA = _Epithelium_Of_Penile_Urethra()
    MESENCHYMAL_LAYER_OF_PENILE_URETHRA = _Mesenchymal_Layer_Of_Penile_Urethra()
    MUSCLE_LAYER_OF_PENILE_URETHRA = _Muscle_Layer_Of_Penile_Urethra()
    EPITHELIUM_OF_PROSTATIC_URETHRA = _Epithelium_Of_Prostatic_Urethra()
    MESENCHYMAL_LAYER_OF_PROSTATIC_URETHRA = _Mesenchymal_Layer_Of_Prostatic_Urethra()
    MUSCLE_LAYER_OF_PROSTATIC_URETHRA = _Muscle_Layer_Of_Prostatic_Urethra()
    GLOMERULAR_BASEMENT_MEMBRANE_OF_MATURING_RENAL_CORPUSCLE = (
        _Glomerular_Basement_Membrane_Of_Maturing_Renal_Corpuscle()
    )
    MALE_EXTERNAL_GENITALIA = _Male_External_Genitalia()
    FEMALE_EXTERNAL_GENITALIA = _Female_External_Genitalia()
    EPITHELIUM_OF_VAGINA = _Epithelium_Of_Vagina()
    MUSCLE_OF_VAGINA = _Muscle_Of_Vagina()
    ADVENTITIA_OF_VAGINA = _Adventitia_Of_Vagina()
    STRAIGHT_LIMB_OF_IMMATURE_LOOP_OF_HENLE = _Straight_Limb_Of_Immature_Loop_Of_Henle()
    BEND_OF_IMMATURE_LOOP_OF_HENLE = _Bend_Of_Immature_Loop_Of_Henle()
    OOCYTE = _Oocyte()
    PRE_GRANULOSA_CELL = _Pre_Granulosa_Cell()
    REST_OF_CORTICAL_COMPONENT_OF_MESENCHYMAL_STROMA_OF_OVARY = (
        _Rest_Of_Cortical_Component_Of_Mesenchymal_Stroma_Of_Ovary()
    )
    URETERIC_TREE_TERMINAL_BRANCH_EXCLUDING_TIP_ITSELF = _Ureteric_Tree_Terminal_Branch_Excluding_Tip_Itself()
    OVIGEROUS_CORD = _Ovigerous_Cord()
    DERMOMYOTOME = _Dermomyotome()
    TRUNK_MYOCOELE = _Trunk_Myocoele()
    TAIL_MYOCOELE = _Tail_Myocoele()
    MYOCOELE = _Myocoele()
    TRUNK_SCLEROTOME = _Trunk_Sclerotome()
    TAIL_SCLEROTOME = _Tail_Sclerotome()
    SCLEROTOME = _Sclerotome()
    SOMITE = _Somite()
    DEVELOPING_VASCULATURE_OF_CAUDA_EPIDIDYMIS = _Developing_Vasculature_Of_Cauda_Epididymis()
    DEVELOPING_VASCULATURE_OF_CORPUS_EPIDIDYMIS = _Developing_Vasculature_Of_Corpus_Epididymis()
    DEVELOPING_VASCULATURE_OF_CAPUT_EPIDIDYMIS = _Developing_Vasculature_Of_Caput_Epididymis()
    DEVELOPING_VASCULATURE_OF_UTERINE_HORN = _Developing_Vasculature_Of_Uterine_Horn()
    DEVELOPING_VASCULATURE_OF_OVIDUCT = _Developing_Vasculature_Of_Oviduct()
    VASCULATURE_OF_UPPER_VAGINA = _Vasculature_Of_Upper_Vagina()
    VASCULATURE_OF_SINOVAGINAL_BULB = _Vasculature_Of_Sinovaginal_Bulb()
    DEVELOPING_VASCULATURE_OF_VAGINA = _Developing_Vasculature_Of_Vagina()
    DEVELOPING_VASCULATURE_SYSTEM_OF_EPIDIDYMIS = _Developing_Vasculature_System_Of_Epididymis()
    SURFACE_EPITHELIUM_OF_TESTIS = _Surface_Epithelium_Of_Testis()
    FOLLICLE_CELL_OF_PRIMORDIAL_FOLLICLE = _Follicle_Cell_Of_Primordial_Follicle()
    CREMASTER_MUSCLE = _Cremaster_Muscle()
    THECA_OF_ATRETIC_FOLLICLE = _Theca_Of_Atretic_Follicle()
    GRANULOSA_OF_RUPTURED_FOLLICLE = _Granulosa_Of_Ruptured_Follicle()
    MUSCLE_LAYER_OF_INFUNDIBULUM = _Muscle_Layer_Of_Infundibulum()
    LONGITUDINAL_MUSCLE_LAYER_OF_INFUNDIBULUM = _Longitudinal_Muscle_Layer_Of_Infundibulum()
    CIRCULAR_MUSCLE_LAYER_OF_INFUNDIBULUM = _Circular_Muscle_Layer_Of_Infundibulum()
    RESIDENT_MACROPHAGE = _Resident_Macrophage()
    REST_OF_RENAL_INTERSTITIUM = _Rest_Of_Renal_Interstitium()
    RENAL_FIBROBLASTS = _Renal_Fibroblasts()
    ANLAGE_OF_LOOP_OF_HENLE_OF_CORTICAL_RENAL_TUBULE = _Anlage_Of_Loop_Of_Henle_Of_Cortical_Renal_Tubule()
    RENAL_CORTICAL_FIBROBLASTS = _Renal_Cortical_Fibroblasts()
    RESIDENT_MACROPHAGE_OF_THE_CORTEX = _Resident_Macrophage_Of_The_Cortex()
    REST_OF_RENAL_CORTICAL_INTERSTITIUM = _Rest_Of_Renal_Cortical_Interstitium()
    RENAL_CORTICAL_LYMPHATICS = _Renal_Cortical_Lymphatics()
    RENAL_CORTICAL_NERVES = _Renal_Cortical_Nerves()
    RENAL_MEDULLARY_FIBROBLASTS = _Renal_Medullary_Fibroblasts()
    RESIDENT_MACROPHAGE_OF_THE_MEDULLA = _Resident_Macrophage_Of_The_Medulla()
    REST_OF_RENAL_MEDULLARY_INTERSTITIUM = _Rest_Of_Renal_Medullary_Interstitium()
    RENAL_MEDULLARY_LYMPHATICS = _Renal_Medullary_Lymphatics()
    RENAL_MEDULLARY_NERVES = _Renal_Medullary_Nerves()
    PERIHILAR_FIBROBLAST = _Perihilar_Fibroblast()
    RESIDENT_MACROPHAGE_OF_THE_PERIHILAR_INTERSTITIUM = _Resident_Macrophage_Of_The_Perihilar_Interstitium()
    REST_OF_PERIHILAR_INTERSTITIUM = _Rest_Of_Perihilar_Interstitium()
    PREMACULA_SEGMENT_OF_DISTAL_STRAIGHT_TUBULE_OF_RENAL_CORTEX = (
        _Premacula_Segment_Of_Distal_Straight_Tubule_Of_Renal_Cortex()
    )
    OUTER_MEDULLARY_FIBROBLAST = _Outer_Medullary_Fibroblast()
    RESIDENT_MACROPHAGE_OF_THE_OUTER_MEDULLA = _Resident_Macrophage_Of_The_Outer_Medulla()
    REST_OF_OUTER_MEDULLARY_INTERSTITIUM = _Rest_Of_Outer_Medullary_Interstitium()
    INNER_MEDULLARY_FIBROBLAST = _Inner_Medullary_Fibroblast()
    RESIDENT_MACROPHAGE_OF_THE_INNER_MEDULLA = _Resident_Macrophage_Of_The_Inner_Medulla()
    REST_OF_INNER_MEDULLARY_INTERSTITIUM = _Rest_Of_Inner_Medullary_Interstitium()
    MEDULLARY_RENAL_TUBULE = _Medullary_Renal_Tubule()
    REST_OF_MEDULLARY_RENAL_TUBULE = _Rest_Of_Medullary_Renal_Tubule()
    PERITUBULAR_FIBROBLASTS_OF_CORTEX = _Peritubular_Fibroblasts_Of_Cortex()
    PERIARTERIAL_FIBROBLASTS_OF_CORTEX = _Periarterial_Fibroblasts_Of_Cortex()
    PERITUBULAR_FIBROBLASTS_OF_OUTER_MEDULLA = _Peritubular_Fibroblasts_Of_Outer_Medulla()
    PERIARTERIAL_FIBROBLASTS_OF_OUTER_MEDULLA = _Periarterial_Fibroblasts_Of_Outer_Medulla()
    PERITUBULAR_FIBROBLASTS_OF_INNER_MEDULLA = _Peritubular_Fibroblasts_Of_Inner_Medulla()
    PERIARTERIAL_FIBROBLASTS_OF_INNER_MEDULLA = _Periarterial_Fibroblasts_Of_Inner_Medulla()
    RENAL_ARTERIAL_SYSTEM = _Renal_Arterial_System()
    RENAL_CAPILLARY = _Renal_Capillary()
    RENAL_VENOUS_SYSTEM = _Renal_Venous_System()
    RENAL_LARGE_BLOOD_VESSEL = _Renal_Large_Blood_Vessel()
    RENAL_SMALL_BLOOD_VESSEL = _Renal_Small_Blood_Vessel()
    SEMINIFEROUS_TUBULE = _Seminiferous_Tubule()
    SPERMATOGONIUM = _Spermatogonium()
    SPERMATOCYTE = _Spermatocyte()
    SPERMATID = _Spermatid()
    SPERMATOZOON = _Spermatozoon()
    MESENCHYME_OF_UROGENITAL_SINUS = _Mesenchyme_Of_Urogenital_Sinus()
    MESENCHYME_OF_PROXIMAL_GENITAL_TUBERCLE_OF_MALE = _Mesenchyme_Of_Proximal_Genital_Tubercle_Of_Male()
    SKIN_OF_PROXIMAL_GENITAL_TUBERCLE_OF_MALE = _Skin_Of_Proximal_Genital_Tubercle_Of_Male()
    DEVELOPING_VASCULATURE_OF_FEMALE_GENITAL_TUBERCLE = _Developing_Vasculature_Of_Female_Genital_Tubercle()
    PROXIMAL_GENITAL_TUBERCLE_OF_MALE = _Proximal_Genital_Tubercle_Of_Male()
    PROXIMAL_URETHRAL_MEATUS_OF_MALE = _Proximal_Urethral_Meatus_Of_Male()
    PROXIMAL_GENITAL_TUBERCLE_OF_FEMALE = _Proximal_Genital_Tubercle_Of_Female()
    URETHRAL_PLATE_EPITHELIUM_OF_MALE = _Urethral_Plate_Epithelium_Of_Male()
    URETHRAL_TUBE_EPITHELIUM_OF_MALE = _Urethral_Tube_Epithelium_Of_Male()
    EPITHELIUM_OF_UROGENITAL_SINUS = _Epithelium_Of_Urogenital_Sinus()
    DEVELOPING_VASCULATURE_OF_MALE_GENITAL_TUBERCLE = _Developing_Vasculature_Of_Male_Genital_Tubercle()
    EARLY_DISTAL_TUBULE_OF_CAPILLARY_LOOP_NEPHRON = _Early_Distal_Tubule_Of_Capillary_Loop_Nephron()
    EARLY_DISTAL_TUBULE_OF_MATURING_NEPHRON = _Early_Distal_Tubule_Of_Maturing_Nephron()
    RENAL_CONNECTING_TUBULE_OF_MATURING_NEPHRON = _Renal_Connecting_Tubule_Of_Maturing_Nephron()
    RENAL_CONNECTING_TUBULE_OF_MATURE_NEPHRON = _Renal_Connecting_Tubule_Of_Mature_Nephron()
    URETHRAL_PLATE_EPITHELIUM = _Urethral_Plate_Epithelium()
    NERVE_OF_PELVIC_URETHRA = _Nerve_Of_Pelvic_Urethra()
    NERVE_OF_PHALLIC_URETHRA = _Nerve_Of_Phallic_Urethra()
    MESENCHYMAL_LAYER_OF_VENTRAL_PRIMITIVE_BLADDER = _Mesenchymal_Layer_Of_Ventral_Primitive_Bladder()
    NERVE_OF_BLADDER = _Nerve_Of_Bladder()
    PELVIC_GANGLION = _Pelvic_Ganglion()
    NERVE_OF_UROGENITAL_SINUS = _Nerve_Of_Urogenital_Sinus()
    MESENCHYMAL_LAYER_OF_DORSAL_PRIMITIVE_BLADDER = _Mesenchymal_Layer_Of_Dorsal_Primitive_Bladder()
    URETHRAL_TUBE_EPITHELIUM_OF_FEMALE = _Urethral_Tube_Epithelium_Of_Female()
    PROXIMAL_URETHRAL_MEATUS_OF_FEMALE = _Proximal_Urethral_Meatus_Of_Female()
    DEVELOPING_VASCULATURE_OF_UROGENITAL_SINUS = _Developing_Vasculature_Of_Urogenital_Sinus()
    NERVES_OF_UROGENITAL_SINUS = _Nerves_Of_Urogenital_Sinus()
    MESENCHYME_OF_PROXIMAL_GENITAL_TUBERCLE_OF_FEMALE = _Mesenchyme_Of_Proximal_Genital_Tubercle_Of_Female()
    SKIN_OF_PROXIMAL_GENITAL_TUBERCLE_OF_FEMALE = _Skin_Of_Proximal_Genital_Tubercle_Of_Female()
    URETHRAL_PLATE_EPITHELIUM_OF_FEMALE = _Urethral_Plate_Epithelium_Of_Female()
    DEVELOPING_VASCULATURE_OF_MALE_MESONEPHROS = _Developing_Vasculature_Of_Male_Mesonephros()
    DEVELOPING_VASCULATURE_OF_FEMALE_MESONEPHROS = _Developing_Vasculature_Of_Female_Mesonephros()
    DEVELOPING_VASCULATURE_OF_PRIMITIVE_BLADDER = _Developing_Vasculature_Of_Primitive_Bladder()
    RENAL_CONNECTING_SEGMENT_OF_RENAL_VESICLE = _Renal_Connecting_Segment_Of_Renal_Vesicle()
    EARLY_PROXIMAL_TUBULE_OF_MATURING_NEPHRON = _Early_Proximal_Tubule_Of_Maturing_Nephron()
    EARLY_PROXIMAL_TUBULE_OF_CAPILLARY_LOOP_NEPHRON = _Early_Proximal_Tubule_Of_Capillary_Loop_Nephron()
    RENAL_CONNECTING_SEGMENT_OF_COMMA_SHAPED_BODY = _Renal_Connecting_Segment_Of_Comma_Shaped_Body()
    PROXIMAL_RENAL_VESICLE = _Proximal_Renal_Vesicle()
    MESENCHYMAL_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = _Mesenchymal_Layer_Of_Ventral_Pelvic_Urethra_Of_Male()
    MESENCHYMAL_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Mesenchymal_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male()
    MESENCHYMAL_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = _Mesenchymal_Layer_Of_Ventral_Pelvic_Urethra_Of_Female()
    MESENCHYMAL_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = _Mesenchymal_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female()
    MUSCLE_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = _Muscle_Layer_Of_Ventral_Pelvic_Urethra_Of_Male()
    MUSCLE_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Muscle_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male()
    MUSCLE_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = _Muscle_Layer_Of_Ventral_Pelvic_Urethra_Of_Female()
    MUSCLE_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = _Muscle_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female()
    NERVE_OF_PELVIC_URETHRA_OF_MALE = _Nerve_Of_Pelvic_Urethra_Of_Male()
    CORTICAL_RENAL_TUBULE_OF_MATURE_NEPHRON_GROUP = _Cortical_Renal_Tubule_Of_Mature_Nephron_Group()
    NERVE_OF_PELVIC_URETHRA_OF_FEMALE = _Nerve_Of_Pelvic_Urethra_Of_Female()
    NERVE_OF_URETHRA = _Nerve_Of_Urethra()
    CORTICAL_RENAL_TUBULE_OF_MATURING_NEPHRON_GROUP = _Cortical_Renal_Tubule_Of_Maturing_Nephron_Group()
    CORTICAL_RENAL_TUBULE_OF_CAPILLARY_LOOP_NEPHRON_GROUP = _Cortical_Renal_Tubule_Of_Capillary_Loop_Nephron_Group()
    MESENCHYMAL_LAYER_OF_VENTRAL_PELVIC_URETHRA = _Mesenchymal_Layer_Of_Ventral_Pelvic_Urethra()
    MESENCHYMAL_LAYER_OF_DORSAL_PELVIC_URETHRA = _Mesenchymal_Layer_Of_Dorsal_Pelvic_Urethra()
    MUSCLE_LAYER_OF_VENTRAL_PELVIC_URETHRA = _Muscle_Layer_Of_Ventral_Pelvic_Urethra()
    MUSCLE_LAYER_OF_DORSAL_PELVIC_URETHRA = _Muscle_Layer_Of_Dorsal_Pelvic_Urethra()
    DEVELOPING_VASCULATURE_OF_GENITOURINARY_SYSTEM = _Developing_Vasculature_Of_Genitourinary_System()
    DEVELOPING_VASCULATURE_OF_URINARY_SYSTEM = _Developing_Vasculature_Of_Urinary_System()
    DEVELOPING_VASCULATURE_OF_REPRODUCTIVE_SYSTEM = _Developing_Vasculature_Of_Reproductive_System()
    DISTAL_RENAL_VESICLE = _Distal_Renal_Vesicle()
    TRUNK = _Trunk()
    HEAD = _Head()
    POLAR_BODY = _Polar_Body()
    ALLANTOIS_BLOOD_VESSEL = _Allantois_Blood_Vessel()
    ALLANTOIS_ENDOTHELIUM = _Allantois_Endothelium()
    EXTRAEMBRYONIC_MESODERM = _Extraembryonic_Mesoderm()
    EXTRAEMBRYONIC_MESENCHYME = _Extraembryonic_Mesenchyme()
    _4_CELL_STAGE_EMBRYO = _4_Cell_Stage_Embryo()
    _8_CELL_STAGE_EMBRYO = _8_Cell_Stage_Embryo()
    YOLK_SAC_BLOOD_VESSEL = _Yolk_Sac_Blood_Vessel()
    TRABECULAR_CORD_MESODERMAL_CORE = _Trabecular_Cord_Mesodermal_Core()
    UMBILICAL_RING = _Umbilical_Ring()
    TRABECULAR_CORD = _Trabecular_Cord()
    INTERPLACENTAL_SPACE = _Interplacental_Space()
    CHORIONIC_PLATE = _Chorionic_Plate()
    CHORIOALLANTOIC_PLACENTA = _Chorioallantoic_Placenta()
    SECONDARY_TROPHOBLAST_GIANT_CELL = _Secondary_Trophoblast_Giant_Cell()
    SPONGIOTROPHOBLAST = _Spongiotrophoblast()
    TROPHOBLAST_GIANT_CELL = _Trophoblast_Giant_Cell()
    LABYRINTHINE_ZONE = _Labyrinthine_Zone()
    EPITHELIUM_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = _Epithelium_Of_Ventral_Pelvic_Urethra_Of_Male()
    LAMINA_PROPRIA_OF_SINOVAGINAL_BULB = _Lamina_Propria_Of_Sinovaginal_Bulb()
    BASAL_CELL_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Basal_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male()
    BASAL_CELL_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = _Basal_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Male()
    VASCULATURE_OF_PELVIC_URETHRA_OF_MALE = _Vasculature_Of_Pelvic_Urethra_Of_Male()
    SUPERFICIAL_CELL_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Superficial_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male()
    EPITHELIUM_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = _Epithelium_Of_Dorsal_Pelvic_Urethra_Of_Female()
    VASCULATURE_OF_PROSTATIC_URETHRA = _Vasculature_Of_Prostatic_Urethra()
    SUPERFICIAL_CELL_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = (
        _Superficial_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female()
    )
    BASAL_CELL_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = _Basal_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female()
    SUPERFICIAL_CELL_LAYER_OF_PROSTATIC_URETHRA = _Superficial_Cell_Layer_Of_Prostatic_Urethra()
    RHABDOSPHINCTER_OF_MALE = _Rhabdosphincter_Of_Male()
    LAMINA_PROPRIA_OF_EJACULATORY_DUCT = _Lamina_Propria_Of_Ejaculatory_Duct()
    BASAL_CELL_LAYER_OF_PROSTATIC_URETHRA = _Basal_Cell_Layer_Of_Prostatic_Urethra()
    LAMINA_PROPRIA_OF_UPPER_VAGINA = _Lamina_Propria_Of_Upper_Vagina()
    SUPERFICIAL_CELL_LAYER_OF_BLADDER_UROTHELIUM = _Superficial_Cell_Layer_Of_Bladder_Urothelium()
    BASAL_CELL_LAYER_OF_BLADDER_UROTHELIUM = _Basal_Cell_Layer_Of_Bladder_Urothelium()
    SUBMUCOSA_OF_BLADDER = _Submucosa_Of_Bladder()
    SUBMUCOSA_OF_NECK = _Submucosa_Of_Neck()
    SUBMUCOSA_OF_FUNDUS = _Submucosa_Of_Fundus()
    SMOOTH_MUSCLE_LAYER_OF_PROSTATIC_URETHRA = _Smooth_Muscle_Layer_Of_Prostatic_Urethra()
    NERVE_OF_PROSTATIC_URETHRA = _Nerve_Of_Prostatic_Urethra()
    MESENCHYMAL_PAD_OF_PELVIC_URETHRA_OF_MALE = _Mesenchymal_Pad_Of_Pelvic_Urethra_Of_Male()
    PERI_PROSTATIC_MESENCHYME = _Peri_Prostatic_Mesenchyme()
    EPITHELIUM_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = _Epithelium_Of_Ventral_Pelvic_Urethra_Of_Female()
    VASCULATURE_OF_PELVIC_URETHRA_OF_FEMALE = _Vasculature_Of_Pelvic_Urethra_Of_Female()
    SUPERFICIAL_CELL_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = (
        _Superficial_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Male()
    )
    NERVE_OF_PROSTATE_GLAND = _Nerve_Of_Prostate_Gland()
    PRESUMPTIVE_NEURAL_CREST_DERIVATIVE_OF_PELVIC_URETHRA_OF_MALE = (
        _Presumptive_Neural_Crest_Derivative_Of_Pelvic_Urethra_Of_Male()
    )
    MESENCHYMAL_PAD_OF_PELVIC_URETHRA_OF_FEMALE = _Mesenchymal_Pad_Of_Pelvic_Urethra_Of_Female()
    PRESUMPTIVE_NEURAL_CREST_DERIVATIVE_OF_PELVIC_URETHRA_OF_FEMALE = (
        _Presumptive_Neural_Crest_Derivative_Of_Pelvic_Urethra_Of_Female()
    )
    MUSCLE_OF_EJACULATORY_DUCT = _Muscle_Of_Ejaculatory_Duct()
    SUPERFICIAL_CELL_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = (
        _Superficial_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Female()
    )
    BASAL_CELL_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = _Basal_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Female()
    SUBMUCOSA_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Submucosa_Of_Dorsal_Pelvic_Urethra_Of_Male()
    LAMINA_PROPRIA_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = _Lamina_Propria_Of_Ventral_Pelvic_Urethra_Of_Male()
    MUSCULARIS_MUCOSA_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = _Muscularis_Mucosa_Of_Dorsal_Pelvic_Urethra_Of_Female()
    LAMINA_PROPRIA_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = _Lamina_Propria_Of_Dorsal_Pelvic_Urethra_Of_Female()
    MUSCULARIS_MUCOSA_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = _Muscularis_Mucosa_Of_Ventral_Pelvic_Urethra_Of_Male()
    SUBMUCOSA_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = _Submucosa_Of_Ventral_Pelvic_Urethra_Of_Male()
    INTERMEDIATE_CELL_LAYER_OF_PROSTATIC_URETHRA = _Intermediate_Cell_Layer_Of_Prostatic_Urethra()
    EPITHELIUM_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Epithelium_Of_Dorsal_Pelvic_Urethra_Of_Male()
    SUBMUCOSA_OF_PROSTATIC_URETHRA = _Submucosa_Of_Prostatic_Urethra()
    MUSCULARIS_MUCOSA_OF_PROSTATIC_URETHRA = _Muscularis_Mucosa_Of_Prostatic_Urethra()
    LAMINA_PROPRIA_OF_PROSTATIC_URETHRA = _Lamina_Propria_Of_Prostatic_Urethra()
    SUBMUCOSA_OF_TRIGONE = _Submucosa_Of_Trigone()
    INTERMEDIATE_CELL_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = (
        _Intermediate_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Female()
    )
    INTERMEDIATE_CELL_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = (
        _Intermediate_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Female()
    )
    INTERMEDIATE_CELL_LAYER_OF_DORSAL_PELVIC_URETHRA_OF_MALE = (
        _Intermediate_Cell_Layer_Of_Dorsal_Pelvic_Urethra_Of_Male()
    )
    SUBMUCOSA_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = _Submucosa_Of_Ventral_Pelvic_Urethra_Of_Female()
    MUSCULARIS_MUCOSA_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = _Muscularis_Mucosa_Of_Ventral_Pelvic_Urethra_Of_Female()
    LAMINA_PROPRIA_OF_VENTRAL_PELVIC_URETHRA_OF_FEMALE = _Lamina_Propria_Of_Ventral_Pelvic_Urethra_Of_Female()
    LAMINA_PROPRIA_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Lamina_Propria_Of_Dorsal_Pelvic_Urethra_Of_Male()
    MUSCULARIS_MUCOSA_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Muscularis_Mucosa_Of_Dorsal_Pelvic_Urethra_Of_Male()
    SUBMUCOSA_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = _Submucosa_Of_Dorsal_Pelvic_Urethra_Of_Female()
    INTERMEDIATE_CELL_LAYER_OF_VENTRAL_PELVIC_URETHRA_OF_MALE = (
        _Intermediate_Cell_Layer_Of_Ventral_Pelvic_Urethra_Of_Male()
    )
    LIMB_INTERDIGITAL_REGION_MESENCHYME = _Limb_Interdigital_Region_Mesenchyme()
    LIMB_INTERDIGITAL_REGION_SKIN = _Limb_Interdigital_Region_Skin()
    FORELIMB_EPITHELIUM = _Forelimb_Epithelium()
    FORELIMB_SKIN = _Forelimb_Skin()
    FORELIMB_DERMIS = _Forelimb_Dermis()
    PHALANX = _Phalanx()
    DIGIT_SKIN = _Digit_Skin()
    DIGIT_EPITHELIUM = _Digit_Epithelium()
    INTERDIGITAL_REGION_EPITHELIUM = _Interdigital_Region_Epithelium()
    LIMB_INTERDIGITAL_REGION = _Limb_Interdigital_Region()
    HINDLIMB_DERMIS = _Hindlimb_Dermis()
    HINDLIMB_SKIN = _Hindlimb_Skin()
    HINDLIMB_EPITHELIUM = _Hindlimb_Epithelium()
    FOREARM_MUSCLE = _Forearm_Muscle()
    FORELIMB_SKELETON = _Forelimb_Skeleton()
    FORELIMB_MUSCULATURE = _Forelimb_Musculature()
    FORELIMB_PRE_CARTILAGE_CONDENSATION = _Forelimb_Pre_Cartilage_Condensation()
    FORELIMB_CARTILAGE_CONDENSATION = _Forelimb_Cartilage_Condensation()
    FORELIMB_EPIDERMIS = _Forelimb_Epidermis()
    FORELIMB_MESENCHYME = _Forelimb_Mesenchyme()
    HAND_PRE_CARTILAGE_CONDENSATION = _Hand_Pre_Cartilage_Condensation()
    HAND_EPITHELIUM = _Hand_Epithelium()
    HAND_CARTILAGE_CONDENSATION = _Hand_Cartilage_Condensation()
    HINDLIMB_CARTILAGE_CONDENSATION = _Hindlimb_Cartilage_Condensation()
    HINDLIMB_SKELETON = _Hindlimb_Skeleton()
    HINDLIMB_MUSCULATURE = _Hindlimb_Musculature()
    HINDLIMB_JOINT = _Hindlimb_Joint()
    HINDLIMB_EPIDERMIS = _Hindlimb_Epidermis()
    HINDLIMB_MESENCHYME = _Hindlimb_Mesenchyme()
    HINDLIMB_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Pre_Cartilage_Condensation()
    FORELIMB_PHALANX_PRE_CARTILAGE_CONDENSATION = _Forelimb_Phalanx_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_CARTILAGE_CONDENSATION = _Forelimb_Digit_Cartilage_Condensation()
    HAND_JOINT = _Hand_Joint()
    FORELIMB_DIGIT = _Forelimb_Digit()
    HAND_SKELETON = _Hand_Skeleton()
    HAND_MUSCLE = _Hand_Muscle()
    FORELIMB_DIGIT_MESENCHYME = _Forelimb_Digit_Mesenchyme()
    FORELIMB_DIGIT_PRE_CARTILAGE_CONDENSATION = _Forelimb_Digit_Pre_Cartilage_Condensation()
    FORELIMB_DIGIT_EPITHELIUM = _Forelimb_Digit_Epithelium()
    FORELIMB_DIGIT_SKIN = _Forelimb_Digit_Skin()
    HINDLIMB_DIGIT = _Hindlimb_Digit()
    FORELIMB_PHALANX = _Forelimb_Phalanx()
    FORELIMB_INTERDIGITAL_REGION = _Forelimb_Interdigital_Region()
    FORELIMB_INTERDIGITAL_REGION_EPITHELIUM = _Forelimb_Interdigital_Region_Epithelium()
    FORELIMB_INTERDIGITAL_REGION_MESENCHYME = _Forelimb_Interdigital_Region_Mesenchyme()
    METACARPUS = _Metacarpus()
    FOOT_EPITHELIUM = _Foot_Epithelium()
    FOOT_PRE_CARTILAGE_CONDENSATION = _Foot_Pre_Cartilage_Condensation()
    FOOT_CARTILAGE_CONDENSATION = _Foot_Cartilage_Condensation()
    FORELIMB_PHALANX_CARTILAGE_CONDENSATION = _Forelimb_Phalanx_Cartilage_Condensation()
    ARACHNOID_MATER = _Arachnoid_Mater()
    MENINGES = _Meninges()
    BRAIN_ARACHNOID_MATER = _Brain_Arachnoid_Mater()
    BRAIN_MENINGES = _Brain_Meninges()
    PIA_MATER = _Pia_Mater()
    DURA_MATER = _Dura_Mater()
    GANGLIONIC_EMINENCE = _Ganglionic_Eminence()
    BRAIN_SUBARACHNOID_SPACE = _Brain_Subarachnoid_Space()
    BRAIN_PIA_MATER = _Brain_Pia_Mater()
    BRAIN_DURA_MATER = _Brain_Dura_Mater()
    VERTEBRAL_CARTILAGE_CONDENSATION = _Vertebral_Cartilage_Condensation()
    ANNULUS_FIBROSUS = _Annulus_Fibrosus()
    VERTEBRAL_PRE_CARTILAGE_CONDENSATION = _Vertebral_Pre_Cartilage_Condensation()
    AMYGDALA = _Amygdala()
    BASAL_GANGLIA = _Basal_Ganglia()
    BRAIN_VENTRICLE = _Brain_Ventricle()
    BRAIN_FLOOR_PLATE = _Brain_Floor_Plate()
    FUTURE_BRAIN_FLOOR_PLATE = _Future_Brain_Floor_Plate()
    BRAINSTEM = _Brainstem()
    BRAIN_VENTRICULAR_LAYER = _Brain_Ventricular_Layer()
    BRAIN_MARGINAL_LAYER = _Brain_Marginal_Layer()
    BRAIN_MANTLE_LAYER = _Brain_Mantle_Layer()
    LUNG_ALVEOLUS = _Lung_Alveolus()
    ALIMENTARY_SYSTEM_EPITHELIUM = _Alimentary_System_Epithelium()
    FLOOR_PLATE = _Floor_Plate()
    ENDOCARDIAL_TUBE = _Endocardial_Tube()
    ENDOCARDIAL_LINING = _Endocardial_Lining()
    CARDIAC_JELLY = _Cardiac_Jelly()
    CARDIAC_MUSCLE_TISSUE = _Cardiac_Muscle_Tissue()
    BRONCHUS = _Bronchus()
    BRONCHUS_MESENCHYME = _Bronchus_Mesenchyme()
    BRONCHUS_EPITHELIUM = _Bronchus_Epithelium()
    ALVEOLAR_SYSTEM = _Alveolar_System()
    BRONCHIOLE_EPITHELIUM = _Bronchiole_Epithelium()
    ALVEOLAR_DUCT = _Alveolar_Duct()
    LOBAR_BRONCHUS_EPITHELIUM = _Lobar_Bronchus_Epithelium()
    LOBAR_BRONCHUS = _Lobar_Bronchus()
    BRONCHIOLE = _Bronchiole()
    LOBAR_BRONCHUS_MESENCHYME = _Lobar_Bronchus_Mesenchyme()
    LIMB_JOINT_PRIMORDIUM = _Limb_Joint_Primordium()
    LIMB_MUSCULATURE = _Limb_Musculature()
    LIMB_CARTILAGE_CONDENSATION = _Limb_Cartilage_Condensation()
    LIMB_SKELETON = _Limb_Skeleton()
    CORTICAL_SUBPLATE = _Cortical_Subplate()
    CEREBRAL_CORTEX_SUBVENTRICULAR_ZONE = _Cerebral_Cortex_Subventricular_Zone()
    LIMB_MESENCHYME = _Limb_Mesenchyme()
    LIMB_PRE_CARTILAGE_CONDENSATION = _Limb_Pre_Cartilage_Condensation()
    CEREBRAL_CORTEX_VENTRICULAR_ZONE = _Cerebral_Cortex_Ventricular_Zone()
    LIMB_ECTODERM = _Limb_Ectoderm()
    DIENCEPHALON_MARGINAL_LAYER = _Diencephalon_Marginal_Layer()
    DIENCEPHALON_VENTRICULAR_LAYER = _Diencephalon_Ventricular_Layer()
    CORTICAL_PLATE = _Cortical_Plate()
    CEREBRAL_CORTEX_INTERMEDIATE_ZONE = _Cerebral_Cortex_Intermediate_Zone()
    CEREBRAL_CORTEX_MARGINAL_ZONE = _Cerebral_Cortex_Marginal_Zone()
    MUSCULOSKELETAL_SYSTEM = _Musculoskeletal_System()
    MUSCLE_TISSUE = _Muscle_Tissue()
    SKELETAL_MUSCLE_TISSUE = _Skeletal_Muscle_Tissue()
    SMOOTH_MUSCLE_TISSUE = _Smooth_Muscle_Tissue()
    DIENCEPHALON_MANTLE_LAYER = _Diencephalon_Mantle_Layer()
    DIGIT_MESENCHYME = _Digit_Mesenchyme()
    PHALANX_PRE_CARTILAGE_CONDENSATION = _Phalanx_Pre_Cartilage_Condensation()
    PHALANX_CARTILAGE_CONDENSATION = _Phalanx_Cartilage_Condensation()
    AUTOPOD = _Autopod()
    AUTOPOD_SKIN = _Autopod_Skin()
    LIMB_EPITHELIUM = _Limb_Epithelium()
    LIMB_DIGIT = _Limb_Digit()
    LIMB_SKIN = _Limb_Skin()
    LIMB_DERMIS = _Limb_Dermis()
    LIMB_EPIDERMIS = _Limb_Epidermis()
    APPENDICULAR_SKELETON = _Appendicular_Skeleton()
    CARTILAGE = _Cartilage()
    CARTILAGE_CONDENSATION = _Cartilage_Condensation()
    NEURAL_FOLD = _Neural_Fold()
    EXTRAEMBRYONIC_BLOOD_VESSEL = _Extraembryonic_Blood_Vessel()
    MESENCHYME_DERIVED_FROM_NEURAL_CREST = _Mesenchyme_Derived_From_Neural_Crest()
    PRE_CARTILAGE_CONDENSATION = _Pre_Cartilage_Condensation()
    NEURAL_CREST = _Neural_Crest()
    EPITHELIUM = _Epithelium()
    INTERVERTEBRAL_DISC = _Intervertebral_Disc()
    VERTEBRA = _Vertebra()
    CHOROID_PLEXUS = _Choroid_Plexus()
    _4TH_VENTRICLE_CHOROID_PLEXUS = _4Th_Ventricle_Choroid_Plexus()
    BLOOD_VESSEL = _Blood_Vessel()
    APICAL_ECTODERMAL_RIDGE = _Apical_Ectodermal_Ridge()
    ATRIUM_ENDOCARDIAL_LINING = _Atrium_Endocardial_Lining()
    ATRIUM_CARDIAC_MUSCLE = _Atrium_Cardiac_Muscle()
    VENTRICLE_ENDOCARDIAL_LINING = _Ventricle_Endocardial_Lining()
    VENTRICLE_CARDIAC_MUSCLE = _Ventricle_Cardiac_Muscle()
    BRANCHIAL_ARCH_MEMBRANE = _Branchial_Arch_Membrane()
    BRANCHIAL_GROOVE = _Branchial_Groove()
    BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_HEAD_MESODERM = _Branchial_Arch_Mesenchyme_Derived_From_Head_Mesoderm()
    BRANCHIAL_POUCH = _Branchial_Pouch()
    BRANCHIAL_ARCH_ECTODERM = _Branchial_Arch_Ectoderm()
    BRANCHIAL_ARCH_ENDODERM = _Branchial_Arch_Endoderm()
    BRANCHIAL_ARCH_MESENCHYME = _Branchial_Arch_Mesenchyme()
    BRANCHIAL_ARCH_MESENCHYME_DERIVED_FROM_NEURAL_CREST = _Branchial_Arch_Mesenchyme_Derived_From_Neural_Crest()
    PARAXIAL_MESENCHYME = _Paraxial_Mesenchyme()
    EYELID_EPITHELIUM = _Eyelid_Epithelium()
    EYELID_MESENCHYME = _Eyelid_Mesenchyme()
    BONE_MARROW = _Bone_Marrow()
    BODY_WALL = _Body_Wall()
    MESENDODERM = _Mesendoderm()
    FACE = _Face()
    ILEUM = _Ileum()
    _6TH_BRANCHIAL_ARCH_MESENCHYME = _6Th_Branchial_Arch_Mesenchyme()
    _6TH_BRANCHIAL_ARCH = _6Th_Branchial_Arch()
    PIRIFORM_CORTEX = _Piriform_Cortex()
    HIPPOCAMPUS_CA1 = _Hippocampus_Ca1()
    HIPPOCAMPUS_CA2 = _Hippocampus_Ca2()
    HIPPOCAMPUS_CA3 = _Hippocampus_Ca3()
    HIPPOCAMPUS_CA4 = _Hippocampus_Ca4()
    HIPPOCAMPUS_REGION = _Hippocampus_Region()
    TAIL_SURFACE_ECTODERM = _Tail_Surface_Ectoderm()
    LINGUAL_SWELLING_MESENCHYME = _Lingual_Swelling_Mesenchyme()
    LINGUAL_SWELLING_EPITHELIUM = _Lingual_Swelling_Epithelium()
    FORELIMB_BUD_PRESUMPTIVE_APICAL_ECTODERMAL_RIDGE = _Forelimb_Bud_Presumptive_Apical_Ectodermal_Ridge()
    TONGUE_PAPILLAE = _Tongue_Papillae()
    PRETECTUM = _Pretectum()
    EPIDERMIS_BASAL_LAYER = _Epidermis_Basal_Layer()
    PALLIDUM = _Pallidum()
    PERIAQUEDUCTAL_GREY = _Periaqueductal_Grey()
    BONE = _Bone()
    ANKLE = _Ankle()
    WRIST = _Wrist()
    EPIDERMIS_SPINOUS_LAYER = _Epidermis_Spinous_Layer()
    EPIDERMIS_GRANULAR_LAYER = _Epidermis_Granular_Layer()
    EPIDERMIS_CORNIFIED_LAYER = _Epidermis_Cornified_Layer()
    FOLIATE_PAPILLAE = _Foliate_Papillae()
    ACCUMBENS_NUCLEUS = _Accumbens_Nucleus()
    BRAINSTEM_NUCLEUS = _Brainstem_Nucleus()
    CRISTA_AMPULLARIS = _Crista_Ampullaris()
    HAIR_INNER_ROOT_SHEATH = _Hair_Inner_Root_Sheath()
    HAIR_OUTER_ROOT_SHEATH = _Hair_Outer_Root_Sheath()
    OLFACTORY_CORTEX_SUBVENTRICULAR_ZONE = _Olfactory_Cortex_Subventricular_Zone()
    LEFT_HEPATIC_DUCT = _Left_Hepatic_Duct()
    FUTURE_PITUITARY = _Future_Pituitary()
    RIGHT_HEPATIC_DUCT = _Right_Hepatic_Duct()
    TAIL_NEURAL_TUBE_FLOOR_PLATE = _Tail_Neural_Tube_Floor_Plate()
    CHONDROCRANIUM_PRE_CARTILAGE_CONDENSATION = _Chondrocranium_Pre_Cartilage_Condensation()
    EAR_EPITHELIUM = _Ear_Epithelium()
    PHARYNGO_TYMPANIC_TUBE_EPITHELIUM = _Pharyngo_Tympanic_Tube_Epithelium()
    CHONDROCRANIUM_CARTILAGE_CONDENSATION = _Chondrocranium_Cartilage_Condensation()
    BRAIN_SUBVENTRICULAR_ZONE = _Brain_Subventricular_Zone()
    ALVEOLAR_SULCUS = _Alveolar_Sulcus()
    SNOUT = _Snout()
    PRESUMPTIVE_IRIS = _Presumptive_Iris()
    NERVE = _Nerve()
    MAIN_OLFACTORY_BULB = _Main_Olfactory_Bulb()
    PALATE_EPITHELIUM = _Palate_Epithelium()
    PALATE_MESENCHYME = _Palate_Mesenchyme()
    PARATHYROID_GLAND = _Parathyroid_Gland()
    PARASYMPATHETIC_GANGLION = _Parasympathetic_Ganglion()
    PERIPHERAL_NERVOUS_SYSTEM_GANGLION = _Peripheral_Nervous_System_Ganglion()
    PERIPHERAL_NERVE = _Peripheral_Nerve()
    SALIVARY_GLAND_EPITHELIUM = _Salivary_Gland_Epithelium()
    SALIVARY_GLAND_MESENCHYME = _Salivary_Gland_Mesenchyme()
    RHOMBOMERE_FLOOR_PLATE = _Rhombomere_Floor_Plate()
    RHOMBOMERE_LATERAL_WALL = _Rhombomere_Lateral_Wall()
    RHOMBOMERE = _Rhombomere()
    RHOMBOMERE_MARGINAL_LAYER = _Rhombomere_Marginal_Layer()
    RHOMBOMERE_VENTRICULAR_LAYER = _Rhombomere_Ventricular_Layer()
    RHOMBOMERE_ROOF_PLATE = _Rhombomere_Roof_Plate()
    RHOMBOMERE_MANTLE_LAYER = _Rhombomere_Mantle_Layer()
    RESPIRATORY_SYSTEM_EPITHELIUM = _Respiratory_System_Epithelium()
    RESPIRATORY_TRACT_EPITHELIUM = _Respiratory_Tract_Epithelium()
    SEMICIRCULAR_CANAL_EPITHELIUM = _Semicircular_Canal_Epithelium()
    SEMICIRCULAR_CANAL_MESENCHYME = _Semicircular_Canal_Mesenchyme()
    SEMICIRCULAR_DUCT = _Semicircular_Duct()
    SEMICIRCULAR_DUCT_AMPULLA = _Semicircular_Duct_Ampulla()
    SEMICIRCULAR_CANAL = _Semicircular_Canal()
    SMALL_INTESTINE = _Small_Intestine()
    TELENCEPHALON_SEPTUM = _Telencephalon_Septum()
    DERMATOME = _Dermatome()
    LIP = _Lip()
    TRUNK_DERMATOME = _Trunk_Dermatome()
    MYOTOME = _Myotome()
    NEOCORTEX = _Neocortex()
    TRUNK_MYOTOME = _Trunk_Myotome()
    MYELENCEPHALON_VENTRICULAR_LAYER = _Myelencephalon_Ventricular_Layer()
    HIPPOCAMPUS = _Hippocampus()
    GANGLION = _Ganglion()
    MYENTERIC_NERVE_PLEXUS = _Myenteric_Nerve_Plexus()
    MEDULLA_OBLONGATA_MANTLE_LAYER = _Medulla_Oblongata_Mantle_Layer()
    METACARPUS_CARTILAGE_CONDENSATION = _Metacarpus_Cartilage_Condensation()
    METACARPUS_PRE_CARTILAGE_CONDENSATION = _Metacarpus_Pre_Cartilage_Condensation()
    MEDULLA_OBLONGATA_VENTRICULAR_LAYER = _Medulla_Oblongata_Ventricular_Layer()
    MEDULLA_OBLONGATA_MARGINAL_LAYER = _Medulla_Oblongata_Marginal_Layer()
    METENCEPHALON_VENTRICULAR_LAYER = _Metencephalon_Ventricular_Layer()
    MESOTHELIUM = _Mesothelium()
    MIDBRAIN_HINDBRAIN_JUNCTION = _Midbrain_Hindbrain_Junction()
    UPPER_JAW_TOOTH_ENAMEL_ORGAN = _Upper_Jaw_Tooth_Enamel_Organ()
    UPPER_JAW_TOOTH_DENTAL_LAMINA = _Upper_Jaw_Tooth_Dental_Lamina()
    LUNG_EPITHELIUM = _Lung_Epithelium()
    UPPER_JAW_TOOTH_DENTAL_PAPILLA = _Upper_Jaw_Tooth_Dental_Papilla()
    UPPER_JAW_EPITHELIUM = _Upper_Jaw_Epithelium()
    LOWER_JAW_TOOTH_DENTAL_PAPILLA = _Lower_Jaw_Tooth_Dental_Papilla()
    UPPER_JAW_TOOTH_MESENCHYME = _Upper_Jaw_Tooth_Mesenchyme()
    UPPER_JAW_TOOTH_EPITHELIUM = _Upper_Jaw_Tooth_Epithelium()
    LUNG_MESENCHYME = _Lung_Mesenchyme()
    LUNG_VASCULAR_ELEMENT = _Lung_Vascular_Element()
    LOWER_JAW_TOOTH_EPITHELIUM = _Lower_Jaw_Tooth_Epithelium()
    SUPERIOR_COLLICULUS = _Superior_Colliculus()
    INFERIOR_COLLICULUS = _Inferior_Colliculus()
    LENS_EPITHELIUM = _Lens_Epithelium()
    INTESTINE_MESENCHYME = _Intestine_Mesenchyme()
    INTESTINE_EPITHELIUM = _Intestine_Epithelium()
    INTESTINE = _Intestine()
    LOWER_JAW_TOOTH_ENAMEL_ORGAN = _Lower_Jaw_Tooth_Enamel_Organ()
    LOWER_JAW_TOOTH_MESENCHYME = _Lower_Jaw_Tooth_Mesenchyme()
    LOWER_JAW_TOOTH_DENTAL_LAMINA = _Lower_Jaw_Tooth_Dental_Lamina()
    MOLAR_EPITHELIUM = _Molar_Epithelium()
    MOLAR_DENTAL_LAMINA = _Molar_Dental_Lamina()
    MOLAR_ENAMEL_ORGAN = _Molar_Enamel_Organ()
    MOLAR_MESENCHYME = _Molar_Mesenchyme()
    MOLAR_DENTAL_PAPILLA = _Molar_Dental_Papilla()
    INNER_EAR_EPITHELIUM = _Inner_Ear_Epithelium()
    VESTIBULAR_COMPONENT_EPITHELIUM = _Vestibular_Component_Epithelium()
    INNER_EAR_MESENCHYME = _Inner_Ear_Mesenchyme()
    ALIMENTARY_SYSTEM_MESENCHYME = _Alimentary_System_Mesenchyme()
    VESTIBULAR_COMPONENT_MESENCHYME = _Vestibular_Component_Mesenchyme()
    ENAMEL_ORGAN = _Enamel_Organ()
    INCISOR = _Incisor()
    INCISOR_EPITHELIUM = _Incisor_Epithelium()
    TOOTH_MESENCHYME = _Tooth_Mesenchyme()
    DENTAL_PAPILLA = _Dental_Papilla()
    INCISOR_DENTAL_PAPILLA = _Incisor_Dental_Papilla()
    INCISOR_MESENCHYME = _Incisor_Mesenchyme()
    INCISOR_ENAMEL_ORGAN = _Incisor_Enamel_Organ()
    INCISOR_DENTAL_LAMINA = _Incisor_Dental_Lamina()
    MOLAR = _Molar()
    HINDBRAIN_VENTRICULAR_LAYER = _Hindbrain_Ventricular_Layer()
    HINDBRAIN_ROOF_PLATE = _Hindbrain_Roof_Plate()
    HINDBRAIN_ROOF = _Hindbrain_Roof()
    JAW_PRIMORDIUM = _Jaw_Primordium()
    DENTAL_LAMINA = _Dental_Lamina()
    TOOTH_EPITHELIUM = _Tooth_Epithelium()
    JAW_EPITHELIUM = _Jaw_Epithelium()
    JAW = _Jaw()
    TOOTH = _Tooth()
    JAW_MESENCHYME = _Jaw_Mesenchyme()
    GUT_LUMEN = _Gut_Lumen()
    GUT_MESENCHYME = _Gut_Mesenchyme()
    GUT_DORSAL_MESENTERY = _Gut_Dorsal_Mesentery()
    GUT_MESENTERY = _Gut_Mesentery()
    HINDBRAIN_LATERAL_WALL = _Hindbrain_Lateral_Wall()
    HINDBRAIN_FLOOR_PLATE = _Hindbrain_Floor_Plate()
    HINDBRAIN_BASAL_PLATE = _Hindbrain_Basal_Plate()
    HINDBRAIN_ALAR_PLATE = _Hindbrain_Alar_Plate()
    HINDBRAIN_MARGINAL_LAYER = _Hindbrain_Marginal_Layer()
    HINDBRAIN_MANTLE_LAYER = _Hindbrain_Mantle_Layer()
    FRONTO_NASAL_PROCESS_EPITHELIUM = _Fronto_Nasal_Process_Epithelium()
    FUTURE_FOREBRAIN_FLOOR_PLATE = _Future_Forebrain_Floor_Plate()
    FOREBRAIN_MARGINAL_LAYER = _Forebrain_Marginal_Layer()
    FOREBRAIN_VENTRICULAR_LAYER = _Forebrain_Ventricular_Layer()
    FOREGUT_EPITHELIUM = _Foregut_Epithelium()
    FOREGUT_MESENCHYME = _Foregut_Mesenchyme()
    PANCREAS_PARENCHYMA = _Pancreas_Parenchyma()
    ISLETS_OF_LANGERHANS = _Islets_Of_Langerhans()
    GUT_EPITHELIUM = _Gut_Epithelium()
    GUT_ENDODERM = _Gut_Endoderm()
    FUTURE_FOREBRAIN_ROOF_PLATE = _Future_Forebrain_Roof_Plate()
    FUTURE_FOREBRAIN_LATERAL_WALL = _Future_Forebrain_Lateral_Wall()
    HINDLIMB_DIGIT_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Digit_Pre_Cartilage_Condensation()
    HINDLIMB_DIGIT_CARTILAGE_CONDENSATION = _Hindlimb_Digit_Cartilage_Condensation()
    METATARSUS = _Metatarsus()
    HINDLIMB_PHALANX = _Hindlimb_Phalanx()
    HINDLIMB_DIGIT_SKIN = _Hindlimb_Digit_Skin()
    HINDLIMB_DIGIT_DERMIS = _Hindlimb_Digit_Dermis()
    HINDLIMB_DIGIT_EPIDERMIS = _Hindlimb_Digit_Epidermis()
    HINDLIMB_INTERDIGITAL_REGION = _Hindlimb_Interdigital_Region()
    HINDLIMB_DIGIT_EPITHELIUM = _Hindlimb_Digit_Epithelium()
    HINDLIMB_DIGIT_MESENCHYME = _Hindlimb_Digit_Mesenchyme()
    HINDLIMB_PHALANX_CARTILAGE_CONDENSATION = _Hindlimb_Phalanx_Cartilage_Condensation()
    FOOT_JOINT = _Foot_Joint()
    HINDLIMB_PHALANX_PRE_CARTILAGE_CONDENSATION = _Hindlimb_Phalanx_Pre_Cartilage_Condensation()
    METATARSUS_CARTILAGE_CONDENSATION = _Metatarsus_Cartilage_Condensation()
    PANCREATIC_DUCT = _Pancreatic_Duct()
    DORSAL_PANCREATIC_DUCT = _Dorsal_Pancreatic_Duct()
    HINDLIMB_INTERDIGITAL_REGION_MESENCHYME = _Hindlimb_Interdigital_Region_Mesenchyme()
    METATARSUS_PRE_CARTILAGE_CONDENSATION = _Metatarsus_Pre_Cartilage_Condensation()
    HINDLIMB_INTERDIGITAL_REGION_EPITHELIUM = _Hindlimb_Interdigital_Region_Epithelium()
    NERVE_OF_UTERUS = _Nerve_Of_Uterus()
    NERVE_OF_PRIMITIVE_BLADDER = _Nerve_Of_Primitive_Bladder()
    NERVE_OF_LABIA = _Nerve_Of_Labia()
    NERVE_OF_CLITORIS = _Nerve_Of_Clitoris()
    NERVE_OF_GENITAL_TUBERCLE_OF_FEMALE = _Nerve_Of_Genital_Tubercle_Of_Female()
    NERVE_OF_VAGINA = _Nerve_Of_Vagina()
    NERVE_OF_EPIDIDYMIS = _Nerve_Of_Epididymis()
    NERVE_OF_SEMINAL_VESICLE = _Nerve_Of_Seminal_Vesicle()
    NERVE_OF_DUCTUS_DEFERENS = _Nerve_Of_Ductus_Deferens()
    NERVE_OF_SCROTUM = _Nerve_Of_Scrotum()
    NERVE_OF_OVARY = _Nerve_Of_Ovary()
    NERVE_OF_OVIDUCT = _Nerve_Of_Oviduct()
    NERVE_OF_UTERINE_HORN = _Nerve_Of_Uterine_Horn()
    NERVE_OF_EJACULATORY_DUCT = _Nerve_Of_Ejaculatory_Duct()
    NERVE_OF_BULBOURETHRAL_GLAND_OF_MALE = _Nerve_Of_Bulbourethral_Gland_Of_Male()
    NERVE_OF_GENITAL_TUBERCLE_OF_MALE = _Nerve_Of_Genital_Tubercle_Of_Male()
    NERVE_OF_PENIS = _Nerve_Of_Penis()
    NERVE_OF_PENILE_URETHRA = _Nerve_Of_Penile_Urethra()
    NERVE_OF_URETER = _Nerve_Of_Ureter()
    _3RD_VENTRICLE_EPENDYMA = _3Rd_Ventricle_Ependyma()
    _6TH_BRANCHIAL_ARCH_ECTODERM = _6Th_Branchial_Arch_Ectoderm()
    ABDOMEN = _Abdomen()
    ABDOMEN_MUSCULATURE = _Abdomen_Musculature()
    ABDOMINAL_SEGMENT_OF_TRUNK = _Abdominal_Segment_Of_Trunk()
    ABDUCENS_NUCLEUS = _Abducens_Nucleus()
    ACCESSORY_OLFACTORY_BULB = _Accessory_Olfactory_Bulb()
    ACCESSORY_OLFACTORY_BULB_EXTERNAL_PLEXIFORM_LAYER = _Accessory_Olfactory_Bulb_External_Plexiform_Layer()
    ACCESSORY_OLFACTORY_BULB_GLOMERULAR_LAYER = _Accessory_Olfactory_Bulb_Glomerular_Layer()
    ACCESSORY_OLFACTORY_BULB_GRANULE_CELL_LAYER = _Accessory_Olfactory_Bulb_Granule_Cell_Layer()
    ACCESSORY_OLFACTORY_BULB_INTERNAL_PLEXIFORM_LAYER = _Accessory_Olfactory_Bulb_Internal_Plexiform_Layer()
    ACCESSORY_OLFACTORY_BULB_MITRAL_CELL_LAYER = _Accessory_Olfactory_Bulb_Mitral_Cell_Layer()
    ADIPOSE_TISSUE = _Adipose_Tissue()
    ADRENAL_CORTEX_ZONE = _Adrenal_Cortex_Zone()
    ADRENAL_GLAND_ZONA_FASCICULATA = _Adrenal_Gland_Zona_Fasciculata()
    ADRENAL_GLAND_ZONA_GLOMERULOSA = _Adrenal_Gland_Zona_Glomerulosa()
    ADRENAL_GLAND_ZONA_RETICULARIS = _Adrenal_Gland_Zona_Reticularis()
    ALIMENTARY_SYSTEM_SMOOTH_MUSCLE = _Alimentary_System_Smooth_Muscle()
    ALVEOLAR_PROCESS = _Alveolar_Process()
    ALVEOLAR_SAC = _Alveolar_Sac()
    ALVEOLAR_WALL = _Alveolar_Wall()
    ALVEOLUS_EPITHELIUM = _Alveolus_Epithelium()
    ALVEOLUS_SMOOTH_MUSCLE = _Alveolus_Smooth_Muscle()
    AMPULLARY_GLAND = _Ampullary_Gland()
    AMYGDALOHIPPOCAMPAL_AREA = _Amygdalohippocampal_Area()
    AMYGDALOPIRIFORM_TRANSITION_AREA = _Amygdalopiriform_Transition_Area()
    ANKLE_JOINT = _Ankle_Joint()
    ANTERIOR_AMYGDALOID_AREA = _Anterior_Amygdaloid_Area()
    ANTERIOR_CORTICAL_AMYGDALOID_NUCLEUS = _Anterior_Cortical_Amygdaloid_Nucleus()
    ANTERIOR_DORSAL_THALAMIC_NUCLEUS = _Anterior_Dorsal_Thalamic_Nucleus()
    ANTERIOR_MEDIAL_CORTEX = _Anterior_Medial_Cortex()
    ANTERIOR_OLFACTORY_NUCLEUS = _Anterior_Olfactory_Nucleus()
    ANTERIOR_THALAMIC_GROUP = _Anterior_Thalamic_Group()
    ANTERIOR_VENTRAL_THALAMIC_NUCLEUS = _Anterior_Ventral_Thalamic_Nucleus()
    AORTA_ENDOTHELIUM = _Aorta_Endothelium()
    AORTA_SMOOTH_MUSCLE = _Aorta_Smooth_Muscle()
    AORTA_TUNICA_ADVENTITIA = _Aorta_Tunica_Adventitia()
    AORTA_TUNICA_INTIMA = _Aorta_Tunica_Intima()
    AORTA_TUNICA_MEDIA = _Aorta_Tunica_Media()
    AORTA_WALL = _Aorta_Wall()
    APEX_OF_CECUM = _Apex_Of_Cecum()
    APOCRINE_GLAND = _Apocrine_Gland()
    ARCUATE_NUCLEUS = _Arcuate_Nucleus()
    AREA_POSTREMA = _Area_Postrema()
    ARTERIAL_BLOOD_VESSEL = _Arterial_Blood_Vessel()
    ARTERIAL_SYSTEM_ENDOTHELIUM = _Arterial_System_Endothelium()
    ARTERIOLE = _Arteriole()
    ARTERY = _Artery()
    ARTERY_ENDOTHELIUM = _Artery_Endothelium()
    ARTICULAR_CARTILAGE = _Articular_Cartilage()
    ARTICULAR_SYSTEM = _Articular_System()
    ASCENDING_COLON = _Ascending_Colon()
    ATRIOVENTRICULAR_BUNDLE = _Atrioventricular_Bundle()
    ATRIOVENTRICULAR_NODE = _Atrioventricular_Node()
    ATRIOVENTRICULAR_VALVE = _Atrioventricular_Valve()
    RIGHT_LUNG_LOBE = _Right_Lung_Lobe()
    AUDITORY_CORTEX = _Auditory_Cortex()
    PINNA_CARTILAGE = _Pinna_Cartilage()
    PINNA_MUSCLE = _Pinna_Muscle()
    AUTOPOD_JOINT = _Autopod_Joint()
    BACK_MUSCULATURE = _Back_Musculature()
    BACK_OF_TRUNK = _Back_Of_Trunk()
    BARREL_CORTEX = _Barrel_Cortex()
    BASAL_FOREBRAIN = _Basal_Forebrain()
    BASAL_VENTRAL_MEDIAL_THALAMIC_NUCLEUS = _Basal_Ventral_Medial_Thalamic_Nucleus()
    BASILAR_MEMBRANE = _Basilar_Membrane()
    BASOLATERAL_AMYGDALOID_NUCLEUS = _Basolateral_Amygdaloid_Nucleus()
    BASOMEDIAL_AMYGDALOID_NUCLEUS = _Basomedial_Amygdaloid_Nucleus()
    BED_NUCLEUS_OF_STRIA_TERMINALIS = _Bed_Nucleus_Of_Stria_Terminalis()
    BICEPS_FEMORIS = _Biceps_Femoris()
    BILE_DUCT = _Bile_Duct()
    BILIARY_TRACT = _Biliary_Tract()
    BLADDER_FUNDUS = _Bladder_Fundus()
    BLADDER_TRIGONE = _Bladder_Trigone()
    BLADDER_WALL = _Bladder_Wall()
    BLOOD_VESSEL_ENDOTHELIUM = _Blood_Vessel_Endothelium()
    BLOOD_VESSEL_SMOOTH_MUSCLE = _Blood_Vessel_Smooth_Muscle()
    BODY_FLUID_OR_SUBSTANCE = _Body_Fluid_Or_Substance()
    BONE_TISSUE = _Bone_Tissue()
    BRAIN_BLOOD_VESSEL = _Brain_Blood_Vessel()
    BRAIN_EPENDYMA = _Brain_Ependyma()
    BRAIN_GRAY_MATTER = _Brain_Gray_Matter()
    BRAIN_NUCLEUS = _Brain_Nucleus()
    BRAIN_VASCULAR_ELEMENT = _Brain_Vascular_Element()
    BRAIN_WHITE_MATTER = _Brain_White_Matter()
    BRAINSTEM_RETICULAR_FORMATION = _Brainstem_Reticular_Formation()
    BRAINSTEM_WHITE_MATTER = _Brainstem_White_Matter()
    BRANCHIAL_GROOVE_ECTODERM = _Branchial_Groove_Ectoderm()
    BRANCHIAL_POUCH_ENDODERM = _Branchial_Pouch_Endoderm()
    BRONCHUS_CARTILAGE = _Bronchus_Cartilage()
    BRONCHUS_CONNECTIVE_TISSUE = _Bronchus_Connective_Tissue()
    BRONCHUS_LAMINA_PROPRIA = _Bronchus_Lamina_Propria()
    BRONCHUS_SMOOTH_MUSCLE = _Bronchus_Smooth_Muscle()
    CA1_PYRAMIDAL_CELL_LAYER = _Ca1_Pyramidal_Cell_Layer()
    CECUM = _Cecum()
    CAPILLARY = _Capillary()
    CARDIOVASCULAR_SYSTEM_ENDOTHELIUM = _Cardiovascular_System_Endothelium()
    CELIAC_ARTERY = _Celiac_Artery()
    CEMENTUM = _Cementum()
    CENTRAL_AMYGDALOID_NUCLEUS = _Central_Amygdaloid_Nucleus()
    CENTRAL_LATERAL_THALAMIC_NUCLEUS = _Central_Lateral_Thalamic_Nucleus()
    CENTRAL_MEDIAL_THALAMIC_NUCLEUS = _Central_Medial_Thalamic_Nucleus()
    CENTRAL_NERVOUS_SYSTEM_ROOF_PLATE = _Central_Nervous_System_Roof_Plate()
    CENTRAL_NERVOUS_SYSTEM_VASCULAR_ELEMENT = _Central_Nervous_System_Vascular_Element()
    VENTRICULAR_LAYER = _Ventricular_Layer()
    CENTRAL_THALAMIC_NUCLEUS = _Central_Thalamic_Nucleus()
    CEREBELLAR_CORTEX = _Cerebellar_Cortex()
    CEREBELLUM_LAYER = _Cerebellum_Layer()
    CEREBELLAR_PEDUNCLE = _Cerebellar_Peduncle()
    CEREBELLUM_VERMIS = _Cerebellum_Vermis()
    CEREBELLUM_ANTERIOR_LOBE = _Cerebellum_Anterior_Lobe()
    CEREBELLUM_EXTERNAL_GRANULE_CELL_LAYER = _Cerebellum_External_Granule_Cell_Layer()
    CEREBELLUM_GRANULE_CELL_LAYER = _Cerebellum_Granule_Cell_Layer()
    CEREBELLAR_HEMISPHERE = _Cerebellar_Hemisphere()
    CEREBELLUM_INTERNAL_GRANULE_CELL_LAYER = _Cerebellum_Internal_Granule_Cell_Layer()
    CEREBELLUM_LOBE = _Cerebellum_Lobe()
    CEREBELLUM_MOLECULAR_LAYER = _Cerebellum_Molecular_Layer()
    CEREBELLUM_POSTERIOR_LOBE = _Cerebellum_Posterior_Lobe()
    CEREBELLUM_PURKINJE_CELL_LAYER = _Cerebellum_Purkinje_Cell_Layer()
    CEREBELLUM_VERMIS_LOBULE = _Cerebellum_Vermis_Lobule()
    CEREBELLUM_VERMIS_LOBULE_I = _Cerebellum_Vermis_Lobule_I()
    CEREBELLUM_VERMIS_LOBULE_II = _Cerebellum_Vermis_Lobule_Ii()
    CEREBELLUM_VERMIS_LOBULE_III = _Cerebellum_Vermis_Lobule_Iii()
    CEREBELLUM_VERMIS_LOBULE_IV = _Cerebellum_Vermis_Lobule_Iv()
    CEREBELLUM_VERMIS_LOBULE_IX = _Cerebellum_Vermis_Lobule_Ix()
    CEREBELLUM_VERMIS_LOBULE_V = _Cerebellum_Vermis_Lobule_V()
    CEREBELLUM_VERMIS_LOBULE_VI = _Cerebellum_Vermis_Lobule_Vi()
    CEREBELLUM_VERMIS_LOBULE_VII = _Cerebellum_Vermis_Lobule_Vii()
    CEREBELLUM_VERMIS_LOBULE_VIII = _Cerebellum_Vermis_Lobule_Viii()
    CEREBELLUM_VERMIS_LOBULE_X = _Cerebellum_Vermis_Lobule_X()
    CEREBELLUM_WHITE_MATTER = _Cerebellum_White_Matter()
    CEREBRAL_CORTEX_VASCULAR_ELEMENT = _Cerebral_Cortex_Vascular_Element()
    CEREBRAL_HEMISPHERE_WHITE_MATTER = _Cerebral_Hemisphere_White_Matter()
    CHONDROCRANIUM_BONE = _Chondrocranium_Bone()
    CILIARY_EPITHELIUM = _Ciliary_Epithelium()
    CILIARY_MUSCLE = _Ciliary_Muscle()
    CILIARY_STROMA = _Ciliary_Stroma()
    CINGULATE_CORTEX = _Cingulate_Cortex()
    CIRCUMVENTRICULAR_ORGAN = _Circumventricular_Organ()
    CLAUSTRUM = _Claustrum()
    COAT_HAIR_FOLLICLE = _Coat_Hair_Follicle()
    COCHLEA_EPITHELIUM = _Cochlea_Epithelium()
    COCHLEAR_NUCLEUS = _Cochlear_Nucleus()
    COELOMIC_EPITHELIUM_OF_REPRODUCTIVE_SYSTEM = _Coelomic_Epithelium_Of_Reproductive_System()
    COMPACT_BONE = _Compact_Bone()
    CONNECTIVE_TISSUE = _Connective_Tissue()
    CORONARY_VASCULAR_PLEXUS = _Coronary_Vascular_Plexus()
    CORPUS_CALLOSUM = _Corpus_Callosum()
    CORTICAL_AMYGDALOID_NUCLEUS = _Cortical_Amygdaloid_Nucleus()
    CORTICAL_LAYER_I = _Cortical_Layer_I()
    CORTICAL_LAYER_II = _Cortical_Layer_Ii()
    CORTICAL_LAYER_III = _Cortical_Layer_Iii()
    CORTICAL_LAYER_IV = _Cortical_Layer_Iv()
    CORTICAL_LAYER_V = _Cortical_Layer_V()
    CORTICAL_LAYER_VI = _Cortical_Layer_Vi()
    CORTICAL_PREPLATE = _Cortical_Preplate()
    COSTAL_CARTILAGE = _Costal_Cartilage()
    CRANIAL_SUTURE = _Cranial_Suture()
    CRANIAL_SYNCHONDROSIS = _Cranial_Synchondrosis()
    CRYPT_OF_LIEBERKUHN = _Crypt_Of_Lieberkuhn()
    CUMULUS_OOPHORUS = _Cumulus_Oophorus()
    CUNEATE_NUCLEUS = _Cuneate_Nucleus()
    DECIDUA = _Decidua()
    DECIDUA_BASALIS = _Decidua_Basalis()
    DECIDUA_CAPSULARIS = _Decidua_Capsularis()
    DEEP_CEREBELLAR_NUCLEUS = _Deep_Cerebellar_Nucleus()
    DEGENERATING_PARAMESONEPHRIC_DUCT_OF_MALE = _Degenerating_Paramesonephric_Duct_Of_Male()
    DENTAL_PULP = _Dental_Pulp()
    DENTAL_SAC = _Dental_Sac()
    DENTATE_GYRUS_GRANULE_CELL_LAYER = _Dentate_Gyrus_Granule_Cell_Layer()
    DENTATE_GYRUS_HILUS = _Dentate_Gyrus_Hilus()
    DENTATE_GYRUS_LAYER = _Dentate_Gyrus_Layer()
    DENTATE_GYRUS_MOLECULAR_LAYER = _Dentate_Gyrus_Molecular_Layer()
    DENTATE_GYRUS_POLYMORPHIC_LAYER = _Dentate_Gyrus_Polymorphic_Layer()
    DENTIN = _Dentin()
    DERMIS_PAPILLARY_LAYER = _Dermis_Papillary_Layer()
    DERMIS_RETICULAR_LAYER = _Dermis_Reticular_Layer()
    DESCENDING_COLON = _Descending_Colon()
    DILATATOR_PUPILLAE = _Dilatator_Pupillae()
    DISTAL_PHALANX = _Distal_Phalanx()
    DISTAL_URETHRAL_EPITHELIUM = _Distal_Urethral_Epithelium()
    DORSAL_COCHLEAR_NUCLEUS = _Dorsal_Cochlear_Nucleus()
    DORSAL_LATERAL_GENICULATE_NUCLEUS = _Dorsal_Lateral_Geniculate_Nucleus()
    DORSAL_MOTOR_NUCLEUS_OF_VAGUS_NERVE = _Dorsal_Motor_Nucleus_Of_Vagus_Nerve()
    DORSAL_NASAL_ARTERY = _Dorsal_Nasal_Artery()
    DORSAL_RAPHE_NUCLEUS = _Dorsal_Raphe_Nucleus()
    DORSAL_TEGMENTAL_NUCLEUS = _Dorsal_Tegmental_Nucleus()
    DORSAL_THALAMUS = _Dorsal_Thalamus()
    MEDIAL_THALAMIC_GROUP = _Medial_Thalamic_Group()
    DORSOMEDIAL_HYPOTHALAMIC_NUCLEUS = _Dorsomedial_Hypothalamic_Nucleus()
    EAR_SKIN = _Ear_Skin()
    EDINGER_WESTPHAL_NUCLEUS = _Edinger_Westphal_Nucleus()
    ENAMEL = _Enamel()
    ENDOCHONDRAL_BONE = _Endochondral_Bone()
    ENDOCRINE_PANCREAS = _Endocrine_Pancreas()
    ENDOCRINE_SYSTEM = _Endocrine_System()
    ENDOMETRIUM_EPITHELIUM = _Endometrium_Epithelium()
    ENDOMETRIUM_GLANDULAR_EPITHELIUM = _Endometrium_Glandular_Epithelium()
    ENDOMETRIUM_LUMINAL_EPITHELIUM = _Endometrium_Luminal_Epithelium()
    ENDOMETRIUM_STROMA = _Endometrium_Stroma()
    ENDOPIRIFORM_NUCLEUS = _Endopiriform_Nucleus()
    ENTERIC_GANGLION = _Enteric_Ganglion()
    ENTORHINAL_CORTEX = _Entorhinal_Cortex()
    EPIDERMIS_STRATUM_LUCIDUM = _Epidermis_Stratum_Lucidum()
    EPIDERMIS_SUPRABASAL_LAYER = _Epidermis_Suprabasal_Layer()
    EPIDIDYMAL_FAT_PAD = _Epididymal_Fat_Pad()
    EPITHELIUM_OF_CAPILLARY_LOOP_RENAL_CORPUSCLE = _Epithelium_Of_Capillary_Loop_Renal_Corpuscle()
    EPITHELIUM_OF_DEGENERATING_PARAMESONEPHRIC_DUCT_OF_MALE = _Epithelium_Of_Degenerating_Paramesonephric_Duct_Of_Male()
    EPITHELIUM_OF_PARAMESONEPHRIC_DUCT_OF_FEMALE = _Epithelium_Of_Paramesonephric_Duct_Of_Female()
    EPITHELIUM_OF_PARAMESONEPHRIC_DUCT_OF_MALE = _Epithelium_Of_Paramesonephric_Duct_Of_Male()
    ESOPHAGUS_BASAL_EPITHELIUM = _Esophagus_Basal_Epithelium()
    ESOPHAGUS_SEROSA = _Esophagus_Serosa()
    ESOPHAGUS_SMOOTH_MUSCLE = _Esophagus_Smooth_Muscle()
    ESOPHAGUS_SQUAMOUS_EPITHELIUM = _Esophagus_Squamous_Epithelium()
    ESOPHAGUS_SUBMUCOSA = _Esophagus_Submucosa()
    ESOPHAGUS_WALL = _Esophagus_Wall()
    EXOCRINE_GLAND = _Exocrine_Gland()
    EXOCRINE_PANCREAS = _Exocrine_Pancreas()
    EXOCRINE_SYSTEM = _Exocrine_System()
    EXTENSOR_DIGITORUM_LONGUS = _Extensor_Digitorum_Longus()
    EXTERNAL_CAPSULE = _External_Capsule()
    EXTERNAL_SPIRAL_SULCUS = _External_Spiral_Sulcus()
    EYE_GLAND = _Eye_Gland()
    EYE_MUSCLE = _Eye_Muscle()
    EYE_SURFACE_REGION = _Eye_Surface_Region()
    FACE_MESENCHYME = _Face_Mesenchyme()
    FACIAL_NUCLEUS = _Facial_Nucleus()
    FASCIOLA_CINEREUM = _Fasciola_Cinereum()
    FAT_PAD = _Fat_Pad()
    FEMORAL_ARTERY = _Femoral_Artery()
    FEMORAL_NERVE = _Femoral_Nerve()
    FIBROUS_JOINT = _Fibrous_Joint()
    FIMBRIA_HIPPOCAMPUS = _Fimbria_Hippocampus()
    FLOCCULUS = _Flocculus()
    FOREARM_BONE = _Forearm_Bone()
    FOREBRAIN_VASCULAR_ELEMENT = _Forebrain_Vascular_Element()
    FORELIMB_NAIL = _Forelimb_Nail()
    FORELIMB_LONG_BONE = _Forelimb_Long_Bone()
    FORNIX = _Fornix()
    NASAL_ARTERY = _Nasal_Artery()
    FOOT_BONE = _Foot_Bone()
    _4TH_VENTRICLE_EPENDYMA = _4Th_Ventricle_Ependyma()
    FRONTAL_ASSOCIATION_CORTEX = _Frontal_Association_Cortex()
    FRONTAL_CORTEX = _Frontal_Cortex()
    FRONTONASAL_SUTURE = _Frontonasal_Suture()
    FUTURE_BRAIN_MARGINAL_LAYER = _Future_Brain_Marginal_Layer()
    FUTURE_BRAIN_ROOF_PLATE = _Future_Brain_Roof_Plate()
    FUTURE_BRAIN_VENTRICULAR_LAYER = _Future_Brain_Ventricular_Layer()
    FUTURE_HINDBRAIN_LATERAL_WALL = _Future_Hindbrain_Lateral_Wall()
    FUTURE_HINDBRAIN_ROOF_PLATE = _Future_Hindbrain_Roof_Plate()
    FUTURE_HINDBRAIN_VENTRICULAR_LAYER = _Future_Hindbrain_Ventricular_Layer()
    FUTURE_SPINAL_CORD_VASCULAR_ELEMENT = _Future_Spinal_Cord_Vascular_Element()
    GALLBLADDER_EPITHELIUM = _Gallbladder_Epithelium()
    GALLBLADDER_LAMINA_PROPRIA = _Gallbladder_Lamina_Propria()
    GALLBLADDER_SEROSA = _Gallbladder_Serosa()
    GALLBLADDER_SMOOTH_MUSCLE = _Gallbladder_Smooth_Muscle()
    GASTRIC_ARTERY = _Gastric_Artery()
    GASTROCNEMIUS_MUSCLE = _Gastrocnemius_Muscle()
    GENICULATE_THALAMIC_GROUP = _Geniculate_Thalamic_Group()
    GENITAL_SWELLING_OF_GENITAL_TUBERCLE = _Genital_Swelling_Of_Genital_Tubercle()
    GIGANTOCELLULAR_RETICULAR_NUCLEUS = _Gigantocellular_Reticular_Nucleus()
    GIRDLE_BONE = _Girdle_Bone()
    GLOBUS_PALLIDUS = _Globus_Pallidus()
    GONAD_GERMINAL_EPITHELIUM = _Gonad_Germinal_Epithelium()
    GREATER_EPITHELIAL_RIDGE = _Greater_Epithelial_Ridge()
    GUT_MUSCULARIS = _Gut_Muscularis()
    HABENULA = _Habenula()
    HAIR_CORTEX = _Hair_Cortex()
    HAIR_CUTICLE = _Hair_Cuticle()
    HAIR_MEDULLA = _Hair_Medulla()
    HAIR_ROOT_SHEATH_MATRIX = _Hair_Root_Sheath_Matrix()
    HAND_BONE = _Hand_Bone()
    HAND_CONNECTIVE_TISSUE = _Hand_Connective_Tissue()
    FORELIMB_DISTAL_PHALANX = _Forelimb_Distal_Phalanx()
    HASSALL_S_CORPUSCLE = _Hassall_S_Corpuscle()
    HEART_BLOOD_VESSEL = _Heart_Blood_Vessel()
    FORELIMB_DIGIT_DERMIS = _Forelimb_Digit_Dermis()
    HEART_SEPTUM = _Heart_Septum()
    BRANCHIAL_ARCH_EPITHELIUM = _Branchial_Arch_Epithelium()
    HEMATOPOIETIC_SYSTEM = _Hematopoietic_System()
    HINDLIMB_LONG_BONE = _Hindlimb_Long_Bone()
    HIPPOCAMPAL_COMMISSURE = _Hippocampal_Commissure()
    HIPPOCAMPAL_FORMATION = _Hippocampal_Formation()
    HIPPOCAMPUS_GRANULE_CELL_LAYER = _Hippocampus_Granule_Cell_Layer()
    HIPPOCAMPUS_LAYER = _Hippocampus_Layer()
    HIPPOCAMPUS_MOLECULAR_LAYER = _Hippocampus_Molecular_Layer()
    HIPPOCAMPUS_PYRAMIDAL_CELL_LAYER = _Hippocampus_Pyramidal_Cell_Layer()
    HIPPOCAMPUS_STRATUM_LACUNOSUM = _Hippocampus_Stratum_Lacunosum()
    HIPPOCAMPUS_STRATUM_LUCIDUM = _Hippocampus_Stratum_Lucidum()
    HIPPOCAMPUS_STRATUM_ORIENS = _Hippocampus_Stratum_Oriens()
    HIPPOCAMPUS_STRATUM_RADIATUM = _Hippocampus_Stratum_Radiatum()
    HYALINE_CARTILAGE = _Hyaline_Cartilage()
    HYPERTROPHIC_CARTILAGE_ZONE = _Hypertrophic_Cartilage_Zone()
    HYPOGLOSSAL_NUCLEUS = _Hypoglossal_Nucleus()
    HYPOTHALAMIC_NUCLEUS = _Hypothalamic_Nucleus()
    HYPOTHALAMUS_LATERAL_ZONE = _Hypothalamus_Lateral_Zone()
    HYPOTHALAMUS_MEDIAL_ZONE = _Hypothalamus_Medial_Zone()
    HYPOTHALAMUS_MEDIAL_ZONE_TUBERAL_AREA = _Hypothalamus_Medial_Zone_Tuberal_Area()
    HYPOTHALAMUS_PERIVENTRICULAR_ZONE = _Hypothalamus_Periventricular_Zone()
    HYPOTHALAMUS_VASCULAR_ELEMENT = _Hypothalamus_Vascular_Element()
    ILEUM_EPITHELIUM = _Ileum_Epithelium()
    ILEUM_MUCOSA = _Ileum_Mucosa()
    RIGHT_LUNG_BRONCHIOLE = _Right_Lung_Bronchiole()
    IMMATURE_LOOP_OF_HENLE_ASCENDING_LIMB = _Immature_Loop_Of_Henle_Ascending_Limb()
    IMMATURE_LOOP_OF_HENLE_DESCENDING_LIMB = _Immature_Loop_Of_Henle_Descending_Limb()
    IMPULSE_CONDUCTING_SYSTEM = _Impulse_Conducting_System()
    INCISOR_DENTAL_PULP = _Incisor_Dental_Pulp()
    INDUSIUM_GRISEUM = _Indusium_Griseum()
    INGUINAL_LYMPH_NODE = _Inguinal_Lymph_Node()
    INSULAR_CORTEX = _Insular_Cortex()
    ALVEOLAR_SEPTUM = _Alveolar_Septum()
    INTERCALATED_AMYGDALOID_NUCLEUS = _Intercalated_Amygdaloid_Nucleus()
    INTERCEREBRAL_COMMISSURE = _Intercerebral_Commissure()
    CEREBRAL_INTERNAL_CAPSULE = _Cerebral_Internal_Capsule()
    INTERNAL_SPIRAL_SULCUS = _Internal_Spiral_Sulcus()
    INTERPEDUNCULAR_NUCLEUS = _Interpeduncular_Nucleus()
    INTESTINE_MUCOSA = _Intestine_Mucosa()
    INTESTINE_MUSCULARIS = _Intestine_Muscularis()
    INTESTINE_MUSCULARIS_MUCOSA = _Intestine_Muscularis_Mucosa()
    INTESTINE_SMOOTH_MUSCLE = _Intestine_Smooth_Muscle()
    INTESTINE_WALL = _Intestine_Wall()
    INTRALAMINAR_THALAMIC_GROUP = _Intralaminar_Thalamic_Group()
    INTRINSIC_NERVE_PLEXUS = _Intrinsic_Nerve_Plexus()
    IRIS_EPITHELIUM = _Iris_Epithelium()
    IRIS_MUSCLE = _Iris_Muscle()
    IRIS_NERVE = _Iris_Nerve()
    IRIS_STROMA = _Iris_Stroma()
    ISLANDS_OF_CALLEJA = _Islands_Of_Calleja()
    JAW_BONE = _Jaw_Bone()
    JAW_PRIMORDIUM_MESENCHYME = _Jaw_Primordium_Mesenchyme()
    JAW_SKELETON = _Jaw_Skeleton()
    SKELETAL_JOINT = _Skeletal_Joint()
    METANEPHROS_EPITHELIUM = _Metanephros_Epithelium()
    METANEPHROS_GLOMERULAR_EPITHELIUM = _Metanephros_Glomerular_Epithelium()
    LOOP_OF_HENLE_OF_RENAL_MEDULLA = _Loop_Of_Henle_Of_Renal_Medulla()
    KIDNEY_OUTER_MEDULLA_PERITUBULAR_CAPILLARY = _Kidney_Outer_Medulla_Peritubular_Capillary()
    LACRIMAL_APPARATUS = _Lacrimal_Apparatus()
    LACRIMAL_GLAND = _Lacrimal_Gland()
    LACRIMAL_GLAND_BUD = _Lacrimal_Gland_Bud()
    LARGE_INTESTINE_CRYPT_OF_LIEBERKUHN = _Large_Intestine_Crypt_Of_Lieberkuhn()
    LARGE_INTESTINE_EPITHELIUM = _Large_Intestine_Epithelium()
    LARGE_INTESTINE_MUCOSA = _Large_Intestine_Mucosa()
    LARGE_INTESTINE_PEYER_S_PATCH = _Large_Intestine_Peyer_S_Patch()
    LARGE_INTESTINE_SMOOTH_MUSCLE = _Large_Intestine_Smooth_Muscle()
    LARGE_INTESTINE_WALL = _Large_Intestine_Wall()
    LARYNX_CONNECTIVE_TISSUE = _Larynx_Connective_Tissue()
    LARYNX_EPITHELIUM = _Larynx_Epithelium()
    LARYNX_MUSCLE = _Larynx_Muscle()
    LARYNX_SUBMUCOSA = _Larynx_Submucosa()
    LARYNX_SUBMUCOSA_GLAND = _Larynx_Submucosa_Gland()
    LATERAL_AMYGDALOID_NUCLEUS = _Lateral_Amygdaloid_Nucleus()
    LATERAL_ENTORHINAL_CORTEX = _Lateral_Entorhinal_Cortex()
    LATERAL_GENICULATE_NUCLEUS = _Lateral_Geniculate_Nucleus()
    LATERAL_HABENULAR_NUCLEUS = _Lateral_Habenular_Nucleus()
    LATERAL_HYPOTHALAMIC_AREA = _Lateral_Hypothalamic_Area()
    LATERAL_MAMMILLARY_NUCLEUS = _Lateral_Mammillary_Nucleus()
    LATERAL_MEDULLARY_RETICULAR_FORMATION = _Lateral_Medullary_Reticular_Formation()
    LATERAL_PREOPTIC_AREA = _Lateral_Preoptic_Area()
    LATERAL_RETICULAR_NUCLEUS = _Lateral_Reticular_Nucleus()
    LATERAL_SEPTAL_COMPLEX = _Lateral_Septal_Complex()
    LATERAL_SEPTAL_NUCLEUS = _Lateral_Septal_Nucleus()
    LATERAL_THALAMIC_GROUP = _Lateral_Thalamic_Group()
    LATERAL_VENTRICLE_EPENDYMA = _Lateral_Ventricle_Ependyma()
    LATERAL_VENTRICLE_SUBEPENDYMAL_LAYER = _Lateral_Ventricle_Subependymal_Layer()
    LATERODORSAL_TEGMENTAL_NUCLEUS = _Laterodorsal_Tegmental_Nucleus()
    LEFT_COMMON_CAROTID_ARTERY = _Left_Common_Carotid_Artery()
    LESSER_EPITHELIAL_RIDGE = _Lesser_Epithelial_Ridge()
    LIGAMENT = _Ligament()
    LIMB_BONE = _Limb_Bone()
    LIMB_LONG_BONE = _Limb_Long_Bone()
    SPIRAL_LIMBUS = _Spiral_Limbus()
    LIVER_ACINUS = _Liver_Acinus()
    LIVER_VASCULATURE = _Liver_Vasculature()
    LIVER_LOBULE = _Liver_Lobule()
    LIVER_VASCULAR_ELEMENT = _Liver_Vascular_Element()
    LOCUS_COERULEUS = _Locus_Coeruleus()
    LONG_BONE = _Long_Bone()
    LONG_BONE_DIAPHYSIS = _Long_Bone_Diaphysis()
    LONG_BONE_EPIPHYSEAL_PLATE = _Long_Bone_Epiphyseal_Plate()
    LONG_BONE_EPIPHYSEAL_PLATE_HYPERTROPHIC_ZONE = _Long_Bone_Epiphyseal_Plate_Hypertrophic_Zone()
    LONG_BONE_EPIPHYSEAL_PLATE_PROLIFERATIVE_ZONE = _Long_Bone_Epiphyseal_Plate_Proliferative_Zone()
    LONG_BONE_EPIPHYSIS = _Long_Bone_Epiphysis()
    LONG_BONE_METAPHYSIS = _Long_Bone_Metaphysis()
    LOOP_OF_HENLE_ASCENDING_LIMB = _Loop_Of_Henle_Ascending_Limb()
    LOOP_OF_HENLE_DESCENDING_LIMB = _Loop_Of_Henle_Descending_Limb()
    LOOP_OF_HENLE_DISTAL_STRAIGHT_TUBULE = _Loop_Of_Henle_Distal_Straight_Tubule()
    LOOP_OF_HENLE_THICK_LIMB = _Loop_Of_Henle_Thick_Limb()
    LOOP_OF_HENLE_THIN_DESCENDING_LIMB = _Loop_Of_Henle_Thin_Descending_Limb()
    LOOP_OF_HENLE_THIN_LIMB = _Loop_Of_Henle_Thin_Limb()
    LOWER_JAW_EPITHELIUM = _Lower_Jaw_Epithelium()
    LOWER_JAW_INCISOR_DENTAL_FOLLICLE = _Lower_Jaw_Incisor_Dental_Follicle()
    LOWER_JAW_MOLAR_DENTAL_FOLLICLE = _Lower_Jaw_Molar_Dental_Follicle()
    LOWER_LEG_BONE = _Lower_Leg_Bone()
    LOWER_RESPIRATORY_TRACT_SMOOTH_MUSCLE = _Lower_Respiratory_Tract_Smooth_Muscle()
    LUNG_CONNECTIVE_TISSUE = _Lung_Connective_Tissue()
    LUNG_PARENCHYMA = _Lung_Parenchyma()
    LYMPH_NODE = _Lymph_Node()
    LYMPH_NODE_CAPSULE = _Lymph_Node_Capsule()
    LYMPH_NODE_CORTEX = _Lymph_Node_Cortex()
    LYMPH_NODE_ENDOTHELIUM = _Lymph_Node_Endothelium()
    LYMPH_NODE_FOLLICLE = _Lymph_Node_Follicle()
    LYMPH_NODE_GERMINAL_CENTER = _Lymph_Node_Germinal_Center()
    LYMPH_NODE_MEDULLA = _Lymph_Node_Medulla()
    LYMPH_NODE_PRIMARY_FOLLICLE = _Lymph_Node_Primary_Follicle()
    LYMPH_NODE_SECONDARY_FOLLICLE = _Lymph_Node_Secondary_Follicle()
    LYMPHATIC_VESSEL = _Lymphatic_Vessel()
    LYMPHATIC_VESSEL_ENDOTHELIUM = _Lymphatic_Vessel_Endothelium()
    MACULA_OF_SACCULE = _Macula_Of_Saccule()
    MACULA_OF_UTRICLE = _Macula_Of_Utricle()
    MAMMARY_BUD = _Mammary_Bud()
    MAMMARY_GLAND_CONNECTIVE_TISSUE = _Mammary_Gland_Connective_Tissue()
    MAMMARY_GLAND_DUCT = _Mammary_Gland_Duct()
    MAMMARY_GLAND_FAT = _Mammary_Gland_Fat()
    MAMMARY_PLACODE = _Mammary_Placode()
    MAMMILLARY_BODY = _Mammillary_Body()
    MEDIAL_AMYGDALOID_NUCLEUS = _Medial_Amygdaloid_Nucleus()
    MEDIAL_DORSAL_THALAMIC_NUCLEUS = _Medial_Dorsal_Thalamic_Nucleus()
    MEDIAL_ENTORHINAL_CORTEX = _Medial_Entorhinal_Cortex()
    MEDIAL_GENICULATE_NUCLEUS = _Medial_Geniculate_Nucleus()
    MEDIAL_HABENULAR_NUCLEUS = _Medial_Habenular_Nucleus()
    MEDIAL_MAMMILLARY_NUCLEUS = _Medial_Mammillary_Nucleus()
    MEDIAL_PREOPTIC_NUCLEUS = _Medial_Preoptic_Nucleus()
    MEDIAL_PREOPTIC_AREA = _Medial_Preoptic_Area()
    MEDIAN_RAPHE_NUCLEUS = _Median_Raphe_Nucleus()
    MEDIAL_SEPTAL_COMPLEX = _Medial_Septal_Complex()
    MEDIAL_SEPTAL_NUCLEUS = _Medial_Septal_Nucleus()
    MEDIAL_VESTIBULAR_NUCLEUS = _Medial_Vestibular_Nucleus()
    MEDIASTINAL_LYMPH_NODE = _Mediastinal_Lymph_Node()
    MEDULLARY_RETICULAR_FORMATION = _Medullary_Reticular_Formation()
    MEDULLARY_TUBULE = _Medullary_Tubule()
    MESENCHYME_OF_DEGENERATING_PARAMESONEPHRIC_DUCT_OF_MALE = _Mesenchyme_Of_Degenerating_Paramesonephric_Duct_Of_Male()
    MESENCHYME_OF_PARAMESONEPHRIC_DUCT_OF_FEMALE = _Mesenchyme_Of_Paramesonephric_Duct_Of_Female()
    MESENCHYME_OF_PARAMESONEPHRIC_DUCT_OF_MALE = _Mesenchyme_Of_Paramesonephric_Duct_Of_Male()
    MESENTERIC_LYMPH_NODE = _Mesenteric_Lymph_Node()
    MESOMETRIUM = _Mesometrium()
    BRANCHIAL_GROOVE_EPITHELIUM = _Branchial_Groove_Epithelium()
    METATARSUS_MESENCHYME = _Metatarsus_Mesenchyme()
    MIDBRAIN_RETICULAR_FORMATION = _Midbrain_Reticular_Formation()
    MIDBRAIN_VASCULAR_ELEMENT = _Midbrain_Vascular_Element()
    MIDDLE_PHALANX = _Middle_Phalanx()
    MIDLINE_THALAMIC_GROUP = _Midline_Thalamic_Group()
    MINOR_SALIVARY_GLAND = _Minor_Salivary_Gland()
    MODIOLUS = _Modiolus()
    MOLAR_DENTAL_PULP = _Molar_Dental_Pulp()
    MUSCULATURE = _Musculature()
    SKELETAL_MUSCULATURE = _Skeletal_Musculature()
    NAIL = _Nail()
    NAIL_BED = _Nail_Bed()
    NAIL_MATRIX = _Nail_Matrix()
    NAIL_PLATE = _Nail_Plate()
    NASAL_MESENCHYME = _Nasal_Mesenchyme()
    NASAL_PROCESS_ECTODERM = _Nasal_Process_Ectoderm()
    NASAL_PROCESS_MESENCHYME = _Nasal_Process_Mesenchyme()
    NECK = _Neck()
    NEOCORTEX_LAYER = _Neocortex_Layer()
    NEOCORTEX_REGION = _Neocortex_Region()
    NEPHRIC_DUCT_OF_FEMALE = _Nephric_Duct_Of_Female()
    NEPHRIC_DUCT_OF_MALE = _Nephric_Duct_Of_Male()
    NEPHRON = _Nephron()
    NEURAL_PLATE = _Neural_Plate()
    NEURAL_GROOVE = _Neural_Groove()
    NEUROHYPOPHYSIS_PARS_NERVOSA = _Neurohypophysis_Pars_Nervosa()
    NUCLEUS_AMBIGUUS = _Nucleus_Ambiguus()
    NUCLEUS_OF_DARKSCHEWITSCH = _Nucleus_Of_Darkschewitsch()
    NUCLEUS_OF_DIAGONAL_BAND = _Nucleus_Of_Diagonal_Band()
    NUCLEUS_OF_LATERAL_OLFACTORY_TRACT = _Nucleus_Of_Lateral_Olfactory_Tract()
    NUCLEUS_OF_TRAPEZOID_BODY = _Nucleus_Of_Trapezoid_Body()
    NUCLEUS_RELATED_TO_VISUAL_CORTEX = _Nucleus_Related_To_Visual_Cortex()
    NUCLEUS_REUNIENS = _Nucleus_Reuniens()
    OBLIQUE_ABDOMINAL_MUSCLE = _Oblique_Abdominal_Muscle()
    OCCIPITAL_CORTEX = _Occipital_Cortex()
    OCULOMOTOR_NUCLEUS = _Oculomotor_Nucleus()
    MAIN_OLFACTORY_BULB_EXTERNAL_PLEXIFORM_LAYER = _Main_Olfactory_Bulb_External_Plexiform_Layer()
    MAIN_OLFACTORY_BULB_GLOMERULAR_LAYER = _Main_Olfactory_Bulb_Glomerular_Layer()
    MAIN_OLFACTORY_BULB_GRANULE_CELL_LAYER = _Main_Olfactory_Bulb_Granule_Cell_Layer()
    MAIN_OLFACTORY_BULB_INTERNAL_PLEXIFORM_LAYER = _Main_Olfactory_Bulb_Internal_Plexiform_Layer()
    MAIN_OLFACTORY_BULB_MITRAL_CELL_LAYER = _Main_Olfactory_Bulb_Mitral_Cell_Layer()
    MAIN_OLFACTORY_BULB_SUBEPENDYMAL_ZONE = _Main_Olfactory_Bulb_Subependymal_Zone()
    OLFACTORY_GLAND = _Olfactory_Gland()
    MAIN_OLFACTORY_BULB_OLFACTORY_NERVE_LAYER = _Main_Olfactory_Bulb_Olfactory_Nerve_Layer()
    OLFACTORY_TRACT = _Olfactory_Tract()
    OLFACTORY_TUBERCLE = _Olfactory_Tubercle()
    OPTIC_TRACT = _Optic_Tract()
    ORAL_REGION_MESENCHYME = _Oral_Region_Mesenchyme()
    ORBICULARIS_OCULI = _Orbicularis_Oculi()
    OSSEUS_COCHLEA = _Osseus_Cochlea()
    OSSEUS_COCHLEAR_CANAL = _Osseus_Cochlear_Canal()
    OSSEUS_SPIRAL_LAMINA = _Osseus_Spiral_Lamina()
    OUTFLOW_TRACT_CARDIAC_MUSCLE = _Outflow_Tract_Cardiac_Muscle()
    OUTFLOW_TRACT_PULMONARY_COMPONENT_DISTAL_PART = _Outflow_Tract_Pulmonary_Component_Distal_Part()
    OVARY_ANTRAL_FOLLICLE = _Ovary_Antral_Follicle()
    OVARY_CAPSULE = _Ovary_Capsule()
    OVARY_FOLLICLE = _Ovary_Follicle()
    OVARY_GROWING_FOLLICLE = _Ovary_Growing_Follicle()
    OVARY_PREANTRAL_FOLLICLE = _Ovary_Preantral_Follicle()
    OVARY_PRIMARY_FOLLICLE = _Ovary_Primary_Follicle()
    OVARY_SECONDARY_FOLLICLE = _Ovary_Secondary_Follicle()
    OVARY_STRATUM_GRANULOSUM = _Ovary_Stratum_Granulosum()
    OVARY_THECA = _Ovary_Theca()
    PALATAL_RUGAE = _Palatal_Rugae()
    HARD_PALATE_PALATAL_RUGAE = _Hard_Palate_Palatal_Rugae()
    PALATAL_RUGAE_EPITHELIUM = _Palatal_Rugae_Epithelium()
    HARD_PALATE_PALATAL_RUGAE_EPITHELIUM = _Hard_Palate_Palatal_Rugae_Epithelium()
    PALATAL_RUGAE_MESENCHYME = _Palatal_Rugae_Mesenchyme()
    HARD_PALATE_PALATAL_RUGAE_MESENCHYME = _Hard_Palate_Palatal_Rugae_Mesenchyme()
    PALATINE_GLAND = _Palatine_Gland()
    PALATINE_TONSIL = _Palatine_Tonsil()
    PANCREAS_EPITHELIUM = _Pancreas_Epithelium()
    PANCREAS_PRIMORDIUM_EPITHELIUM = _Pancreas_Primordium_Epithelium()
    PANCREAS_PRIMORDIUM_MESENCHYME = _Pancreas_Primordium_Mesenchyme()
    PANCREAS_TIP_EPITHELIUM = _Pancreas_Tip_Epithelium()
    PANCREAS_TRUNK_EPITHELIUM = _Pancreas_Trunk_Epithelium()
    PANCREATIC_ACINUS = _Pancreatic_Acinus()
    PANCREATIC_ISLET_CORE = _Pancreatic_Islet_Core()
    PANCREATIC_ISLET_MANTLE = _Pancreatic_Islet_Mantle()
    PAPILLARY_DUCT = _Papillary_Duct()
    PARABIGEMINAL_NUCLEUS = _Parabigeminal_Nucleus()
    PARABRACHIAL_NUCLEUS = _Parabrachial_Nucleus()
    PARACENTRAL_NUCLEUS = _Paracentral_Nucleus()
    PARAFASCICULAR_NUCLEUS = _Parafascicular_Nucleus()
    PARAMESONEPHRIC_DUCT_OF_FEMALE = _Paramesonephric_Duct_Of_Female()
    PARAMESONEPHRIC_DUCT_OF_MALE = _Paramesonephric_Duct_Of_Male()
    PARANASAL_SINUS = _Paranasal_Sinus()
    PARATHYROID_GLAND_CAPSULE = _Parathyroid_Gland_Capsule()
    PARATHYROID_GLAND_PARENCHYMA = _Parathyroid_Gland_Parenchyma()
    PARAVENTRICULAR_HYPOTHALAMIC_NUCLEUS = _Paraventricular_Hypothalamic_Nucleus()
    PARAVENTRICULAR_THALAMIC_NUCLEUS = _Paraventricular_Thalamic_Nucleus()
    PARIETAL_CORTEX = _Parietal_Cortex()
    PATELLA = _Patella()
    PECTORAL_GIRDLE_SKELETON = _Pectoral_Girdle_Skeleton()
    PECTORALIS = _Pectoralis()
    FORELIMB_DIGIT_EPIDERMIS = _Forelimb_Digit_Epidermis()
    PEDUNCULAR_PONTINE_NUCLEUS = _Peduncular_Pontine_Nucleus()
    MIDDLE_EAR_EPITHELIUM = _Middle_Ear_Epithelium()
    PENIS_EPITHELIUM = _Penis_Epithelium()
    PENIS_SKIN = _Penis_Skin()
    PERICHONDRIUM = _Perichondrium()
    PERILYMPHATIC_CHANNEL = _Perilymphatic_Channel()
    PERINEURAL_VASCULAR_PLEXUS = _Perineural_Vascular_Plexus()
    PERIODONTAL_LIGAMENT = _Periodontal_Ligament()
    PERIOLIVARY_NUCLEUS = _Periolivary_Nucleus()
    PERIOSTEUM = _Periosteum()
    PERIRHINAL_CORTEX = _Perirhinal_Cortex()
    PERITONEAL_FLUID = _Peritoneal_Fluid()
    PEYER_S_PATCH_GERMINAL_CENTER = _Peyer_S_Patch_Germinal_Center()
    PHOTORECEPTOR_LAYER = _Photoreceptor_Layer()
    PHOTORECEPTOR_LAYER_INNER_SEGMENT = _Photoreceptor_Layer_Inner_Segment()
    PHOTORECEPTOR_LAYER_OUTER_SEGMENT = _Photoreceptor_Layer_Outer_Segment()
    PLACENTA = _Placenta()
    PLASMA = _Plasma()
    SPINAL_CORD_INTERMEDIATE_GREY = _Spinal_Cord_Intermediate_Grey()
    PONTINE_NUCLEUS = _Pontine_Nucleus()
    PONTINE_RETICULAR_FORMATION = _Pontine_Reticular_Formation()
    POSTERIOR_AMYGDALOID_NUCLEUS = _Posterior_Amygdaloid_Nucleus()
    POSTERIOR_COMMISSURE = _Posterior_Commissure()
    POSTERIOR_SEPTAL_COMPLEX = _Posterior_Septal_Complex()
    POSTERIOR_THALAMIC_GROUP = _Posterior_Thalamic_Group()
    POSTERIOR_THALAMIC_NUCLEUS = _Posterior_Thalamic_Nucleus()
    POSTEROLATERAL_CORTICAL_AMYGDALOID_NUCLEUS = _Posterolateral_Cortical_Amygdaloid_Nucleus()
    POSTEROMEDIAL_CORTICAL_AMYGDALOID_NUCLEUS = _Posteromedial_Cortical_Amygdaloid_Nucleus()
    PREPUTIAL_GLAND = _Preputial_Gland()
    PREPUTIAL_SWELLING = _Preputial_Swelling()
    PRESUBICULUM = _Presubiculum()
    PRIMARY_MOTOR_CORTEX = _Primary_Motor_Cortex()
    PRIMARY_OOCYTE = _Primary_Oocyte()
    PRIMARY_SOMATOSENSORY_CORTEX = _Primary_Somatosensory_Cortex()
    PRIMARY_SPERMATOCYTE = _Primary_Spermatocyte()
    PRIMARY_VISUAL_CORTEX = _Primary_Visual_Cortex()
    FORELIMB_INTERDIGITAL_REGION_SKIN = _Forelimb_Interdigital_Region_Skin()
    PROSTATE_GLAND_DORSOLATERAL_LOBE = _Prostate_Gland_Dorsolateral_Lobe()
    PROSTATE_EPITHELIUM = _Prostate_Epithelium()
    PROSTATE_GLAND_LOBE = _Prostate_Gland_Lobe()
    PROSTATE_GLAND_SMOOTH_MUSCLE = _Prostate_Gland_Smooth_Muscle()
    PROSTATE_STROMA = _Prostate_Stroma()
    FORELIMB_INTERDIGITAL_REGION_DERMIS = _Forelimb_Interdigital_Region_Dermis()
    PROXIMAL_PHALANX = _Proximal_Phalanx()
    RIGHT_LUNG_ALVEOLAR_SYSTEM = _Right_Lung_Alveolar_System()
    PURKINJE_FIBER = _Purkinje_Fiber()
    PUTAMEN = _Putamen()
    RAPHE_MAGNUS_NUCLEUS = _Raphe_Magnus_Nucleus()
    RAPHE_NUCLEUS = _Raphe_Nucleus()
    RAPHE_PALLIDUS_NUCLEUS = _Raphe_Pallidus_Nucleus()
    RED_NUCLEUS = _Red_Nucleus()
    RENAL_CONVOLUTED_TUBULE = _Renal_Convoluted_Tubule()
    RENAL_CORPUSCLE = _Renal_Corpuscle()
    RENAL_PAPILLA = _Renal_Papilla()
    REPRODUCTIVE_SYSTEM_MESENCHYME = _Reproductive_System_Mesenchyme()
    RESPIRATORY_BRONCHIOLE = _Respiratory_Bronchiole()
    RESPIRATORY_BRONCHIOLE_EPITHELIUM = _Respiratory_Bronchiole_Epithelium()
    RESPIRATORY_SYSTEM_BLOOD_VESSEL = _Respiratory_System_Blood_Vessel()
    RESPIRATORY_SYSTEM_BLOOD_VESSEL_ENDOTHELIUM = _Respiratory_System_Blood_Vessel_Endothelium()
    RESPIRATORY_SYSTEM_MUSCLE = _Respiratory_System_Muscle()
    RESPIRATORY_SYSTEM_SMOOTH_MUSCLE = _Respiratory_System_Smooth_Muscle()
    RETICULAR_MEMBRANE = _Reticular_Membrane()
    RETICULAR_TEGMENTAL_NUCLEUS = _Reticular_Tegmental_Nucleus()
    RETICULAR_THALAMIC_NUCLEUS = _Reticular_Thalamic_Nucleus()
    RETINA_EPITHELIUM = _Retina_Epithelium()
    RETINA_GANGLION_CELL_LAYER = _Retina_Ganglion_Cell_Layer()
    RETINA_INNER_PLEXIFORM_LAYER = _Retina_Inner_Plexiform_Layer()
    RETINA_LAYER = _Retina_Layer()
    RETINA_OUTER_PLEXIFORM_LAYER = _Retina_Outer_Plexiform_Layer()
    RETROHIPPOCAMPAL_CORTEX = _Retrohippocampal_Cortex()
    RHOMBOMERE_NEURAL_CREST = _Rhombomere_Neural_Crest()
    RHOMBOMERE_NEURAL_FOLD = _Rhombomere_Neural_Fold()
    RIGHT_COMMON_CAROTID_ARTERY = _Right_Common_Carotid_Artery()
    SALIVARY_DUCT = _Salivary_Duct()
    SCALA_MEDIA = _Scala_Media()
    SCALA_TYMPANI = _Scala_Tympani()
    SCALA_VESTIBULI = _Scala_Vestibuli()
    SEBACEOUS_GLAND = _Sebaceous_Gland()
    SECONDARY_OOCYTE = _Secondary_Oocyte()
    SECONDARY_SOMATOSENSORY_CORTEX = _Secondary_Somatosensory_Cortex()
    SECONDARY_SPERMATOCYTE = _Secondary_Spermatocyte()
    SECONDARY_VISUAL_CORTEX = _Secondary_Visual_Cortex()
    SECRETORY_CIRCUMVENTRICULAR_ORGAN = _Secretory_Circumventricular_Organ()
    SEMILUNAR_VALVE = _Semilunar_Valve()
    SEMINIFEROUS_TUBULE_EPITHELIUM = _Seminiferous_Tubule_Epithelium()
    SEMITENDINOSUS = _Semitendinosus()
    SEPTAL_NUCLEUS = _Septal_Nucleus()
    SEPTAL_OLFACTORY_ORGAN = _Septal_Olfactory_Organ()
    GRUENEBERG_GANGLION = _Grueneberg_Ganglion()
    SEPTAL_ORGAN_OF_MASERA = _Septal_Organ_Of_Masera()
    SEPTOFIMBRIAL_NUCLEUS = _Septofimbrial_Nucleus()
    SEPTOHIPPOCAMPAL_NUCLEUS = _Septohippocampal_Nucleus()
    SERRATUS_MUSCLE = _Serratus_Muscle()
    SERUM = _Serum()
    SESAMOID_BONE_OF_GASTROCNEMIUS = _Sesamoid_Bone_Of_Gastrocnemius()
    SINOATRIAL_NODE = _Sinoatrial_Node()
    SKELETAL_SYSTEM = _Skeletal_System()
    SKIN_GLAND = _Skin_Gland()
    SKIN_MUCOUS_GLAND = _Skin_Mucous_Gland()
    SKIN_MUSCLE = _Skin_Muscle()
    SMALL_INTESTINE_CRYPT_OF_LIEBERKUHN = _Small_Intestine_Crypt_Of_Lieberkuhn()
    SMALL_INTESTINE_EPITHELIUM = _Small_Intestine_Epithelium()
    SMALL_INTESTINE_LAMINA_PROPRIA = _Small_Intestine_Lamina_Propria()
    SMALL_INTESTINE_MUCOSA = _Small_Intestine_Mucosa()
    SMALL_INTESTINE_MUSCULARIS_MUCOSA = _Small_Intestine_Muscularis_Mucosa()
    SMALL_INTESTINE_PEYER_S_PATCH = _Small_Intestine_Peyer_S_Patch()
    SMALL_INTESTINE_SMOOTH_MUSCLE = _Small_Intestine_Smooth_Muscle()
    INTESTINAL_VILLUS = _Intestinal_Villus()
    SMALL_INTESTINE_WALL = _Small_Intestine_Wall()
    SOLEUS = _Soleus()
    SOLITARY_TRACT_NUCLEUS = _Solitary_Tract_Nucleus()
    SPHINCTER_PUPILLAE = _Sphincter_Pupillae()
    SPINAL_CORD_CENTRAL_CANAL = _Spinal_Cord_Central_Canal()
    SPINAL_CORD_DORSAL_HORN = _Spinal_Cord_Dorsal_Horn()
    SPINAL_CORD_EPENDYMAL_LAYER = _Spinal_Cord_Ependymal_Layer()
    SPINAL_CORD_GRAY_MATTER = _Spinal_Cord_Gray_Matter()
    SPINAL_CORD_VASCULAR_ELEMENT = _Spinal_Cord_Vascular_Element()
    SPINAL_CORD_VENTRAL_HORN = _Spinal_Cord_Ventral_Horn()
    SPINAL_CORD_WHITE_MATTER = _Spinal_Cord_White_Matter()
    SPINAL_GANGLION_OR_NERVE = _Spinal_Ganglion_Or_Nerve()
    SPINAL_VESTIBULAR_NUCLEUS = _Spinal_Vestibular_Nucleus()
    SPIRAL_LIGAMENT = _Spiral_Ligament()
    SPIRAL_PROMINENCE = _Spiral_Prominence()
    SPIRAL_SULCUS = _Spiral_Sulcus()
    SPIRAL_VESSEL = _Spiral_Vessel()
    SPLEEN_CAPSULE = _Spleen_Capsule()
    SPLEEN_GERMINAL_CENTER = _Spleen_Germinal_Center()
    SPLEEN_LYMPHOID_FOLLICLE = _Spleen_Lymphoid_Follicle()
    SPLEEN_PULP = _Spleen_Pulp()
    SPLEEN_RED_PULP = _Spleen_Red_Pulp()
    SPLEEN_SMOOTH_MUSCLE = _Spleen_Smooth_Muscle()
    SPLEEN_TRABECULUM = _Spleen_Trabeculum()
    SPLEEN_WHITE_PULP = _Spleen_White_Pulp()
    BODY_OF_STOMACH = _Body_Of_Stomach()
    STOMACH_CARDIAC_REGION = _Stomach_Cardiac_Region()
    STOMACH_GLANDULAR_EPITHELIUM = _Stomach_Glandular_Epithelium()
    STOMACH_MUCOSA = _Stomach_Mucosa()
    STOMACH_MUSCULARIS_MUCOSA = _Stomach_Muscularis_Mucosa()
    RIGHT_LUNG_ALVEOLAR_DUCT = _Right_Lung_Alveolar_Duct()
    STOMACH_REGION = _Stomach_Region()
    STOMACH_SEROSA = _Stomach_Serosa()
    STOMACH_SMOOTH_MUSCLE = _Stomach_Smooth_Muscle()
    STOMACH_SQUAMOUS_EPITHELIUM = _Stomach_Squamous_Epithelium()
    STOMACH_SUBMUCOSA = _Stomach_Submucosa()
    STOMACH_WALL = _Stomach_Wall()
    STRIA_VASCULARIS = _Stria_Vascularis()
    SUBCOMMISSURAL_ORGAN = _Subcommissural_Organ()
    SUBCUTANEOUS_ADIPOSE_TISSUE = _Subcutaneous_Adipose_Tissue()
    SUBFORNICAL_ORGAN = _Subfornical_Organ()
    DENTATE_GYRUS_SUBGRANULAR_ZONE = _Dentate_Gyrus_Subgranular_Zone()
    SUBICULUM = _Subiculum()
    SUBMANDIBULAR_DUCT = _Submandibular_Duct()
    SUBMUCOUS_NERVE_PLEXUS = _Submucous_Nerve_Plexus()
    SUBSTANTIA_NIGRA = _Substantia_Nigra()
    SUBSTANTIA_NIGRA_PARS_COMPACTA = _Substantia_Nigra_Pars_Compacta()
    SUBSTANTIA_NIGRA_PARS_LATERALIS = _Substantia_Nigra_Pars_Lateralis()
    SUBSTANTIA_NIGRA_PARS_RETICULATA = _Substantia_Nigra_Pars_Reticulata()
    SUBTHALAMIC_NUCLEUS = _Subthalamic_Nucleus()
    SUPERIOR_OLIVARY_NUCLEUS = _Superior_Olivary_Nucleus()
    SUPRACHIASMATIC_NUCLEUS = _Suprachiasmatic_Nucleus()
    SUPRAMAMMILLARY_NUCLEUS = _Supramammillary_Nucleus()
    SUPRAOPTIC_NUCLEUS = _Supraoptic_Nucleus()
    SWEAT_GLAND = _Sweat_Gland()
    SYMPATHETIC_NERVE_TRUNK = _Sympathetic_Nerve_Trunk()
    SYNCHONDROSIS = _Synchondrosis()
    TAENIA_TECTA = _Taenia_Tecta()
    TAIL_BLOOD_VESSEL = _Tail_Blood_Vessel()
    TAIL_MYOTOME = _Tail_Myotome()
    TASTE_BUD = _Taste_Bud()
    TECTORIAL_MEMBRANE = _Tectorial_Membrane()
    TEMPORAL_CORTEX_ASSOCIATION_AREA = _Temporal_Cortex_Association_Area()
    TENDO_CALCANEUS = _Tendo_Calcaneus()
    TENDON = _Tendon()
    TENSOR_FASCIAE_LATA = _Tensor_Fasciae_Lata()
    TESTIS_CORTICAL_REGION = _Testis_Cortical_Region()
    TESTIS_MEDULLARY_REGION = _Testis_Medullary_Region()
    TESTIS_MESENCHYME = _Testis_Mesenchyme()
    THALAMIC_NUCLEUS = _Thalamic_Nucleus()
    THALAMUS_VASCULAR_ELEMENT = _Thalamus_Vascular_Element()
    THIN_ASCENDING_LIMB_OF_MEDULLA = _Thin_Ascending_Limb_Of_Medulla()
    THORACIC_SEGMENT_OF_TRUNK = _Thoracic_Segment_Of_Trunk()
    THYMUS_CORTEX = _Thymus_Cortex()
    THYMUS_EPITHELIUM = _Thymus_Epithelium()
    THYMUS_PARATHYROID_PRIMORDIUM = _Thymus_Parathyroid_Primordium()
    TIBIALIS_ANTERIOR = _Tibialis_Anterior()
    TIBIALIS_MUSCLE = _Tibialis_Muscle()
    TISSUE = _Tissue()
    TONGUE_PAPILLA_EPITHELIUM = _Tongue_Papilla_Epithelium()
    TONGUE_VASCULAR_ELEMENT = _Tongue_Vascular_Element()
    TONSIL = _Tonsil()
    TOOTH_SUBSTANCE = _Tooth_Substance()
    TRABECULAR_BONE = _Trabecular_Bone()
    TRACHEA_BLOOD_VESSEL = _Trachea_Blood_Vessel()
    TRACHEA_CARTILAGE = _Trachea_Cartilage()
    TRACHEA_CONNECTIVE_TISSUE = _Trachea_Connective_Tissue()
    TRACHEA_LAMINA_PROPRIA = _Trachea_Lamina_Propria()
    TRACHEA_NON_CARTILAGE_CONNECTIVE_TISSUE = _Trachea_Non_Cartilage_Connective_Tissue()
    TRACHEA_SUBMUCOSA = _Trachea_Submucosa()
    TRANSVERSE_COLON = _Transverse_Colon()
    TRIGEMINAL_V_MESENCEPHALIC_NUCLEUS = _Trigeminal_V_Mesencephalic_Nucleus()
    TRIGEMINAL_V_MOTOR_NUCLEUS = _Trigeminal_V_Motor_Nucleus()
    TRIGEMINAL_NUCLEUS = _Trigeminal_Nucleus()
    TRIGEMINAL_V_SENSORY_NUCLEUS = _Trigeminal_V_Sensory_Nucleus()
    TRIGEMINAL_V_SPINAL_SENSORY_NUCLEUS = _Trigeminal_V_Spinal_Sensory_Nucleus()
    TROCHLEAR_NUCLEUS = _Trochlear_Nucleus()
    TRUNCUS_ARTERIOSUS = _Truncus_Arteriosus()
    TRUNK_MUSCULATURE = _Trunk_Musculature()
    TUBEROMAMMILLARY_NUCLEUS = _Tuberomammillary_Nucleus()
    TURBINATE_BONE_PRIMORDIUM = _Turbinate_Bone_Primordium()
    UPPER_ARM_BONE = _Upper_Arm_Bone()
    UPPER_LEG_BONE = _Upper_Leg_Bone()
    UPPER_RESPIRATORY_TRACT_EPITHELIUM = _Upper_Respiratory_Tract_Epithelium()
    URETER_INTERSTITIUM = _Ureter_Interstitium()
    URETHRA_EPITHELIUM = _Urethra_Epithelium()
    BLADDER_MUCOSA = _Bladder_Mucosa()
    URINARY_SYSTEM_MESENCHYME = _Urinary_System_Mesenchyme()
    UROGENITAL_RIDGE = _Urogenital_Ridge()
    UTERUS_STROMA = _Uterus_Stroma()
    UVEA = _Uvea()
    LAMINA_PROPRIA_OF_VAGINA = _Lamina_Propria_Of_Vagina()
    CARDIAC_VALVE_LEAFLET = _Cardiac_Valve_Leaflet()
    VASCULAR_PLEXUS = _Vascular_Plexus()
    VASCULAR_SYSTEM = _Vascular_System()
    VEIN = _Vein()
    VENOUS_SYSTEM_ENDOTHELIUM = _Venous_System_Endothelium()
    VENTRAL_LATERAL_GENICULATE_NUCLEUS = _Ventral_Lateral_Geniculate_Nucleus()
    VENTRAL_NASAL_ARTERY = _Ventral_Nasal_Artery()
    VENTRAL_POSTERIOR_LATERAL_THALAMIC_NUCLEUS = _Ventral_Posterior_Lateral_Thalamic_Nucleus()
    VENTRAL_POSTERIOR_MEDIAL_THALAMIC_NUCLEUS = _Ventral_Posterior_Medial_Thalamic_Nucleus()
    VENTRAL_POSTERIOR_THALAMIC_GROUP = _Ventral_Posterior_Thalamic_Group()
    VENTRAL_TEGMENTAL_AREA = _Ventral_Tegmental_Area()
    VENTRAL_TEGMENTAL_NUCLEUS = _Ventral_Tegmental_Nucleus()
    PRETHALAMUS = _Prethalamus()
    VENTROMEDIAL_HYPOTHALAMIC_NUCLEUS = _Ventromedial_Hypothalamic_Nucleus()
    VENULE = _Venule()
    VERTEBRA_CAUDAL_ARTICULAR_PROCESS = _Vertebra_Caudal_Articular_Process()
    VERTEBRAL_COLUMN = _Vertebral_Column()
    VESTIBULAR_EPITHELIUM = _Vestibular_Epithelium()
    VESTIBULAR_MEMBRANE = _Vestibular_Membrane()
    VESTIBULAR_NUCLEUS = _Vestibular_Nucleus()
    VISCEROCRANIUM_BONE = _Viscerocranium_Bone()
    WHARTON_S_JELLY = _Wharton_S_Jelly()
    WHITE_FAT = _White_Fat()
    WHITE_MATTER = _White_Matter()
    YOLK_SAC_PARIETAL_ENDODERM = _Yolk_Sac_Parietal_Endoderm()
    YOLK_SAC_VISCERAL_ENDODERM = _Yolk_Sac_Visceral_Endoderm()
    ZONA_INCERTA = _Zona_Incerta()
    PELVIC_REGION_OF_TRUNK = _Pelvic_Region_Of_Trunk()
    VENOUS_BLOOD_VESSEL = _Venous_Blood_Vessel()
    FORELIMB_BONE = _Forelimb_Bone()
    HINDLIMB_BONE = _Hindlimb_Bone()
    CORNEA_ENDOTHELIUM = _Cornea_Endothelium()
    FORELIMB_INTERDIGITAL_REGION_EPIDERMIS = _Forelimb_Interdigital_Region_Epidermis()
    HINDLIMB_INTERDIGITAL_REGION_SKIN = _Hindlimb_Interdigital_Region_Skin()
    HINDLIMB_INTERDIGITAL_REGION_DERMIS = _Hindlimb_Interdigital_Region_Dermis()
    HINDLIMB_INTERDIGITAL_REGION_EPIDERMIS = _Hindlimb_Interdigital_Region_Epidermis()
    LIMB_INTERDIGITAL_REGION_DERMIS = _Limb_Interdigital_Region_Dermis()
    LIMB_INTERDIGITAL_REGION_EPIDERMIS = _Limb_Interdigital_Region_Epidermis()
    FUTURE_FOREBRAIN_VENTRICULAR_LAYER = _Future_Forebrain_Ventricular_Layer()
    LIMB_BUD = _Limb_Bud()
    GUM = _Gum()
    NERVE_OF_FEMALE_REPRODUCTIVE_SYSTEM = _Nerve_Of_Female_Reproductive_System()
    NERVE_OF_MALE_REPRODUCTIVE_SYSTEM = _Nerve_Of_Male_Reproductive_System()
    NERVE_OF_URINARY_SYSTEM = _Nerve_Of_Urinary_System()
    ORGAN = _Organ()
    LIVER_AND_BILIARY_SYSTEM_EPITHELIUM = _Liver_And_Biliary_System_Epithelium()
    REPRODUCTIVE_SYSTEM_EPITHELIUM = _Reproductive_System_Epithelium()
    SENSORY_ORGAN_EPITHELIUM = _Sensory_Organ_Epithelium()
    URINARY_SYSTEM_EPITHELIUM = _Urinary_System_Epithelium()
    GENITOURINARY_SYSTEM_EPITHELIUM = _Genitourinary_System_Epithelium()
    SENSORY_ORGAN = _Sensory_Organ()
    OUTER_EAR_EPITHELIUM = _Outer_Ear_Epithelium()
    EYE_EPITHELIUM = _Eye_Epithelium()
    NASAL_EPITHELIUM = _Nasal_Epithelium()
    NARIS_EPITHELIUM = _Naris_Epithelium()
    NASAL_PROCESS_EPITHELIUM = _Nasal_Process_Epithelium()
    EMBRYO_MESENCHYME = _Embryo_Mesenchyme()
    FEMALE_REPRODUCTIVE_SYSTEM_EPITHELIUM = _Female_Reproductive_System_Epithelium()
    MALE_REPRODUCTIVE_SYSTEM_EPITHELIUM = _Male_Reproductive_System_Epithelium()
    PROXIMAL_URETHRAL_EPITHELIUM = _Proximal_Urethral_Epithelium()
    PROXIMAL_URETHRAL_MEATUS = _Proximal_Urethral_Meatus()
    GUM_EPITHELIUM = _Gum_Epithelium()
    INTEGUMENTAL_SYSTEM_MESENCHYME = _Integumental_System_Mesenchyme()
    RESPIRATORY_SYSTEM_MESENCHYME = _Respiratory_System_Mesenchyme()
    METANEPHROS_PARIETAL_EPITHELIUM = _Metanephros_Parietal_Epithelium()
    METANEPHROS_VISCERAL_EPITHELIUM = _Metanephros_Visceral_Epithelium()
    SENSORY_ORGAN_MESENCHYME = _Sensory_Organ_Mesenchyme()
    EAR_MESENCHYME = _Ear_Mesenchyme()
    CARDIOVASCULAR_SYSTEM_MESENCHYME = _Cardiovascular_System_Mesenchyme()
    FEMALE_REPRODUCTIVE_SYSTEM_MESENCHYME = _Female_Reproductive_System_Mesenchyme()
    MALE_REPRODUCTIVE_SYSTEM_MESENCHYME = _Male_Reproductive_System_Mesenchyme()
    CARTILAGE_PRIMORDIUM_OF_FUTURE_SPINOUS_PROCESS = _Cartilage_Primordium_Of_Future_Spinous_Process()
    RESPIRATORY_SYSTEM_CONNECTIVE_TISSUE = _Respiratory_System_Connective_Tissue()
    SENSORY_ORGAN_CARTILAGE = _Sensory_Organ_Cartilage()
    OSSICLE_CARTILAGE_CONDENSATION = _Ossicle_Cartilage_Condensation()
    PECTORAL_THORACIC_CARTILAGE_CONDENSATION = _Pectoral_Thoracic_Cartilage_Condensation()
    PELVIC_GIRDLE_CARTILAGE_CONDENSATION = _Pelvic_Girdle_Cartilage_Condensation()
    OSSICLE_PRE_CARTILAGE_CONDENSATION = _Ossicle_Pre_Cartilage_Condensation()
    PECTORAL_THORACIC_PRE_CARTILAGE_CONDENSATION = _Pectoral_Thoracic_Pre_Cartilage_Condensation()
    PELVIC_GIRDLE_PRE_CARTILAGE_CONDENSATION = _Pelvic_Girdle_Pre_Cartilage_Condensation()
    ECTODERM = _Ectoderm()
    ENDODERM = _Endoderm()
    MESODERM = _Mesoderm()
    SKELETAL_MUSCLE = _Skeletal_Muscle()
    EYE_NEURAL_ECTODERM = _Eye_Neural_Ectoderm()
    ALIMENTARY_SYSTEM_ECTODERM = _Alimentary_System_Ectoderm()
    ALIMENTARY_SYSTEM_ENDODERM = _Alimentary_System_Endoderm()
    ABDOMINAL_LYMPH_NODE = _Abdominal_Lymph_Node()
    VASCULAR_ELEMENT = _Vascular_Element()
    ALIMENTARY_SYSTEM_VASCULAR_ELEMENT = _Alimentary_System_Vascular_Element()
    RESPIRATORY_SYSTEM_VASCULAR_ELEMENT = _Respiratory_System_Vascular_Element()
    HEAD_BONE = _Head_Bone()
    RIGHT_LUNG_ALVEOLUS = _Right_Lung_Alveolus()
    PITUITARY_GLAND = _Pituitary_Gland()
    ENDOCRINE_GLAND = _Endocrine_Gland()
    GERM_CELL_OF_GONAD = _Germ_Cell_Of_Gonad()
    MEDIASTINUM = _Mediastinum()
    AUDITORY_SYSTEM = _Auditory_System()
    VISUAL_SYSTEM = _Visual_System()
    OLFACTORY_SYSTEM = _Olfactory_System()
    LUNG_HILUS = _Lung_Hilus()
    LOBAR_BRONCHUS_VASCULAR_ELEMENT = _Lobar_Bronchus_Vascular_Element()
    LUNG_RUDIMENT = _Lung_Rudiment()
    LUNG_RUDIMENT_EPITHELIUM = _Lung_Rudiment_Epithelium()
    LUNG_RUDIMENT_MESENCHYME = _Lung_Rudiment_Mesenchyme()
    LUNG_RUDIMENT_VASCULAR_ELEMENT = _Lung_Rudiment_Vascular_Element()
    RIB_HEAD_CARTILAGE = _Rib_Head_Cartilage()
    RIB_NECK_CARTILAGE = _Rib_Neck_Cartilage()
    RIB_SHAFT = _Rib_Shaft()
    RIB_SHAFT_NON_OSSIFIED_REGION = _Rib_Shaft_Non_Ossified_Region()
    RIB_SHAFT_OSSIFIED_REGION = _Rib_Shaft_Ossified_Region()
    UMBILICAL_ARTERY = _Umbilical_Artery()
    UMBILICAL_VEIN = _Umbilical_Vein()
    LEFT_UMBILICAL_VEIN = _Left_Umbilical_Vein()
    RIGHT_UMBILICAL_VEIN = _Right_Umbilical_Vein()
    VITELLINE_VEIN = _Vitelline_Vein()
    LEFT_VITELLINE_VEIN = _Left_Vitelline_Vein()
    RIGHT_VITELLINE_VEIN = _Right_Vitelline_Vein()
    FUTURE_TELENCEPHALON = _Future_Telencephalon()
    PROEPICARDIUM = _Proepicardium()
    NASAL_CAVITY_MUCOSA = _Nasal_Cavity_Mucosa()
    NASAL_CAVITY_LAMINA_PROPRIA = _Nasal_Cavity_Lamina_Propria()
    NASAL_SEPTUM_MUCOSA = _Nasal_Septum_Mucosa()
    NASAL_SEPTUM_LAMINA_PROPRIA = _Nasal_Septum_Lamina_Propria()
    ULTIMOBRANCHIAL_BODY = _Ultimobranchial_Body()
    BODY_REGION = _Body_Region()
    EARLY_EMBRYO = _Early_Embryo()
    GERM_LAYER = _Germ_Layer()
    UMBILICAL_OR_VITELLINE_VESSEL = _Umbilical_Or_Vitelline_Vessel()
    BLASTOCYST = _Blastocyst()
    RIB_CARTILAGE = _Rib_Cartilage()
    CAVITY_OR_LINING = _Cavity_Or_Lining()
    PROAMNIOTIC_CAVITY = _Proamniotic_Cavity()
    PRIMARY_YOLK_SAC_CAVITY = _Primary_Yolk_Sac_Cavity()
    CONCEPTUS = _Conceptus()
    _1_CELL_STAGE_CONCEPTUS = _1_Cell_Stage_Conceptus()
    _2_CELL_STAGE_CONCEPTUS = _2_Cell_Stage_Conceptus()
    _4_CELL_STAGE_CONCEPTUS = _4_Cell_Stage_Conceptus()
    _8_CELL_STAGE_CONCEPTUS = _8_Cell_Stage_Conceptus()
    MORULA_STAGE_CONCEPTUS = _Morula_Stage_Conceptus()
    BLASTOCYST_STAGE_CONCEPTUS = _Blastocyst_Stage_Conceptus()
    LIMB_MUSCLE = _Limb_Muscle()
    HINDLIMB_MUSCLE = _Hindlimb_Muscle()
    FORELIMB_MUSCLE = _Forelimb_Muscle()
    NECK_MUSCLE = _Neck_Muscle()
    AMYGDALOID_NUCLEUS = _Amygdaloid_Nucleus()
    ANAL_SPHINCTER = _Anal_Sphincter()
    ARM_MUSCLE = _Arm_Muscle()
    LEG_MUSCLE = _Leg_Muscle()
    ATRIUM_AURICULAR_REGION = _Atrium_Auricular_Region()
    ATRIUM_AURICULAR_REGION_CARDIAC_MUSCLE = _Atrium_Auricular_Region_Cardiac_Muscle()
    ATRIUM_AURICULAR_REGION_ENDOCARDIAL_LINING = _Atrium_Auricular_Region_Endocardial_Lining()
    ATRIUM_LUMEN = _Atrium_Lumen()
    COMMON_ATRIAL_CHAMBER_AURICULAR_REGION = _Common_Atrial_Chamber_Auricular_Region()
    COMMON_ATRIAL_CHAMBER_AURICULAR_REGION_CARDIAC_MUSCLE = _Common_Atrial_Chamber_Auricular_Region_Cardiac_Muscle()
    COMMON_ATRIAL_CHAMBER_AURICULAR_REGION_ENDOCARDIAL_LINING = (
        _Common_Atrial_Chamber_Auricular_Region_Endocardial_Lining()
    )
    CRANIUM_BONE_PRIMORDIUM = _Cranium_Bone_Primordium()
    _4_8_CELL_STAGE_CONCEPTUS = _4_8_Cell_Stage_Conceptus()
    CRANIAL_PREGANGLION = _Cranial_Preganglion()
    HYOID_CARTILAGE_PRIMORDIUM = _Hyoid_Cartilage_Primordium()
    INTERVENTRICULAR_FORAMEN = _Interventricular_Foramen()
    ANTERIOR_VISCERAL_ENDODERM = _Anterior_Visceral_Endoderm()
    POSTERIOR_VISCERAL_ENDODERM = _Posterior_Visceral_Endoderm()
    CLOACAL_EPITHELIUM_OF_CLOACAL_MEMBRANE = _Cloacal_Epithelium_Of_Cloacal_Membrane()
    SURFACE_ECTODERM_OF_CLOACAL_MEMBRANE = _Surface_Ectoderm_Of_Cloacal_Membrane()
    SUPERFICIAL_CELL_OF_BLADDER_UROTHELIUM = _Superficial_Cell_Of_Bladder_Urothelium()
    INTERMEDIATE_CELL_LAYER_OF_BLADDER_UROTHELIUM = _Intermediate_Cell_Layer_Of_Bladder_Urothelium()
    KRT5_EXPRESSING_BASAL_CELL_OF_BLADDER_UROTHELIUM = _Krt5_Expressing_Basal_Cell_Of_Bladder_Urothelium()
    SUBUROTHELIAL_LAMINA_PROPRIA_OF_BLADDER = _Suburothelial_Lamina_Propria_Of_Bladder()
    OUTER_LAMINA_PROPRIA_OF_BLADDER = _Outer_Lamina_Propria_Of_Bladder()
    OUTER_LAYER_OF_BLADDER = _Outer_Layer_Of_Bladder()
    BLADDER_NECK = _Bladder_Neck()
    VENTRAL_BLADDER_NECK = _Ventral_Bladder_Neck()
    URETER_JUNCTION_OF_BLADDER_TRIGONE = _Ureter_Junction_Of_Bladder_Trigone()
    URETHRA_JUNCTION_OF_BLADDER_TRIGONE = _Urethra_Junction_Of_Bladder_Trigone()
    URETERAL_SMOOTH_MUSCLE_OF_TRIGONE = _Ureteral_Smooth_Muscle_Of_Trigone()
    FUNDUS_JUNCTION_OF_VENTRAL_BLADDER_NECK = _Fundus_Junction_Of_Ventral_Bladder_Neck()
    URETHRA_JUNCTION_OF_VENTRAL_BLADDER_NECK = _Urethra_Junction_Of_Ventral_Bladder_Neck()
    UNDIFFERENTIATED_EPITHELIAL_CELL_OF_UROTHELIUM_OF_PRIMITIVE_BLADDER = (
        _Undifferentiated_Epithelial_Cell_Of_Urothelium_Of_Primitive_Bladder()
    )
    INTERMEDIATE_CELL_OF_UROTHELIUM_OF_PRIMITIVE_BLADDER = _Intermediate_Cell_Of_Urothelium_Of_Primitive_Bladder()
    P_0_CELL_OF_UROTHELIUM_OF_PRIMITIVE_BLADDER = _P_0_Cell_Of_Urothelium_Of_Primitive_Bladder()
    INNER_MESENCHYMAL_LAYER_OF_PRIMITIVE_BLADDER = _Inner_Mesenchymal_Layer_Of_Primitive_Bladder()
    OUTER_MESENCHYMAL_LAYER_OF_PRIMITIVE_BLADDER = _Outer_Mesenchymal_Layer_Of_Primitive_Bladder()
    MUSCLE_LAYER_OF_PRIMITIVE_BLADDER = _Muscle_Layer_Of_Primitive_Bladder()
    SMOOTH_MUSCLE_CELL_OF_OUTER_MESENCHYMAL_LAYER_OF_PRIMITIVE_BLADDER = (
        _Smooth_Muscle_Cell_Of_Outer_Mesenchymal_Layer_Of_Primitive_Bladder()
    )
    MESENCHYMAL_CELL_OF_OUTER_MESENCHYMAL_LAYER_OF_PRIMITIVE_BLADDER = (
        _Mesenchymal_Cell_Of_Outer_Mesenchymal_Layer_Of_Primitive_Bladder()
    )
    OUTER_LAYER_OF_PRIMITIVE_BLADDER = _Outer_Layer_Of_Primitive_Bladder()
    SEROSA_OF_PRIMITIVE_BLADDER = _Serosa_Of_Primitive_Bladder()
    ADVENTITIA_OF_PRIMITIVE_BLADDER = _Adventitia_Of_Primitive_Bladder()
    PRIMITIVE_BLADDER_CAUDAL_UROGENITAL_SINUS_TRANSITION_ZONE = (
        _Primitive_Bladder_Caudal_Urogenital_Sinus_Transition_Zone()
    )
    EPITHELIUM_OF_PRIMITIVE_BLADDER_CAUDAL_UROGENITAL_SINUS_TRANSITION_ZONE = (
        _Epithelium_Of_Primitive_Bladder_Caudal_Urogenital_Sinus_Transition_Zone()
    )
    MESENCHYME_OF_PRIMITIVE_BLADDER_CAUDAL_UROGENITAL_SINUS_TRANSITION_ZONE = (
        _Mesenchyme_Of_Primitive_Bladder_Caudal_Urogenital_Sinus_Transition_Zone()
    )
    UROGENITAL_SINUS_RIDGE = _Urogenital_Sinus_Ridge()
    REST_OF_CAUDAL_UROGENITAL_SINUS_EPITHELIUM = _Rest_Of_Caudal_Urogenital_Sinus_Epithelium()
    COMMON_NEPHRIC_DUCT = _Common_Nephric_Duct()
    DEVELOPING_VASCULATURE_OF_PELVIC_URETHRA = _Developing_Vasculature_Of_Pelvic_Urethra()
    ADVENTITIA_OF_PELVIC_URETHRA = _Adventitia_Of_Pelvic_Urethra()
    REST_OF_EPITHELIUM_OF_PELVIC_URETHRA = _Rest_Of_Epithelium_Of_Pelvic_Urethra()
    SUPERFICIAL_CELL_LAYER_OF_PELVIC_URETHRA_OF_FEMALE = _Superficial_Cell_Layer_Of_Pelvic_Urethra_Of_Female()
    INTERMEDIATE_CELL_LAYER_OF_PELVIC_URETHRA_OF_FEMALE = _Intermediate_Cell_Layer_Of_Pelvic_Urethra_Of_Female()
    BASAL_CELL_LAYER_OF_PELVIC_URETHRA_OF_FEMALE = _Basal_Cell_Layer_Of_Pelvic_Urethra_Of_Female()
    UROGENITAL_SINUS_RIDGE_OF_FEMALE = _Urogenital_Sinus_Ridge_Of_Female()
    REST_OF_EPITHELIUM_OF_DORSAL_PELVIC_URETHRA_OF_FEMALE = _Rest_Of_Epithelium_Of_Dorsal_Pelvic_Urethra_Of_Female()
    LAMINA_PROPRIA_OF_PELVIC_URETHRA_OF_FEMALE = _Lamina_Propria_Of_Pelvic_Urethra_Of_Female()
    MUSCULARIS_MUCOSA_OF_PELVIC_URETHRA_OF_FEMALE = _Muscularis_Mucosa_Of_Pelvic_Urethra_Of_Female()
    SUBMUCOSA_OF_PELVIC_URETHRA_OF_FEMALE = _Submucosa_Of_Pelvic_Urethra_Of_Female()
    ANTERIOR_MESENCHYMAL_PAD_OF_FEMALE = _Anterior_Mesenchymal_Pad_Of_Female()
    DORSAL_MESENCHYMAL_PAD_OF_FEMALE = _Dorsal_Mesenchymal_Pad_Of_Female()
    VENTRAL_MESENCHYMAL_PAD_OF_FEMALE = _Ventral_Mesenchymal_Pad_Of_Female()
    SMOOTH_MUSCLE_LAYER_OF_PELVIC_URETHRA_OF_FEMALE = _Smooth_Muscle_Layer_Of_Pelvic_Urethra_Of_Female()
    RHABDOSPHINCTER_OF_FEMALE = _Rhabdosphincter_Of_Female()
    ADVENTITIA_OF_PELVIC_URETHRA_OF_FEMALE = _Adventitia_Of_Pelvic_Urethra_Of_Female()
    EGG_CYLINDER = _Egg_Cylinder()
    SUPERFICIAL_CELL_LAYER_OF_PELVIC_URETHRA_OF_MALE = _Superficial_Cell_Layer_Of_Pelvic_Urethra_Of_Male()
    INTERMEDIATE_CELL_LAYER_OF_PELVIC_URETHRA_OF_MALE = _Intermediate_Cell_Layer_Of_Pelvic_Urethra_Of_Male()
    BASAL_CELL_LAYER_OF_PELVIC_URETHRA_OF_MALE = _Basal_Cell_Layer_Of_Pelvic_Urethra_Of_Male()
    UROGENITAL_SINUS_RIDGE_OF_MALE = _Urogenital_Sinus_Ridge_Of_Male()
    REST_OF_EPITHELIUM_OF_DORSAL_PELVIC_URETHRA_OF_MALE = _Rest_Of_Epithelium_Of_Dorsal_Pelvic_Urethra_Of_Male()
    LAMINA_PROPRIA_OF_PELVIC_URETHRA_OF_MALE = _Lamina_Propria_Of_Pelvic_Urethra_Of_Male()
    MUSCULARIS_MUCOSA_OF_PELVIC_URETHRA_OF_MALE = _Muscularis_Mucosa_Of_Pelvic_Urethra_Of_Male()
    SUBMUCOSA_OF_PELVIC_URETHRA_OF_MALE = _Submucosa_Of_Pelvic_Urethra_Of_Male()
    ANTERIOR_MESENCHYMAL_PAD_OF_MALE = _Anterior_Mesenchymal_Pad_Of_Male()
    DORSAL_MESENCHYMAL_PAD_OF_MALE = _Dorsal_Mesenchymal_Pad_Of_Male()
    VENTRAL_MESENCHYMAL_PAD_OF_MALE = _Ventral_Mesenchymal_Pad_Of_Male()
    ADVENTITIA_OF_PELVIC_URETHRA_OF_MALE = _Adventitia_Of_Pelvic_Urethra_Of_Male()
    VENTRAL_EPITHELIAL_BUD_OF_FEMALE = _Ventral_Epithelial_Bud_Of_Female()
    URETHRAL_GLAND_OF_PELVIC_URETHRA_OF_FEMALE = _Urethral_Gland_Of_Pelvic_Urethra_Of_Female()
    URETHRAL_GLAND_OF_CLITORAL_URETHRA = _Urethral_Gland_Of_Clitoral_Urethra()
    VENTRAL_EPITHELIAL_BUD_OF_MALE = _Ventral_Epithelial_Bud_Of_Male()
    EPITHELIUM_OF_DORSAL_PROSTATIC_URETHRA = _Epithelium_Of_Dorsal_Prostatic_Urethra()
    VERUMONTANUM = _Verumontanum()
    REST_OF_EPITHELIUM_OF_DORSAL_PROSTATIC_URETHRA = _Rest_Of_Epithelium_Of_Dorsal_Prostatic_Urethra()
    EPITHELIUM_OF_VENTRAL_PROSTATIC_URETHRA = _Epithelium_Of_Ventral_Prostatic_Urethra()
    ADVENTITIA_OF_PROSTATIC_URETHRA = _Adventitia_Of_Prostatic_Urethra()
    PROSTATE_BUD = _Prostate_Bud()
    ANTERIOR_PROSTATE_BUD = _Anterior_Prostate_Bud()
    DORSAL_PROSTATE_BUD = _Dorsal_Prostate_Bud()
    VENTRAL_PROSTATE_BUD = _Ventral_Prostate_Bud()
    LATERAL_PROSTATE_BUD = _Lateral_Prostate_Bud()
    EPITHELIUM_OF_ANTERIOR_PROSTATE_BUD = _Epithelium_Of_Anterior_Prostate_Bud()
    PERI_PROSTATIC_MESENCHYME_OF_ANTERIOR_PROSTATE_BUD = _Peri_Prostatic_Mesenchyme_Of_Anterior_Prostate_Bud()
    EPITHELIUM_OF_DORSAL_PROSTATE_BUD = _Epithelium_Of_Dorsal_Prostate_Bud()
    PERI_PROSTATIC_MESENCHYME_OF_DORSAL_PROSTATE_BUD = _Peri_Prostatic_Mesenchyme_Of_Dorsal_Prostate_Bud()
    EPITHELIUM_OF_VENTRAL_PROSTATE_BUD = _Epithelium_Of_Ventral_Prostate_Bud()
    PERI_PROSTATIC_MESENCHYME_OF_VENTRAL_PROSTATE_BUD = _Peri_Prostatic_Mesenchyme_Of_Ventral_Prostate_Bud()
    EPITHELIUM_OF_LATERAL_PROSTATE_BUD = _Epithelium_Of_Lateral_Prostate_Bud()
    PERI_PROSTATIC_MESENCHYME_OF_LATERAL_PROSTATE_BUD = _Peri_Prostatic_Mesenchyme_Of_Lateral_Prostate_Bud()
    SHOULDER_MUSCLE = _Shoulder_Muscle()
    TERES_MUSCLE = _Teres_Muscle()
    TERES_MINOR = _Teres_Minor()
    PSOAS_MUSCLE = _Psoas_Muscle()
    METACARPAL_BONE = _Metacarpal_Bone()
    METATARSAL_BONE = _Metatarsal_Bone()
    FOOT_MUSCLE = _Foot_Muscle()
    PARS_ACROMIALIS_OF_DELTOID = _Pars_Acromialis_Of_Deltoid()
    PARS_CLAVICULARIS_OF_DELTOID = _Pars_Clavicularis_Of_Deltoid()
    PARS_SCAPULARIS_OF_DELTOID = _Pars_Scapularis_Of_Deltoid()
    PROXIMAL_CARPAL_BONE = _Proximal_Carpal_Bone()
    PISIFORM = _Pisiform()
    SCAPHOLUNATE = _Scapholunate()
    TRIQUETRUM = _Triquetrum()
    DISTAL_CARPAL_BONE = _Distal_Carpal_Bone()
    CAPITATE = _Capitate()
    CENTRAL_CARPAL_BONE = _Central_Carpal_Bone()
    FALCIFORM = _Falciform()
    HAMATE = _Hamate()
    TRAPEZIUM = _Trapezium()
    TRAPEZOID = _Trapezoid()
    CUBOID = _Cuboid()
    MEDIAL_CUNEIFORM = _Medial_Cuneiform()
    INTERMEDIATE_CUNEIFORM = _Intermediate_Cuneiform()
    LATERAL_CUNEIFORM = _Lateral_Cuneiform()
    TIBIALE = _Tibiale()
    NAVICULAR = _Navicular()
    ANCONEUS = _Anconeus()
    CORACOBRACHIALIS = _Coracobrachialis()
    TENSOR_FASCIAE_ANTEBRACHII = _Tensor_Fasciae_Antebrachii()
    LATERAL_HEAD_OF_TRICEPS_BRACHII = _Lateral_Head_Of_Triceps_Brachii()
    LONG_HEAD_OF_TRICEPS_BRACHII = _Long_Head_Of_Triceps_Brachii()
    MEDIAL_HEAD_OF_TRICEPS_BRACHII = _Medial_Head_Of_Triceps_Brachii()
    EXTENSOR_CARPI_RADIALIS = _Extensor_Carpi_Radialis()
    EXTENSOR_CARPI_RADIALIS_BREVIS = _Extensor_Carpi_Radialis_Brevis()
    EXTENSOR_CARPI_RADIALIS_LONGUS = _Extensor_Carpi_Radialis_Longus()
    EXTENSOR_CARPI_ULNARIS = _Extensor_Carpi_Ulnaris()
    EXTENSOR_DIGITORUM_COMMUNIS = _Extensor_Digitorum_Communis()
    EXTENSOR_DIGITORUM_LATERALIS = _Extensor_Digitorum_Lateralis()
    EXTENSOR_INDICIS_PROPRIUS = _Extensor_Indicis_Proprius()
    EXTENSOR_POLLICIS = _Extensor_Pollicis()
    EXTENSOR_POLLICIS_BREVIS = _Extensor_Pollicis_Brevis()
    EXTENSOR_POLLICIS_LONGUS = _Extensor_Pollicis_Longus()
    FLEXOR_CARPI_RADIALIS = _Flexor_Carpi_Radialis()
    FLEXOR_CARPI_ULNARIS = _Flexor_Carpi_Ulnaris()
    HUMERAL_HEAD_OF_FLEXOR_DIGITORUM_PROFUNDUS = _Humeral_Head_Of_Flexor_Digitorum_Profundus()
    RADIAL_HEAD_OF_FLEXOR_DIGITORUM_PROFUNDUS = _Radial_Head_Of_Flexor_Digitorum_Profundus()
    ULNAR_HEAD_OF_FLEXOR_DIGITORUM_PROFUNDUS = _Ulnar_Head_Of_Flexor_Digitorum_Profundus()
    FLEXOR_DIGITORUM_SUPERFICIALIS = _Flexor_Digitorum_Superficialis()
    FLEXOR_DIGITORUM_SUPERFICIALIS_1 = _Flexor_Digitorum_Superficialis_1()
    FLEXOR_DIGITORUM_SUPERFICIALIS_2 = _Flexor_Digitorum_Superficialis_2()
    PALMARIS_LONGUS = _Palmaris_Longus()
    PRONATOR_QUADRATUS = _Pronator_Quadratus()
    PRONATOR_TERES = _Pronator_Teres()
    SUPINATOR = _Supinator()
    ABDUCTOR_POLLICIS = _Abductor_Pollicis()
    ABDUCTOR_POLLICIS_LONGUS = _Abductor_Pollicis_Longus()
    ABDUCTOR_POLLICIS_BREVIS = _Abductor_Pollicis_Brevis()
    ABDUCTOR_DIGITI_QUINTI_OF_HAND = _Abductor_Digiti_Quinti_Of_Hand()
    ADDUCTOR_POLLICIS = _Adductor_Pollicis()
    FLEXOR_DIGITI_PRIMI_BREVIS_OF_HAND = _Flexor_Digiti_Primi_Brevis_Of_Hand()
    FLEXOR_DIGITI_QUINTI_BREVIS = _Flexor_Digiti_Quinti_Brevis()
    INTEROSSEUS_MUSCLE_OF_HAND = _Interosseus_Muscle_Of_Hand()
    LUMBRICAL_MUSCLE_OF_HAND = _Lumbrical_Muscle_Of_Hand()
    OPPONENS_DIGITI_QUINTI = _Opponens_Digiti_Quinti()
    ADDUCTOR_BREVIS = _Adductor_Brevis()
    ADDUCTOR_LONGUS = _Adductor_Longus()
    ADDUCTOR_MAGNUS = _Adductor_Magnus()
    ACCESSORY_HEAD_OF_BICEPS_FEMORIS = _Accessory_Head_Of_Biceps_Femoris()
    ANTERIOR_HEAD_OF_BICEPS_FEMORIS = _Anterior_Head_Of_Biceps_Femoris()
    POSTERIOR_HEAD_OF_BICEPS_FEMORIS = _Posterior_Head_Of_Biceps_Femoris()
    CAUDOFEMORALIS = _Caudofemoralis()
    GEMELLUS_MUSCLE = _Gemellus_Muscle()
    GEMELLUS_INFERIOR = _Gemellus_Inferior()
    GEMELLUS_SUPERIOR = _Gemellus_Superior()
    GLUTEUS_MINIMUS = _Gluteus_Minimus()
    GRACILIS_MUSCLE = _Gracilis_Muscle()
    GRACILIS_ANTICUS = _Gracilis_Anticus()
    GRACILIS_POSTICUS = _Gracilis_Posticus()
    OBTURATOR_MUSCLE = _Obturator_Muscle()
    OBTURATOR_EXTERNUS = _Obturator_Externus()
    OBTURATOR_INTERNUS = _Obturator_Internus()
    PECTINEUS = _Pectineus()
    PIRIFORMIS = _Piriformis()
    POPLITEUS = _Popliteus()
    QUADRATUS_FEMORIS = _Quadratus_Femoris()
    SEMIMEMBRANOSUS = _Semimembranosus()
    VASTUS_INTERMEDIUS = _Vastus_Intermedius()
    VASTUS_LATERALIS = _Vastus_Lateralis()
    VASTUS_MEDIALIS = _Vastus_Medialis()
    EXTENSOR_HALLUCIS_LONGUS = _Extensor_Hallucis_Longus()
    FLEXOR_DIGITORUM_BREVIS = _Flexor_Digitorum_Brevis()
    FLEXOR_DIGITORUM_LONGUS = _Flexor_Digitorum_Longus()
    LATERAL_HEAD_OF_GASTROCNEMIUS = _Lateral_Head_Of_Gastrocnemius()
    MEDIAL_HEAD_OF_GASTROCNEMIUS = _Medial_Head_Of_Gastrocnemius()
    PERONEUS_MUSCLE = _Peroneus_Muscle()
    PERONEUS_BREVIS = _Peroneus_Brevis()
    PERONEUS_LONGUS = _Peroneus_Longus()
    PLANTARIS = _Plantaris()
    TIBIALIS_POSTERIOR = _Tibialis_Posterior()
    ABDUCTOR_DIGITI_QUINTI_OF_FOOT = _Abductor_Digiti_Quinti_Of_Foot()
    ADDUCTOR_INDICIS = _Adductor_Indicis()
    EXTENSOR_DIGITORUM_BREVIS = _Extensor_Digitorum_Brevis()
    FLEXOR_DIGITI_PRIMI_BREVIS_OF_FOOT = _Flexor_Digiti_Primi_Brevis_Of_Foot()
    PERONEUS_DIGITI_QUARTI = _Peroneus_Digiti_Quarti()
    PERONEUS_DIGITI_QUINTI = _Peroneus_Digiti_Quinti()
    INTEROSSEUS_MUSCLE_OF_FOOT = _Interosseus_Muscle_Of_Foot()
    LUMBRICAL_MUSCLE_OF_FOOT = _Lumbrical_Muscle_Of_Foot()
    QUADRATUS_PLANTAE = _Quadratus_Plantae()
    TENSOR_APONEUROSIS_PLANTARIS = _Tensor_Aponeurosis_Plantaris()
    RECTUS_FEMORIS = _Rectus_Femoris()
    TRICEPS_SURAE_MUSCLE = _Triceps_Surae_Muscle()
    MEDIAN_SULCUS = _Median_Sulcus()
    SERRATUS_DORSALIS = _Serratus_Dorsalis()
    MEDULLARY_VELUM = _Medullary_Velum()
    VERTEBRAL_VEIN = _Vertebral_Vein()
    FORAMEN_TRANSVERSARIUM = _Foramen_Transversarium()
    UTERUS_LUMEN = _Uterus_Lumen()
    OTIC_GANGLION = _Otic_Ganglion()
    SPHENOPALATINE_GANGLION = _Sphenopalatine_Ganglion()
    SUBMANDIBULAR_GANGLION = _Submandibular_Ganglion()
    RIGHT_LUNG_ACCESSORY_LOBE_VASCULAR_ELEMENT = _Right_Lung_Accessory_Lobe_Vascular_Element()
    RIGHT_LUNG_CAUDAL_LOBE_VASCULAR_ELEMENT = _Right_Lung_Caudal_Lobe_Vascular_Element()
    RIGHT_LUNG_CRANIAL_LOBE_VASCULAR_ELEMENT = _Right_Lung_Cranial_Lobe_Vascular_Element()
    RIGHT_LUNG_MIDDLE_LOBE_VASCULAR_ELEMENT = _Right_Lung_Middle_Lobe_Vascular_Element()
    LUNG_LOBE = _Lung_Lobe()
    TERMINAL_BRONCHIOLE = _Terminal_Bronchiole()
    TERMINAL_BRONCHIOLE_EPITHELIUM = _Terminal_Bronchiole_Epithelium()
    BRONCHIAL_VEIN = _Bronchial_Vein()
    ARTERY_SMOOTH_MUSCLE = _Artery_Smooth_Muscle()
    ARTERIOLE_ENDOTHELIUM = _Arteriole_Endothelium()
    ARTERIOLE_SMOOTH_MUSCLE = _Arteriole_Smooth_Muscle()
    VEIN_ENDOTHELIUM = _Vein_Endothelium()
    VEIN_SMOOTH_MUSCLE = _Vein_Smooth_Muscle()
    VENULE_ENDOTHELIUM = _Venule_Endothelium()
    CAPILLARY_BED = _Capillary_Bed()
    CAPILLARY_ENDOTHELIUM = _Capillary_Endothelium()
    ARTERY_TUNICA_INTIMA = _Artery_Tunica_Intima()
    ARTERY_TUNICA_MEDIA = _Artery_Tunica_Media()
    ARTERY_TUNICA_ADVENTITIA = _Artery_Tunica_Adventitia()
    BLOOD_VESSEL_LAYER = _Blood_Vessel_Layer()
    TUNICA_INTIMA = _Tunica_Intima()
    TUNICA_MEDIA = _Tunica_Media()
    TUNICA_ADVENTITIA = _Tunica_Adventitia()
    BLOOD_VESSEL_ELASTIC_TISSUE = _Blood_Vessel_Elastic_Tissue()
    INTERNAL_ELASTIC_LAMINA = _Internal_Elastic_Lamina()
    EXTERNAL_ELASTIC_LAMINA = _External_Elastic_Lamina()
    ARTERY_INTERNAL_ELASTIC_LAMINA = _Artery_Internal_Elastic_Lamina()
    ARTERY_EXTERNAL_ELASTIC_LAMINA = _Artery_External_Elastic_Lamina()
    ARTERIOLE_TUNICA_INTIMA = _Arteriole_Tunica_Intima()
    ARTERIOLE_TUNICA_MEDIA = _Arteriole_Tunica_Media()
    ARTERIOLE_TUNICA_ADVENTITIA = _Arteriole_Tunica_Adventitia()
    VEIN_TUNICA_INTIMA = _Vein_Tunica_Intima()
    VEIN_TUNICA_MEDIA = _Vein_Tunica_Media()
    VEIN_TUNICA_ADVENTITIA = _Vein_Tunica_Adventitia()
    LYMPHATIC_VESSEL_TUNICA_INTIMA = _Lymphatic_Vessel_Tunica_Intima()
    LYMPHATIC_VESSEL_TUNICA_MEDIA = _Lymphatic_Vessel_Tunica_Media()
    LYMPHATIC_VESSEL_SMOOTH_MUSCLE = _Lymphatic_Vessel_Smooth_Muscle()
    LYMPHATIC_VESSEL_TUNICA_ADVENTITIA = _Lymphatic_Vessel_Tunica_Adventitia()
    SURFACE_ECTODERM_OF_GENITAL_TUBERCLE = _Surface_Ectoderm_Of_Genital_Tubercle()
    PALATINE_VASCULATURE = _Palatine_Vasculature()
    REICHERT_S_CARTILAGE_PRE_CARTILAGE_CONDENSATION = _Reichert_S_Cartilage_Pre_Cartilage_Condensation()
    REICHERT_S_CARTILAGE_CONDENSATION = _Reichert_S_Cartilage_Condensation()
    REICHERT_S_CARTILAGE = _Reichert_S_Cartilage()
    STYLOID_PROCESS_OF_TEMPORAL_BONE = _Styloid_Process_Of_Temporal_Bone()
    HYOID_BODY_UPPER_PART = _Hyoid_Body_Upper_Part()
    CHORDAE_TENDINAE = _Chordae_Tendinae()
    HEPATIC_VENOUS_PLEXUS = _Hepatic_Venous_Plexus()
    LINGUAL_ARTERY = _Lingual_Artery()
    THYMIC_VEIN = _Thymic_Vein()
    LIVER_LOBAR_INTERZONE = _Liver_Lobar_Interzone()
    VENOUS_PLEXUS = _Venous_Plexus()
    VERTEBRAL_VENOUS_PLEXUS = _Vertebral_Venous_Plexus()
    EXTERNAL_VERTEBRAL_VENOUS_PLEXUS = _External_Vertebral_Venous_Plexus()
    INTERNAL_VERTEBRAL_VENOUS_PLEXUS = _Internal_Vertebral_Venous_Plexus()
    TAILGUT = _Tailgut()
    BLADDER_URETHRA_TRANSITION_ZONE = _Bladder_Urethra_Transition_Zone()
    EPITHELIUM_OF_BLADDER_URETHRA_TRANSITION_ZONE = _Epithelium_Of_Bladder_Urethra_Transition_Zone()
    MESENCHYME_OF_BLADDER_URETHRA_TRANSITION_ZONE = _Mesenchyme_Of_Bladder_Urethra_Transition_Zone()
    REMNANT_OF_MESONEPHRIC_TUBULE_OF_MALE = _Remnant_Of_Mesonephric_Tubule_Of_Male()
    FORELIMB_INTERPHALANGEAL_JOINT = _Forelimb_Interphalangeal_Joint()
    HINDLIMB_INTERPHALANGEAL_JOINT = _Hindlimb_Interphalangeal_Joint()
    METATARSAL_PHALANGEAL_JOINT = _Metatarsal_Phalangeal_Joint()
    BRONCHIOLE_SMOOTH_MUSCLE = _Bronchiole_Smooth_Muscle()
    HAIR_FOLLICLE_OF_MALE_PREPUCE = _Hair_Follicle_Of_Male_Prepuce()
    LAMINA_PROPRIA_OF_MALE_PREPUCE = _Lamina_Propria_Of_Male_Prepuce()
    PREPUTIAL_SPACE_OF_MALE = _Preputial_Space_Of_Male()
    NERVE_OF_UROTHELIUM_OF_BLADDER = _Nerve_Of_Urothelium_Of_Bladder()
    NERVE_OF_LAMINA_PROPRIA_OF_BLADDER = _Nerve_Of_Lamina_Propria_Of_Bladder()
    NERVE_OF_DETRUSOR_MUSCLE_OF_BLADDER = _Nerve_Of_Detrusor_Muscle_Of_Bladder()
    NERVE_OF_OUTER_LAYER_OF_BLADDER = _Nerve_Of_Outer_Layer_Of_Bladder()
    NERVE_OF_UROTHELIUM_OF_BLADDER_FUNDUS = _Nerve_Of_Urothelium_Of_Bladder_Fundus()
    NERVE_OF_UROTHELIUM_OF_BLADDER_NECK = _Nerve_Of_Urothelium_Of_Bladder_Neck()
    NERVE_OF_UROTHELIUM_OF_BLADDER_TRIGONE = _Nerve_Of_Urothelium_Of_Bladder_Trigone()
    NERVE_OF_UROTHELIUM_OF_VENTRAL_BLADDER_NECK = _Nerve_Of_Urothelium_Of_Ventral_Bladder_Neck()
    NERVE_OF_LAMINA_PROPRIA_OF_BLADDER_FUNDUS = _Nerve_Of_Lamina_Propria_Of_Bladder_Fundus()
    NERVE_OF_LAMINA_PROPRIA_OF_BLADDER_NECK = _Nerve_Of_Lamina_Propria_Of_Bladder_Neck()
    NERVE_OF_BLOOD_VESSEL_OF_LAMINA_PROPRIA_OF_BLADDER_FUNDUS = (
        _Nerve_Of_Blood_Vessel_Of_Lamina_Propria_Of_Bladder_Fundus()
    )
    NERVE_OF_BLOOD_VESSEL_OF_LAMINA_PROPRIA_OF_BLADDER_NECK = _Nerve_Of_Blood_Vessel_Of_Lamina_Propria_Of_Bladder_Neck()
    NERVE_OF_SUBUROTHELIAL_LAMINA_PROPRIA_OF_BLADDER_FUNDUS = _Nerve_Of_Suburothelial_Lamina_Propria_Of_Bladder_Fundus()
    NERVE_OF_OUTER_LAMINA_PROPRIA_OF_BLADDER_FUNDUS = _Nerve_Of_Outer_Lamina_Propria_Of_Bladder_Fundus()
    NERVE_OF_LAMINA_PROPRIA_OF_BLADDER_TRIGONE = _Nerve_Of_Lamina_Propria_Of_Bladder_Trigone()
    NERVE_OF_LAMINA_PROPRIA_OF_VENTRAL_BLADDER_NECK = _Nerve_Of_Lamina_Propria_Of_Ventral_Bladder_Neck()
    NERVE_OF_BLOOD_VESSEL_OF_SUBUROTHELIAL_LAMINA_PROPRIA_OF_BLADDER_FUNDUS = (
        _Nerve_Of_Blood_Vessel_Of_Suburothelial_Lamina_Propria_Of_Bladder_Fundus()
    )
    NERVE_OF_BLOOD_VESSEL_OF_OUTER_LAMINA_PROPRIA_OF_BLADDER_FUNDUS = (
        _Nerve_Of_Blood_Vessel_Of_Outer_Lamina_Propria_Of_Bladder_Fundus()
    )
    NERVE_OF_BLOOD_VESSEL_OF_LAMINA_PROPRIA_OF_TRIGONE = _Nerve_Of_Blood_Vessel_Of_Lamina_Propria_Of_Trigone()
    NERVE_OF_BLOOD_VESSEL_OF_LAMINA_PROPRIA_OF_VENTRAL_BLADDER_NECK = (
        _Nerve_Of_Blood_Vessel_Of_Lamina_Propria_Of_Ventral_Bladder_Neck()
    )
    NERVE_OF_NONVASCULAR_TISSUE_OF_DETRUSOR_OF_BLADDER = _Nerve_Of_Nonvascular_Tissue_Of_Detrusor_Of_Bladder()
    NERVE_OF_BLOOD_VESSEL_OF_DETRUSOR_OF_BLADDER = _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Bladder()
    NERVE_OF_DETRUSOR_MUSCLE_OF_BLADDER_FUNDUS = _Nerve_Of_Detrusor_Muscle_Of_Bladder_Fundus()
    NERVE_OF_DETRUSOR_MUSCLE_OF_BLADDER_NECK = _Nerve_Of_Detrusor_Muscle_Of_Bladder_Neck()
    NERVE_OF_DETRUSOR_MUSCLE_OF_BLADDER_TRIGONE = _Nerve_Of_Detrusor_Muscle_Of_Bladder_Trigone()
    NERVE_OF_DETRUSOR_MUSCLE_OF_VENTRAL_BLADDER_NECK = _Nerve_Of_Detrusor_Muscle_Of_Ventral_Bladder_Neck()
    NERVE_OF_BLOOD_VESSEL_OF_DETRUSOR_OF_BLADDER_FUNDUS = _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Bladder_Fundus()
    NERVE_OF_BLOOD_VESSEL_OF_DETRUSOR_OF_BLADDER_NECK = _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Bladder_Neck()
    NERVE_OF_BLOOD_VESSEL_OF_DETRUSOR_OF_TRIGONE = _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Trigone()
    NERVE_OF_BLOOD_VESSEL_OF_DETRUSOR_OF_VENTRAL_BLADDER_NECK = (
        _Nerve_Of_Blood_Vessel_Of_Detrusor_Of_Ventral_Bladder_Neck()
    )
    NERVE_OF_NONVASCULAR_TISSUE_OF_OUTER_LAYER_OF_BLADDER = _Nerve_Of_Nonvascular_Tissue_Of_Outer_Layer_Of_Bladder()
    NERVE_OF_BLOOD_VESSEL_OF_OUTER_LAYER_OF_BLADDER = _Nerve_Of_Blood_Vessel_Of_Outer_Layer_Of_Bladder()
    NERVE_OF_SEROSA_OF_BLADDER_FUNDUS = _Nerve_Of_Serosa_Of_Bladder_Fundus()
    NERVE_OF_ADVENTITIA_OF_BLADDER_NECK = _Nerve_Of_Adventitia_Of_Bladder_Neck()
    NERVE_OF_ADVENTITIA_OF_BLADDER_TRIGONE = _Nerve_Of_Adventitia_Of_Bladder_Trigone()
    NERVE_OF_ADVENTITIA_OF_VENTRAL_BLADDER_NECK = _Nerve_Of_Adventitia_Of_Ventral_Bladder_Neck()
    NERVE_OF_BLOOD_VESSEL_OF_SEROSA_OF_BLADDER_FUNDUS = _Nerve_Of_Blood_Vessel_Of_Serosa_Of_Bladder_Fundus()
    NERVE_OF_BLOOD_VESSEL_OF_ADVENTITIA_OF_BLADDER_NECK = _Nerve_Of_Blood_Vessel_Of_Adventitia_Of_Bladder_Neck()
    NERVE_OF_BLOOD_VESSEL_OF_ADVENTITIA_OF_TRIGONE = _Nerve_Of_Blood_Vessel_Of_Adventitia_Of_Trigone()
    NERVE_OF_BLOOD_VESSEL_OF_ADVENTITIA_OF_VENTRAL_BLADDER_NECK = (
        _Nerve_Of_Blood_Vessel_Of_Adventitia_Of_Ventral_Bladder_Neck()
    )
    DUODENUM_MESENCHYME = _Duodenum_Mesenchyme()
    GENITAL_TUBERCLE_MESENCHYME = _Genital_Tubercle_Mesenchyme()
    SMALL_INTESTINE_MESENCHYME = _Small_Intestine_Mesenchyme()
    GENITAL_TUBERCLE_EPITHELIUM = _Genital_Tubercle_Epithelium()
    DIGIT_DERMIS = _Digit_Dermis()
    DIGIT_EPIDERMIS = _Digit_Epidermis()
    TAIL_DERMATOME = _Tail_Dermatome()
    STRIATED_MUSCLE_TISSUE = _Striated_Muscle_Tissue()
    SIGMOID_COLON = _Sigmoid_Colon()
    BACK_SKIN = _Back_Skin()
    NERVE_OF_BLADDER_FUNDUS = _Nerve_Of_Bladder_Fundus()
    NERVE_OF_BLADDER_NECK = _Nerve_Of_Bladder_Neck()
    NERVE_OF_BLADDER_TRIGONE = _Nerve_Of_Bladder_Trigone()
    NERVE_OF_VENTRAL_BLADDER_NECK = _Nerve_Of_Ventral_Bladder_Neck()
    GLANDULAR_RIDGE = _Glandular_Ridge()
    MALE_UROGENITAL_MATING_PROTUBERANCE = _Male_Urogenital_Mating_Protuberance()
    BONE_OF_OS_PENIS = _Bone_Of_Os_Penis()
    HYALINE_CARTILAGE_OF_OS_PENIS = _Hyaline_Cartilage_Of_Os_Penis()
    MALE_UROGENITAL_MATING_PROTUBERANCE_CARTILAGE = _Male_Urogenital_Mating_Protuberance_Cartilage()
    MALE_UROGENITAL_MATING_PROTUBERANCE_CORPUS_CAVERNOSUM = _Male_Urogenital_Mating_Protuberance_Corpus_Cavernosum()
    MALE_UROGENITAL_MATING_PROTUBERANCE_SURFACE_EPITHELIUM = _Male_Urogenital_Mating_Protuberance_Surface_Epithelium()
    MALE_UROGENITAL_MATING_PROTUBERANCE_RIDGE_GROOVE = _Male_Urogenital_Mating_Protuberance_Ridge_Groove()
    MALE_UROGENITAL_MATING_PROTUBERANCE_SKIN = _Male_Urogenital_Mating_Protuberance_Skin()
    CORPUS_CAVERNOSUM_GLANDIS = _Corpus_Cavernosum_Glandis()
    CORPUS_CAVERNOSUM_URETHRA = _Corpus_Cavernosum_Urethra()
    FEMALE_PREPUCE_HAIR_FOLLICLE = _Female_Prepuce_Hair_Follicle()
    FEMALE_PREPUCE_LAMINA_PROPRIA = _Female_Prepuce_Lamina_Propria()
    SCROTUM_SKIN = _Scrotum_Skin()
    LAMINA_PROPRIA_OF_SCROTUM = _Lamina_Propria_Of_Scrotum()
    DEVELOPING_VASCULATURE_OF_SCROTAL_SWELLING = _Developing_Vasculature_Of_Scrotal_Swelling()
    SEPTUM_OF_SCROTAL_FOLD = _Septum_Of_Scrotal_Fold()
    DEVELOPING_VASCULATURE_OF_SCROTAL_FOLD = _Developing_Vasculature_Of_Scrotal_Fold()
    DEVELOPING_VASCULATURE_OF_LABIAL_FOLD = _Developing_Vasculature_Of_Labial_Fold()
    DEVELOPING_VASCULATURE_OF_LABIAL_SWELLING = _Developing_Vasculature_Of_Labial_Swelling()
    LAMINA_PROPRIA_OF_SEMINAL_VESICLE = _Lamina_Propria_Of_Seminal_Vesicle()
    ADVENTITIA_OF_EJACULATORY_DUCT = _Adventitia_Of_Ejaculatory_Duct()
    LAMINA_PROPRIA_OF_DUCTUS_DEFERENS = _Lamina_Propria_Of_Ductus_Deferens()
    URETHRAL_SEAM = _Urethral_Seam()
    MIGRATING_NEURAL_CREST = _Migrating_Neural_Crest()
    URETHRAL_GLAND_OF_PELVIC_URETHRA_OF_MALE = _Urethral_Gland_Of_Pelvic_Urethra_Of_Male()
    URETHRAL_GLAND_OF_PENILE_URETHRA = _Urethral_Gland_Of_Penile_Urethra()
    MALE_URETHRAL_GLAND_BUD = _Male_Urethral_Gland_Bud()
    ANTERIOR_MALE_URETHRAL_GLAND_BUD = _Anterior_Male_Urethral_Gland_Bud()
    POSTERIOR_MALE_URETHRAL_GLAND_BUD = _Posterior_Male_Urethral_Gland_Bud()
    FEMALE_ACCESSORY_GLAND = _Female_Accessory_Gland()
    BULBOURETHRAL_GLAND_OF_FEMALE = _Bulbourethral_Gland_Of_Female()
    EPITHELIUM_OF_BULBOURETHRAL_GLAND_OF_FEMALE = _Epithelium_Of_Bulbourethral_Gland_Of_Female()
    LAMINA_PROPRIA_OF_BULBOURETHRAL_GLAND_OF_FEMALE = _Lamina_Propria_Of_Bulbourethral_Gland_Of_Female()
    VASCULATURE_OF_BULBOURETHRAL_GLAND_OF_FEMALE = _Vasculature_Of_Bulbourethral_Gland_Of_Female()
    PHALLIC_URETHRA_OF_FEMALE = _Phallic_Urethra_Of_Female()
    URETHRAL_MEATUS_OF_PENILE_URETHRA = _Urethral_Meatus_Of_Penile_Urethra()
    UROGENITAL_MEMBRANE_OF_FEMALE = _Urogenital_Membrane_Of_Female()
    UROGENITAL_MEMBRANE_OF_MALE = _Urogenital_Membrane_Of_Male()
    MESENCHYME_OF_METANEPHROS = _Mesenchyme_Of_Metanephros()
    HEART_MESENCHYME = _Heart_Mesenchyme()
    PREDENTIN = _Predentin()
    TOOTH_BASEMENT_MEMBRANE = _Tooth_Basement_Membrane()
    MESENCHYME_OF_GLANS_OF_FEMALE_GENITAL_TUBERCLE = _Mesenchyme_Of_Glans_Of_Female_Genital_Tubercle()
    URETHRAL_PLATE_EPITHELIUM_OF_UROGENITAL_MEMBRANE_OF_FEMALE = (
        _Urethral_Plate_Epithelium_Of_Urogenital_Membrane_Of_Female()
    )
    SKIN_OF_UROGENITAL_MEMBRANE_OF_FEMALE = _Skin_Of_Urogenital_Membrane_Of_Female()
    URETHRAL_PLATE_EPITHELIUM_OF_UROGENITAL_MEMBRANE_OF_MALE = (
        _Urethral_Plate_Epithelium_Of_Urogenital_Membrane_Of_Male()
    )
    SKIN_OF_UROGENITAL_MEMBRANE_OF_MALE = _Skin_Of_Urogenital_Membrane_Of_Male()
    VISUAL_CORTEX = _Visual_Cortex()
    PRELIMBIC_AREA = _Prelimbic_Area()
    CA3_PYRAMIDAL_CELL_LAYER = _Ca3_Pyramidal_Cell_Layer()
    FOREBRAIN_MIDBRAIN_BOUNDARY_REGION = _Forebrain_Midbrain_Boundary_Region()
    SUBCOMMISSURAL_ORGAN_PRIMORDIUM = _Subcommissural_Organ_Primordium()
    URETHRAL_TUBE_EPITHELIUM_OF_CLITORAL_URETHRA = _Urethral_Tube_Epithelium_Of_Clitoral_Urethra()
    PROXIMAL_URETHRAL_MEATUS_OF_CLITORAL_URETHRA = _Proximal_Urethral_Meatus_Of_Clitoral_Urethra()
    URETHRAL_MEATUS_OF_CLITORAL_URETHRA = _Urethral_Meatus_Of_Clitoral_Urethra()
    URETHRAL_TUBE_EPITHELIUM_OF_PENILE_URETHRA = _Urethral_Tube_Epithelium_Of_Penile_Urethra()
    GLAND_OF_VAGINAL_EPITHELIUM = _Gland_Of_Vaginal_Epithelium()
    REST_OF_EPITHELIUM_OF_VAGINA = _Rest_Of_Epithelium_Of_Vagina()
    HINDLIMB_NAIL = _Hindlimb_Nail()
    MYOMETRIUM_INNER_CIRCULAR_SMOOTH_MUSCLE_LAYER = _Myometrium_Inner_Circular_Smooth_Muscle_Layer()
    MYOMETRIUM_OUTER_LONGITUDINAL_SMOOTH_MUSCLE_LAYER = _Myometrium_Outer_Longitudinal_Smooth_Muscle_Layer()
    GREAT_VESSEL_OF_HEART = _Great_Vessel_Of_Heart()
    AORTIC_SAC = _Aortic_Sac()
    OUTFLOW_TRACT_DISTAL_PART = _Outflow_Tract_Distal_Part()
    ANTERIOR_AMNIOTIC_FOLD = _Anterior_Amniotic_Fold()
    POSTERIOR_AMNIOTIC_FOLD = _Posterior_Amniotic_Fold()
    PERIOPTIC_VASCULAR_PLEXUS = _Perioptic_Vascular_Plexus()
    CEREBRAL_VENOUS_PLEXUS = _Cerebral_Venous_Plexus()
    ANTERIOR_CEREBRAL_VEIN = _Anterior_Cerebral_Vein()
    PARACARDIAC_GANGLION = _Paracardiac_Ganglion()
    DENTATE_GYRUS_PRIMORDIUM = _Dentate_Gyrus_Primordium()
    PROSPECTIVE_HIPPOCAMPAL_FISSURE = _Prospective_Hippocampal_Fissure()
    HIPPOCAMPAL_FISSURE = _Hippocampal_Fissure()
    MACULA_OF_VESTIBULAR_COMPONENT = _Macula_Of_Vestibular_Component()
    EARLY_CONCEPTUS = _Early_Conceptus()
    OVARY_FOLLICLE_CELL = _Ovary_Follicle_Cell()
    MESENCHYME_OF_PREPUTIAL_SWELLING = _Mesenchyme_Of_Preputial_Swelling()
    SKIN_OF_PREPUTIAL_SWELLING = _Skin_Of_Preputial_Swelling()
    VIBRISSA_INNER_ROOT_SHEATH = _Vibrissa_Inner_Root_Sheath()
    VIBRISSA_OUTER_ROOT_SHEATH = _Vibrissa_Outer_Root_Sheath()
    HAIR_GERM = _Hair_Germ()
    CA2_PYRAMIDAL_CELL_LAYER = _Ca2_Pyramidal_Cell_Layer()
    HAIR_EPIDERMAL_PLACODE = _Hair_Epidermal_Placode()
    VIBRISSA_ROOT_SHEATH_MATRIX = _Vibrissa_Root_Sheath_Matrix()
    VIBRISSA_DERMAL_PAPILLA = _Vibrissa_Dermal_Papilla()
    HAIR_FOLLICLE_DERMAL_PAPILLA = _Hair_Follicle_Dermal_Papilla()
    PELAGE_HAIR = _Pelage_Hair()
    BULBUS_CORDIS_ENDOCARDIAL_TUBE = _Bulbus_Cordis_Endocardial_Tube()
    BULBUS_CORDIS_ENDOCARDIAL_LINING = _Bulbus_Cordis_Endocardial_Lining()
    BULBUS_CORDIS_CARDIAC_MUSCLE = _Bulbus_Cordis_Cardiac_Muscle()
    BULBUS_CORDIS_CARDIAC_JELLY = _Bulbus_Cordis_Cardiac_Jelly()
    COSTO_CHONDRAL_JOINT = _Costo_Chondral_Joint()
    VENTRAL_ECTODERMAL_RIDGE = _Ventral_Ectodermal_Ridge()
    INTERSOMITIC_ARTERY = _Intersomitic_Artery()
    UMBILICAL_BLOOD_VESSEL = _Umbilical_Blood_Vessel()
    VITELLINE_BLOOD_VESSEL = _Vitelline_Blood_Vessel()
    PERIRENAL_FAT = _Perirenal_Fat()
    LARGE_INTESTINE_MESENCHYME = _Large_Intestine_Mesenchyme()
    THORACIC_CAVITY = _Thoracic_Cavity()
    HAIR_SHAFT = _Hair_Shaft()
    ABDOMINAL_FAT_PAD = _Abdominal_Fat_Pad()
    LEG_BLOOD_VESSEL = _Leg_Blood_Vessel()
    LIMB_JOINT = _Limb_Joint()
    TAIL_SKIN = _Tail_Skin()
    ARTERIAL_SYSTEM_SMOOTH_MUSCLE = _Arterial_System_Smooth_Muscle()
    THYROID_GLAND_FOLLICLE = _Thyroid_Gland_Follicle()
    ABDOMINAL_CAVITY = _Abdominal_Cavity()
    PEYER_S_PATCH_EPITHELIUM = _Peyer_S_Patch_Epithelium()
    ABDOMINAL_MAMMARY_GLAND = _Abdominal_Mammary_Gland()
    NIPPLE = _Nipple()
    DERMIS_CONNECTIVE_TISSUE = _Dermis_Connective_Tissue()
    SUBSTANTIA_GELATINOSA = _Substantia_Gelatinosa()
    COMMON_PERONEAL_NERVE = _Common_Peroneal_Nerve()
    TIBIAL_NERVE = _Tibial_Nerve()
    AURICULAR_NERVE = _Auricular_Nerve()
    HARDERIAN_GLAND_EPITHELIUM = _Harderian_Gland_Epithelium()
    LACRIMAL_GLAND_EPITHELIUM = _Lacrimal_Gland_Epithelium()
    MACULA_OF_RETINA = _Macula_Of_Retina()
    RETINA_LIMITING_LAMINA = _Retina_Limiting_Lamina()
    RETINA_EXTERNAL_LIMITING_LAMINA = _Retina_External_Limiting_Lamina()
    RETINA_INTERNAL_LIMITING_LAMINA = _Retina_Internal_Limiting_Lamina()
    RETINA_BLOOD_VESSEL = _Retina_Blood_Vessel()
    SQUAMOSAL_BONE = _Squamosal_Bone()
    BRUNNER_S_GLAND = _Brunner_S_Gland()
    ESOPHAGUS_SKELETAL_MUSCLE = _Esophagus_Skeletal_Muscle()
    RENAL_TUBULE_EPITHELIUM = _Renal_Tubule_Epithelium()
    EPIDIDYMAL_DUCT = _Epididymal_Duct()
    XIPHOID_CARTILAGE = _Xiphoid_Cartilage()
    AUCHENE_HAIR = _Auchene_Hair()
    GUARD_HAIR = _Guard_Hair()
    PANCREATICO_DUODENAL_ARTERY = _Pancreatico_Duodenal_Artery()
    TIBIAL_ARTERY = _Tibial_Artery()
    LEFT_CORONARY_ARTERY = _Left_Coronary_Artery()
    RIGHT_CORONARY_ARTERY = _Right_Coronary_Artery()
    SEPTAL_CORONARY_ARTERY = _Septal_Coronary_Artery()
    BILE_CANALICULUS = _Bile_Canaliculus()
    EXOCRINE_GLAND_FLUID_OR_SECRETION = _Exocrine_Gland_Fluid_Or_Secretion()
    SALIVA = _Saliva()
    TEAR = _Tear()
    MAMMARY_GLAND_FLUID_OR_SECRETION = _Mammary_Gland_Fluid_Or_Secretion()
    COLOSTROM = _Colostrom()
    MAMMARY_GLAND_MILK = _Mammary_Gland_Milk()
    MALE_REPRODUCTIVE_SYSTEM_FLUID_OR_SECRETION = _Male_Reproductive_System_Fluid_Or_Secretion()
    SEMEN = _Semen()
    SEMINAL_FLUID = _Seminal_Fluid()
    BULBOURETHRAL_GLAND_SECRETION = _Bulbourethral_Gland_Secretion()
    PROSTATE_GLAND_SECRETION = _Prostate_Gland_Secretion()
    SEMINAL_VESICLE_GLAND_SECRETION = _Seminal_Vesicle_Gland_Secretion()
    OTOLYMPH = _Otolymph()
    ENDOLYMPH = _Endolymph()
    PERILYMPH = _Perilymph()
    RESPIRATORY_SYSTEM_FLUID_OR_SECRETION = _Respiratory_System_Fluid_Or_Secretion()
    LUNG_SURFACTANT = _Lung_Surfactant()
    NASAL_MUCUS = _Nasal_Mucus()
    SPUTUM = _Sputum()
    URINE = _Urine()
    INGUINAL_FAT_PAD = _Inguinal_Fat_Pad()
    CORPORA_QUADRIGEMINA = _Corpora_Quadrigemina()
    PRE_BOTZINGER_COMPLEX = _Pre_Botzinger_Complex()
    PERITUBULAR_CAPILLARY = _Peritubular_Capillary()
    INNER_RENAL_MEDULLA_VASA_RECTA = _Inner_Renal_Medulla_Vasa_Recta()
    OUTER_RENAL_MEDULLA_VASA_RECTA = _Outer_Renal_Medulla_Vasa_Recta()
    MESANGIUM = _Mesangium()
    GLOMERULAR_MESANGIUM = _Glomerular_Mesangium()
    PAROTID_DUCT = _Parotid_Duct()
    SUBLINGUAL_DUCT = _Sublingual_Duct()
    SPINAL_CORD_INTERMEDIOLATERAL_NUCLEUS = _Spinal_Cord_Intermediolateral_Nucleus()
    MAMMARY_GLAND_ALVEOLUS = _Mammary_Gland_Alveolus()
    ALISPHENOID_BONE = _Alisphenoid_Bone()
    PROSTATE_DUCT = _Prostate_Duct()
    COCHLEAR_LABYRINTH = _Cochlear_Labyrinth()
    ZYGOMATIC_ARCH = _Zygomatic_Arch()
    TEMPORAL_BONE_ROUND_WINDOW = _Temporal_Bone_Round_Window()
    MANDIBLE_CONDYLAR_PROCESS = _Mandible_Condylar_Process()
    TRABECULAE_CARNEAE_CARDIAC_MUSCLE = _Trabeculae_Carneae_Cardiac_Muscle()
    TRACHEA_GLAND = _Trachea_Gland()
    DORSAL_STRIATUM = _Dorsal_Striatum()
    VENTRAL_STRIATUM = _Ventral_Striatum()
    EXORBITAL_LACRIMAL_GLAND = _Exorbital_Lacrimal_Gland()
    INTRAORBITAL_LACRIMAL_GLAND = _Intraorbital_Lacrimal_Gland()
    CARPAL_TARSAL_BONE = _Carpal_Tarsal_Bone()
    BONY_LABYRINTH = _Bony_Labyrinth()
    CARTILAGINOUS_JOINT = _Cartilaginous_Joint()
    PILOSEBACEOUS_GLAND = _Pilosebaceous_Gland()
    TRUNK_BONE = _Trunk_Bone()
    ACCESSORY_OLFACTORY_BULB_ANLAGE = _Accessory_Olfactory_Bulb_Anlage()
    ACCESSORY_OLFACTORY_BULB_ANLAGE_MITRAL_CELL_LAYER = _Accessory_Olfactory_Bulb_Anlage_Mitral_Cell_Layer()
    MAIN_OLFACTORY_BULB_VENTRICULAR_LAYER = _Main_Olfactory_Bulb_Ventricular_Layer()
    MAIN_OLFACTORY_BULB_PROSPECTIVE_GLOMERULAR_LAYER = _Main_Olfactory_Bulb_Prospective_Glomerular_Layer()
    VERTEBRAL_BODY = _Vertebral_Body()
    LEFT_KIDNEY = _Left_Kidney()
    RIGHT_KIDNEY = _Right_Kidney()
    ALIMENTARY_SYSTEM_MUCOSA = _Alimentary_System_Mucosa()
    ALIMENTARY_SYSTEM_LAMINA_PROPRIA = _Alimentary_System_Lamina_Propria()
    STOMACH_LAMINA_PROPRIA = _Stomach_Lamina_Propria()
    EYE_ANTERIOR_SEGMENT = _Eye_Anterior_Segment()
    EYE_POSTERIOR_SEGMENT = _Eye_Posterior_Segment()
    SENSORY_GANGLION = _Sensory_Ganglion()
    BARORECEPTOR = _Baroreceptor()
    LIMB_BLOOD_VESSEL = _Limb_Blood_Vessel()
    MAIN_OLFACTORY_BULB_PROSPECTIVE_GRANULE_CELL_LAYER = _Main_Olfactory_Bulb_Prospective_Granule_Cell_Layer()
    CORTICOSPINAL_TRACT = _Corticospinal_Tract()
    CEREBELLUM_PURKINJE_CELL_CLUSTER = _Cerebellum_Purkinje_Cell_Cluster()
    HYPOTHALAMUS_SUBVENTRICULAR_ZONE = _Hypothalamus_Subventricular_Zone()
    THALAMUS_SUBVENTRICULAR_ZONE = _Thalamus_Subventricular_Zone()
    ZONA_LIMITANS_INTRATHALAMICA = _Zona_Limitans_Intrathalamica()
    NERVE_FIBER_TRACT = _Nerve_Fiber_Tract()
    FASCICULUS_RETROFLEXUS = _Fasciculus_Retroflexus()
    STRIA_MEDULLARIS = _Stria_Medullaris()
    CHOROID_PLEXUS_EPITHELIUM = _Choroid_Plexus_Epithelium()
    CHOROID_PLEXUS_STROMA = _Choroid_Plexus_Stroma()
    HEAD_BLOOD_VESSEL = _Head_Blood_Vessel()
    CORNEA_BLOOD_VESSEL = _Cornea_Blood_Vessel()
    SPIRAL_ARTERY = _Spiral_Artery()
    VENOUS_SYSTEM_SMOOTH_MUSCLE = _Venous_System_Smooth_Muscle()
    VERTEBRAL_NEURAL_ARCH = _Vertebral_Neural_Arch()
    INTRAMEMBRANOUS_BONE = _Intramembranous_Bone()
    PRESPHENOID_BONE = _Presphenoid_Bone()
    PTERYGOID_BONE = _Pterygoid_Bone()
    SUPRAOCCIPITAL_BONE = _Supraoccipital_Bone()
    PALATINE_BONE = _Palatine_Bone()
    SESAMOID_BONE = _Sesamoid_Bone()
    ULNAR_SESAMOID_BONE = _Ulnar_Sesamoid_Bone()
    NUCLEUS_PREPOSITUS = _Nucleus_Prepositus()
    LOWER_BACK = _Lower_Back()
    LOWER_BACK_NERVE = _Lower_Back_Nerve()
    SAPHENOUS_NERVE = _Saphenous_Nerve()
    GENIOHYOID = _Geniohyoid()
    LEVATOR_AURIS_LONGUS = _Levator_Auris_Longus()
    PERINEUM = _Perineum()
    PERINEAL_MUSCLE = _Perineal_Muscle()
    SMOOTH_MUSCLE_OF_URETHRA = _Smooth_Muscle_Of_Urethra()
    PUDENDUM_OF_FEMALE = _Pudendum_Of_Female()
    CORPUS_CAVERNOSUM_OF_PENIS = _Corpus_Cavernosum_Of_Penis()
    THORACIC_MAMMARY_GLAND = _Thoracic_Mammary_Gland()
    MAMMARY_GLAND_LOBULE = _Mammary_Gland_Lobule()
    LEFT_LUNG_RESPIRATORY_BRONCHIOLE = _Left_Lung_Respiratory_Bronchiole()
    LEFT_LUNG_TERMINAL_BRONCHIOLE = _Left_Lung_Terminal_Bronchiole()
    RIGHT_LUNG_RESPIRATORY_BRONCHIOLE = _Right_Lung_Respiratory_Bronchiole()
    RIGHT_LUNG_TERMINAL_BRONCHIOLE = _Right_Lung_Terminal_Bronchiole()
    AWL_HAIR = _Awl_Hair()
    ZIGZAG_HAIR = _Zigzag_Hair()
    RENAL_LYMPHATIC = _Renal_Lymphatic()
    PONTINE_RETICULAR_NUCLEUS = _Pontine_Reticular_Nucleus()
    LATERAL_VESTIBULAR_NUCLEUS = _Lateral_Vestibular_Nucleus()
    CARDIAC_GANGLION = _Cardiac_Ganglion()
    CARDIAC_FIBROUS_SKELETON = _Cardiac_Fibrous_Skeleton()
    CARDIAC_INTERSTITIUM = _Cardiac_Interstitium()
    PROSOMERE_1 = _Prosomere_1()
    PROSOMERE_2 = _Prosomere_2()
    PROSOMERE_3 = _Prosomere_3()
    SPLEEN_MARGINAL_ZONE = _Spleen_Marginal_Zone()
    EYELID_MUSCLE = _Eyelid_Muscle()
    LEVATOR_PALPEBRAE_SUPERIORIS = _Levator_Palpebrae_Superioris()
    PRIMORDIAL_GERM_CELL_OF_EXTRAEMBRYONIC_MESODERM = _Primordial_Germ_Cell_Of_Extraembryonic_Mesoderm()
    VENTRAL_LATERAL_THALAMIC_NUCLEUS = _Ventral_Lateral_Thalamic_Nucleus()
    PREOPTIC_AREA = _Preoptic_Area()
    LATERAL_PREOPTIC_NUCLEUS = _Lateral_Preoptic_Nucleus()
    FACE_SKIN = _Face_Skin()
    HEAD_SKIN = _Head_Skin()
    BASAL_MAGNOCELLULAR_COMPLEX = _Basal_Magnocellular_Complex()
    ANTERIOR_ENTOPEDUNCULAR_AREA = _Anterior_Entopeduncular_Area()
    VOMERONASAL_BRANCH_OF_OLFACTORY_I_NERVE = _Vomeronasal_Branch_Of_Olfactory_I_Nerve()
    VOMERONASAL_ORGAN_SENSORY_EPITHELIUM = _Vomeronasal_Organ_Sensory_Epithelium()
    VOMERONASAL_ORGAN_NON_SENSORY_EPITHELIUM = _Vomeronasal_Organ_Non_Sensory_Epithelium()
    VOMERONASAL_ORGAN_VASCULAR_PUMP_ANLAGE = _Vomeronasal_Organ_Vascular_Pump_Anlage()
    VOMERONASAL_ORGAN_VASCULAR_PUMP = _Vomeronasal_Organ_Vascular_Pump()
    VOMERONASAL_ORGAN_GLANDULAR_TISSUE = _Vomeronasal_Organ_Glandular_Tissue()
    RIB_CAGE = _Rib_Cage()
    GONADAL_FAT_PAD = _Gonadal_Fat_Pad()
    MESENTERIC_ADIPOSE_TISSUE = _Mesenteric_Adipose_Tissue()
    LOWER_URINARY_TRACT = _Lower_Urinary_Tract()
    FOLLICLE_CELL_OF_ANTRAL_FOLLICLE = _Follicle_Cell_Of_Antral_Follicle()
    RHOMBIC_LIP = _Rhombic_Lip()
    UPPER_RHOMBIC_LIP = _Upper_Rhombic_Lip()
    LOWER_RHOMBIC_LIP = _Lower_Rhombic_Lip()
    PROSOMERE = _Prosomere()
    CERVICAL_DORSAL_ROOT_GANGLION = _Cervical_Dorsal_Root_Ganglion()
    THORACIC_DORSAL_ROOT_GANGLION = _Thoracic_Dorsal_Root_Ganglion()
    LUMBAR_DORSAL_ROOT_GANGLION = _Lumbar_Dorsal_Root_Ganglion()
    SACRAL_DORSAL_ROOT_GANGLION = _Sacral_Dorsal_Root_Ganglion()
    PROAMNIOTIC_CANAL = _Proamniotic_Canal()
    ACROMIO_CLAVICULAR_JOINT = _Acromio_Clavicular_Joint()
    STERNO_COSTAL_JOINT = _Sterno_Costal_Joint()
    MESENCEPHALIC_VENOUS_PLEXUS = _Mesencephalic_Venous_Plexus()
    PTERYGOID_VENOUS_PLEXUS = _Pterygoid_Venous_Plexus()
    BRACHIAL_ARTERY = _Brachial_Artery()
    INFERIOR_ALVEOLAR_ARTERY = _Inferior_Alveolar_Artery()
    LATERAL_CAUDAL_ARTERY = _Lateral_Caudal_Artery()
    SUPERIOR_VESICAL_ARTERY = _Superior_Vesical_Artery()
    ADRENAL_VEIN = _Adrenal_Vein()
    OCCIPITAL_VEIN = _Occipital_Vein()
    SUPERIOR_ANASTOMOTIC_VEIN = _Superior_Anastomotic_Vein()
    MULTIFIDUS = _Multifidus()
    PHARYNGEAL_RAPHE = _Pharyngeal_Raphe()
    QUADRICEPS_TENDON = _Quadriceps_Tendon()
    INTESTINE_LAMINA_PROPRIA = _Intestine_Lamina_Propria()
    LARGE_INTESTINE_LAMINA_PROPRIA = _Large_Intestine_Lamina_Propria()
    OLFACTORY_MIGRATORY_MASS = _Olfactory_Migratory_Mass()
    NERVE_TO_SOLEUS = _Nerve_To_Soleus()
    PRIMORDIAL_GERM_CELL = _Primordial_Germ_Cell()
    SYNOVIAL_JOINT = _Synovial_Joint()
    PRIMORDIAL_GERM_CELL_OF_BASE_OF_ALLANTOIS = _Primordial_Germ_Cell_Of_Base_Of_Allantois()
    PRIMITIVE_HINDGUT = _Primitive_Hindgut()
    PRIMORDIAL_GERM_CELL_OF_DORSAL_MESENTERY = _Primordial_Germ_Cell_Of_Dorsal_Mesentery()
    MYSTACIAL_PAD = _Mystacial_Pad()
    HEAD_SURFACE_ECTODERM = _Head_Surface_Ectoderm()
    TRUNK_SURFACE_ECTODERM = _Trunk_Surface_Ectoderm()
    HEART_VALVE_PRIMORDIUM = _Heart_Valve_Primordium()
    ATRIOVENTRICULAR_VALVE_PRIMORDIUM = _Atrioventricular_Valve_Primordium()
    SEMILUNAR_VALVE_PRIMORDIUM = _Semilunar_Valve_Primordium()
    OUTFLOW_TRACT_ENDOCARDIAL_CUSHION = _Outflow_Tract_Endocardial_Cushion()
    PRIMITIVE_MENINGES = _Primitive_Meninges()
    LEPTOMENINGES = _Leptomeninges()
    METENCEPHALON_MARGINAL_LAYER = _Metencephalon_Marginal_Layer()
    MYELENCEPHALON_MARGINAL_LAYER = _Myelencephalon_Marginal_Layer()
    METENCEPHALON_MANTLE_LAYER = _Metencephalon_Mantle_Layer()
    TELENCEPHALON_SUBVENTRICULAR_ZONE = _Telencephalon_Subventricular_Zone()
    DIENCEPHALON_SUBVENTRICULAR_ZONE = _Diencephalon_Subventricular_Zone()
    SPINAL_NERVE_DORSAL_ROOT = _Spinal_Nerve_Dorsal_Root()
    SPINAL_CORD_MIXED_SPINAL_NERVE = _Spinal_Cord_Mixed_Spinal_Nerve()
    SPINAL_NERVE_VENTRAL_ROOT = _Spinal_Nerve_Ventral_Root()
    TRABECULAR_MYOCARDIUM = _Trabecular_Myocardium()
    COMPACT_MYOCARDIUM = _Compact_Myocardium()
    HEART_PAPILLARY_MUSCLE = _Heart_Papillary_Muscle()
    ATRIOVENTRICULAR_CANAL_ENDOCARDIAL_LINING = _Atrioventricular_Canal_Endocardial_Lining()
    SUPERIOR_ATRIOVENTRICULAR_ENDOCARDIAL_CUSHION = _Superior_Atrioventricular_Endocardial_Cushion()
    INFERIOR_ATRIOVENTRICULAR_ENDOCARDIAL_CUSHION = _Inferior_Atrioventricular_Endocardial_Cushion()
    HEART_ENDOTHELIUM = _Heart_Endothelium()
    OUTFLOW_TRACT_ENDOTHELIUM = _Outflow_Tract_Endothelium()
    VASCULATURE = _Vasculature()
    SECONDARY_HEART_FIELD = _Secondary_Heart_Field()
    SOMATOSENSORY_CORTEX = _Somatosensory_Cortex()
    PREFRONTAL_CORTEX = _Prefrontal_Cortex()
    ORBITOFRONTAL_CORTEX = _Orbitofrontal_Cortex()
    CA1_STRATUM_RADIATUM = _Ca1_Stratum_Radiatum()
    CONJUNCTIVA_EPITHELIUM = _Conjunctiva_Epithelium()
    FAST_MUSCLE_TISSUE = _Fast_Muscle_Tissue()
    SLOW_MUSCLE_TISSUE = _Slow_Muscle_Tissue()
    JAW_PRIMORDIUM_EPITHELIUM = _Jaw_Primordium_Epithelium()
    DENTAL_PLACODE = _Dental_Placode()
    TOOTH_BUD = _Tooth_Bud()
    CAP_STAGE_TOOTH = _Cap_Stage_Tooth()
    BELL_STAGE_TOOTH = _Bell_Stage_Tooth()
    EARLY_BELL_STAGE_TOOTH = _Early_Bell_Stage_Tooth()
    MID_BELL_STAGE_TOOTH = _Mid_Bell_Stage_Tooth()
    LATE_BELL_STAGE_TOOTH = _Late_Bell_Stage_Tooth()
    LAMINA_PROPRIA = _Lamina_Propria()
    IRIDOCORNEAL_ANGLE = _Iridocorneal_Angle()
    EYE_TRABECULAR_MESHWORK = _Eye_Trabecular_Meshwork()
    PRE_PLACODAL_REGION = _Pre_Placodal_Region()
    ECTODERMAL_PLACODE = _Ectodermal_Placode()
    CRANIAL_PLACODE = _Cranial_Placode()
    OPTIC_PLACODE = _Optic_Placode()
    ADENOHYPOPHYSEAL_PLACODE = _Adenohypophyseal_Placode()
    NEUROGENIC_PLACODE = _Neurogenic_Placode()
    TRIGEMINAL_PLACODE = _Trigeminal_Placode()
    EPIBRANCHIAL_PLACODE = _Epibranchial_Placode()
    GENICULATE_PLACODE = _Geniculate_Placode()
    PETROSAL_PLACODE = _Petrosal_Placode()
    NODOSE_PLACODE = _Nodose_Placode()
    NON_NEUROGENIC_PLACODE = _Non_Neurogenic_Placode()
    TONGUE_PAPILLARY_PLACODE = _Tongue_Papillary_Placode()
    INTEGUMENTAL_SYSTEM_PLACODE = _Integumental_System_Placode()
    VIBRISSA_PLACODE = _Vibrissa_Placode()
    OTIC_PRE_PLACODE = _Otic_Pre_Placode()
    ANTERIOR_PITUITARY_PRE_PLACODE = _Anterior_Pituitary_Pre_Placode()
    LENS_PRE_PLACODE = _Lens_Pre_Placode()
    EXTRAHEPATIC_BILE_DUCT = _Extrahepatic_Bile_Duct()
    INTRAHEPATIC_BILE_DUCT = _Intrahepatic_Bile_Duct()
    VENTRAL_COCHLEAR_NUCLEUS = _Ventral_Cochlear_Nucleus()
    STOMACH_MUSCULARIS_EXTERNA = _Stomach_Muscularis_Externa()
    AMNIOTIC_FLUID = _Amniotic_Fluid()
    RETROSPLENIAL_CORTEX = _Retrosplenial_Cortex()
    ATRIOVENTRICULAR_CANAL_CARDIAC_MUSCLE = _Atrioventricular_Canal_Cardiac_Muscle()
    HYPOTHALAMUS_PERIVENTRICULAR_REGION = _Hypothalamus_Periventricular_Region()
    HYPOTHALAMUS_SUBPARAVENTRICULAR_ZONE = _Hypothalamus_Subparaventricular_Zone()
    BRAIN_ROOF_PLATE = _Brain_Roof_Plate()
    CEREBELLUM_GRAY_MATTER = _Cerebellum_Gray_Matter()
    MAMMILLARY_AREA = _Mammillary_Area()
    CUNEATE_FASCICULUS = _Cuneate_Fasciculus()
    GRACILE_FASCICULUS = _Gracile_Fasciculus()
    SPINAL_CORD_LAMINA = _Spinal_Cord_Lamina()
    ABDOMEN_ORGAN = _Abdomen_Organ()
    ADRENAL_GLAND_CAPSULE = _Adrenal_Gland_Capsule()
    ADRENAL_GLAND_X_ZONE = _Adrenal_Gland_X_Zone()
    AFFERENT_LYMPHATIC_VESSEL = _Afferent_Lymphatic_Vessel()
    EFFERENT_LYMPHATIC_VESSEL = _Efferent_Lymphatic_Vessel()
    ANTERIOR_BUCCAL_GLAND = _Anterior_Buccal_Gland()
    ANTERIOR_LINGUAL_GLAND = _Anterior_Lingual_Gland()
    MAJOR_SALIVARY_GLAND = _Major_Salivary_Gland()
    CORNEA_ANTERIOR_LIMITING_LAMINA = _Cornea_Anterior_Limiting_Lamina()
    ANUS = _Anus()
    AORTA_ELASTIC_TISSUE = _Aorta_Elastic_Tissue()
    HEART_APEX = _Heart_Apex()
    AREOLA = _Areola()
    CERVICAL_MAMMARY_GLAND = _Cervical_Mammary_Gland()
    INGUINAL_MAMMARY_GLAND = _Inguinal_Mammary_Gland()
    AXILLARY_LYMPH_NODE = _Axillary_Lymph_Node()
    AURICULAR_LYMPH_NODE = _Auricular_Lymph_Node()
    BRACHIAL_LYMPH_NODE = _Brachial_Lymph_Node()
    BRONCHIAL_LYMPH_NODE = _Bronchial_Lymph_Node()
    CELIAC_LYMPH_NODE = _Celiac_Lymph_Node()
    CERVICAL_LYMPH_NODE = _Cervical_Lymph_Node()
    GASTRIC_LYMPH_NODE = _Gastric_Lymph_Node()
    HEPATIC_LYMPH_NODE = _Hepatic_Lymph_Node()
    ILEOCOLIC_LYMPH_NODE = _Ileocolic_Lymph_Node()
    ILIAC_LYMPH_NODE = _Iliac_Lymph_Node()
    LUMBAR_LYMPH_NODE = _Lumbar_Lymph_Node()
    MANDIBULAR_LYMPH_NODE = _Mandibular_Lymph_Node()
    PANCREATIC_LYMPH_NODE = _Pancreatic_Lymph_Node()
    PARAAORTIC_LYMPH_NODE = _Paraaortic_Lymph_Node()
    PAROTID_LYMPH_NODE = _Parotid_Lymph_Node()
    POPLITEAL_LYMPH_NODE = _Popliteal_Lymph_Node()
    RENAL_LYMPH_NODE = _Renal_Lymph_Node()
    SACRAL_LYMPH_NODE = _Sacral_Lymph_Node()
    SCIATIC_LYMPH_NODE = _Sciatic_Lymph_Node()
    SPLENIC_LYMPH_NODE = _Splenic_Lymph_Node()
    SUBCUTANEOUS_LYMPH_NODE = _Subcutaneous_Lymph_Node()
    SUBMANDIBULAR_LYMPH_NODE = _Submandibular_Lymph_Node()
    THYMIC_LYMPH_NODE = _Thymic_Lymph_Node()
    TRACHEOBRONCHIAL_LYMPH_NODE = _Tracheobronchial_Lymph_Node()
    LYMPH_NODE_TRABECULUM = _Lymph_Node_Trabeculum()
    LYMPH_NODE_B_CELL_DOMAIN = _Lymph_Node_B_Cell_Domain()
    LYMPHOID_TISSUE = _Lymphoid_Tissue()
    BRONCHUS_ASSOCIATED_LYMPHOID_TISSUE = _Bronchus_Associated_Lymphoid_Tissue()
    GUT_ASSOCIATED_LYMPHOID_TISSUE = _Gut_Associated_Lymphoid_Tissue()
    MUCOSA_ASSOCIATED_LYMPHOID_TISSUE = _Mucosa_Associated_Lymphoid_Tissue()
    NASAL_ASSOCIATED_LYMPHOID_TISSUE = _Nasal_Associated_Lymphoid_Tissue()
    OROPHARYNGEAL_LYMPHOID_TISSUE = _Oropharyngeal_Lymphoid_Tissue()
    BASICRANIUM = _Basicranium()
    ALIMENTARY_SYSTEM_FLUID_OR_SECRETION = _Alimentary_System_Fluid_Or_Secretion()
    ESOPHAGUS_SECRETION = _Esophagus_Secretion()
    STOMACH_SECRETION = _Stomach_Secretion()
    INTESTINE_SECRETION = _Intestine_Secretion()
    PANCREAS_SECRETION = _Pancreas_Secretion()
    ENDOCRINE_PANCREAS_SECRETION = _Endocrine_Pancreas_Secretion()
    EXOCRINE_PANCREAS_SECRETION = _Exocrine_Pancreas_Secretion()
    BILE = _Bile()
    BILE_DUCT_EPITHELIUM = _Bile_Duct_Epithelium()
    EXTRAHEPATIC_BILE_DUCT_EPITHELIUM = _Extrahepatic_Bile_Duct_Epithelium()
    INTRAHEPATIC_BILE_DUCT_EPITHELIUM = _Intrahepatic_Bile_Duct_Epithelium()
    INTERLOBULAR_BILE_DUCT = _Interlobular_Bile_Duct()
    INTRALOBULAR_BILE_DUCT = _Intralobular_Bile_Duct()
    BONE_MARROW_CAVITY = _Bone_Marrow_Cavity()
    CEREBELLUM_ANTERIOR_VERMIS = _Cerebellum_Anterior_Vermis()
    CEREBELLUM_POSTERIOR_VERMIS = _Cerebellum_Posterior_Vermis()
    CEREBELLUM_LOBULE = _Cerebellum_Lobule()
    CEREBELLUM_HEMISPHERE_LOBULE = _Cerebellum_Hemisphere_Lobule()
    FLOCCULONODULAR_LOBE = _Flocculonodular_Lobe()
    CEREBROSPINAL_FLUID = _Cerebrospinal_Fluid()
    CERUMEN = _Cerumen()
    FECES = _Feces()
    FEMALE_REPRODUCTIVE_SYSTEM_FLUID_OR_SECRETION = _Female_Reproductive_System_Fluid_Or_Secretion()
    OVARY_FOLLICLE_FLUID = _Ovary_Follicle_Fluid()
    LYMPH = _Lymph()
    OCULAR_REFRACTIVE_MEDIA = _Ocular_Refractive_Media()
    PERICARDIAL_FLUID = _Pericardial_Fluid()
    PLEURAL_FLUID = _Pleural_Fluid()
    SKIN_FLUID_OR_SECRETION = _Skin_Fluid_Or_Secretion()
    SEBUM = _Sebum()
    SWEAT = _Sweat()
    SYNOVIAL_FLUID = _Synovial_Fluid()
    C1_VERTEBRA_VENTRAL_TUBERCLE = _C1_Vertebra_Ventral_Tubercle()
    CERVIX_UTERI_SQUAMOUS_EPITHELIUM = _Cervix_Uteri_Squamous_Epithelium()
    THORACIC_BODY_WALL = _Thoracic_Body_Wall()
    CILIATED_COLUMNAR_OVIDUCT_EPITHELIUM = _Ciliated_Columnar_Oviduct_Epithelium()
    CUBOIDAL_OVIDUCT_EPITHELIUM = _Cuboidal_Oviduct_Epithelium()
    CRANIOCERVICAL_REGION = _Craniocervical_Region()
    CRISTA_AMPULLARIS_NEUROEPITHELIUM = _Crista_Ampullaris_Neuroepithelium()
    DENTATE_NUCLEUS = _Dentate_Nucleus()
    FASTIGIAL_NUCLEUS = _Fastigial_Nucleus()
    DERMIS_ADIPOSE_TISSUE = _Dermis_Adipose_Tissue()
    HOLOCRINE_GLAND = _Holocrine_Gland()
    MEROCRINE_GLAND = _Merocrine_Gland()
    ECCRINE_SWEAT_GLAND = _Eccrine_Sweat_Gland()
    ELASTIC_CARTILAGE = _Elastic_Cartilage()
    ETHMOID_SINUS = _Ethmoid_Sinus()
    FRONTAL_SINUS = _Frontal_Sinus()
    MAXILLARY_SINUS = _Maxillary_Sinus()
    SPHENOID_SINUS = _Sphenoid_Sinus()
    EYELASH = _Eyelash()
    FIBROCARTILAGE = _Fibrocartilage()
    FONTANEL = _Fontanel()
    GLOMERULAR_CAPILLARY_ENDOTHELIUM = _Glomerular_Capillary_Endothelium()
    GLOTTIS = _Glottis()
    GUSTATORY_SYSTEM = _Gustatory_System()
    ELASTIC_TISSUE = _Elastic_Tissue()
    CARDIOVASCULAR_SYSTEM_ELASTIC_TISSUE = _Cardiovascular_System_Elastic_Tissue()
    HEART_ELASTIC_TISSUE = _Heart_Elastic_Tissue()
    RESPIRATORY_SYSTEM_ELASTIC_TISSUE = _Respiratory_System_Elastic_Tissue()
    BRONCHUS_ELASTIC_TISSUE = _Bronchus_Elastic_Tissue()
    LUNG_ELASTIC_TISSUE = _Lung_Elastic_Tissue()
    TRACHEA_ELASTIC_TISSUE = _Trachea_Elastic_Tissue()
    HEART_VENTRICLE_WALL = _Heart_Ventricle_Wall()
    HELIX = _Helix()
    HEPATIC_PORTAL_VEIN = _Hepatic_Portal_Vein()
    IMMUNE_SYSTEM = _Immune_System()
    INFERIOR_CEREBELLAR_PEDUNCLE = _Inferior_Cerebellar_Peduncle()
    MIDDLE_CEREBELLAR_PEDUNCLE = _Middle_Cerebellar_Peduncle()
    SUPERIOR_CEREBELLAR_PEDUNCLE = _Superior_Cerebellar_Peduncle()
    HAIR_FOLLICLE_INFUNDIBULUM = _Hair_Follicle_Infundibulum()
    AXILLARY_FAT_PAD = _Axillary_Fat_Pad()
    INTERSCAPULAR_FAT_PAD = _Interscapular_Fat_Pad()
    MEDIASTINAL_FAT_PAD = _Mediastinal_Fat_Pad()
    OMENTAL_FAT_PAD = _Omental_Fat_Pad()
    PANCREATIC_FAT_PAD = _Pancreatic_Fat_Pad()
    PARAMETRIAL_FAT_PAD = _Parametrial_Fat_Pad()
    PERIOVARIAN_FAT_PAD = _Periovarian_Fat_Pad()
    RENAL_FAT_PAD = _Renal_Fat_Pad()
    RETROPERITONEAL_FAT_PAD = _Retroperitoneal_Fat_Pad()
    JOINT_OF__RIB = _Joint_Of_Rib()
    INTERCHONDRAL_JOINT = _Interchondral_Joint()
    JOINT_OF_VERTEBRAL_ARCH = _Joint_Of_Vertebral_Arch()
    INTERVERTEBRAL_JOINT = _Intervertebral_Joint()
    JOINT_OF_GIRDLE = _Joint_Of_Girdle()
    RENAL_PYRAMID = _Renal_Pyramid()
    LABIUM_MAJORUM = _Labium_Majorum()
    LABIUM_MINORUM = _Labium_Minorum()
    LACRIMAL_BONE = _Lacrimal_Bone()
    LACRIMAL_SAC = _Lacrimal_Sac()
    OCULOMOTOR_MUSCLE = _Oculomotor_Muscle()
    RECTUS_EXTRAOCULAR_MUSCLE = _Rectus_Extraocular_Muscle()
    INFERIOR_RECTUS_EXTRAOCULAR_MUSCLE = _Inferior_Rectus_Extraocular_Muscle()
    LATERAL_RECTUS_EXTRAOCULAR_MUSCLE = _Lateral_Rectus_Extraocular_Muscle()
    MEDIAL_RECTUS_EXTRAOCULAR_MUSCLE = _Medial_Rectus_Extraocular_Muscle()
    SUPERIOR_RECTUS_EXTRAOCULAR_MUSCLE = _Superior_Rectus_Extraocular_Muscle()
    OBLIQUE_EXTRAOCULAR_MUSCLE = _Oblique_Extraocular_Muscle()
    INFERIOR_OBLIQUE_EXTRAOCULAR_MUSCLE = _Inferior_Oblique_Extraocular_Muscle()
    SUPERIOR_OBLIQUE_EXTRAOCULAR_MUSCLE = _Superior_Oblique_Extraocular_Muscle()
    LINGUAL_TONSIL = _Lingual_Tonsil()
    PHARYNGEAL_TONSIL = _Pharyngeal_Tonsil()
    TONSIL_CAPSULE = _Tonsil_Capsule()
    TONSIL_CRYPT = _Tonsil_Crypt()
    LIVER_PERISINUSOIDAL_SPACE = _Liver_Perisinusoidal_Space()
    PINNA_LOBULE = _Pinna_Lobule()
    MEMBRANOUS_URETHRA_OF_MALE = _Membranous_Urethra_Of_Male()
    MALE_REPRODUCTIVE_GLAND_OR_ORGAN = _Male_Reproductive_Gland_Or_Organ()
    MALLEUS_MANUBRIUM = _Malleus_Manubrium()
    MALLEUS_PROCESSUS_BREVIS = _Malleus_Processus_Brevis()
    MALLEUS_HEAD = _Malleus_Head()
    MALLEUS_NECK = _Malleus_Neck()
    MANDIBLE_ANGULAR_PROCESS = _Mandible_Angular_Process()
    MANDIBLE_HEAD = _Mandible_Head()
    MANDIBLE_NECK = _Mandible_Neck()
    MANDIBLE_CORONOID_PROCESS = _Mandible_Coronoid_Process()
    MANDIBLE_TEMPORAL_CREST = _Mandible_Temporal_Crest()
    MANDIBLE_SYMPHYSIS = _Mandible_Symphysis()
    MANDIBLE_PETROUS_PART = _Mandible_Petrous_Part()
    MANDIBLE_SQUAMOUS_PART = _Mandible_Squamous_Part()
    MANDIBLE_ALVEOLAR_PROCESS = _Mandible_Alveolar_Process()
    MAXILLA_ALVEOLAR_PROCESS = _Maxilla_Alveolar_Process()
    MASTICATORY_MUSCLE = _Masticatory_Muscle()
    METAPODIAL_PAD = _Metapodial_Pad()
    NASAL_BRIDGE = _Nasal_Bridge()
    NEUROENDOCRINE_GLAND = _Neuroendocrine_Gland()
    ORBIT_OF_SKULL = _Orbit_Of_Skull()
    OSSEUS_LABYRINTH_VESTIBULE = _Osseus_Labyrinth_Vestibule()
    VESTIBULAR_AQUEDUCT = _Vestibular_Aqueduct()
    OSSEUS_SEMICIRCULAR_CANAL = _Osseus_Semicircular_Canal()
    MEMBRANOUS_LABYRINTH = _Membranous_Labyrinth()
    VESTIBULAR_LABYRINTH = _Vestibular_Labyrinth()
    OTOLITHIC_MEMBRANE = _Otolithic_Membrane()
    OTOLITH_ORGAN = _Otolith_Organ()
    BULBAR_CONJUNCTIVA = _Bulbar_Conjunctiva()
    PALPEBRAL_CONJUNCTIVA = _Palpebral_Conjunctiva()
    PALPEBRAL_FISSURE = _Palpebral_Fissure()
    HEART_VENTRICLE_PAPILLARY_MUSCLE = _Heart_Ventricle_Papillary_Muscle()
    VERTEBRAL_PEDICLE = _Vertebral_Pedicle()
    PELVIC_LIGAMENT = _Pelvic_Ligament()
    PERIORBITAL_REGION = _Periorbital_Region()
    PEYER_S_PATCH_FOLLICLE = _Peyer_S_Patch_Follicle()
    PLACENTA_METRIAL_GLAND = _Placenta_Metrial_Gland()
    PONTINE_RAPHE_NUCLEUS = _Pontine_Raphe_Nucleus()
    PORTAL_LOBULE = _Portal_Lobule()
    PORTAL_TRIAD = _Portal_Triad()
    EYE_POSTERIOR_CHAMBER = _Eye_Posterior_Chamber()
    PUPILLARY_MEMBRANE = _Pupillary_Membrane()
    PUPIL = _Pupil()
    PARAVERTEBRAL_GANGLION = _Paravertebral_Ganglion()
    PREVERTEBRAL_GANGLION = _Prevertebral_Ganglion()
    MESENTERIC_GANGLION = _Mesenteric_Ganglion()
    INFERIOR_MESENTERIC_GANGLION = _Inferior_Mesenteric_Ganglion()
    SUPERIOR_MESENTERIC_GANGLION = _Superior_Mesenteric_Ganglion()
    RETROTRAPEZOID_NUCLEUS = _Retrotrapezoid_Nucleus()
    SEPTUM_PELLUCIDUM = _Septum_Pellucidum()
    REPRODUCTIVE_SYSTEM_GLAND = _Reproductive_System_Gland()
    SHOULDER_BONE = _Shoulder_Bone()
    SOMATIC_NERVOUS_SYSTEM = _Somatic_Nervous_System()
    SPHENOID_BONE_PTERYGOID_PROCESS = _Sphenoid_Bone_Pterygoid_Process()
    SPINAL_CORD_DORSAL_COLUMN = _Spinal_Cord_Dorsal_Column()
    SPINAL_CORD_LATERAL_COLUMN = _Spinal_Cord_Lateral_Column()
    SPINAL_CORD_LATERAL_MOTOR_COLUMN = _Spinal_Cord_Lateral_Motor_Column()
    SPINAL_CORD_MEDIAL_MOTOR_COLUMN = _Spinal_Cord_Medial_Motor_Column()
    SPINAL_CORD_MOTOR_COLUMN = _Spinal_Cord_Motor_Column()
    SPINAL_CORD_VENTRAL_COLUMN = _Spinal_Cord_Ventral_Column()
    SPIRAL_MODIOLAR_ARTERY = _Spiral_Modiolar_Artery()
    SPLEEN_CENTRAL_ARTERIOLE = _Spleen_Central_Arteriole()
    SPLEEN_MARGINAL_SINUS = _Spleen_Marginal_Sinus()
    SPLEEN_TRABECULAR_ARTERY = _Spleen_Trabecular_Artery()
    SPLEEN_TRABECULAR_VEIN = _Spleen_Trabecular_Vein()
    STAPES_BASE = _Stapes_Base()
    STOMACH_SMOOTH_MUSCLE_CIRCULAR_LAYER = _Stomach_Smooth_Muscle_Circular_Layer()
    DUVET_HAIR = _Duvet_Hair()
    NONSKELETAL_LIGAMENT = _Nonskeletal_Ligament()
    SKELETAL_LIGAMENT = _Skeletal_Ligament()
    STYLOHYOID_LIGAMENT = _Stylohyoid_Ligament()
    SUBLINGUAL_GANGLION = _Sublingual_Ganglion()
    SULCUS_AMPULLARIS = _Sulcus_Ampullaris()
    VESTIBULAR_GANGLION_SUPERIOR_PART = _Vestibular_Ganglion_Superior_Part()
    VESTIBULAR_GANGLION_INFERIOR_PART = _Vestibular_Ganglion_Inferior_Part()
    EYELID_TARSUS = _Eyelid_Tarsus()
    MEIBOMIAN_GLAND = _Meibomian_Gland()
    OVARY_THECA_EXTERNA = _Ovary_Theca_Externa()
    OVARY_THECA_INTERNA = _Ovary_Theca_Interna()
    THYMUS_LOBULE = _Thymus_Lobule()
    THYMUS_SUBCAPSULAR_EPITHELIUM = _Thymus_Subcapsular_Epithelium()
    THYMUS_TRABECULA = _Thymus_Trabecula()
    TONGUE_SQUAMOUS_EPITTHELIUM = _Tongue_Squamous_Epitthelium()
    TONGUE_KERATINIZED_EPITHELIUM = _Tongue_Keratinized_Epithelium()
    TONGUE_TASTE_BUD = _Tongue_Taste_Bud()
    TOOTH_CAVITY = _Tooth_Cavity()
    VERTEBRA_TRANSVERSE_PROCESS = _Vertebra_Transverse_Process()
    TROCHANTER_OF_FEMUR = _Trochanter_Of_Femur()
    UTERINE_ARTERY = _Uterine_Artery()
    VENOUS_SINUS = _Venous_Sinus()
    VERTEBRA_LAMINA = _Vertebra_Lamina()
    VITREOUS_BODY = _Vitreous_Body()
    VOMER_BONE = _Vomer_Bone()
    _4TH_VENTRICLE_APERTURE = _4Th_Ventricle_Aperture()
    _4TH_VENTRICLE_LATERAL_APERTURE = _4Th_Ventricle_Lateral_Aperture()
    _4TH_VENTRICLE_MEDIAN_APERTURE = _4Th_Ventricle_Median_Aperture()
    LIMB_SEGMENT = _Limb_Segment()
    STYLOPOD = _Stylopod()
    ZEUGOPOD = _Zeugopod()
    HYPOPHARYNX = _Hypopharynx()
    OVARIAN_BURSA = _Ovarian_Bursa()
    PANCREAS_VASCULATURE = _Pancreas_Vasculature()
    _4TH_VENTRICLE_CHOROID_PLEXUS_EPITHELIUM = _4Th_Ventricle_Choroid_Plexus_Epithelium()
    _4TH_VENTRICLE_CHOROID_PLEXUS_STROMA = _4Th_Ventricle_Choroid_Plexus_Stroma()
    LATERAL_VENTRICLE_CHOROID_PLEXUS_EPITHELIUM = _Lateral_Ventricle_Choroid_Plexus_Epithelium()
    LATERAL_VENTRICLE_CHOROID_PLEXUS_STROMA = _Lateral_Ventricle_Choroid_Plexus_Stroma()
    ABDOMEN_BLOOD_VESSEL = _Abdomen_Blood_Vessel()
    ABDOMEN_CONNECTIVE_TISSUE = _Abdomen_Connective_Tissue()
    ABDOMEN_NERVE = _Abdomen_Nerve()
    ABDOMEN_SKIN = _Abdomen_Skin()
    TAIL_DERMIS = _Tail_Dermis()
    TAIL_EPIDERMIS = _Tail_Epidermis()
    SPINAL_CORD_REGION = _Spinal_Cord_Region()
    SPINAL_CORD_CERVICAL_REGION = _Spinal_Cord_Cervical_Region()
    SPINAL_CORD_THORACIC_REGION = _Spinal_Cord_Thoracic_Region()
    SPINAL_CORD_LUMBAR_REGION = _Spinal_Cord_Lumbar_Region()
    SPINAL_CORD_SACRAL_REGION = _Spinal_Cord_Sacral_Region()
    SPINAL_CORD_COCCYGEAL_REGION = _Spinal_Cord_Coccygeal_Region()
    UNSEGMENTED_MESENCHYME = _Unsegmented_Mesenchyme()
    _3RD_VENTRICLE_CHOROID_PLEXUS_EPITHEILUM = _3Rd_Ventricle_Choroid_Plexus_Epitheilum()
    _3RD_VENTRICLE_CHOROID_PLEXUS_STROMA = _3Rd_Ventricle_Choroid_Plexus_Stroma()
    ABDOMINAL_SEGMENT_BLOOD_VESSEL = _Abdominal_Segment_Blood_Vessel()
    ABDOMINAL_SEGMENT_BONE = _Abdominal_Segment_Bone()
    ABDOMINAL_SEGMENT_CONNECTIVE_TISSUE = _Abdominal_Segment_Connective_Tissue()
    ABDOMINAL_SEGMENT_MUSCLE = _Abdominal_Segment_Muscle()
    ABDOMINAL_SEGMENT_NERVE = _Abdominal_Segment_Nerve()
    ABDOMINAL_SEGMENT_ORGAN = _Abdominal_Segment_Organ()
    ABDOMINAL_SEGMENT_SKIN = _Abdominal_Segment_Skin()
    ABDOMINAL_WALL = _Abdominal_Wall()
    ACCESSORY_HEPATIC_VEIN = _Accessory_Hepatic_Vein()
    CRANIAL_NERVE_NUCLEUS = _Cranial_Nerve_Nucleus()
    ACCESSORY_XI_NERVE_NUCLEUS = _Accessory_Xi_Nerve_Nucleus()
    ALIMENTARY_SYSTEM_MESENTERY = _Alimentary_System_Mesentery()
    ALVEOLAR_ARTERY = _Alveolar_Artery()
    ANTERIOR_INFERIOR_CEREBELLAR_ARTERY = _Anterior_Inferior_Cerebellar_Artery()
    ANTERIOR_TIBIAL_ARTERY = _Anterior_Tibial_Artery()
    AURICULAR_ARTERY = _Auricular_Artery()
    BUCCAL_ARTERY = _Buccal_Artery()
    CEREBELLAR_ARTERY = _Cerebellar_Artery()
    CERVICAL_ARTERY = _Cervical_Artery()
    DIGITAL_ARTERY = _Digital_Artery()
    DORSAL_ARTERY_OF_FOOT = _Dorsal_Artery_Of_Foot()
    DORSAL_INTERCOSTAL_ARTERY = _Dorsal_Intercostal_Artery()
    DORSAL_METACARPAL_ARTERY = _Dorsal_Metacarpal_Artery()
    DORSAL_PENIS_ARTERY = _Dorsal_Penis_Artery()
    ETHMOIDAL_ARTERY = _Ethmoidal_Artery()
    ILEOCOLIC_ARTERY = _Ileocolic_Artery()
    ILIAC_CIRCUMFLEX_ARTERY = _Iliac_Circumflex_Artery()
    ILIO_LUMBAR_ARTERY = _Ilio_Lumbar_Artery()
    INFERIOR_PANCREATICO_DUODENAL_ARTERY = _Inferior_Pancreatico_Duodenal_Artery()
    INFERIOR_RECTAL_ARTERY = _Inferior_Rectal_Artery()
    INFERIOR_SUPRARENAL_ARTERY = _Inferior_Suprarenal_Artery()
    INFERIOR_VESICAL_ARTERY = _Inferior_Vesical_Artery()
    INFRAORBITAL_ARTERY = _Infraorbital_Artery()
    INTRALOBAR_ARTERY = _Intralobar_Artery()
    LABIAL_ARTERY = _Labial_Artery()
    LABYRINTHINE_ARTERY = _Labyrinthine_Artery()
    LACRIMAL_ARTERY = _Lacrimal_Artery()
    LATERAL_THORACIC_ARTERY = _Lateral_Thoracic_Artery()
    LEFT_HEPATIC_ARTERY = _Left_Hepatic_Artery()
    LEFT_PULMONARY_ARTERY = _Left_Pulmonary_Artery()
    LEFT_RENAL_ARTERY = _Left_Renal_Artery()
    LEFT_SPERMATIC_ARTERY = _Left_Spermatic_Artery()
    LEFT_SUBCLAVIAN_ARTERY = _Left_Subclavian_Artery()
    MEDIAL_PLANTAR_ARTERY = _Medial_Plantar_Artery()
    MEDIAL_TARSAL_ARTERY = _Medial_Tarsal_Artery()
    MEDIAN_ARTERY = _Median_Artery()
    MENINGEAL_ARTERY = _Meningeal_Artery()
    MENTAL_ARTERY = _Mental_Artery()
    MIDDLE_COLIC_ARTERY = _Middle_Colic_Artery()
    PERINEAL_ARTERY = _Perineal_Artery()
    PHRENIC_ARTERY = _Phrenic_Artery()
    POPLITEAL_ARTERY = _Popliteal_Artery()
    POSTERIOR_TIBIAL_ARTERY = _Posterior_Tibial_Artery()
    PUDENDAL_ARTERY = _Pudendal_Artery()
    RADIAL_ARTERY = _Radial_Artery()
    RETINAL_ARTERY = _Retinal_Artery()
    SPERMATIC_ARTERY = _Spermatic_Artery()
    SUBLINGUAL_ARTERY = _Sublingual_Artery()
    SUBSCAPULAR_ARTERY = _Subscapular_Artery()
    SUPERFICIAL_CERVICAL_ARTERY = _Superficial_Cervical_Artery()
    SUPERIOR_TEMPORAL_ARTERY = _Superior_Temporal_Artery()
    SUPERIOR_EXTERNAL_PUDENDAL_ARTERY = _Superior_External_Pudendal_Artery()
    SUPERIOR_GLUTEAL_ARTERY = _Superior_Gluteal_Artery()
    SUPERIOR_PANCREATICO_DUODENAL_ARTERY = _Superior_Pancreatico_Duodenal_Artery()
    SUPERIOR_SUPRARENAL_ARTERY = _Superior_Suprarenal_Artery()
    SUPRARENAL_ARTERY = _Suprarenal_Artery()
    SURAL_ARTERY = _Sural_Artery()
    SYSTEMIC_ARTERY = _Systemic_Artery()
    TEMPORAL_ARTERY = _Temporal_Artery()
    THORACO_ACROMIAL_ARTERY = _Thoraco_Acromial_Artery()
    THORACODORSAL_ARTERY = _Thoracodorsal_Artery()
    TRANSVERSE_FACIAL_ARTERY = _Transverse_Facial_Artery()
    VESICAL_ARTERY = _Vesical_Artery()
    ANTERIOR_AURICULAR_VEIN = _Anterior_Auricular_Vein()
    ANTERIOR_FACIAL_VEIN = _Anterior_Facial_Vein()
    ANTERIOR_JUGULAR_VEIN = _Anterior_Jugular_Vein()
    ANTERIOR_TIBIAL_VEIN = _Anterior_Tibial_Vein()
    AURICULAR_VEIN = _Auricular_Vein()
    CARDIAC_VEIN = _Cardiac_Vein()
    CAUDAL_AURICULAR_VEIN = _Caudal_Auricular_Vein()
    CEREBELLAR_VEIN = _Cerebellar_Vein()
    CEREBRAL_VEIN = _Cerebral_Vein()
    DIGITAL_VEIN = _Digital_Vein()
    DORSAL_CEREBRAL_VEIN = _Dorsal_Cerebral_Vein()
    DORSAL_METATARSAL_VEIN = _Dorsal_Metatarsal_Vein()
    EXTERNAL_ILIAC_VEIN = _External_Iliac_Vein()
    EXTERNAL_THORACIC_VEIN = _External_Thoracic_Vein()
    GASTRIC_VEIN = _Gastric_Vein()
    GREAT_SAPHENOUS_VEIN = _Great_Saphenous_Vein()
    HYPOGASTRIC_VEIN = _Hypogastric_Vein()
    ILEAL_VEIN = _Ileal_Vein()
    ILEOCOLIC_VEIN = _Ileocolic_Vein()
    ILIAC_VEIN = _Iliac_Vein()
    ILIO_LUMBAR_VEIN = _Ilio_Lumbar_Vein()
    INFERIOR_CEREBELLAR_VEIN = _Inferior_Cerebellar_Vein()
    INFERIOR_CEREBRAL_VEIN = _Inferior_Cerebral_Vein()
    INFERIOR_EXTERNAL_PUDENDAL_VEIN = _Inferior_External_Pudendal_Vein()
    INFERIOR_PALPEBRAL_VEIN = _Inferior_Palpebral_Vein()
    INFERIOR_PHRENIC_VEIN = _Inferior_Phrenic_Vein()
    INFERIOR_VESICAL_VEIN = _Inferior_Vesical_Vein()
    INTERNAL_MAMMARY_VEIN = _Internal_Mammary_Vein()
    JEJUNAL_VEIN = _Jejunal_Vein()
    LATERAL_MARGINAL_VEIN = _Lateral_Marginal_Vein()
    LATERAL_SAPHENOUS_VEIN = _Lateral_Saphenous_Vein()
    LATERAL_THORACIC_VEIN = _Lateral_Thoracic_Vein()
    LEFT_HEPATIC_VEIN = _Left_Hepatic_Vein()
    LEFT_PULMONARY_VEIN = _Left_Pulmonary_Vein()
    LEFT_RENAL_VEIN = _Left_Renal_Vein()
    LEFT_TESTICULAR_VEIN = _Left_Testicular_Vein()
    MASSETERIC_VEIN = _Masseteric_Vein()
    MAXILLARY_VEIN = _Maxillary_Vein()
    MEDIAL_MARGINAL_VEIN = _Medial_Marginal_Vein()
    MEDIAL_PLANTAR_VEIN = _Medial_Plantar_Vein()
    MEDIAL_SAPHENOUS_VEIN = _Medial_Saphenous_Vein()
    MEDIAN_CUBITAL_VEIN = _Median_Cubital_Vein()
    MIDDLE_COLIC_VEIN = _Middle_Colic_Vein()
    MIDDLE_HEPATIC_VEIN = _Middle_Hepatic_Vein()
    MIDDLE_TEMPORAL_VEIN = _Middle_Temporal_Vein()
    PANCREATICO_DUODENAL_VEIN = _Pancreatico_Duodenal_Vein()
    PERICARDIACOPHRENIC_VEIN = _Pericardiacophrenic_Vein()
    PERINEAL_VEIN = _Perineal_Vein()
    PHRENIC_VEIN = _Phrenic_Vein()
    POPLITEAL_VEIN = _Popliteal_Vein()
    POSTERIOR_FACIAL_VEIN = _Posterior_Facial_Vein()
    POSTERIOR_TIBIAL_VEIN = _Posterior_Tibial_Vein()
    PUDENDAL_VEIN = _Pudendal_Vein()
    RETINAL_VEIN = _Retinal_Vein()
    SAPHENOUS_VEIN = _Saphenous_Vein()
    SMALL_SAPHENOUS_VEIN = _Small_Saphenous_Vein()
    SUBMENTAL_VEIN = _Submental_Vein()
    SUBCOSTAL_VEIN = _Subcostal_Vein()
    SUBSCAPULAR_VEIN = _Subscapular_Vein()
    SUPERIOR_CEREBELLAR_VEIN = _Superior_Cerebellar_Vein()
    SUPERIOR_EXTERNAL_PUDENDAL_VEIN = _Superior_External_Pudendal_Vein()
    SUPERIOR_INTERCOSTAL_VEIN = _Superior_Intercostal_Vein()
    SUPERIOR_PANCREATICO_DUODENAL_VEIN = _Superior_Pancreatico_Duodenal_Vein()
    SUPRAORBITAL_VEIN = _Supraorbital_Vein()
    TEMPORAL_VEIN = _Temporal_Vein()
    THORACIC_VEIN = _Thoracic_Vein()
    THORACODORSAL_VEIN = _Thoracodorsal_Vein()
    TIBIAL_VEIN = _Tibial_Vein()
    TRANSVERSE_FACIAL_VEIN = _Transverse_Facial_Vein()
    VEIN_OF_CLITORIS = _Vein_Of_Clitoris()
    VEIN_OF_LOWER_LIP = _Vein_Of_Lower_Lip()
    VEIN_OF_TRABECULAR_BONE = _Vein_Of_Trabecular_Bone()
    VEIN_OF_UPPER_LIP = _Vein_Of_Upper_Lip()
    VESICAL_VEIN = _Vesical_Vein()
    COMMON_HEPATIC_ARTERY = _Common_Hepatic_Artery()
    COMMON_PALMAR_DIGITAL_ARTERY = _Common_Palmar_Digital_Artery()
    COMMON_PLANTAR_DIGITAL_ARTERY = _Common_Plantar_Digital_Artery()
    FORELIMB_COMMON_DORSAL_DIGITAL_ARTERY = _Forelimb_Common_Dorsal_Digital_Artery()
    FORELIMB_DIGITAL_ARTERY = _Forelimb_Digital_Artery()
    FORELIMB_PROPER_DORSAL_DIGITAL_ARTERY = _Forelimb_Proper_Dorsal_Digital_Artery()
    HINDLIMB_COMMON_DORSAL_DIGITAL_ARTERY = _Hindlimb_Common_Dorsal_Digital_Artery()
    HINDLIMB_DIGITAL_ARTERY = _Hindlimb_Digital_Artery()
    HINDLIMB_PROPER_DORSAL_DIGITAL_ARTERY = _Hindlimb_Proper_Dorsal_Digital_Artery()
    PROFUNDA_BRACHII_ARTERY = _Profunda_Brachii_Artery()
    PROFUNDA_FEMORIS_ARTERY = _Profunda_Femoris_Artery()
    PROPER_HEPATIC_ARTERY = _Proper_Hepatic_Artery()
    PROPER_PALMAR_DIGITAL_ARTERY = _Proper_Palmar_Digital_Artery()
    PROPER_PLANTAR_DIGITAL_ARTERY = _Proper_Plantar_Digital_Artery()
    SAPHENOUS_ARTERY = _Saphenous_Artery()
    COMMON_PLANTAR_VEIN = _Common_Plantar_Vein()
    COMMON_PALMAR_DIGITAL_VEIN = _Common_Palmar_Digital_Vein()
    FORELIMB_DIGITAL_VEIN = _Forelimb_Digital_Vein()
    HINDLIMB_DIGITAL_VEIN = _Hindlimb_Digital_Vein()
    GREAT_VEIN_OF_HEART = _Great_Vein_Of_Heart()
    LIENAL_VEIN = _Lienal_Vein()
    NASO_FRONTAL_VEIN = _Naso_Frontal_Vein()
    PARAUMBILICAL_VEIN = _Paraumbilical_Vein()
    PROPER_PALMAR_VEIN = _Proper_Palmar_Vein()
    PROPER_PLANTAR_VEIN = _Proper_Plantar_Vein()
    SURAL_VEIN = _Sural_Vein()
    CHEST = _Chest()
    CHEST_WALL = _Chest_Wall()
    UPPER_BACK = _Upper_Back()
    PELVIC_CAVITY = _Pelvic_Cavity()
    NECK_BLOOD_VESSEL = _Neck_Blood_Vessel()
    TRUNK_BLOOD_VESSEL = _Trunk_Blood_Vessel()
    THORACIC_SEGMENT_BLOOD_VESSEL = _Thoracic_Segment_Blood_Vessel()
    CHEST_BLOOD_VESSEL = _Chest_Blood_Vessel()
    THORACIC_CAVITY_BLOOD_VESSEL = _Thoracic_Cavity_Blood_Vessel()
    THORACIC_CAVITY_ARTERY = _Thoracic_Cavity_Artery()
    THORACIC_CAVITY_VEIN = _Thoracic_Cavity_Vein()
    BACK_BLOOD_VESSEL = _Back_Blood_Vessel()
    PELVIS_BLOOD_VESSEL = _Pelvis_Blood_Vessel()
    CRANIOCERVICAL_REGION_BONE = _Craniocervical_Region_Bone()
    NECK_BONE = _Neck_Bone()
    THORACIC_SEGMENT_BONE = _Thoracic_Segment_Bone()
    BACK_BONE = _Back_Bone()
    PELVIS_BONE = _Pelvis_Bone()
    NECK_CONNECTIVE_TISSUE = _Neck_Connective_Tissue()
    NECK_CARTILAGE = _Neck_Cartilage()
    TRUNK_CONNECTIVE_TISSUE = _Trunk_Connective_Tissue()
    THORACIC_SEGMENT_CONNECTIVE_TISSUE = _Thoracic_Segment_Connective_Tissue()
    CHEST_CONNECTIVE_TISSUE = _Chest_Connective_Tissue()
    THORACIC_CAVITY_CONNECTIVE_TISSUE = _Thoracic_Cavity_Connective_Tissue()
    BACK_CONNECTIVE_TISSUE = _Back_Connective_Tissue()
    PELVIS_CONNECTIVE_TISSUE = _Pelvis_Connective_Tissue()
    AXIAL_MESODERM = _Axial_Mesoderm()
    CRANIOCERVICAL_REGION_MUSCLE = _Craniocervical_Region_Muscle()
    THORACIC_SEGMENT_MUSCLE = _Thoracic_Segment_Muscle()
    UPPER_BACK_MUSCLE = _Upper_Back_Muscle()
    LOWER_BACK_MUSCLE = _Lower_Back_Muscle()
    NECK_NERVE = _Neck_Nerve()
    TRUNK_NERVE = _Trunk_Nerve()
    THORACIC_SEGMENT_NERVE = _Thoracic_Segment_Nerve()
    CHEST_NERVE = _Chest_Nerve()
    THORACIC_CAVITY_NERVE = _Thoracic_Cavity_Nerve()
    BACK_NERVE = _Back_Nerve()
    PELVIS_NERVE = _Pelvis_Nerve()
    TRUNK_ORGAN = _Trunk_Organ()
    THORACIC_SEGMENT_ORGAN = _Thoracic_Segment_Organ()
    CHEST_ORGAN = _Chest_Organ()
    THORACIC_CAVITY_ORGAN = _Thoracic_Cavity_Organ()
    BACK_ORGAN = _Back_Organ()
    PELVIS_ORGAN = _Pelvis_Organ()
    CRANIOCERVICAL_REGION_SKIN = _Craniocervical_Region_Skin()
    NECK_SKIN = _Neck_Skin()
    TRUNK_SKIN = _Trunk_Skin()
    CHEST_SKIN = _Chest_Skin()
    UPPER_BACK_SKIN = _Upper_Back_Skin()
    LOWER_BACK_SKIN = _Lower_Back_Skin()
    PELVIS_SKIN = _Pelvis_Skin()
    APPENDAGE = _Appendage()
    METACARPAL_METATARSAL_BONE = _Metacarpal_Metatarsal_Bone()
    LIMB_DIGIT_1 = _Limb_Digit_1()
    LIMB_DIGIT_2 = _Limb_Digit_2()
    LIMB_DIGIT_3 = _Limb_Digit_3()
    LIMB_DIGIT_4 = _Limb_Digit_4()
    LIMB_DIGIT_5 = _Limb_Digit_5()
    DIGIT_CONNECTIVE_TISSUE = _Digit_Connective_Tissue()
    LIMB_NERVE = _Limb_Nerve()
    FORELIMB_BLOOD_VESSEL = _Forelimb_Blood_Vessel()
    ARM_BLOOD_VESSEL = _Arm_Blood_Vessel()
    UPPER_ARM_BLOOD_VESSEL = _Upper_Arm_Blood_Vessel()
    FOREARM_BLOOD_VESSEL = _Forearm_Blood_Vessel()
    HAND_BLOOD_VESSEL = _Hand_Blood_Vessel()
    FORELIMB_DIGIT_BLOOD_VESSEL = _Forelimb_Digit_Blood_Vessel()
    HINDLIMB_BLOOD_VESSEL = _Hindlimb_Blood_Vessel()
    UPPER_LEG_BLOOD_VESSEL = _Upper_Leg_Blood_Vessel()
    LOWER_LEG_BLOOD_VESSEL = _Lower_Leg_Blood_Vessel()
    FOOT_BLOOD_VESSEL = _Foot_Blood_Vessel()
    HINDLIMB_DIGIT_BLOOD_VESSEL = _Hindlimb_Digit_Blood_Vessel()
    ARM_BONE = _Arm_Bone()
    LEG_BONE = _Leg_Bone()
    FORELIMB_DIGIT_BONE = _Forelimb_Digit_Bone()
    FORELIMB_MIDDLE_PHALANX = _Forelimb_Middle_Phalanx()
    FORELIMB_PROXIMAL_PHALANX = _Forelimb_Proximal_Phalanx()
    HIP_BONE = _Hip_Bone()
    HINDLIMB_DIGIT_BONE = _Hindlimb_Digit_Bone()
    HINDLIMB_DISTAL_PHALANX = _Hindlimb_Distal_Phalanx()
    HINDLIMB_MIDDLE_PHALANX = _Hindlimb_Middle_Phalanx()
    HINDLIMB_PROXIMAL_PHALANX = _Hindlimb_Proximal_Phalanx()
    LIMB_CONNECTIVE_TISSUE = _Limb_Connective_Tissue()
    FORELIMB_CONNECTIVE_TISSUE = _Forelimb_Connective_Tissue()
    SHOULDER_CONNECTIVE_TISSUE = _Shoulder_Connective_Tissue()
    ARM_CONNECTIVE_TISSUE = _Arm_Connective_Tissue()
    UPPER_ARM_CONNECTIVE_TISSUE = _Upper_Arm_Connective_Tissue()
    ELBOW_CONNECTIVE_TISSUE = _Elbow_Connective_Tissue()
    FOREARM_CONNECTIVE_TISSUE = _Forearm_Connective_Tissue()
    WRIST_CONNECTIVE_TISSUE = _Wrist_Connective_Tissue()
    FORELIMB_DIGIT_CONNECTIVE_TISSUE = _Forelimb_Digit_Connective_Tissue()
    HINDLIMB_CONNECTIVE_TISSUE = _Hindlimb_Connective_Tissue()
    HIP_CONNECTIVE_TISSUE = _Hip_Connective_Tissue()
    LEG_CONNECTIVE_TISSUE = _Leg_Connective_Tissue()
    UPPER_LEG_CONNECTIVE_TISSUE = _Upper_Leg_Connective_Tissue()
    KNEE_CONNECTIVE_TISSUE = _Knee_Connective_Tissue()
    LOWER_LEG_CONNECTIVE_TISSUE = _Lower_Leg_Connective_Tissue()
    ANKLE_CONNECTIVE_TISSUE = _Ankle_Connective_Tissue()
    FOOT_CONNECTIVE_TISSUE = _Foot_Connective_Tissue()
    HINDLIMB_DIGIT_CONNECTIVE_TISSUE = _Hindlimb_Digit_Connective_Tissue()
    FORELIMB_DIGIT_MUSCLE = _Forelimb_Digit_Muscle()
    HIP_MUSCLE = _Hip_Muscle()
    HINDLIMB_DIGIT_MUSCLE = _Hindlimb_Digit_Muscle()
    FORELIMB_NERVE = _Forelimb_Nerve()
    SHOULDER_NERVE = _Shoulder_Nerve()
    ARM_NERVE = _Arm_Nerve()
    UPPER_ARM_NERVE = _Upper_Arm_Nerve()
    FOREARM_NERVE = _Forearm_Nerve()
    WRIST_NERVE = _Wrist_Nerve()
    HAND_NERVE = _Hand_Nerve()
    FORELIMB_DIGIT_NERVE = _Forelimb_Digit_Nerve()
    HINDLIMB_NERVE = _Hindlimb_Nerve()
    LEG_NERVE = _Leg_Nerve()
    UPPER_LEG_NERVE = _Upper_Leg_Nerve()
    LOWER_LEG_NERVE = _Lower_Leg_Nerve()
    ANKLE_NERVE = _Ankle_Nerve()
    FOOT_NERVE = _Foot_Nerve()
    HINDLIMB_DIGIT_NERVE = _Hindlimb_Digit_Nerve()
    AXILLA_SKIN = _Axilla_Skin()
    ARM_SKIN = _Arm_Skin()
    WRIST_SKIN = _Wrist_Skin()
    LEG_SKIN = _Leg_Skin()
    ANKLE_SKIN = _Ankle_Skin()
    HEEL_SKIN = _Heel_Skin()
    METAPODIAL_PAD_EPIDERMIS = _Metapodial_Pad_Epidermis()
    LEFT_ADRENAL_GLAND = _Left_Adrenal_Gland()
    RIGHT_ADRENAL_GLAND = _Right_Adrenal_Gland()
    LEFT_BRANCH_OF_ATRIOVENTRICULAR_BUNDLE = _Left_Branch_Of_Atrioventricular_Bundle()
    RIGHT_BRANCH_OF_ATRIOVENTRICULAR_BUNDLE = _Right_Branch_Of_Atrioventricular_Bundle()
    LEFT_OUTER_EAR = _Left_Outer_Ear()
    RIGHT_OUTER_EAR = _Right_Outer_Ear()
    LEFT_EYE = _Left_Eye()
    RIGHT_EYE = _Right_Eye()
    LEFT_MAIN_BRONCHUS = _Left_Main_Bronchus()
    RIGHT_MAIN_BRONCHUS = _Right_Main_Bronchus()
    LEFT_OVARY = _Left_Ovary()
    RIGHT_OVARY = _Right_Ovary()
    LEFT_OVIDUCT = _Left_Oviduct()
    RIGHT_OVIDUCT = _Right_Oviduct()
    LEFT_TESTIS = _Left_Testis()
    RIGHT_TESTIS = _Right_Testis()
    LEFT_URETER = _Left_Ureter()
    RIGHT_URETER = _Right_Ureter()
    LEFT_UTERINE_HORN = _Left_Uterine_Horn()
    RIGHT_UTERINE_HORN = _Right_Uterine_Horn()
    RIGHT_HEPATIC_ARTERY = _Right_Hepatic_Artery()
    RIGHT_HEPATIC_VEIN = _Right_Hepatic_Vein()
    RIGHT_PULMONARY_ARTERY = _Right_Pulmonary_Artery()
    RIGHT_PULMONARY_VEIN = _Right_Pulmonary_Vein()
    RIGHT_RENAL_ARTERY = _Right_Renal_Artery()
    RIGHT_RENAL_VEIN = _Right_Renal_Vein()
    RIGHT_SPERMATIC_ARTERY = _Right_Spermatic_Artery()
    RIGHT_TESTICULAR_VEIN = _Right_Testicular_Vein()
    RIGHT_SUBCLAVIAN_ARTERY = _Right_Subclavian_Artery()
    PAMPINIFORM_PLEXUS = _Pampiniform_Plexus()
    AURICULAR_BLOOD_VESSEL = _Auricular_Blood_Vessel()
    IRIS_BLOOD_VESSEL = _Iris_Blood_Vessel()
    EYELID_BLOOD_VESSEL = _Eyelid_Blood_Vessel()
    INTERSOMITIC_BLOOD_VESSEL = _Intersomitic_Blood_Vessel()
    ALVEOLAR_ATRIUM = _Alveolar_Atrium()
    ALVEOLAR_PORE = _Alveolar_Pore()
    ANAL_FOLD = _Anal_Fold()
    ANAL_REGION_SKELETAL_MUSCLE = _Anal_Region_Skeletal_Muscle()
    ANAL_REGION_SMOOTH_MUSCLE = _Anal_Region_Smooth_Muscle()
    ANAL_SAC = _Anal_Sac()
    ANOCOCCYGEUS = _Anococcygeus()
    ANSIFORM_LOBULE = _Ansiform_Lobule()
    ANSIFORM_LOBULE_CRUS_I = _Ansiform_Lobule_Crus_I()
    ANSIFORM_LOBULE_CRUS_II = _Ansiform_Lobule_Crus_Ii()
    COPULA_PYRAMIDIS = _Copula_Pyramidis()
    LOBULE_SIMPLEX = _Lobule_Simplex()
    PARAFLOCCULUS = _Paraflocculus()
    PARAMEDIAN_LOBULE = _Paramedian_Lobule()
    ANTERIOR_COMMISSURE_ANTERIOR_PART = _Anterior_Commissure_Anterior_Part()
    ANTERIOR_DIGASTRIC_MUSCLE = _Anterior_Digastric_Muscle()
    POSTERIOR_DIGASTRIC_MUSCLE = _Posterior_Digastric_Muscle()
    BED_NUCLEUS_OF_STRIA_TERMINALIS_ANTERIOR_PART = _Bed_Nucleus_Of_Stria_Terminalis_Anterior_Part()
    BED_NUCLEUS_OF_STRIA_TERMINALIS_POSTERIOR_PART = _Bed_Nucleus_Of_Stria_Terminalis_Posterior_Part()
    ANTERIOR_HYPOTHALAMIC_NUCLEUS = _Anterior_Hypothalamic_Nucleus()
    ANTERIOR_COMMISSURE_POSTERIOR_PART = _Anterior_Commissure_Posterior_Part()
    ANTERIOR_SEMICIRCULAR_DUCT = _Anterior_Semicircular_Duct()
    LATERAL_SEMICIRCULAR_DUCT = _Lateral_Semicircular_Duct()
    POSTERIOR_SEMICIRCULAR_DUCT = _Posterior_Semicircular_Duct()
    CORNEA_ANTERIOR_STROMA = _Cornea_Anterior_Stroma()
    CORNEA_POSTERIOR_STROMA = _Cornea_Posterior_Stroma()
    ANTERIOR_TEGMENTAL_NUCLEUS = _Anterior_Tegmental_Nucleus()
    ANTERIOR_UVEA = _Anterior_Uvea()
    AORTIC_VALVE_ANULUS = _Aortic_Valve_Anulus()
    MITRAL_VALVE_ANULUS = _Mitral_Valve_Anulus()
    PULMONARY_VALVE_ANULUS = _Pulmonary_Valve_Anulus()
    TRICUSPID_VALVE_ANULUS = _Tricuspid_Valve_Anulus()
    HEART_ANULUS_FIBROSUS = _Heart_Anulus_Fibrosus()
    APEX_OF_ARYTENOID = _Apex_Of_Arytenoid()
    BASE_OF_ARYTENOID = _Base_Of_Arytenoid()
    APEX_OF_HEART_VENTRICLE = _Apex_Of_Heart_Ventricle()
    APOCRINE_SWEAT_GLAND = _Apocrine_Sweat_Gland()
    AQUEOUS_DRAINAGE_SYSTEM = _Aqueous_Drainage_System()
    AQUEOUS_VEIN = _Aqueous_Vein()
    INFERIOR_LABIAL_ARTERY = _Inferior_Labial_Artery()
    SUPERIOR_LABIAL_ARTERY = _Superior_Labial_Artery()
    ATRIOVENTRICULAR_SEPTAL_COMPLEX = _Atrioventricular_Septal_Complex()
    ATRIAL_TRABECULA = _Atrial_Trabecula()
    AUDITORY_BULLA = _Auditory_Bulla()
    AURICULAR_LIGAMENT = _Auricular_Ligament()
    BACHMANN_S_BUNDLE = _Bachmann_S_Bundle()
    BARRINGTON_S_NUCLEUS = _Barrington_S_Nucleus()
    TONGUE_ANTERIOR_PART = _Tongue_Anterior_Part()
    TONGUE_POSTERIOR_PART = _Tongue_Posterior_Part()
    BASILIC_VEIN = _Basilic_Vein()
    BILIARY_DUCTULE = _Biliary_Ductule()
    BODY_FLUID = _Body_Fluid()
    BODY_CAVITY = _Body_Cavity()
    BODY_OF_STERNUM = _Body_Of_Sternum()
    HARD_PALATE_BONY_PART = _Hard_Palate_Bony_Part()
    BRACHIAL_VEIN = _Brachial_Vein()
    BRAIN_COMMISSURE = _Brain_Commissure()
    BRAIN_VENTRICLE_AND_CHOROID_PLEXUS = _Brain_Ventricle_And_Choroid_Plexus()
    BRONCHOALVEOLAR_DUCT_JUNCTION = _Bronchoalveolar_Duct_Junction()
    BRONCHUS_SUBMUCOSA = _Bronchus_Submucosa()
    BRUCH_S_MEMBRANE = _Bruch_S_Membrane()
    CHEEK = _Cheek()
    BUCCAL_POUCH = _Buccal_Pouch()
    BUCCINATOR = _Buccinator()
    BULBOSPONGIOSUS = _Bulbospongiosus()
    ISCHIOCAVERNOSUS = _Ischiocavernosus()
    CANAL_OF_SCHLEMM = _Canal_Of_Schlemm()
    CANTHUS = _Canthus()
    OUTER_CANTHUS = _Outer_Canthus()
    CARDIAC_REGION_GASTRIC_GLAND = _Cardiac_Region_Gastric_Gland()
    CARDIAC_NERVE_PLEXUS = _Cardiac_Nerve_Plexus()
    CELIAC_NERVE_PLEXUS = _Celiac_Nerve_Plexus()
    PULMONARY_NERVE_PLEXUS = _Pulmonary_Nerve_Plexus()
    CARTILAGINOUS_JOINT_SUTURE = _Cartilaginous_Joint_Suture()
    GOMPHOSIS = _Gomphosis()
    SYNDESMOSIS = _Syndesmosis()
    BONY_OTIC_CAPSULE = _Bony_Otic_Capsule()
    CARTILAGINOUS_OTIC_CAPSULE = _Cartilaginous_Otic_Capsule()
    CAUDA_EQUINA = _Cauda_Equina()
    CAUDAL_GANGLIONIC_EMINENCE = _Caudal_Ganglionic_Eminence()
    LATERAL_GANGLIONIC_EMINENCE = _Lateral_Ganglionic_Eminence()
    MEDIAL_GANGLIONIC_EMINENCE = _Medial_Ganglionic_Eminence()
    CAUDAL_HUMERAL_CIRCUMFLEX_VEIN = _Caudal_Humeral_Circumflex_Vein()
    CELLULAR_CARTILAGE = _Cellular_Cartilage()
    MUSCLE_ORGAN = _Muscle_Organ()
    MYOCARDIUM_LAYER = _Myocardium_Layer()
    SYNOVIUM = _Synovium()
    CEREBRAL_HEMISPHERE_GRAY_MATTER = _Cerebral_Hemisphere_Gray_Matter()
    CHOLEDOCHODUODENAL_JUNCTION = _Choledochoduodenal_Junction()
    ENTERIC_NERVE = _Enteric_Nerve()
    CHOLINERGIC_ENTERIC_NERVE = _Cholinergic_Enteric_Nerve()
    PELVIS_MUSCLE = _Pelvis_Muscle()
    COCCYGEUS = _Coccygeus()
    CONSTRICTOR_VULVAE = _Constrictor_Vulvae()
    CORNICULATE_CARTILAGE = _Corniculate_Cartilage()
    KIDNEY_OUTER_CORTEX = _Kidney_Outer_Cortex()
    KIDNEY_CORTICAL_ARCH = _Kidney_Cortical_Arch()
    KIDNEY_COLUMN = _Kidney_Column()
    KIDNEY_CORTEX_PERITUBULAR_CAPILLARY = _Kidney_Cortex_Peritubular_Capillary()
    RENAL_STRAIGHT_TUBULE = _Renal_Straight_Tubule()
    RENAL_TUBULE_BASEMENT_MEMBRANE = _Renal_Tubule_Basement_Membrane()
    COSTAL_ARCH = _Costal_Arch()
    DISTAL_RIB = _Distal_Rib()
    FALSE_RIB = _False_Rib()
    FLOATING_RIB = _Floating_Rib()
    PROXIMAL_RIB = _Proximal_Rib()
    COSTO_CERVICAL_TRUNK = _Costo_Cervical_Trunk()
    CRANIAL_CAVITY = _Cranial_Cavity()
    CRICOARYTENOID_MUSCLE = _Cricoarytenoid_Muscle()
    CRUS_CEREBRI = _Crus_Cerebri()
    CUTANEOUS_MUSCLE = _Cutaneous_Muscle()
    CUTANEOUS_TRUNCI_MUSCLE = _Cutaneous_Trunci_Muscle()
    LEVATOR_NASOLABIALIS = _Levator_Nasolabialis()
    LEVATOR_LABII_SUPERIORIS = _Levator_Labii_Superioris()
    INTEGUMENT = _Integument()
    HYPODERMIS = _Hypodermis()
    CUTANEOUS_VEIN = _Cutaneous_Vein()
    EPONYCHIUM = _Eponychium()
    HYPONYCHIUM = _Hyponychium()
    PROXIMAL_NAIL_BED = _Proximal_Nail_Bed()
    DEEP_CERVICAL_LYMPH_NODE = _Deep_Cervical_Lymph_Node()
    DEEP_ILIAC_CIRCUMFLEX_VEIN = _Deep_Iliac_Circumflex_Vein()
    DEEP_TEMPORAL_VEIN = _Deep_Temporal_Vein()
    DEFERENT_DUCT_ARTERY = _Deferent_Duct_Artery()
    DEFERENT_DUCT_VEIN = _Deferent_Duct_Vein()
    DENTATE_GYRUS_PYRAMIDAL_LAYER = _Dentate_Gyrus_Pyramidal_Layer()
    DEPRESSOR_LABII_INFERIORIS = _Depressor_Labii_Inferioris()
    DORSAL_FOOT_INTEROSSEUS_MUSCLE = _Dorsal_Foot_Interosseus_Muscle()
    PLANTAR_FOOT_INTEROSSEUS_MUSCLE = _Plantar_Foot_Interosseus_Muscle()
    DORSAL_HAND_INTEROSSEUS_MUSCLE = _Dorsal_Hand_Interosseus_Muscle()
    PALMAR_HAND_INTEROSSEUS_MUSCLE = _Palmar_Hand_Interosseus_Muscle()
    DORSAL_VENOUS_ARCH = _Dorsal_Venous_Arch()
    EPIGLOTTIC_CARTILAGE = _Epiglottic_Cartilage()
    ESOPHAGUS_SMOOTH_MUSCLE_CIRCULAR_LAYER = _Esophagus_Smooth_Muscle_Circular_Layer()
    ESOPHAGUS_SMOOTH_MUSCLE_LONGITUDINAL_LAYER = _Esophagus_Smooth_Muscle_Longitudinal_Layer()
    EXTERNAL_AUDITORY_MEATUS_CARTILAGINOUS_PART = _External_Auditory_Meatus_Cartilaginous_Part()
    EXTERNAL_AUDITORY_MEATUS_OSSEUS_PART = _External_Auditory_Meatus_Osseus_Part()
    EXTRINSIC_AURICULAR_MUSCLE = _Extrinsic_Auricular_Muscle()
    INTRINSIC_AURICULAR_MUSCLE = _Intrinsic_Auricular_Muscle()
    EYE_CHAMBER = _Eye_Chamber()
    EYE_SKIN_GLAND = _Eye_Skin_Gland()
    EYE_SEBACEOUS_GLAND = _Eye_Sebaceous_Gland()
    EYELID_CONNECTIVE_TISSUE = _Eyelid_Connective_Tissue()
    EYELID_SUBCUTANEOUS_CONNECTIVE_TISSUE = _Eyelid_Subcutaneous_Connective_Tissue()
    EYELID_SUBMUSCULAR_CONNECTIVE_TISSUE = _Eyelid_Submuscular_Connective_Tissue()
    EYELID_NERVE = _Eyelid_Nerve()
    EYELID_SKIN = _Eyelid_Skin()
    MEMBRANOUS_URETHRA_OF_FEMALE = _Membranous_Urethra_Of_Female()
    FEMUR_DIAPHYSIS = _Femur_Diaphysis()
    FEMUR_EPIPHYSIS = _Femur_Epiphysis()
    FEMUR_METAPHYSIS = _Femur_Metaphysis()
    HEAD_OF_FEMUR = _Head_Of_Femur()
    MEMBRANOUS_URETHRA = _Membranous_Urethra()
    FOREBRAIN_MENINGES = _Forebrain_Meninges()
    FOREBRAIN_ARACHNOID_MATER = _Forebrain_Arachnoid_Mater()
    FOREBRAIN_DURA_MATER = _Forebrain_Dura_Mater()
    FOREBRAIN_PIA_MATER = _Forebrain_Pia_Mater()
    LOWER_RESPIRATORY_TRACT_CARTILAGE = _Lower_Respiratory_Tract_Cartilage()
    LOWER_RESPIRATORY_TRACT_CONNECTIVE_TISSUE = _Lower_Respiratory_Tract_Connective_Tissue()
    LOWER_RESPIRATORY_TRACT_EPITHELIUM = _Lower_Respiratory_Tract_Epithelium()
    MAIN_BRONCHUS_CONNECTIVE_TISSUE = _Main_Bronchus_Connective_Tissue()
    MAIN_BRONCHUS_SMOOTH_MUSCLE = _Main_Bronchus_Smooth_Muscle()
    TRACHEA_BASEMENT_MEMBRANE = _Trachea_Basement_Membrane()
    TRACHEA_BASAL_LAMINA = _Trachea_Basal_Lamina()
    TRACHEA_RETICULAR_LAMINA = _Trachea_Reticular_Lamina()
    TRACHEAL_BIFURCATION = _Tracheal_Bifurcation()
    LARGE_INTESTINE_MUSCULARIS_MUCOSA = _Large_Intestine_Muscularis_Mucosa()
    LARGE_INTESTINE_SEROSA = _Large_Intestine_Serosa()
    LARGE_INTESTINE_SMOOTH_MUSCLE_CIRCULAR_LAYER = _Large_Intestine_Smooth_Muscle_Circular_Layer()
    LARGE_INTESTINE_SMOOTH_MUSCLE_LONGITUDINAL_LAYER = _Large_Intestine_Smooth_Muscle_Longitudinal_Layer()
    LARGE_INTESTINE_SUBMUCOSA = _Large_Intestine_Submucosa()
    SMALL_INTESTINE_SEROSA = _Small_Intestine_Serosa()
    SMALL_INTESTINE_SMOOTH_MUSCLE_CIRCULAR_LAYER = _Small_Intestine_Smooth_Muscle_Circular_Layer()
    SMALL_INTESTINE_SMOOTH_MUSCLE_LONGITUDINAL_LAYER = _Small_Intestine_Smooth_Muscle_Longitudinal_Layer()
    SMALL_INTESTINE_SUBMUCOSA = _Small_Intestine_Submucosa()
    RESPIRATORY_SYSTEM_ARTERIAL_BLOOD_VESSEL = _Respiratory_System_Arterial_Blood_Vessel()
    RESPIRATORY_SYSTEM_ARTERIAL_ENDOTHELIUM = _Respiratory_System_Arterial_Endothelium()
    RESPIRATORY_SYSTEM_ARTERIAL_SMOOTH_MUSCLE = _Respiratory_System_Arterial_Smooth_Muscle()
    RESPIRATORY_SYSTEM_ARTERIOLE = _Respiratory_System_Arteriole()
    RESPIRATORY_SYSTEM_ARTERY = _Respiratory_System_Artery()
    RESPIRATORY_SYSTEM_BASEMENT_MEMBRANE = _Respiratory_System_Basement_Membrane()
    RESPIRATORY_SYSTEM_BASAL_LAMINA = _Respiratory_System_Basal_Lamina()
    RESPIRATORY_SYSTEM_RETICULAR_LAMINA = _Respiratory_System_Reticular_Lamina()
    RESPIRATORY_SYSTEM_BLOOD_VESSEL_SMOOTH_MUSCLE = _Respiratory_System_Blood_Vessel_Smooth_Muscle()
    RESPIRATORY_SYSTEM_CAPILLARY = _Respiratory_System_Capillary()
    RESPIRATORY_SYSTEM_CAPILLARY_ENDOTHELIUM = _Respiratory_System_Capillary_Endothelium()
    RESPIRATORY_SYSTEM_LAMINA_PROPRIA = _Respiratory_System_Lamina_Propria()
    RESPIRATORY_SYSTEM_MUCOSA = _Respiratory_System_Mucosa()
    RESPIRATORY_SYSTEM_SUBMUCOSA = _Respiratory_System_Submucosa()
    RESPIRATORY_SYSTEM_LYMPHATIC_VESSEL = _Respiratory_System_Lymphatic_Vessel()
    RESPIRATORY_SYSTEM_LYMPHATIC_VESSEL_ENDOTHELIUM = _Respiratory_System_Lymphatic_Vessel_Endothelium()
    RESPIRATORY_SYSTEM_LYMPHATIC_VESSEL_SMOOTH_MUSCLE = _Respiratory_System_Lymphatic_Vessel_Smooth_Muscle()
    RESPIRATORY_SYSTEM_SKELETAL_MUSCLE = _Respiratory_System_Skeletal_Muscle()
    RESPIRATORY_SYSTEM_VENOUS_BLOOD_VESSEL = _Respiratory_System_Venous_Blood_Vessel()
    RESPIRATORY_SYSTEM_VENOUS_ENDOTHELIUM = _Respiratory_System_Venous_Endothelium()
    RESPIRATORY_SYSTEM_VENOUS_SMOOTH_MUSCLE = _Respiratory_System_Venous_Smooth_Muscle()
    RESPIRATORY_SYSTEM_VENULE = _Respiratory_System_Venule()
    FLEXOR_HALLUCIS_LONGUS = _Flexor_Hallucis_Longus()
    FOVEA_CENTRALIS = _Fovea_Centralis()
    FRONTAL_ARTERY = _Frontal_Artery()
    FUSIFORM_NUCLEUS = _Fusiform_Nucleus()
    ALIMENTARY_SYSTEM_SEROSA = _Alimentary_System_Serosa()
    GRACILE_NUCLEUS = _Gracile_Nucleus()
    GREATER_TROCHANTER = _Greater_Trochanter()
    LESSER_TROCHANTER = _Lesser_Trochanter()
    GRAY_MATTER = _Gray_Matter()
    HEART_AND_PERICARDIUM = _Heart_And_Pericardium()
    HEPATIC_DUCT_SMOOTH_MUSCLE = _Hepatic_Duct_Smooth_Muscle()
    HILAR_PART_OF_HEPATIC_DUCT = _Hilar_Part_Of_Hepatic_Duct()
    HYOID_APPARATUS = _Hyoid_Apparatus()
    ILEOCECAL_JUNCTION = _Ileocecal_Junction()
    ILIAC_CREST = _Iliac_Crest()
    ILIOCOSTALIS = _Iliocostalis()
    ILIOCOSTALIS_THORACIS = _Iliocostalis_Thoracis()
    ILIOTHORACIC = _Iliothoracic()
    INFERIOR_EYELID_TARSUS = _Inferior_Eyelid_Tarsus()
    SUPERIOR_EYELID_TARSUS = _Superior_Eyelid_Tarsus()
    MEDIAL_PALPEBRAL_LIGAMENT = _Medial_Palpebral_Ligament()
    ORBITAL_SEPTUM = _Orbital_Septum()
    INFERIOR_OLIVARY_COMMISSURE = _Inferior_Olivary_Commissure()
    INFERIOR_OLIVE_BETA_SUBNUCLEUS = _Inferior_Olive_Beta_Subnucleus()
    INFERIOR_OLIVE_DORSAL_ACCESSORY_NUCLEUS = _Inferior_Olive_Dorsal_Accessory_Nucleus()
    INFERIOR_OLIVE_MEDIAL_ACCESSORY_NUCLEUS = _Inferior_Olive_Medial_Accessory_Nucleus()
    INFERIOR_OLIVE_MEDIAL_NUCLEUS = _Inferior_Olive_Medial_Nucleus()
    INFERIOR_OLIVE_PRINCIPAL_NUCLEUS = _Inferior_Olive_Principal_Nucleus()
    INFERIOR_PANCREATICO_DUODENAL_VEIN = _Inferior_Pancreatico_Duodenal_Vein()
    SYMPATHETIC_NERVE_PLEXUS = _Sympathetic_Nerve_Plexus()
    INTERNAL_CAROTID_NERVE_PLEXUS = _Internal_Carotid_Nerve_Plexus()
    INTESTINE_SEROSA = _Intestine_Serosa()
    JOINT_ARTICULAR_SURFACE = _Joint_Articular_Surface()
    JOINT_FIBROUS_CAPSULE = _Joint_Fibrous_Capsule()
    JOINT_OF_VERTEBRAL_BODY = _Joint_Of_Vertebral_Body()
    JUXTAMEDULLARY_CORTEX = _Juxtamedullary_Cortex()
    LACRIMAL_CANALICULUS = _Lacrimal_Canaliculus()
    LAMELLAR_BONE = _Lamellar_Bone()
    LARYNX_LIGAMENT = _Larynx_Ligament()
    LARYNGEAL_EXTRINSIC_LIGAMENT = _Laryngeal_Extrinsic_Ligament()
    LARYNGEAL_INTRINSIC_LIGAMENT = _Laryngeal_Intrinsic_Ligament()
    LARYNGEAL_EXTRINSIC_MUSCLE = _Laryngeal_Extrinsic_Muscle()
    LARYNGEAL_INTRINSIC_MUSCLE = _Laryngeal_Intrinsic_Muscle()
    LARYNX_MUCOUS_GLAND = _Larynx_Mucous_Gland()
    SPINAL_CORD_BASAL_NUCLEUS = _Spinal_Cord_Basal_Nucleus()
    LATERAL_CERVICAL_NUCLEUS = _Lateral_Cervical_Nucleus()
    LATERAL_SPINAL_NUCLEUS = _Lateral_Spinal_Nucleus()
    SPINAL_CORD_DORSAL_NUCLEUS = _Spinal_Cord_Dorsal_Nucleus()
    LATERAL_DORSAL_DIGITAL_ARTERY_FOR_DIGIT_5 = _Lateral_Dorsal_Digital_Artery_For_Digit_5()
    MEDIAN_DORSAL_DIGITAL_ARTERY_FOR_DIGIT_1 = _Median_Dorsal_Digital_Artery_For_Digit_1()
    LATERAL_GLOBUS_PALLIDUS = _Lateral_Globus_Pallidus()
    MEDIAL_GLOBUS_PALLIDUS = _Medial_Globus_Pallidus()
    LIMITING_RIDGE_OF_STOMACH = _Limiting_Ridge_Of_Stomach()
    LINGUAL_GLAND_DUCT = _Lingual_Gland_Duct()
    LIP_SKELETAL_MUSCLE = _Lip_Skeletal_Muscle()
    LIP_SKIN = _Lip_Skin()
    LIVER_LEFT_LATERAL_LOBE = _Liver_Left_Lateral_Lobe()
    LIVER_LEFT_MEDIAL_LOBE = _Liver_Left_Medial_Lobe()
    LIVER_PAPILLARY_PROCESS = _Liver_Papillary_Process()
    LOBAR_BRONCHUS_CONNECTIVE_TISSUE = _Lobar_Bronchus_Connective_Tissue()
    LONGISSIMUS_MUSCLE = _Longissimus_Muscle()
    LONGISSIMUS_ATLANTIS = _Longissimus_Atlantis()
    LONGISSIMUS_CAPITIS = _Longissimus_Capitis()
    LONGISSIMUS_CERVICIS = _Longissimus_Cervicis()
    LONGISSIMUS_LUMBORUM = _Longissimus_Lumborum()
    LONGISSIMUS_THORACIS = _Longissimus_Thoracis()
    LONGUS_COLLI = _Longus_Colli()
    LUMBAR_SYMPATHETIC_NERVE_TRUNK = _Lumbar_Sympathetic_Nerve_Trunk()
    PELVIC_SYMPATHETIC_NERVE_TRUNK = _Pelvic_Sympathetic_Nerve_Trunk()
    THORACIC_SYMPATHETIC_NERVE_TRUNK = _Thoracic_Sympathetic_Nerve_Trunk()
    LUMBOSACROCAUDALIS = _Lumbosacrocaudalis()
    LUNATE = _Lunate()
    SCAPHOID = _Scaphoid()
    LYMPH_NODE_FOLLICULAR_MANTLE = _Lymph_Node_Follicular_Mantle()
    LYMPH_NODE_SUBCORTICAL_SINUS = _Lymph_Node_Subcortical_Sinus()
    LYMPH_NODE_T_CELL_DOMAIN = _Lymph_Node_T_Cell_Domain()
    LYMPHOID_SYSTEM = _Lymphoid_System()
    LYMPH_ORGAN = _Lymph_Organ()
    MAGNOCELLULAR_NUCLEUS = _Magnocellular_Nucleus()
    OVAL_NUCLEUS = _Oval_Nucleus()
    MAMMARY_SEBACEOUS_GLAND = _Mammary_Sebaceous_Gland()
    MAMMARY_GLAND_SMOOTH_MUSCLE = _Mammary_Gland_Smooth_Muscle()
    MEDIAL_FEMORAL_CIRCUMFLEX_ARTERY = _Medial_Femoral_Circumflex_Artery()
    OBTURATOR_ARTERY = _Obturator_Artery()
    OCCIPITAL_ARTERY = _Occipital_Artery()
    OCULAR_ANGLE_ARTERY = _Ocular_Angle_Artery()
    PERONEAL_ARTERY = _Peroneal_Artery()
    ULNAR_ARTERY = _Ulnar_Artery()
    URETERIC_ARTERY = _Ureteric_Artery()
    OBTURATOR_VEIN = _Obturator_Vein()
    PANCREATIC_VEIN = _Pancreatic_Vein()
    URETERIC_VEIN = _Ureteric_Vein()
    MODIFIED_SEBACEOUS_GLAND = _Modified_Sebaceous_Gland()
    NASAL_CARTILAGE = _Nasal_Cartilage()
    NASOPHARYNX_CONNECTIVE_TISSUE = _Nasopharynx_Connective_Tissue()
    NERVE_PLEXUS = _Nerve_Plexus()
    NOSE_SKIN = _Nose_Skin()
    BRACHIOCEPHALIC_MUSCLE = _Brachiocephalic_Muscle()
    CLEIDOBRACHIALIS_MUSCLE = _Cleidobrachialis_Muscle()
    CLEIDOCEPHALICUS_MUSCLE = _Cleidocephalicus_Muscle()
    CLEIDOOCCIPITAL_MUSCLE = _Cleidooccipital_Muscle()
    OMOHYOID = _Omohyoid()
    OMOTRANSVERSE = _Omotransverse()
    ORBITALIS_MUSCLE = _Orbitalis_Muscle()
    PAROTIDOAURICULAR = _Parotidoauricular()
    SARTORIUS = _Sartorius()
    SEMISPINALIS_CAPITIS = _Semispinalis_Capitis()
    SEMISPINALIS_CERVICIS = _Semispinalis_Cervicis()
    SEMISPINALIS_THORACIS = _Semispinalis_Thoracis()
    SERRATUS_DORSALIS_CAUDALIS = _Serratus_Dorsalis_Caudalis()
    SERRATUS_DORSALIS_CRANIALIS = _Serratus_Dorsalis_Cranialis()
    SPHINCTER_COLLI_SUPERFICIALIS = _Sphincter_Colli_Superficialis()
    SPINALIS_THORACIS = _Spinalis_Thoracis()
    SPLENIUS = _Splenius()
    STERNOOCCIPITAL = _Sternooccipital()
    ZYGOMATICUS_MUSCLE = _Zygomaticus_Muscle()
    OPHTHALMIC_PLEXUS = _Ophthalmic_Plexus()
    OROPHARYNX_EPITHELIUM = _Oropharynx_Epithelium()
    OUTER_EAR_CARTILAGE = _Outer_Ear_Cartilage()
    OUTFLOW_TRACT_PERICARDIUM = _Outflow_Tract_Pericardium()
    OUTFLOW_TRACT_SMOOTH_MUSCLE = _Outflow_Tract_Smooth_Muscle()
    RECTUS_THORACIS = _Rectus_Thoracis()
    PANCREAS_LOBE = _Pancreas_Lobe()
    PANCREAS_LEFT_LOBE = _Pancreas_Left_Lobe()
    PANCREAS_RIGHT_LOBE = _Pancreas_Right_Lobe()
    PARARENAL_FAT = _Pararenal_Fat()
    PARIETAL_MESOTHELIUM = _Parietal_Mesothelium()
    PERIANAL_SKIN = _Perianal_Skin()
    PERIFORNICAL_NUCLEUS = _Perifornical_Nucleus()
    PERIPEDUNCULAR_NUCLEUS = _Peripeduncular_Nucleus()
    PHRENIC_NERVE_TRUNK = _Phrenic_Nerve_Trunk()
    AXILLARY_NERVE_TRUNK = _Axillary_Nerve_Trunk()
    INTERCOSTAL_NERVE_TRUNK = _Intercostal_Nerve_Trunk()
    POST_CRANIAL_AXIAL_SKELETON = _Post_Cranial_Axial_Skeleton()
    PRESACRAL_VERTEBRA = _Presacral_Vertebra()
    PRESCAPULAR_LYMPH_NODE = _Prescapular_Lymph_Node()
    RETROPHARYNGEAL_LYMPH_NODE = _Retropharyngeal_Lymph_Node()
    SUPERFICIAL_CERVICAL_LYMPH_NODE = _Superficial_Cervical_Lymph_Node()
    PRINCIPAL_NUCLEUS = _Principal_Nucleus()
    TRANSVERSE_NUCLEUS = _Transverse_Nucleus()
    PROXIMAL_SESAMOID_BONE_OF_FOOT = _Proximal_Sesamoid_Bone_Of_Foot()
    PROXIMAL_SESAMOID_BONE_OF_HAND = _Proximal_Sesamoid_Bone_Of_Hand()
    RAPHE_OBSCURUS_NUCLEUS = _Raphe_Obscurus_Nucleus()
    REPRODUCTIVE_ORGAN = _Reproductive_Organ()
    RETROCHIASMATIC_AREA = _Retrochiasmatic_Area()
    RHOMBOID = _Rhomboid()
    RIB_DORSAL_SEGMENT = _Rib_Dorsal_Segment()
    HEAD_OF_RIB = _Head_Of_Rib()
    TUBERCLE_OF_RIB = _Tubercle_Of_Rib()
    SCALENUS_DORSALIS = _Scalenus_Dorsalis()
    SCALENUS_MEDIUS = _Scalenus_Medius()
    SEGMENTAL_BRONCHUS = _Segmental_Bronchus()
    SEGMENTAL_BRONCHUS_EPITHELIUM = _Segmental_Bronchus_Epithelium()
    SENSORY_CIRCUMVENTRICULAR_ORGAN = _Sensory_Circumventricular_Organ()
    SUPRAOPTIC_CREST = _Supraoptic_Crest()
    SKELETAL_MUSCLE_CONNECTIVE_TISSUE = _Skeletal_Muscle_Connective_Tissue()
    SKELETAL_TISSUE = _Skeletal_Tissue()
    SMALL_INTESTINE_MESENTERY = _Small_Intestine_Mesentery()
    SNOUT_SKIN = _Snout_Skin()
    SPINAL_CORD_CENTRAL_GRAY = _Spinal_Cord_Central_Gray()
    SPINAL_CORD_DORSAL_COMMISSURAL_NUCLEUS = _Spinal_Cord_Dorsal_Commissural_Nucleus()
    SPINAL_CORD_RETICULAR_NUCLEUS = _Spinal_Cord_Reticular_Nucleus()
    SPLEEN_PERIARTERIOLAR_LYMPHATIC_SHEATH = _Spleen_Periarteriolar_Lymphatic_Sheath()
    SPLEEN_VENOUS_SINUS = _Spleen_Venous_Sinus()
    SPLENIC_CORD = _Splenic_Cord()
    STOMACH_GREATER_CURVATURE = _Stomach_Greater_Curvature()
    STOMACH_LESSER_CURVATURE = _Stomach_Lesser_Curvature()
    SUPERFICIAL_PALMAR_ARCH = _Superficial_Palmar_Arch()
    SUPERIOR_SALIVATORY_NUCLEUS = _Superior_Salivatory_Nucleus()
    SURAL_NERVE = _Sural_Nerve()
    SYMPHYSIS = _Symphysis()
    TAIL_MUSCLE = _Tail_Muscle()
    TAIL_TIP = _Tail_Tip()
    TAIL_VEIN = _Tail_Vein()
    INTERTARSAL_JOINT = _Intertarsal_Joint()
    TERMINAL_BRONCHUS = _Terminal_Bronchus()
    TERMINAL_BRONCHUS_EPITHELIUM = _Terminal_Bronchus_Epithelium()
    THORACIC_SEGMENT_SKIN = _Thoracic_Segment_Skin()
    THYMUS_LYMPHOID_TISSUE = _Thymus_Lymphoid_Tissue()
    THYROID_GLAND_CAPSULE = _Thyroid_Gland_Capsule()
    THYROID_GLAND_MEDULLA = _Thyroid_Gland_Medulla()
    THYROID_GLAND_PARENCHYMA = _Thyroid_Gland_Parenchyma()
    TIBIA_DIAPHYSIS = _Tibia_Diaphysis()
    TIBIA_EPIPHYSIS = _Tibia_Epiphysis()
    TIBIA_METAPHYSIS = _Tibia_Metaphysis()
    TRIGEMINAL_V_PRINCIPAL_SENSORY_NUCLEUS = _Trigeminal_V_Principal_Sensory_Nucleus()
    TRUE_RIB = _True_Rib()
    TYMPANIC_CAVITY_BLOOD_VESSEL = _Tympanic_Cavity_Blood_Vessel()
    TYMPANIC_CAVITY_MUSCLE = _Tympanic_Cavity_Muscle()
    TYMPANIC_CAVITY_NERVE = _Tympanic_Cavity_Nerve()
    TYMPANIC_CAVITY = _Tympanic_Cavity()
    URETER_LUMINAL_UROTHELIUM = _Ureter_Luminal_Urothelium()
    URETER_SUBLUMINAL_UROTHELIUM = _Ureter_Subluminal_Urothelium()
    URETERAL_VALVE = _Ureteral_Valve()
    URETEROPELVIC_JUNCTION = _Ureteropelvic_Junction()
    URETEROVESICAL_JUNCTION = _Ureterovesical_Junction()
    URETHRA_GLAND = _Urethra_Gland()
    URETHRA_LAMINA_PROPRIA = _Urethra_Lamina_Propria()
    URETHRA_MESENCHYMAL_LAYER = _Urethra_Mesenchymal_Layer()
    URETHRA_MUSCLE = _Urethra_Muscle()
    URETHRA_SKELETAL_MUSCLE = _Urethra_Skeletal_Muscle()
    URETHRAL_SPHINCTER = _Urethral_Sphincter()
    URETHRALIS = _Urethralis()
    URINARY_BLADDER_MUSCLE = _Urinary_Bladder_Muscle()
    UTERUS_SEROSA = _Uterus_Serosa()
    VAGINA_SEBACEOUS_GLAND = _Vagina_Sebaceous_Gland()
    VAGINA_SQUAMOUS_EPITHELIUM = _Vagina_Squamous_Epithelium()
    VAGINAL_HYMEN = _Vaginal_Hymen()
    VAGINAL_VEIN = _Vaginal_Vein()
    VAGUS_NERVE = _Vagus_Nerve()
    LEFT_VAGUS_NERVE_TRUNK = _Left_Vagus_Nerve_Trunk()
    RIGHT_VAGUS_NERVE_TRUNK = _Right_Vagus_Nerve_Trunk()
    VENA_CAVA_ENDOTHELIUM = _Vena_Cava_Endothelium()
    VAGINAL_VENOUS_PLEXUS = _Vaginal_Venous_Plexus()
    VERTEBRA_CRANIAL_ARTICULAR_PROCESS = _Vertebra_Cranial_Articular_Process()
    VERTEBRA_NEURAL_CANAL = _Vertebra_Neural_Canal()
    VISCERAL_MESOTHELIUM = _Visceral_Mesothelium()
    VITREOUS_CHAMBER = _Vitreous_Chamber()
    WHITE_FIBROCARTILAGE = _White_Fibrocartilage()
    ZYGOMATIC_BONE_TEMPORAL_PROCESS = _Zygomatic_Bone_Temporal_Process()
    ZYMBAL_S_GLAND = _Zymbal_S_Gland()
    BRONCHUS_BASEMENT_MEMBRANE = _Bronchus_Basement_Membrane()
    BRONCHUS_BASAL_LAMINA = _Bronchus_Basal_Lamina()
    BRONCHUS_RETICULAR_LAMINA = _Bronchus_Reticular_Lamina()
    CEREBELLAR_GLOMERULUS = _Cerebellar_Glomerulus()
    SUBARACHNOID_CISTERN = _Subarachnoid_Cistern()
    CEREBELLOMEDULLARY_CISTERN = _Cerebellomedullary_Cistern()
    LATERAL_CEREBELLOMEDULLARY_CISTERN = _Lateral_Cerebellomedullary_Cistern()
    POSTERIOR_CEREBELLOMEDULLARY_CISTERN = _Posterior_Cerebellomedullary_Cistern()
    QUADRIGEMINAL_CISTERN = _Quadrigeminal_Cistern()
    CEREBELLUM_FISSURE = _Cerebellum_Fissure()
    CEREBELLUM_INTERPOSITUS_NUCLEUS = _Cerebellum_Interpositus_Nucleus()
    CEREBELLUM_GLOBOSE_NUCLEUS = _Cerebellum_Globose_Nucleus()
    CEREBELLUM_EMBOLIFORM_NUCLEUS = _Cerebellum_Emboliform_Nucleus()
    CEREBELLUM_INTERMEDIATE_ZONE = _Cerebellum_Intermediate_Zone()
    CEREBELLUM_VERMIS_LOBULE_VIIA = _Cerebellum_Vermis_Lobule_Viia()
    CEREBELLUM_VERMIS_LOBULE_VIIB = _Cerebellum_Vermis_Lobule_Viib()
    CERVICAL_RIB = _Cervical_Rib()
    NECK_OF_RIB = _Neck_Of_Rib()
    CHIN = _Chin()
    CINGULUM_BUNDLE = _Cingulum_Bundle()
    CIRCLE_OF_WILLIS = _Circle_Of_Willis()
    COCHLEA_BASEMENT_MEMBRANE = _Cochlea_Basement_Membrane()
    EXTERNAL_NOSE = _External_Nose()
    COLUMELLA_NASI = _Columella_Nasi()
    VENTRICLE_COMPACT_MYOCARDIUM = _Ventricle_Compact_Myocardium()
    CONJUNCTIVAL_FORNIX = _Conjunctival_Fornix()
    CORNEO_SCLERAL_JUNCTION = _Corneo_Scleral_Junction()
    CORONARY_SINUS = _Coronary_Sinus()
    CRISTA_TERMINALIS = _Crista_Terminalis()
    CRYPT_OF_LIEBERKUHN_OF_DUODENUM = _Crypt_Of_Lieberkuhn_Of_Duodenum()
    CRYPT_OF_LIEBERKUHN_OF_ILEUM = _Crypt_Of_Lieberkuhn_Of_Ileum()
    CRYPT_OF_LIEBERKUHN_OF_JEJUNUM = _Crypt_Of_Lieberkuhn_Of_Jejunum()
    CUTANEOUS_ELASTIC_TISSUE = _Cutaneous_Elastic_Tissue()
    DEPRESSOR_ANGULI_ORIS = _Depressor_Anguli_Oris()
    ALIMENTARY_SYSTEM_ORGAN = _Alimentary_System_Organ()
    DORSAL_TELENCEPHALIC_COMMISSURE = _Dorsal_Telencephalic_Commissure()
    VENTRAL_TELENCEPHALIC_COMMISSURE = _Ventral_Telencephalic_Commissure()
    RETICULAR_TISSUE = _Reticular_Tissue()
    ENDONEURIUM = _Endoneurium()
    EPINEURIUM = _Epineurium()
    PERINEURIUM = _Perineurium()
    ENDONEURIAL_FLUID = _Endoneurial_Fluid()
    EPAXIAL_MUSCULATURE = _Epaxial_Musculature()
    HYPAXIAL_MUSCULATURE = _Hypaxial_Musculature()
    BODY_WALL_MUSCULATURE = _Body_Wall_Musculature()
    GIRDLE_REGION = _Girdle_Region()
    GIRDLE_MUSCULATURE = _Girdle_Musculature()
    PECTORAL_GIRDLE_REGION = _Pectoral_Girdle_Region()
    PECTORAL_GIRDLE_MUSCULATURE = _Pectoral_Girdle_Musculature()
    LIMB_GIRDLE_COMPLEX = _Limb_Girdle_Complex()
    LIMB_GIRDLE_COMPLEX_MUSCULATURE = _Limb_Girdle_Complex_Musculature()
    PECTORAL_COMPLEX = _Pectoral_Complex()
    PECTORAL_COMPLEX_MUSCULATURE = _Pectoral_Complex_Musculature()
    PELVIC_GIRDLE_REGION = _Pelvic_Girdle_Region()
    PELVIC_COMPLEX = _Pelvic_Complex()
    PELVIC_COMPLEX__MUSCULATURE = _Pelvic_Complex_Musculature()
    EPENDYMA = _Ependyma()
    EPIDERMAL_DERMAL_JUNCTION = _Epidermal_Dermal_Junction()
    OVARY_FOLLICULAR_ANTRUM = _Ovary_Follicular_Antrum()
    FORAMEN_MAGNUM = _Foramen_Magnum()
    FOREHEAD = _Forehead()
    GENU_OF_FACIAL_NERVE = _Genu_Of_Facial_Nerve()
    NASAL_GLAND = _Nasal_Gland()
    GLYMPHATIC_SYSTEM = _Glymphatic_System()
    GOLGI_TENDON_ORGAN = _Golgi_Tendon_Organ()
    GONIAL_BONE = _Gonial_Bone()
    HABENULAR_COMMISSURE = _Habenular_Commissure()
    HAIR_FOLLICLE_BULGE = _Hair_Follicle_Bulge()
    HAIR_FOLLICLE_ISTHMUS = _Hair_Follicle_Isthmus()
    HAIR_FOLLICLE_MATRIX_REGION = _Hair_Follicle_Matrix_Region()
    HEMOTRICHORIAL_PLACENTAL_MEMBRANE = _Hemotrichorial_Placental_Membrane()
    HEPATIC_CORD = _Hepatic_Cord()
    INGUINAL_CANAL = _Inguinal_Canal()
    INNER_EAR_CANAL = _Inner_Ear_Canal()
    INTEGUMENTAL_SYSTEM_ADNEXA = _Integumental_System_Adnexa()
    INTERPHALANGEAL_JOINT = _Interphalangeal_Joint()
    COLLECTING_DUCT_EPITHELIUM = _Collecting_Duct_Epithelium()
    METANEPHROS_CORTICOMEDULLARY_BOUNDARY = _Metanephros_Corticomedullary_Boundary()
    DORSAL_CORTICOSPINAL_TRACT = _Dorsal_Corticospinal_Tract()
    LATERAL_CORTICOSPINAL_TRACT = _Lateral_Corticospinal_Tract()
    VENTRAL_CORTICOSPINAL_TRACT = _Ventral_Corticospinal_Tract()
    HEAD_OF_FIBULA = _Head_Of_Fibula()
    NECK_OF_FIBULA = _Neck_Of_Fibula()
    BODY_OF_FIBULA = _Body_Of_Fibula()
    LATERAL_MALLEOLUS_OF_FIBULA = _Lateral_Malleolus_Of_Fibula()
    LATERAL_NASAL_GLAND = _Lateral_Nasal_Gland()
    LINE_OF_SCHWALBE = _Line_Of_Schwalbe()
    LONG_BONE_EPIPHYSEAL_PLATE_OSSIFICATION_ZONE = _Long_Bone_Epiphyseal_Plate_Ossification_Zone()
    LYMPH_NODE_MEDULLARY_CORD = _Lymph_Node_Medullary_Cord()
    LYMPH_NODE_MEDULLARY_SINUS = _Lymph_Node_Medullary_Sinus()
    MAJOR_SUBLINGUAL_DUCT = _Major_Sublingual_Duct()
    MAMMARY_DUCT_TERMINAL_END_BUD = _Mammary_Duct_Terminal_End_Bud()
    MAMMARY_FAT_PAD = _Mammary_Fat_Pad()
    MAMMARY_GLAND_LUMINAL_EPITHELIUM = _Mammary_Gland_Luminal_Epithelium()
    MAMMARY_GLAND_MYOEPITHELIUM = _Mammary_Gland_Myoepithelium()
    MAMMILLOTHALAMIC_TRACT_OF_HYPOTHALAMUS = _Mammillothalamic_Tract_Of_Hypothalamus()
    EYELID_MARGIN = _Eyelid_Margin()
    MEDULLARY_RAY = _Medullary_Ray()
    MESANGIAL_MATRIX = _Mesangial_Matrix()
    METOPTIC_PILLAR = _Metoptic_Pillar()
    MINOR_SUBLINGUAL_DUCT = _Minor_Sublingual_Duct()
    MOLAR_CROWN = _Molar_Crown()
    FLOOR_OF_ORAL_CAVITY = _Floor_Of_Oral_Cavity()
    URETHRA_MUCOSA = _Urethra_Mucosa()
    MUCOUS_GLAND = _Mucous_Gland()
    NASAL_CONCHA_OF_ETHMOID_BONE = _Nasal_Concha_Of_Ethmoid_Bone()
    NOSE_TIP = _Nose_Tip()
    OCULAR_FUNDUS = _Ocular_Fundus()
    MAIN_OLFACTORY_BULB_LAYER = _Main_Olfactory_Bulb_Layer()
    OLFACTORY_SEGMENT_OF_NASAL_MUCOSA = _Olfactory_Segment_Of_Nasal_Mucosa()
    PRETECTAL_NUCLEUS = _Pretectal_Nucleus()
    ANTERIOR_PRETECTAL_NUCLEUS = _Anterior_Pretectal_Nucleus()
    OLIVARY_PRETECTAL_NUCLEUS = _Olivary_Pretectal_Nucleus()
    POSTERIOR_PRETECTAL_NUCLEUS = _Posterior_Pretectal_Nucleus()
    OSTEOID = _Osteoid()
    OTOLITH = _Otolith()
    LEFT_VENTRICLE_OUTFLOW_PART = _Left_Ventricle_Outflow_Part()
    RIGHT_VENTRICLE_OUTFLOW_PART = _Right_Ventricle_Outflow_Part()
    OVARY_CORTEX = _Ovary_Cortex()
    OVARY_MEDULLA = _Ovary_Medulla()
    PALATAL_MUSCLE = _Palatal_Muscle()
    PALATAL_BONE = _Palatal_Bone()
    PALATINE_BONE_HORIZONTAL_PLATE = _Palatine_Bone_Horizontal_Plate()
    PALATINE_PROCESS_OF_MAXILLA = _Palatine_Process_Of_Maxilla()
    PAROTID_GLAND_ACINUS = _Parotid_Gland_Acinus()
    PAROTID_GLAND_MYOEPITHELIUM = _Parotid_Gland_Myoepithelium()
    PECITINATE_MUSCLE = _Pecitinate_Muscle()
    PERIANAL_GLAND = _Perianal_Gland()
    PERIORBITAL_SKIN = _Periorbital_Skin()
    PERIPHERAL_LYMPH_NODE = _Peripheral_Lymph_Node()
    PEYER_S_PATCH_T_CELL_AREA = _Peyer_S_Patch_T_Cell_Area()
    PUBIC_SYMPHYSIS = _Pubic_Symphysis()
    LUNG_ACINUS = _Lung_Acinus()
    LUNG_ALVEOLAR_PARENCHYMA = _Lung_Alveolar_Parenchyma()
    PULMONARY_NEUROENDOCRINE_BODY = _Pulmonary_Neuroendocrine_Body()
    PYLORIC_CANAL = _Pyloric_Canal()
    PYRAMIDAL_DECUSSATION = _Pyramidal_Decussation()
    RESPIRATORY_CONDUCTING_TUBE = _Respiratory_Conducting_Tube()
    RETROSPLENIAL_GRANULAR_CORTEX = _Retrosplenial_Granular_Cortex()
    MOLAR_ROOT = _Molar_Root()
    SCALP = _Scalp()
    SEROUS_GLAND = _Serous_Gland()
    SINOTUBULAR_JUNCTION = _Sinotubular_Junction()
    FOREHEAD_SKIN = _Forehead_Skin()
    SOMATIC_MOTOR_SYSTEM = _Somatic_Motor_System()
    SOMATIC_SENSORY_SYSTEM = _Somatic_Sensory_System()
    SPINAL_CORD_COMMISSURE = _Spinal_Cord_Commissure()
    SPINAL_CORD_VENTRAL_COMMISSURE = _Spinal_Cord_Ventral_Commissure()
    AUTONOMIC_NERVE = _Autonomic_Nerve()
    SYMPATHETIC_NERVE = _Sympathetic_Nerve()
    SPLANCHNIC_NERVE = _Splanchnic_Nerve()
    SPLEEN_PRIMARY_B_FOLLICLE = _Spleen_Primary_B_Follicle()
    SPLEEN_SECONDARY_B_FOLLICLE = _Spleen_Secondary_B_Follicle()
    SPLEEN_B_CELL_CORONA = _Spleen_B_Cell_Corona()
    SPLEEN_FOLLICULAR_DENDRITIC_CELL_NETWORK = _Spleen_Follicular_Dendritic_Cell_Network()
    SPLEEN_PERIFOLLICULAR_ZONE = _Spleen_Perifollicular_Zone()
    STOMACH_SMOOTH_MUSCLE_INNER_OBLIQUE_LAYER = _Stomach_Smooth_Muscle_Inner_Oblique_Layer()
    STOMACH_SMOOTH_MUSCLE_OUTER_LONGITUDINAL_LAYER = _Stomach_Smooth_Muscle_Outer_Longitudinal_Layer()
    SUBARCUATE_FOSSA = _Subarcuate_Fossa()
    SUBENDOCARDIUM = _Subendocardium()
    SUBGLOTTIC_REGION = _Subglottic_Region()
    SUBMUCOSAL_GLAND = _Submucosal_Gland()
    TAIL_HAIR = _Tail_Hair()
    MEIBOMIAN_GLAND_ACINUS = _Meibomian_Gland_Acinus()
    THROAT = _Throat()
    THYMUS_CORTICOMEDULLARY_BOUNDARY = _Thymus_Corticomedullary_Boundary()
    TOOTH_ROOT = _Tooth_Root()
    TUNNEL_OF_CORTI = _Tunnel_Of_Corti()
    URETHRAL_MEATUS = _Urethral_Meatus()
    UROTHELIUM = _Urothelium()
    UTERINE_FAT_PAD = _Uterine_Fat_Pad()
    UTRICULOSACCULAR_DUCT = _Utriculosaccular_Duct()
    UTRICLE_DUCT = _Utricle_Duct()
    SACCULE_DUCT = _Saccule_Duct()
    VAGINA_ORIFICE = _Vagina_Orifice()
    VENTRAL_BODY_WALL = _Ventral_Body_Wall()
    VESTIBULO_AUDITORY_SYSTEM = _Vestibulo_Auditory_System()
    VESTIBULAR_SYSTEM = _Vestibular_System()
    BLOOD_VESSEL_WALL = _Blood_Vessel_Wall()
    CHORDAMESODERM = _Chordamesoderm()
    PRECHORDAL_MESODERM = _Prechordal_Mesoderm()
    PRECHORDAL_PLATE = _Prechordal_Plate()
    CARDIAC_NEURAL_CREST = _Cardiac_Neural_Crest()
    CARDIOGENIC_SPLANCHNIC_MESODERM = _Cardiogenic_Splanchnic_Mesoderm()
    PRIMARY_HEART_FIELD = _Primary_Heart_Field()
    NEURAXIS_FLEXURE = _Neuraxis_Flexure()
    CEPHALIC_MIDBRAIN_FLEXURE = _Cephalic_Midbrain_Flexure()
    PONTINE_FLEXURE = _Pontine_Flexure()
    CERVICAL_FLEXURE = _Cervical_Flexure()
    NEPHROGENIC_CORD_ROSTRAL_PART = _Nephrogenic_Cord_Rostral_Part()
    NEPHROGENIC_CORD_CAUDAL_PART = _Nephrogenic_Cord_Caudal_Part()
    NEPHRON_EPITHELIUM = _Nephron_Epithelium()
    CEREBELLAR_PLATE = _Cerebellar_Plate()
    NEUROMERE = _Neuromere()
    NEUROPORE = _Neuropore()
    CRUCIATE_LIGAMENT_OF_KNEE = _Cruciate_Ligament_Of_Knee()
    MENISCUS_OF_KNEE = _Meniscus_Of_Knee()
    LATERAL_MENISCUS_OF_KNEE = _Lateral_Meniscus_Of_Knee()
    MEDIAL_MENISCUS_OF_KNEE = _Medial_Meniscus_Of_Knee()
    DEEP_PERONEAL_NERVE = _Deep_Peroneal_Nerve()
    SUPERFICIAL_PERONEAL_NERVE = _Superficial_Peroneal_Nerve()
    LATERAL_FEMORAL_CUTANEOUS_NERVE = _Lateral_Femoral_Cutaneous_Nerve()
    UPPER_LIP_SKIN = _Upper_Lip_Skin()
    LOWER_LIP_SKIN = _Lower_Lip_Skin()
    PERIDERM = _Periderm()
    THYMUS_CORTEX_EPITHELIUM = _Thymus_Cortex_Epithelium()
    THYMUS_MEDULLA_EPITHELIUM = _Thymus_Medulla_Epithelium()
    DUODENUM_VILLUS = _Duodenum_Villus()
    JEJUNUM_VILLUS = _Jejunum_Villus()
    ILEUM_VILLUS = _Ileum_Villus()
    GUT_MUCOSA = _Gut_Mucosa()
    GUT_SEROSA = _Gut_Serosa()
    BLADDER_LUMEN = _Bladder_Lumen()
    VERTEBROBASILAR_ARTERIAL_SYSTEM = _Vertebrobasilar_Arterial_System()
    CEREBRAL_HEMISPHERE = _Cerebral_Hemisphere()
    LEFT_CEREBRAL_HEMISPHERE = _Left_Cerebral_Hemisphere()
    RIGHT_CEREBRAL_HEMISPHERE = _Right_Cerebral_Hemisphere()
    UPPER_JAW_PRIMORDIUM = _Upper_Jaw_Primordium()
    LOWER_JAW_PRIMORDIUM = _Lower_Jaw_Primordium()
    LONG_BONE_EPIPHYSEAL_PLATE_RESTING_ZONE = _Long_Bone_Epiphyseal_Plate_Resting_Zone()
    EXTRACELLULAR_MATRIX = _Extracellular_Matrix()
    BASEMENT_MEMBRANE = _Basement_Membrane()
    BASEMENT_MEMBRANE_OF_EPITHELIUM = _Basement_Membrane_Of_Epithelium()
    UTERUS_EPITHELIUM = _Uterus_Epithelium()
    ATLANTO_OCCIPITAL_JOINT = _Atlanto_Occipital_Joint()
    OPTIC_CHOROID_PLUS_PIGMENTED_RETINAL_EPITHELIUM = _Optic_Choroid_Plus_Pigmented_Retinal_Epithelium()
    LYMPH_SAC = _Lymph_Sac()
    MAMMARY_GLAND_PRIMORDIUM = _Mammary_Gland_Primordium()
    MAMMARY_GLAND_PRIMORDIUM_EPITHELIUM = _Mammary_Gland_Primordium_Epithelium()
    MAMMARY_FAT_PAD_PRECURSOR = _Mammary_Fat_Pad_Precursor()
    MAMMARY_SPROUT = _Mammary_Sprout()
    CARPAL_METACARPAL_JOINT = _Carpal_Metacarpal_Joint()
    TARSAL_METATARSAL_JOINT = _Tarsal_Metatarsal_Joint()
    PROXIMAL_INTERPHALANGEAL_JOINT = _Proximal_Interphalangeal_Joint()
    DISTAL_INTERPHALANGEAL_JOINT = _Distal_Interphalangeal_Joint()
    FORELIMB_PROXIMAL_INTERPHALANGEAL_JOINT = _Forelimb_Proximal_Interphalangeal_Joint()
    FORELIMB_DISTAL_INTERPHALANGEAL_JOINT = _Forelimb_Distal_Interphalangeal_Joint()
    HINDLIMB_PROXIMAL_INTERPHALANGEAL_JOINT = _Hindlimb_Proximal_Interphalangeal_Joint()
    HINDLIMB_DISTAL_INTERPHALANGEAL_JOINT = _Hindlimb_Distal_Interphalangeal_Joint()
    JOINT_OF_AUDITORY_OSSICLE = _Joint_Of_Auditory_Ossicle()
    INCUDOMALLEAL_JOINT = _Incudomalleal_Joint()
    HEART_TRABECULA = _Heart_Trabecula()
    ATRIAL_TRABECULA_CARDIAC_MUSCLE = _Atrial_Trabecula_Cardiac_Muscle()
    ATRIOVENTRICULAR_SULCUS = _Atrioventricular_Sulcus()
    LIMB_TENDON = _Limb_Tendon()
    TENDON_PRIMORDIUM = _Tendon_Primordium()
    LIMB_TENDON_PRIMORDIUM = _Limb_Tendon_Primordium()
    FORELIMB_TENDON_PRIMORDIUM = _Forelimb_Tendon_Primordium()
    HINDLIMB_TENDON_PRIMORDIUM = _Hindlimb_Tendon_Primordium()
    FORELIMB_TENDON = _Forelimb_Tendon()
    HINDLIMB_TENDON = _Hindlimb_Tendon()
    FORELIMB_JOINT_PRIMORDIUM = _Forelimb_Joint_Primordium()
    HINDLIMB_JOINT_PRIMORDIUM = _Hindlimb_Joint_Primordium()
    HAND_JOINT_PRIMORDIUM = _Hand_Joint_Primordium()
    FOOT_JOINT_PRIMORDIUM = _Foot_Joint_Primordium()
    ANTERIOR_CRUCIATE_LIGAMENT = _Anterior_Cruciate_Ligament()
    POSTERIOR_CRUCIATE_LIGAMENT = _Posterior_Cruciate_Ligament()
    INTESTINE_SMOOTH_MUSCLE_CIRCULAR_LAYER = _Intestine_Smooth_Muscle_Circular_Layer()
    INTESTINE_SMOOTH_MUSCLE_LONGITUDINAL_LAYER = _Intestine_Smooth_Muscle_Longitudinal_Layer()
    SECONDARY_MOTOR_CORTEX = _Secondary_Motor_Cortex()
    ECTORHINAL_AREA = _Ectorhinal_Area()
    INFRALIMBIC_AREA = _Infralimbic_Area()
    ORBITAL_AREA = _Orbital_Area()
    ANTERIOR_MEDIAL_THALAMIC_NUCLEUS = _Anterior_Medial_Thalamic_Nucleus()
    VESTIBULOCEREBELLAR_NUCLEUS = _Vestibulocerebellar_Nucleus()
    LATERAL_DORSAL_THALAMIC_NUCLEUS = _Lateral_Dorsal_Thalamic_Nucleus()
    LATERAL_POSTERIOR_THALAMIC_NUCLEUS = _Lateral_Posterior_Thalamic_Nucleus()
    VENTRAL_MEDIAL_THALAMIC_NUCLEUS = _Ventral_Medial_Thalamic_Nucleus()
    CRANIAL_CARTILAGE = _Cranial_Cartilage()
    TECTUM_TRANSVERSUM = _Tectum_Transversum()
    CERVICAL_LOOP = _Cervical_Loop()
    STELLATE_RETICULUM = _Stellate_Reticulum()
    STRATUM_INTERMEDIUM = _Stratum_Intermedium()
    HERTWIG_S_EPITHELIAL_ROOT_SHEATH = _Hertwig_S_Epithelial_Root_Sheath()
    ENAMEL_EPITHELIUM = _Enamel_Epithelium()
    INNER_ENAMEL_EPITHELIUM = _Inner_Enamel_Epithelium()
    OUTER_ENAMEL_EPITHELIUM = _Outer_Enamel_Epithelium()
    DENTAL_ALVEOLUS = _Dental_Alveolus()
    INTERALVEOLAR_BONE = _Interalveolar_Bone()
    EARLY_BUD_STAGE_TOOTH = _Early_Bud_Stage_Tooth()
    LATE_BUD_STAGE_TOOTH = _Late_Bud_Stage_Tooth()
    ENAMEL_KNOT = _Enamel_Knot()
    PRIMARY_ENAMEL_KNOT = _Primary_Enamel_Knot()
    SECONDARY_ENAMEL_KNOT = _Secondary_Enamel_Knot()
    TERTIARY_ENAMEL_KNOT = _Tertiary_Enamel_Knot()
    TENSOR_VELI_PALATINI = _Tensor_Veli_Palatini()
    LEVATOR_VELI_PALATINI = _Levator_Veli_Palatini()
    PALATOPHARYNGEUS = _Palatopharyngeus()
    LIMB_PRIMORDIUM = _Limb_Primordium()
    SMALL_INTESTINE_VASCULAR_ELEMENT = _Small_Intestine_Vascular_Element()
    SPLEEN_VASCULAR_ELEMENT = _Spleen_Vascular_Element()
    INTESTINE_VASCULAR_ELEMENT = _Intestine_Vascular_Element()
    LATERAL_NASAL_GLAND_2 = _Lateral_Nasal_Gland_2()
    LATERAL_NASAL_GLAND_3 = _Lateral_Nasal_Gland_3()
    LATERAL_NASAL_GLAND_4 = _Lateral_Nasal_Gland_4()
    LATERAL_NASAL_GLAND_5 = _Lateral_Nasal_Gland_5()
    LATERAL_NASAL_GLAND_DUCT = _Lateral_Nasal_Gland_Duct()
    LATERAL_NASAL_GLAND_EPITHELIUM = _Lateral_Nasal_Gland_Epithelium()
    LATERAL_NASAL_GLAND_MESENCHYME = _Lateral_Nasal_Gland_Mesenchyme()
    MAXILLARY_SINUS_GLAND_PRIMORDIUM = _Maxillary_Sinus_Gland_Primordium()
    MAXILLARY_SINUS_GLAND_PRIMORDIUM_EPITHELIUM = _Maxillary_Sinus_Gland_Primordium_Epithelium()
    MAXILLARY_SINUS_GLAND_PRIMORDIUM_MESENCHYME = _Maxillary_Sinus_Gland_Primordium_Mesenchyme()
    MAXILLARY_SINUS_GLAND = _Maxillary_Sinus_Gland()
    MAXILLARY_SINUS_GLAND_EPITHELIUM = _Maxillary_Sinus_Gland_Epithelium()
    MAXILLARY_SINUS_GLAND_MESENCHYME = _Maxillary_Sinus_Gland_Mesenchyme()
    MEDIAL_NASAL_GLAND = _Medial_Nasal_Gland()
    MEDIAL_NASAL_GLAND_EPITHELIUM = _Medial_Nasal_Gland_Epithelium()
    MEDIAL_NASAL_GLAND_MESENCHYME = _Medial_Nasal_Gland_Mesenchyme()
    STENO_S_GLAND = _Steno_S_Gland()
    STENO_S_DUCT = _Steno_S_Duct()
    STENO_S_GLAND_EPITHELIUM = _Steno_S_Gland_Epithelium()
    STENO_S_GLAND_MESENCHYME = _Steno_S_Gland_Mesenchyme()
    MAXILLARY_SINUS_EPITHELIUM = _Maxillary_Sinus_Epithelium()
    MAXILLARY_SINUS_MESENCHYME = _Maxillary_Sinus_Mesenchyme()
    NASAL_GLAND_EPITHELIUM = _Nasal_Gland_Epithelium()
    NASAL_GLAND_MESENCHYME = _Nasal_Gland_Mesenchyme()
    PARATHYROID_PRIMORDIUM = _Parathyroid_Primordium()
    ADRENOGONADAL_PRIMORDIUM = _Adrenogonadal_Primordium()
    ADRENAL_PRIMORDIUM = _Adrenal_Primordium()
    TESTIS_EPITHELIUM = _Testis_Epithelium()
    FOREGUT_GLAND_PRIMORDIUM = _Foregut_Gland_Primordium()
    MANDIBLE_CONDYLAR_CONDENSATION = _Mandible_Condylar_Condensation()
    MANDIBULAR_FOSSA = _Mandibular_Fossa()
    EMBRYONIC_VISCERAL_ENDODERM = _Embryonic_Visceral_Endoderm()
    EMBRYONIC_POSTERIOR_VISCERAL_ENDODERM = _Embryonic_Posterior_Visceral_Endoderm()
    EXTRAEMBRYONIC_POSTERIOR_VISCERAL_ENDODERM = _Extraembryonic_Posterior_Visceral_Endoderm()
    ALLANTOIS_ASSOCIATED_POSTERIOR_VISCERAL_ENDODERM = _Allantois_Associated_Posterior_Visceral_Endoderm()
    ALLANTOIC_CORE_DOMAIN = _Allantoic_Core_Domain()
    EXTRAEMBRYONIC_PRIMITIVE_STREAK = _Extraembryonic_Primitive_Streak()
    LENS_PRIMORDIUM = _Lens_Primordium()
    POSTERIOR_CROWN_OF_NODE = _Posterior_Crown_Of_Node()
    MARGINAL_VEIN_OF_LIMB = _Marginal_Vein_Of_Limb()
    CORTICAL_HEM = _Cortical_Hem()
    NUCLEUS_OF_LATERAL_LEMNISCUS = _Nucleus_Of_Lateral_Lemniscus()
    DORSAL_NUCLEUS_OF_LATERAL_LEMNISCUS = _Dorsal_Nucleus_Of_Lateral_Lemniscus()
    INTERMEDIATE_NUCLEUS_OF_LATERAL_LEMNISCUS = _Intermediate_Nucleus_Of_Lateral_Lemniscus()
    VENTRAL_NUCLEUS_OF_LATERAL_LEMNISCUS = _Ventral_Nucleus_Of_Lateral_Lemniscus()
    GENITAL_TUBERCLE_SURFACE_EPITHELIUM = _Genital_Tubercle_Surface_Epithelium()
    OVIDUCT_ISTHMUS = _Oviduct_Isthmus()
    OVIDUCT_AMPULLA = _Oviduct_Ampulla()
    PARAMEDIAN_RAPHE_NUCLEUS = _Paramedian_Raphe_Nucleus()
    PARVICELLULAR_RETICULAR_NUCLEUS = _Parvicellular_Reticular_Nucleus()
    CEREBRAL_PEDUNCLE = _Cerebral_Peduncle()
    LOWER_UROGENITAL_TRACT = _Lower_Urogenital_Tract()
    LOWER_UROGENITAL_TRACT_ADVENTITIA = _Lower_Urogenital_Tract_Adventitia()
    LOWER_UROGENITAL_TRACT_EPITHELIUM = _Lower_Urogenital_Tract_Epithelium()
    LOWER_UROGENITAL_TRACT_MESENCHYME = _Lower_Urogenital_Tract_Mesenchyme()
    LOWER_UROGENITAL_TRACT_MUSCLE = _Lower_Urogenital_Tract_Muscle()
    LOWER_UROGENITAL_TRACT_NERVE = _Lower_Urogenital_Tract_Nerve()
    LOWER_UROGENITAL_TRACT_VASCULATURE = _Lower_Urogenital_Tract_Vasculature()
    ROSTRAL_MIGRATORY_STREAM = _Rostral_Migratory_Stream()
    LOWER_UROGENITAL_TRACT_OF_FEMALE = _Lower_Urogenital_Tract_Of_Female()
    LOWER_UROGENITAL_TRACT_OF_MALE = _Lower_Urogenital_Tract_Of_Male()
    FEMALE_LOWER_UROGENITAL_TRACT_EPITHELIUM = _Female_Lower_Urogenital_Tract_Epithelium()
    FEMALE_LOWER_UROGENITAL_TRACT_MESENCHYME = _Female_Lower_Urogenital_Tract_Mesenchyme()
    FEMALE_LOWER_UROGENITAL_TRACT_MUSCLE = _Female_Lower_Urogenital_Tract_Muscle()
    MALE_LOWER_UROGENITAL_TRACT_EPITHELIUM = _Male_Lower_Urogenital_Tract_Epithelium()
    MALE_LOWER_UROGENITAL_TRACT_MESENCHYME = _Male_Lower_Urogenital_Tract_Mesenchyme()
    MALE_LOWER_UROGENITAL_TRACT_MUSCLE = _Male_Lower_Urogenital_Tract_Muscle()
    CILIARY_ZONULE = _Ciliary_Zonule()
    EXTERNAL_GENITALIA = _External_Genitalia()
    PREPUCE = _Prepuce()
    SKELETAL_JOINT_PRIMORDIUM = _Skeletal_Joint_Primordium()
    ANTERIOR_PRE_PLACODAL_REGION = _Anterior_Pre_Placodal_Region()
    POSTERIOR_PRE_PLACODAL_REGION = _Posterior_Pre_Placodal_Region()
    VENTRICLE_EPENDYMA = _Ventricle_Ependyma()
    LOWER_URINARY_TRACT_EPITHELIUM = _Lower_Urinary_Tract_Epithelium()
    LOWER_URINARY_TRACT_MESENCHYME = _Lower_Urinary_Tract_Mesenchyme()
    DISTAL_GENITAL_TUBERCLE = _Distal_Genital_Tubercle()
    GLANS_OF_GENITAL_TUBERCLE = _Glans_Of_Genital_Tubercle()
    PROXIMAL_GENITAL_TUBERCLE = _Proximal_Genital_Tubercle()
    NUCLEUS_INCERTUS = _Nucleus_Incertus()
    HAIR_PEG = _Hair_Peg()
    FACIAL_PROMINENCE = _Facial_Prominence()
    FACIAL_PROMINENCE_ECTODERM = _Facial_Prominence_Ectoderm()
    FACIAL_PROMINENCE_MESENCHYME = _Facial_Prominence_Mesenchyme()
    MANDIBULAR_PROCESS_ECTODERM = _Mandibular_Process_Ectoderm()
    MAXILLARY_PROCESS_ECTODERM = _Maxillary_Process_Ectoderm()
    EPIDIDYMIS_INITIAL_SEGMENT = _Epididymis_Initial_Segment()
    GESCHMACKSSTREIFEN = _Geschmacksstreifen()
    PALLIUM = _Pallium()
    LATERAL_PALLIUM = _Lateral_Pallium()
    VENTRAL_PALLIUM = _Ventral_Pallium()
    SUBPALLIUM = _Subpallium()
    DIAGONAL_DOMAIN = _Diagonal_Domain()
    PROXIMAL_STRAIGHT_TUBULE = _Proximal_Straight_Tubule()
    OOCYTE_OF_PREANTRAL_FOLLICLE = _Oocyte_Of_Preantral_Follicle()
    OOCYTE_OF_ANTRAL_FOLLICLE = _Oocyte_Of_Antral_Follicle()
    FOLLICLE_CELL_OF_PREANTRAL_FOLLICLE = _Follicle_Cell_Of_Preantral_Follicle()
    DORSAL_AORTA_ENDOTHELIUM = _Dorsal_Aorta_Endothelium()
    EPIDERMIS_INTERMEDIATE_LAYER = _Epidermis_Intermediate_Layer()
    AORTA_GONAD_MESONEPHROS = _Aorta_Gonad_Mesonephros()
    DENTATE_NOTCH = _Dentate_Notch()
    PARATENIAL_NUCLEUS = _Paratenial_Nucleus()
    ANTERIOR_NEURAL_RIDGE = _Anterior_Neural_Ridge()
    JUNCTIONAL_ZONE = _Junctional_Zone()
    TEMPORO_MANDIBULAR_JOINT_DISC = _Temporo_Mandibular_Joint_Disc()
    ENTOPEDUNCULAR_NUCLEUS = _Entopeduncular_Nucleus()
    CRANIOFACIAL_SUTURE = _Craniofacial_Suture()
    FACIAL_SUTURE = _Facial_Suture()
    FONTANELLE = _Fontanelle()
    CORONAL_SUTURE_FRONTAL_OSTEOGENIC_FRONT = _Coronal_Suture_Frontal_Osteogenic_Front()
    CORONAL_SUTURE_MESENCHYME = _Coronal_Suture_Mesenchyme()
    CORONAL_SUTURE_PARIETAL_OSTEOGENIC_FRONT = _Coronal_Suture_Parietal_Osteogenic_Front()
    FRONTAL_SUTURE_FRONTAL_OSTEOGENIC_FRONT = _Frontal_Suture_Frontal_Osteogenic_Front()
    FRONTAL_SUTURE_MESENCHYME = _Frontal_Suture_Mesenchyme()
    LAMBDOID_SUTURE_INTERPARIETAL_OSTEOGENIC_FRONT = _Lambdoid_Suture_Interparietal_Osteogenic_Front()
    LAMBDOID_SUTURE_MESENCHYME = _Lambdoid_Suture_Mesenchyme()
    LAMBDOID_SUTURE_PARIETAL_OSTEOGENIC_FRONT = _Lambdoid_Suture_Parietal_Osteogenic_Front()
    SAGITTAL_SUTURE_MESENCHYME = _Sagittal_Suture_Mesenchyme()
    SAGITTAL_SUTURE_PARIETAL_OSTEOGENIC_FRONT = _Sagittal_Suture_Parietal_Osteogenic_Front()
    SALIVARY_GLAND_PRIMORDIUM = _Salivary_Gland_Primordium()
    SALIVARY_GLAND_PRIMORDIUM_EPITHELIUM = _Salivary_Gland_Primordium_Epithelium()
    SALIVARY_GLAND_PRIMORDIUM_MESENCHYME = _Salivary_Gland_Primordium_Mesenchyme()
    HUMERUS_EPIPHYSIS = _Humerus_Epiphysis()
    MUSCLE_BLOOD_VESSEL = _Muscle_Blood_Vessel()
    SKIN_BLOOD_VESSEL = _Skin_Blood_Vessel()
    THYMUS_BLOOD_VESSEL = _Thymus_Blood_Vessel()
    BODY_OF_STOMACH_GASTRIC_GLAND = _Body_Of_Stomach_Gastric_Gland()
    GUBERNACULUM = _Gubernaculum()
    GUBERNACULUM_OF_FEMALE = _Gubernaculum_Of_Female()
    VON_EBNER_S_GLAND = _Von_Ebner_S_Gland()
    INTERFOLLICULAR_EPIDERMIS = _Interfollicular_Epidermis()
    DERMO_EPIDERMAL_JUNCTION = _Dermo_Epidermal_Junction()
    CRANIAL_SUTURE_MESENCHYME = _Cranial_Suture_Mesenchyme()
    CRANIAL_SUTURE_OSTEOGENIC_FRONT = _Cranial_Suture_Osteogenic_Front()
    CORONAL_SUTURE_OSTEOGENIC_FRONT = _Coronal_Suture_Osteogenic_Front()
    LAMBDOID_SUTURE_OSTEOGENIC_FRONT = _Lambdoid_Suture_Osteogenic_Front()
    EXOCOELOMIC_CAVITY_FLUID = _Exocoelomic_Cavity_Fluid()
    CORTICAL_ANTIHEM = _Cortical_Antihem()
    BASAL_CELL_LAYER_OF_PELVIC_URETHRA = _Basal_Cell_Layer_Of_Pelvic_Urethra()
    INTERMEDIATE_CELL_LAYER_OF_PELVIC_URETHRA = _Intermediate_Cell_Layer_Of_Pelvic_Urethra()
    SUPERFICIAL_CELL_LAYER_OF_PELVIC_URETHRA = _Superficial_Cell_Layer_Of_Pelvic_Urethra()
    SPINAL_NERVE_ROOT = _Spinal_Nerve_Root()
    PALEOCORTEX = _Paleocortex()

    ALL = tuple(_MouseAnatomicalStructureModel.__subclasses__())

    ONE_OF = Annotated[
        Union[tuple(_MouseAnatomicalStructureModel.__subclasses__())], Field(discriminator="registry_identifier")
    ]


MouseAnatomicalStructure.EMG_MUSCLES = Annotated[
    Union[
        _Deltoid,
        _Pectoralis_Major,
        _Triceps_Brachii,
        _Lateral_Head_Of_Triceps_Brachii,
        _Long_Head_Of_Triceps_Brachii,
        _Medial_Head_Of_Triceps_Brachii,
        _Biceps_Brachii,
        _Long_Head_Of_Biceps_Brachii,
        _Short_Head_Of_Biceps_Brachii,
        _Tendon_Of_Biceps_Brachii,
        _Pars_Scapularis_Of_Deltoid,
        _Extensor_Carpi_Radialis_Longus,
        _Extensor_Digitorum_Communis,
        _Extensor_Digitorum_Lateralis,
        _Extensor_Carpi_Ulnaris,
        _Flexor_Carpi_Radialis,
        _Flexor_Carpi_Ulnaris,
        _Flexor_Digitorum_Profundus,
    ],
    Field(discriminator="registry_identifier"),
]

MouseAnatomicalStructure.BODY_PARTS = Annotated[
    Union[
        _Forelimb,
        _Head,
        _Hindlimb,
        _Neck,
        _Tail,
        _Trunk,
    ],
    Field(discriminator="registry_identifier"),
]
